(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     31656,       1289]*)
(*NotebookOutlinePosition[     32495,       1316]*)
(*  CellTagsIndexPosition[     32451,       1312]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ShowCellBracket->False,
  ScriptMinSize->9],

Cell[StyleData[All, "AllBrackets"],
  PageWidth->WindowWidth,
  ShowCellBracket->True,
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ShowCellBracket->False,
  ScriptMinSize->5,
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}],

Cell[StyleData[All, "EnhancedPrintout"],
  PageWidth->PaperWidth,
  ShowCellBracket->False,
  ScriptMinSize->5,
  FontFamily->"Palatino",
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PrintingStyleEnvironment->"Printout",
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PrintingOptions->{"PrintingMargins"->{{97, 97}, {180, 64}},
  "FirstPageHeader"->False,
  "FacingPages"->True},
  CellLabelAutoDelete->False,
  CellFrameLabelMargins->6,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{12, Inherited}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->36,
  FontWeight->"Bold"],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{2, 10}, {15, 30}},
  FontSize->30],

Cell[StyleData["Title", "EnhancedPrintout"],
  CellMargins->{{2, 10}, {15, 30}},
  FontFamily->"Futura",
  FontSize->30]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{12, Inherited}, {10, 2}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->28],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{2, 10}, {10, 15}},
  FontSize->24],

Cell[StyleData["Subtitle", "EnhancedPrintout"],
  CellMargins->{{2, 10}, {10, 15}},
  FontFamily->"Futura",
  FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{12, Inherited}, {10, 20}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->12],

Cell[StyleData["Subsubtitle", "EnhancedPrintout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontFamily->"Futura",
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellFrame->{{0, 0}, {0.5, 0}},
  CellMargins->{{10, Inherited}, {8, 30}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameMargins->8,
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->20,
  FontWeight->"Bold"],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{2, 0}, {7, 24}},
  FontSize->16],

Cell[StyleData["Section", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {7, 24}},
  FontFamily->"Futura",
  FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{24, Inherited}, {8, 30}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold"],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{9, 0}, {7, 24}},
  FontSize->12],

Cell[StyleData["Subsection", "EnhancedPrintout"],
  CellMargins->{{9, 0}, {7, 24}},
  FontFamily->"Futura",
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellMargins->{{12, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  FontFamily->"Helvetica",
  FontWeight->"Bold"],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{2, 0}, {7, 18}},
  FontSize->10],

Cell[StyleData["Subsubsection", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {7, 18}},
  FontFamily->"Futura",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontSize->11],

Cell[StyleData["Text", "EnhancedPrintout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{12, 10}, {6, 6}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"SmallText",
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->1,
  FontSize->7],

Cell[StyleData["SmallText", "EnhancedPrintout"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  ShowCellBracket->True,
  CellMargins->{{45, 10}, {5, 7}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontWeight->"Bold"],

Cell[StyleData["Input", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9],

Cell[StyleData["Input", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  ShowCellBracket->True,
  CellMargins->{{46, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Output"],

Cell[StyleData["Output", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9],

Cell[StyleData["Output", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  ShowCellBracket->True,
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Message", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->9,
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->9,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  ShowCellBracket->True,
  CellMargins->{{75, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{57, Inherited}, {Inherited, Inherited}},
  FontSize->9],

Cell[StyleData["Print", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{57, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  ShowCellBracket->True,
  CellMargins->{{47, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontSize->9],

Cell[StyleData["Graphics", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontFamily->"Courier",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "EnhancedPrintout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inline Formatting", "Section"],

Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],

Cell[StyleData["RM"],
  StyleMenuListing->None,
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["BF"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["IT"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["TR"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["TI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["TB"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["TBI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["MR"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["MO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["MB"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["MBO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["SR"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["SO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SB"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["SBO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic"]
}, Closed]],

Cell[CellGroupData[{

Cell["Miscellaneous Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["MathCaption"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{46, 42}, {0, 14}},
  PageBreakBelow->False,
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 8},
  FontColor->RGBColor[0, 0, 0.6]],

Cell[StyleData["MathCaption", "Printout"],
  CellMargins->{{42, 42}, {0, 14}},
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["MathCaption", "EnhancedPrintout"],
  CellMargins->{{42, 42}, {0, 14}},
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Commentary"],
  CellFrame->{{2, 0}, {0, 0}},
  CellMargins->{{36, 10}, {7, 7}},
  PageBreakBelow->False,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0, 0.2, 1],
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  FontSlant->"Italic"],

Cell[StyleData["Commentary", "Printout"],
  CellMargins->{{32, 0}, {6, 6}},
  CellFrameColor->GrayLevel[0.8],
  FontSize->10],

Cell[StyleData["Commentary", "EnhancedPrintout"],
  CellMargins->{{32, 0}, {6, 6}},
  CellFrameColor->GrayLevel[0.8],
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedText"],
  CellMargins->{{20, 4}, {0, 4}},
  ShowSpecialCharacters->Automatic,
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-21,
  CounterIncrements->"Text"],

Cell[StyleData["ItemizedText", "Printout"],
  ParagraphIndent->-18,
  FontSize->10],

Cell[StyleData["ItemizedText", "EnhancedPrintout"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedTextNote"],
  CellMargins->{{41, 4}, {0, 4}},
  ShowSpecialCharacters->Automatic,
  ParagraphSpacing->{0, 4},
  CounterIncrements->"Text"],

Cell[StyleData["ItemizedTextNote", "Printout"],
  CellMargins->{{38, 4}, {0, 4}},
  FontSize->10],

Cell[StyleData["ItemizedTextNote", "EnhancedPrintout"],
  CellMargins->{{38, 4}, {0, 4}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndentedText"],
  CellMargins->{{20, 4}, {0, 6}},
  ShowSpecialCharacters->Automatic,
  ParagraphSpacing->{0, 8},
  CounterIncrements->"Text"],

Cell[StyleData["IndentedText", "Printout"],
  FontSize->10],

Cell[StyleData["IndentedText", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Emphasis Boxes and Pictures", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.3, 0.7},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[1]],

Cell[StyleData["DefinitionBox", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TopBox"],
  CellFrame->{{0.5, 0.5}, {0, 0.5}},
  CellMargins->{{11, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left}}],

Cell[StyleData["TopBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MiddleBox"],
  CellFrame->{{0.5, 0.5}, {0, 0}},
  CellMargins->{{11, 4}, {0, -7}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left}}],

Cell[StyleData["MiddleBox", "Printout"],
  CellMargins->{{2, 0}, {0, 0}},
  Background->GrayLevel[0.900008]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BottomBox"],
  CellFrame->{{0.5, 0.5}, {0.5, 0}},
  CellMargins->{{11, 4}, {0, -7}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left}}],

Cell[StyleData["BottomBox", "Printout"],
  CellMargins->{{2, 4}, {0, 0}},
  FontSize->10,
  Background->GrayLevel[1]],

Cell[StyleData["BottomBox", "Printout"],
  CellMargins->{{2, 4}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TopSpanBox"],
  CellFrame->{{0.5, 0.5}, {0, 0.5}},
  CellMargins->{{11, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.9, 0.03},
  ColumnAlignments->{Left}}],

Cell[StyleData["TopSpanBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[1]],

Cell[StyleData["TopSpanBox", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MiddleSpanBox"],
  CellFrame->{{0.5, 0.5}, {0, 0}},
  CellMargins->{{11, 4}, {0, 0}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.9, 0.03},
  ColumnAlignments->{Left}}],

Cell[StyleData["MiddleSpanBox", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[1]],

Cell[StyleData["MiddleSpanBox", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Picture"],
  CellMargins->{{12, Inherited}, {0, 8}},
  CellHorizontalScrolling->True],

Cell[StyleData["Picture", "Printout"],
  CellMargins->{{2, Inherited}, {0, 8}}],

Cell[StyleData["Picture", "EnhancedPrintout"],
  CellMargins->{{2, Inherited}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Caption"],
  CellMargins->{{12, 4}, {0, 2}},
  PageBreakAbove->False,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Caption", "Printout"],
  CellMargins->{{2, 4}, {2, 4}},
  FontSize->7],

Cell[StyleData["Caption", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {2, 4}},
  FontFamily->"Futura",
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section"],

Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{45, 10}, {7, 7}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{55, 55}, {0, 10}},
  FontSize->10],

Cell[StyleData["NumberedEquation", "EnhancedPrintout"],
  CellMargins->{{55, 55}, {0, 10}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{10, Inherited}, {7, 7}},
  CellHorizontalScrolling->True,
  TextAlignment->Center,
  ScriptLevel->0,
  SingleLetterItalics->True,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Printout"]],

Cell[StyleData["DisplayFormula", "EnhancedPrintout"],
  FontFamily->"Palatino"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayMath"],
  CellMargins->{{45, 10}, {7, 7}},
  Evaluatable->False,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input"],

Cell[StyleData["DisplayMath", "Printout"],
  CellMargins->{{39, 0}, {6, 6}},
  FontSize->9],

Cell[StyleData["DisplayMath", "EnhancedPrintout"],
  CellMargins->{{39, 0}, {4, 6}},
  FontFamily->"WRICourier",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellFrame->{{0, 0}, {0.5, 0.5}},
  CellMargins->{{12, Inherited}, {7, 7}},
  CellFrameMargins->{{0, 0}, {7, 5}},
  FontFamily->"Courier"],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontSize->9.5],

Cell[StyleData["Program", "EnhancedPrintout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontFamily->"WRICourier",
  FontSize->9.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Contents and Index", "Section"],

Cell[CellGroupData[{

Cell[StyleData["ContentsTitle"],
  CellMargins->{{10, 4}, {0, 18}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->26,
  FontWeight->"Bold"],

Cell[StyleData["ContentsTitle", "Printout"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontSize->18],

Cell[StyleData["ContentsTitle", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ContentsSection"],
  CellMargins->{{20, 4}, {3, 18}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["ContentsSection", "Printout"],
  CellMargins->{{12, 0}, {3, 18}},
  PageBreakBelow->False,
  FontSize->11],

Cell[StyleData["ContentsSection", "EnhancedPrintout"],
  CellMargins->{{12, 0}, {3, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Contents"],
  CellMargins->{{21, 4}, {0, 8}},
  StyleMenuListing->None],

Cell[StyleData["Contents", "Printout"],
  CellMargins->{{13, 0}, {0, 8}}],

Cell[StyleData["Contents", "EnhancedPrintout"],
  CellMargins->{{13, 0}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Index"],
  CellMargins->{{21, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["Index", "Printout"],
  CellMargins->{{13, 0}, {0, 0}},
  FontSize->10],

Cell[StyleData["Index", "EnhancedPrintout"],
  CellMargins->{{13, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndexSubentry"],
  CellMargins->{{36, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["IndexSubentry", "Printout"],
  CellMargins->{{24, 0}, {0, 0}},
  FontSize->10],

Cell[StyleData["IndexSubentry", "EnhancedPrintout"],
  CellMargins->{{24, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->8,
  FontWeight->"Bold"],

Cell[StyleData["Header", "Printout"]],

Cell[StyleData["Header", "EnhancedPrintout"],
  FontFamily->"Futura"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->7,
  FontSlant->"Plain"],

Cell[StyleData["Footer", "Printout"]],

Cell[StyleData["Footer", "EnhancedPrintout"],
  FontFamily->"Futura"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->8,
  FontWeight->"Bold"],

Cell[StyleData["PageNumber", "Printout"]],

Cell[StyleData["PageNumber", "EnhancedPrintout"],
  FontFamily->"Futura"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Hyperlink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnLink", "Printout"],
  FontFamily->"Courier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnLink", "EnhancedPrintout"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefGuideLink", "EnhancedPrintout"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["GettingStartedLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{484, 391},
WindowMargins->{{9, Automatic}, {Automatic, 0}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 37, 0, 62, "Subtitle"],
Cell[1771, 53, 193, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[1989, 61, 42, 0, 50, "Section"],
Cell[2034, 63, 103, 3, 36, 31, 0, "StyleData", "All", "Working"],
Cell[2140, 68, 106, 3, 36, 35, 0, "StyleData", "All", "AllBrackets"],
Cell[2249, 73, 166, 5, 34, 32, 0, "StyleData", "All", "Printout"],
Cell[2418, 80, 200, 6, 35, 40, 0, "StyleData", "All", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2655, 91, 35, 0, 30, "Section"],
Cell[2693, 93, 101, 3, 30, "Text"],
Cell[2797, 98, 610, 16, 36, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3444, 119, 38, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[3507, 123, 347, 9, 112, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}}],
Cell[3857, 134, 88, 2, 91, 36, 0, "StyleData", "Title", "Printout"],
Cell[3948, 138, 120, 3, 98, 44, 0, "StyleData", "Title", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4105, 146, 314, 8, 58, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[4422, 156, 91, 2, 70, 39, 0, "StyleData", "Subtitle", "Printout"],
Cell[4516, 160, 123, 3, 70, 47, 0, "StyleData", "Subtitle", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[4676, 168, 317, 8, 46, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[4996, 178, 93, 2, 70, 42, 0, "StyleData", "Subsubtitle", "Printout"],
Cell[5092, 182, 125, 3, 70, 50, 0, "StyleData", "Subsubtitle", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5254, 190, 358, 10, 56, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[5615, 202, 88, 2, 70, 38, 0, "StyleData", "Section", "Printout"],
Cell[5706, 206, 120, 3, 70, 46, 0, "StyleData", "Section", "EnhancedPrintout"]

}, Closed]],

Cell[CellGroupData[{
Cell[5863, 214, 323, 9, 44, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[6189, 225, 91, 2, 61, 41, 0, "StyleData", "Subsection", "Printout"],
Cell[6283, 229, 123, 3, 67, 49, 0, "StyleData", "Subsection", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6443, 237, 233, 6, 42, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[6679, 245, 94, 2, 70, 44, 0, "StyleData", "Subsubsection", "Printout"],
Cell[6776, 249, 126, 3, 70, 52, 0, "StyleData", "Subsubsection", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6951, 258, 39, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[7015, 262, 140, 4, 42, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[7158, 268, 108, 3, 39, 35, 0, "StyleData", "Text", "Printout"],
Cell[7269, 273, 142, 4, 40, 43, 0, "StyleData", "Text", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7448, 282, 165, 5, 36, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[7616, 289, 112, 3, 33, 40, 0, "StyleData", "SmallText", "Printout"],
Cell[7731, 294, 146, 4, 34, 48, 0, "StyleData", "SmallText", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7926, 304, 42, 0, 30, "Section"],
Cell[7971, 306, 248, 5, 62, "Text"],

Cell[CellGroupData[{
Cell[8244, 315, 492, 15, 42, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[8739, 332, 111, 3, 36, 36, 0, "StyleData", "Input", "Printout"],
Cell[8853, 337, 119, 3, 36, 44, 0, "StyleData", "Input", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9009, 345, 479, 14, 39, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[9491, 361, 112, 3, 36, 37, 0, "StyleData", "Output", "Printout"],
Cell[9606, 366, 120, 3, 36, 45, 0, "StyleData", "Output", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9763, 374, 549, 16, 38, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[10315, 392, 164, 4, 34, 38, 0, "StyleData", "Message", "Printout"],
Cell[10482, 398, 197, 5, 34, 46, 0, "StyleData", "Message", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[10716, 408, 523, 15, 36, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[11242, 425, 135, 3, 34, 36, 0, "StyleData", "Print", "Printout"],
Cell[11380, 430, 168, 4, 34, 44, 0, "StyleData", "Print", "EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11585, 439, 414, 12, 36, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[12002, 453, 163, 4, 34, 39, 0, "StyleData", "Graphics", "Printout"],
Cell[12168, 459, 196, 5, 34, 47, 0, "StyleData", "Graphics", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[12401, 469, 128, 4, 34, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[12532, 475, 130, 4, 32, 40, 0, "StyleData", "CellLabel", "Printout"],
Cell[12665, 481, 138, 4, 32, 48, 0, "StyleData", "CellLabel", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12852, 491, 36, 0, 30, "Section"],
Cell[12891, 493, 121, 3, 30, "Text"],
Cell[13015, 498, 92, 3, 36, 21, 0, "StyleData", "RM", "All",
  StyleMenuListing->None],
Cell[13110, 503, 69, 2, 38, 21, 0, "StyleData", "BF", "All",
  StyleMenuListing->None],
Cell[13182, 507, 70, 2, 38, 21, 0, "StyleData", "IT", "All",
  StyleMenuListing->None],
Cell[13255, 511, 115, 4, 36, 21, 0, "StyleData", "TR", "All",
  StyleMenuListing->None],
Cell[13373, 517, 116, 4, 38, 21, 0, "StyleData", "TI", "All",
  StyleMenuListing->None],
Cell[13492, 523, 114, 4, 38, 21, 0, "StyleData", "TB", "All",
  StyleMenuListing->None],
Cell[13609, 529, 116, 4, 38, 22, 0, "StyleData", "TBI", "All",
  StyleMenuListing->None],
Cell[13728, 535, 117, 4, 36, 21, 0, "StyleData", "MR", "All",
  StyleMenuListing->None],
Cell[13848, 541, 118, 4, 37, 21, 0, "StyleData", "MO", "All",
  StyleMenuListing->None],
Cell[13969, 547, 116, 4, 37, 21, 0, "StyleData", "MB", "All",
  StyleMenuListing->None],
Cell[14088, 553, 118, 4, 37, 22, 0, "StyleData", "MBO", "All",
  StyleMenuListing->None],
Cell[14209, 559, 119, 4, 37, 21, 0, "StyleData", "SR", "All",
  StyleMenuListing->None],
Cell[14331, 565, 120, 4, 38, 21, 0, "StyleData", "SO", "All",
  StyleMenuListing->None],
Cell[14454, 571, 118, 4, 38, 21, 0, "StyleData", "SB", "All",
  StyleMenuListing->None],
Cell[14575, 577, 120, 4, 38, 22, 0, "StyleData", "SBO", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[14732, 586, 39, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[14796, 590, 215, 6, 42, 30, 0, "StyleData", "MathCaption", "All"],
Cell[15014, 598, 121, 3, 41, 42, 0, "StyleData", "MathCaption", "Printout"],
Cell[15138, 603, 155, 4, 42, 50, 0, "StyleData", "MathCaption", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15330, 612, 256, 8, 41, 29, 0, "StyleData", "Commentary", "All"],
Cell[15589, 622, 125, 3, 38, 41, 0, "StyleData", "Commentary", "Printout"],
Cell[15717, 627, 159, 4, 40, 49, 0, "StyleData", "Commentary", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[15913, 636, 182, 5, 32, 31, 0, "StyleData", "ItemizedText", "All",
  CounterIncrements->"Text"],
Cell[16098, 643, 83, 2, 31, 43, 0, "StyleData", "ItemizedText", "Printout"],
Cell[16184, 647, 117, 3, 32, 51, 0, "StyleData", "ItemizedText", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16338, 655, 162, 4, 32, 35, 0, "StyleData", "ItemizedTextNote", "All",
  CounterIncrements->"Text"],
Cell[16503, 661, 97, 2, 31, 47, 0, "StyleData", "ItemizedTextNote", 
"Printout"],
Cell[16603, 665, 131, 3, 32, 55, 0, "StyleData", "ItemizedTextNote", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[16771, 673, 158, 4, 32, 31, 0, "StyleData", "IndentedText", "All",
  CounterIncrements->"Text"],
Cell[16932, 679, 59, 1, 33, 43, 0, "StyleData", "IndentedText", "Printout"],
Cell[16994, 682, 93, 2, 34, 51, 0, "StyleData", "IndentedText", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17136, 690, 46, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[17207, 694, 329, 11, 53, 32, 0, "StyleData", "DefinitionBox", "All"],
Cell[17539, 707, 121, 3, 52, 44, 0, "StyleData", "DefinitionBox", "Printout"],

Cell[17663, 712, 155, 4, 53, 52, 0, "StyleData", "DefinitionBox", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[17855, 721, 394, 13, 48, 25, 0, "StyleData", "TopBox", "All",
  StyleMenuListing->None],
Cell[18252, 736, 105, 2, 52, 37, 0, "StyleData", "TopBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18394, 743, 396, 13, 48, 28, 0, "StyleData", "MiddleBox", "All",
  StyleMenuListing->None],
Cell[18793, 758, 108, 2, 44, 40, 0, "StyleData", "MiddleBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[18938, 765, 398, 13, 48, 28, 0, "StyleData", "BottomBox", "All",
  StyleMenuListing->None],
Cell[19339, 780, 117, 3, 35, 40, 0, "StyleData", "BottomBox", "Printout"],
Cell[19459, 785, 143, 4, 36, 40, 0, "StyleData", "BottomBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[19639, 794, 397, 13, 48, 29, 0, "StyleData", "TopSpanBox", "All",
  StyleMenuListing->None],
Cell[20039, 809, 118, 3, 43, 41, 0, "StyleData", "TopSpanBox", "Printout"],
Cell[20160, 814, 152, 4, 44, 49, 0, "StyleData", "TopSpanBox", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[20349, 823, 398, 13, 48, 32, 0, "StyleData", "MiddleSpanBox", "All",
  StyleMenuListing->None],
Cell[20750, 838, 121, 3, 35, 44, 0, "StyleData", "MiddleSpanBox", "Printout"],

Cell[20874, 843, 155, 4, 36, 52, 0, "StyleData", "MiddleSpanBox", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[21066, 852, 101, 2, 32, 26, 0, "StyleData", "Picture", "All"],
Cell[21170, 856, 79, 1, 36, 38, 0, "StyleData", "Picture", "Printout"],
Cell[21252, 859, 87, 1, 36, 46, 0, "StyleData", "Picture", "EnhancedPrintout"]

}, Closed]],

Cell[CellGroupData[{
Cell[21376, 865, 127, 4, 30, 26, 0, "StyleData", "Caption", "All"],
Cell[21506, 871, 86, 2, 29, 38, 0, "StyleData", "Caption", "Printout"],
Cell[21595, 875, 118, 3, 32, 46, 0, "StyleData", "Caption", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[21762, 884, 49, 0, 30, "Section"],
Cell[21814, 886, 225, 4, 62, "Text"],

Cell[CellGroupData[{
Cell[22064, 894, 318, 7, 42, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[22385, 903, 99, 2, 70, 47, 0, "StyleData", "NumberedEquation", 
"Printout"],
Cell[22487, 907, 133, 3, 70, 55, 0, "StyleData", "NumberedEquation", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22669, 916, 43, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[22737, 920, 236, 6, 42, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[22976, 928, 45, 0, 70, 45, 0, "StyleData", "DisplayFormula", "Printout"],

Cell[23024, 930, 79, 1, 70, 53, 0, "StyleData", "DisplayFormula", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23140, 936, 389, 12, 39, 30, 0, "StyleData", "DisplayMath", "All",
  CounterIncrements->"Input"],
Cell[23532, 950, 91, 2, 70, 42, 0, "StyleData", "DisplayMath", "Printout"],
Cell[23626, 954, 127, 3, 70, 50, 0, "StyleData", "DisplayMath", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[23790, 962, 166, 4, 52, 26, 0, "StyleData", "Program", "All"],
Cell[23959, 968, 98, 2, 51, 38, 0, "StyleData", "Program", "Printout"],
Cell[24060, 972, 134, 3, 52, 46, 0, "StyleData", "Program", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24243, 981, 37, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[24305, 985, 158, 5, 60, 32, 0, "StyleData", "ContentsTitle", "All",
  StyleMenuListing->None],
Cell[24466, 992, 119, 3, 70, 44, 0, "StyleData", "ContentsTitle", "Printout"],

Cell[24588, 997, 151, 4, 70, 52, 0, "StyleData", "ContentsTitle", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24776, 1006, 160, 5, 37, 34, 0, "StyleData", "ContentsSection", "All",
  StyleMenuListing->None],
Cell[24939, 1013, 122, 3, 48, 46, 0, "StyleData", "ContentsSection", 
"Printout"],
Cell[25064, 1018, 154, 4, 53, 54, 0, "StyleData", "ContentsSection", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25255, 1027, 87, 2, 32, 27, 0, "StyleData", "Contents", "All",
  StyleMenuListing->None],
Cell[25345, 1031, 73, 1, 70, 39, 0, "StyleData", "Contents", "Printout"],
Cell[25421, 1034, 123, 3, 70, 47, 0, "StyleData", "Contents", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25581, 1042, 108, 3, 32, 24, 0, "StyleData", "Index", "All",
  StyleMenuListing->None],
Cell[25692, 1047, 86, 2, 70, 36, 0, "StyleData", "Index", "Printout"],
Cell[25781, 1051, 120, 3, 70, 44, 0, "StyleData", "Index", "EnhancedPrintout"]

}, Closed]],

Cell[CellGroupData[{
Cell[25938, 1059, 116, 3, 32, 32, 0, "StyleData", "IndexSubentry", "All",
  StyleMenuListing->None],
Cell[26057, 1064, 94, 2, 70, 44, 0, "StyleData", "IndexSubentry", "Printout"],

Cell[26154, 1068, 128, 3, 70, 52, 0, "StyleData", "IndexSubentry", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[26331, 1077, 49, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[26405, 1081, 148, 5, 29, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[26556, 1088, 37, 0, 29, 37, 0, "StyleData", "Header", "Printout"],
Cell[26596, 1090, 69, 1, 29, 45, 0, "StyleData", "Header", "EnhancedPrintout"]

}, Closed]],

Cell[CellGroupData[{
Cell[26702, 1096, 148, 5, 27, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[26853, 1103, 37, 0, 27, 37, 0, "StyleData", "Footer", "Printout"],
Cell[26893, 1105, 69, 1, 27, 45, 0, "StyleData", "Footer", "EnhancedPrintout"]

}, Closed]],

Cell[CellGroupData[{
Cell[26999, 1111, 152, 5, 32, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None],
Cell[27154, 1118, 41, 0, 29, 41, 0, "StyleData", "PageNumber", "Printout"],
Cell[27198, 1120, 73, 1, 29, 49, 0, "StyleData", "PageNumber", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27320, 1127, 35, 0, 30, "Section"],
Cell[27358, 1129, 184, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[27567, 1137, 302, 8, 70, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[27872, 1147, 123, 3, 70, 40, 0, "StyleData", "Hyperlink", "Printout"],
Cell[27998, 1152, 157, 4, 70, 48, 0, "StyleData", "Hyperlink", 
"EnhancedPrintout"]
}, Closed]],
Cell[28170, 1159, 104, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[28299, 1166, 316, 8, 70, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[28618, 1176, 126, 3, 70, 43, 0, "StyleData", "MainBookLink", "Printout"],

Cell[28747, 1181, 160, 4, 70, 51, 0, "StyleData", "MainBookLink", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28944, 1190, 337, 9, 70, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[29284, 1201, 148, 4, 70, 40, 0, "StyleData", "AddOnLink", "Printout"],
Cell[29435, 1207, 159, 4, 70, 48, 0, "StyleData", "AddOnLink", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29631, 1216, 345, 9, 70, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[29979, 1227, 126, 3, 70, 43, 0, "StyleData", "RefGuideLink", "Printout"],

Cell[30108, 1232, 162, 4, 70, 51, 0, "StyleData", "RefGuideLink", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30307, 1241, 328, 8, 70, 37, 0, "StyleData", "GettingStartedLink", 
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[30638, 1251, 132, 3, 70, 49, 0, "StyleData", "GettingStartedLink", 
"Printout"],
Cell[30773, 1256, 166, 4, 70, 57, 0, "StyleData", "GettingStartedLink", 
"EnhancedPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30976, 1265, 332, 8, 70, 39, 0, "StyleData", "OtherInformationLink", 
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[31311, 1275, 134, 3, 70, 51, 0, "StyleData", "OtherInformationLink", 
"Printout"],
Cell[31448, 1280, 168, 4, 70, 59, 0, "StyleData", "OtherInformationLink", 
"EnhancedPrintout"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

