(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    298310,       9996]*)
(*NotebookOutlinePosition[    305634,      10256]*)
(*  CellTagsIndexPosition[    304030,      10193]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Bonds", "Section",
  CellTags->"0.1"],

Cell["\<\
Now we will compute bond values and several bond risk measures. \
This version of the package supports \"Actual/Actual\" and \"30/360\" \
calendar computations. \
\>", "Text",
  CellTags->"0.2"],

Cell[TextData[{
  "This loads the ",
  StyleBox["Bonds", "MB"],
  " subpackage. "
}], "MathCaption",
  CellTags->"0.3"],

Cell["<< Finance`Bonds`", "Input",
  CellLabel->"In[1]:="],

Cell["Here are the basic bond package functions. ", "MathCaption",
  CellTags->"0.4"],

Cell[CellGroupData[{

Cell["?Finance`Bonds`*", "Input",
  CellLabel->"In[2]:="],

Cell["\<\
AccruedInterest        DirtyPrice
Bond                   FlatPrice
CashFlowsDates         FullPayment
CleanPrice             NumberOfCouponPayments
CouponPaymentDate      Payment\
\>", "Print"]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Bond",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[
                FormBox[
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    RowBox[{"coupon", 
                      StyleBox[",",
                        "MR"], " ", "maturity", 
                      StyleBox[",",
                        "MR"], " ", "par", 
                      StyleBox[",",
                        "MR"], " ", "frequency"}], 
                    StyleBox["}",
                      "MR"]}],
                  "TraditionalForm"],
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            StyleBox[\(an\ object\ representing\ a\ bond\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True],

Cell["Bond object. ", "Caption"],

Cell["\<\
A bond is a finance object. Note that its parameters must be specified in the \
right order. \
\>", "MathCaption",
  CellTags->"0.6"],

Cell[CellGroupData[{

Cell["?Bond", "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \("Bond[{coupon, maturity, par, frequency}] is an object representing a \
bond."\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "The object ",
  StyleBox["bond3", "MB"],
  " is a 10% bond that pays semiannual interest and matures on September 15, \
1996. The redemption (or par) value is $1,000. "
}], "MathCaption",
  CellTags->"0.7"],

Cell[CellGroupData[{

Cell["\<\
bond3 =
   Bond[{10 Percent, {9, 15, 1996} , 1000 USDollar, 2}]\
\>", "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(Bond[{1\/10, {9, 15, 1996}, 1000\ USDollar, 2}]\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "The object ",
  StyleBox["bond10", "MB"],
  " is a 10% bond that pays semiannual interest and matures on September 15, \
2003. The redemption value is $1,000. "
}], "MathCaption",
  CellTags->"0.8"],

Cell[CellGroupData[{

Cell["\<\
bond10 =
   Bond[{10 Percent, {9, 15, 2003} , 1000 USDollar, 2}]\
\>", "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(Bond[{1\/10, {9, 15, 2003}, 1000\ USDollar, 2}]\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  "The object ",
  StyleBox["bond30", "MB"],
  " is a 10% bond that pays semiannual interest and matures on September 15, \
2023. The redemption value is $1,000. "
}], "MathCaption",
  CellTags->"0.9"],

Cell[CellGroupData[{

Cell["\<\
bond30 =
   Bond[{10 Percent, {9, 15, 2023}, 1000 USDollar, 2}]\
\>", "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(Bond[{1\/10, {9, 15, 2023}, 1000\ USDollar, 2}]\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Payment",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["bond",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["settlement",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["ytm",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(return\ the\ payment\ of\ the\ bond\ for\ the\ given\ 
                settlement\ date\ and\ yield\ to\ maturity\ \(ytm . \)\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[GridBox[{
                    {
                      RowBox[{
                        StyleBox["AccruedInterest",
                          FontFamily->"Courier"], 
                        StyleBox["[",
                          "MR",
                          FontFamily->"Courier"], 
                        RowBox[{
                          StyleBox["bond",
                            FontSlant->"Italic"], 
                          StyleBox[",",
                            "MR",
                            FontSlant->"Italic"], 
                          StyleBox[" ",
                            FontSlant->"Italic"], 
                          StyleBox["settlement",
                            FontSlant->"Italic"]}], 
                        StyleBox["]",
                          "MR",
                          FontFamily->"Courier"]}], " "}
                    }],
                "TextForm"],
              "Text"]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(return\ the\ accrued\ interest\ of\ the\ bond\ for\ the\ given
                \ settlement\ date\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Value",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["bond",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["settlement",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["ytm",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(return\ the\ value\ of\ the\ bond\ 
                \((payment\ plus\ accrued\ interest)\)\ for\ the\ given\ 
                settlement\ date\ and\ yield\ to\ maturity\ ytm\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True],

Cell["Basic bond functions. ", "Caption"],

Cell["We take the settlement day to be September 15, 1993. ", "MathCaption",
  CellTags->"0.11"],

Cell["settlement1 = {9, 15, 1993};", "Input",
  CellLabel->"In[7]:="],

Cell[TextData[{
  "Here is the payment of ",
  StyleBox["bond10", "MB"],
  " on September 15, 1993 and on June 15, 1996 assuming that the required \
yield to maturity is 15%. "
}], "MathCaption",
  CellTags->"0.12"],

Cell[CellGroupData[{

Cell["Payment[bond10, settlement1, .15]", "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(745.137716020201867`\ USDollar\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell["\<\
Our results are approximate because we are using \
floating\[Hyphen]point numbers for some of the arguments. \
\>", "MathCaption",\

  CellTags->"0.13"],

Cell[CellGroupData[{

Cell["Payment[bond10, {7, 15, 1996}, .15]", "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(784.450150239046628`\ USDollar\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell["If we don't use any decimals, we get an exact result. ", "MathCaption",
  CellTags->"0.14"],

Cell[CellGroupData[{

Cell["Payment[bond10, {7, 15, 1996}, 15 Percent]", "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(\(-\(\(1525\ USDollar\)\/46\)\) + 
      \(123798042593265188730476900\ \((5\/43)\)\^\(31/92\)\ 2\^\(1/92\)\ 
          USDollar\)\/73885357344138503765449\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["Of course, the numerical values are the same. ", "MathCaption",
  CellTags->"0.15"],

Cell[CellGroupData[{

Cell["N[%]", "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(784.450150239043786`\ USDollar\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["\<\
This computes the bond payment of a 9% coupon bond paying \
semiannually with 20 years to maturity and a par value of $1,000 if the \
required yield is 12%. \
\>", "MathCaption",
  CellTags->"0.16"],

Cell[CellGroupData[{

Cell["\<\
Payment[Bond[{.09, {9, 15, 2013}, 1000 USDollar, 2}],
   settlement1, .12]\
\>", "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(774.305546927124765`\ USDollar\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[{
  "We define the payment of a 30\[Hyphen]year U.S. Treasury bond paying \
semiannually as a function of the coupon rate ",
  StyleBox["c", "MB"],
  " and the yield to maturity ",
  StyleBox["y", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.17"],

Cell["\<\
p[c_, y_] = Payment[Bond[{c, {9, 15, 2023}, 100, 2}],
   settlement1, y];\
\>", "Input",
  CellLabel->"In[13]:="],

Cell["\<\
We will use the same label several times in the following examples. \
\
\>", "MathCaption",
  CellTags->"0.18"],

Cell["label1 = {\"Yield to maturity\", \"Bond payment\"};", "Input",
  CellLabel->"In[14]:="],

Cell["\<\
This graph represents the payment\[Hyphen]yield relationship for \
the bond with a 10% coupon rate. \
\>", "MathCaption",
  CellTags->"0.19"],

Cell[CellGroupData[{

Cell["Plot[p[.10, y], {y, 0, .20}, FrameLabel -> label1];", "Input",
  CellLabel->"In[15]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.76191 -0.0696869 0.00168251 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -12 -9 ]
[.2619 -0.0125 12 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -53 -21.5625 ]
[.5 -0.0125 53 -9 ]
[-0.0125 .01444 -12 -4.5 ]
[-0.0125 .01444 0 4.5 ]
[-0.0125 .09856 -18 -4.5 ]
[-0.0125 .09856 0 4.5 ]
[-0.0125 .18269 -18 -4.5 ]
[-0.0125 .18269 0 4.5 ]
[-0.0125 .26682 -18 -4.5 ]
[-0.0125 .26682 0 4.5 ]
[-0.0125 .35094 -18 -4.5 ]
[-0.0125 .35094 0 4.5 ]
[-0.0125 .43507 -18 -4.5 ]
[-0.0125 .43507 0 4.5 ]
[-0.0125 .51919 -18 -4.5 ]
[-0.0125 .51919 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -38 ]
[-0.01875 .30902 -18 38 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -114 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Yield) show
99.000000 12.812500 moveto
(to) show
117.000000 12.812500 moveto
(maturity) show
165.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .01444 m
.00625 .01444 L
s
[(50)] -0.0125 .01444 1 0 Mshowa
0 .09856 m
.00625 .09856 L
s
[(100)] -0.0125 .09856 1 0 Mshowa
0 .18269 m
.00625 .18269 L
s
[(150)] -0.0125 .18269 1 0 Mshowa
0 .26682 m
.00625 .26682 L
s
[(200)] -0.0125 .26682 1 0 Mshowa
0 .35094 m
.00625 .35094 L
s
[(250)] -0.0125 .35094 1 0 Mshowa
0 .43507 m
.00625 .43507 L
s
[(300)] -0.0125 .43507 1 0 Mshowa
0 .51919 m
.00625 .51919 L
s
[(350)] -0.0125 .51919 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(400)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03126 m
.00375 .03126 L
s
0 .04809 m
.00375 .04809 L
s
0 .06491 m
.00375 .06491 L
s
0 .08174 m
.00375 .08174 L
s
0 .11539 m
.00375 .11539 L
s
0 .13221 m
.00375 .13221 L
s
0 .14904 m
.00375 .14904 L
s
0 .16587 m
.00375 .16587 L
s
0 .19952 m
.00375 .19952 L
s
0 .21634 m
.00375 .21634 L
s
0 .23317 m
.00375 .23317 L
s
0 .24999 m
.00375 .24999 L
s
0 .28364 m
.00375 .28364 L
s
0 .30047 m
.00375 .30047 L
s
0 .31729 m
.00375 .31729 L
s
0 .33412 m
.00375 .33412 L
s
0 .36777 m
.00375 .36777 L
s
0 .38459 m
.00375 .38459 L
s
0 .40142 m
.00375 .40142 L
s
0 .41824 m
.00375 .41824 L
s
0 .45189 m
.00375 .45189 L
s
0 .46872 m
.00375 .46872 L
s
0 .48554 m
.00375 .48554 L
s
0 .50237 m
.00375 .50237 L
s
0 .53602 m
.00375 .53602 L
s
0 .55284 m
.00375 .55284 L
s
0 .56967 m
.00375 .56967 L
s
0 .58649 m
.00375 .58649 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -123.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
99 10.2813 translate
90 rotate
-99 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bond) show
93.000000 12.812500 moveto
(payment) show
135.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01444 m
1 .01444 L
s
.99375 .09856 m
1 .09856 L
s
.99375 .18269 m
1 .18269 L
s
.99375 .26682 m
1 .26682 L
s
.99375 .35094 m
1 .35094 L
s
.99375 .43507 m
1 .43507 L
s
.99375 .51919 m
1 .51919 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03126 m
1 .03126 L
s
.99625 .04809 m
1 .04809 L
s
.99625 .06491 m
1 .06491 L
s
.99625 .08174 m
1 .08174 L
s
.99625 .11539 m
1 .11539 L
s
.99625 .13221 m
1 .13221 L
s
.99625 .14904 m
1 .14904 L
s
.99625 .16587 m
1 .16587 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .21634 m
1 .21634 L
s
.99625 .23317 m
1 .23317 L
s
.99625 .24999 m
1 .24999 L
s
.99625 .28364 m
1 .28364 L
s
.99625 .30047 m
1 .30047 L
s
.99625 .31729 m
1 .31729 L
s
.99625 .33412 m
1 .33412 L
s
.99625 .36777 m
1 .36777 L
s
.99625 .38459 m
1 .38459 L
s
.99625 .40142 m
1 .40142 L
s
.99625 .41824 m
1 .41824 L
s
.99625 .45189 m
1 .45189 L
s
.99625 .46872 m
1 .46872 L
s
.99625 .48554 m
1 .48554 L
s
.99625 .50237 m
1 .50237 L
s
.99625 .53602 m
1 .53602 L
s
.99625 .55284 m
1 .55284 L
s
.99625 .56967 m
1 .56967 L
s
.99625 .58649 m
1 .58649 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .60332 m
.06244 .5095 L
.10458 .426 L
.14415 .36187 L
.18221 .31066 L
.22272 .26525 L
.26171 .22874 L
.30316 .1962 L
.34309 .16982 L
.3815 .1482 L
.42237 .12854 L
.46172 .11228 L
.49955 .09871 L
.53984 .08612 L
.57861 .07552 L
.61984 .06562 L
.65954 .05721 L
.69774 .05001 L
.73838 .04317 L
.77751 .03726 L
.81909 .03161 L
.85916 .02669 L
.89771 .02239 L
.93871 .01821 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{295.563, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40O003h00Oogoo:7oo003oOolX
Ool00?moobQoo`00bWoo0P00Fgoo003;Ool00`00Oomoo`1IOol0075oo`<0009oo`<000=oo`80009o
o`<000=oo`<000eoo`8000=oo`8000Uoo`06001oo`00Ool007oo10000Woo0P000goo0`0000Aoo`00
0000009oo`<000=oo`8000=oo`03001oogoo05Uoo`00LWoo00<007ooOol00Woo00D007ooOomoo`00
00Eoo`05001oogooOol00002Ool00`00Oomoo`0:Ool01P00Oomoo`00Ool0009oo`03001oogoo00Io
o`06001oo`00Ool007oo0`000Woo00H007ooOol007oo0002Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`05001oo`00Ool0001JOol0079oo`03001oogoo009oo`04001oogooOol30003Ool01@00
Oomoogoo00000Woo00<007ooOol02Woo00<007ooOol00Woo00@007ooOol000Qoo`05001oo`00Ool0
0003Ool01000Oomoo`0017oo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Ool0001JOol0075oo`03001oo`00009oo`8000=oo`<000=oo`03001oogoo009oo`<000]oo`@0
00=oo`8000Uoo`800003Ool007oo009oo`800003Ool0000000800004Ool00000Ool200000goo0000
000200000goo00000002Ool4000017oo000007oo0P00FGoo001`Ool01@00Oomoogoo000037oo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol06Goo00<007ooOol04Goo00<007ooOol0Ggoo001`
Ool200000goo00000002Ool00`00Oomoo`06Ool20005Ool2000hOol00`00Oomoo`1SOol00?moobQo
o`00ogoo:7oo000ZOol00`00Oomoo`0bOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`05000]Ool00`00Oomoo`02Ool00`00Oomo
o`050002Ool00`00Oomoo`0]Ool00`00Oomoo`02Ool01000Oomoogoo0`001Goo000YOol00`00Ool0
000bOol00`00Ool00007Ool00`00Ool00002Ool00`00Ool0000/Ool00`00Ool00008Ool00`00Oomo
o`0/Ool00`00Ool00008Ool01`00Oomoogoo001oo`0002eoo`03001oo`0000Moo`03001oogoo00Eo
o`00:Goo00<007oo0000<Woo00<007oo00001goo00<007oo000017oo00<007ooOol0:Woo00<007oo
000027oo00<007ooOol0;7oo00<007oo000027oo00<007ooOol00goo00<007ooOol0:goo00<007oo
000027oo00<007ooOol017oo000YOol00`00Ool0000bOol00`00Ool00007Ool00`00Ool00002Ool2
000]Ool00`00Ool00008Ool00`00Oomoo`0/Ool00`00Ool00008Ool01000Oomoogoo0P00;Woo00<0
07oo000027oo00<007ooOol017oo000YOol00`00Ool0000bOol00`00Ool00007Ool00`00Ool00002
Ool00`00Oomoo`0/Ool00`00Ool00008Ool00`00Oomoo`0/Ool00`00Ool00008Ool01@00Oomoogoo
0000;goo00<007oo00001goo00<007oo00001Goo000ZOol00`00Oomoo`0bOol00`00Oomoo`07Ool0
1000Oomoogoo0`00;Goo00<007ooOol01Woo0P00;goo00<007ooOol01Woo0P000goo0`00;Woo00<0
07ooOol01goo00<007ooOol017oo003oOolXOol00?moobQoo`00ogoo:7oo003oOolXOol00?moobQo
o`00ogoo:7oo000UOoom0005Ool001Uoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00=o
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00=oo`03001oogoo00=oo`0067oo00<007oo00000Woo00<007oo00001Goo00<007oo
Ool0nGoo00<007ooOol00goo000JOol01P00Oomoo`00Ool000Eoo`800?1oo`D000Aoo`8000Eoo`00
67oo0P000goo00<007oo00001Goo00<007ooOol0iGoo2P002Woo00<007ooOol00goo000HOol00`00
Oomoo`02Ool00`00Ool00005Ool00`00Oomoo`3KOol:000DOol00`00Oomoo`03Ool001Qoo`<000=o
o`03001oogoo00Aoo`03001oogoo0=Aoo`L001ioo`03001oogoo00=oo`009Goo0P00d7oo1@0097oo
0P001Goo000UOol00`00Oomoo`37Ool8000ZOol00`00Oomoo`03Ool002Eoo`03001oogoo0;eoo`X0
039oo`03001oogoo00=oo`009Goo00<007ooOol0]Goo2000?7oo00<007ooOol00goo000UOol00`00
Oomoo`2`Ool50014Ool00`00Oomoo`03Ool002Eoo`800:aoo`D004Qoo`8000Eoo`009Goo00<007oo
Ool0YWoo1@00CWoo00<007ooOol00goo000UOol00`00Oomoo`2QOol5001COol00`00Oomoo`03Ool0
02Eoo`03001oogoo09aoo`D005Qoo`03001oogoo00=oo`009Goo0P00VGoo1000G7oo0P001Goo000U
Ool00`00Oomoo`2EOol3001QOol00`00Oomoo`03Ool002Eoo`03001oogoo095oo`@006Aoo`03001o
ogoo00=oo`009Goo00<007ooOol0SGoo1000J7oo00<007ooOol00goo000UOol20029Ool5001[Ool2
0005Ool002Eoo`03001oogoo08Aoo`@0075oo`03001oogoo00=oo`004Woo1@000Woo00<007ooOol0
0Woo00<007ooOol017oo00<007ooOol0PWoo0P00MGoo00<007ooOol00goo000DOol01`00Oomoogoo
001oo`00009oo`03001oo`0000Eoo`03001oogoo07moo`<007Moo`03001oogoo00=oo`0057oo00L0
07ooOomoo`00Ool00002Ool00`00Ool00005Ool2001nOol2001iOol20005Ool001Aoo`07001oogoo
Ool007oo00000Woo00<007oo00001Goo00<007ooOol0NWoo0`00O7oo00<007ooOol00goo000DOol0
1`00Oomoogoo001oo`00009oo`03001oo`0000Eoo`03001oogoo07Moo`<007moo`03001oogoo00=o
o`004goo0P0017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0Lgoo1000PWoo00<007oo
Ool00goo000UOol00`00Oomoo`1`Ool30026Ool00`00Oomoo`03Ool002Eoo`8006moo`8008Qoo`80
00Eoo`009Goo00<007ooOol0Jgoo0`00Rgoo00<007ooOol00goo000UOol00`00Oomoo`1YOol2002>
Ool00`00Oomoo`03Ool002Eoo`03001oogoo06Moo`80091oo`03001oogoo00=oo`009Goo0P00IWoo
0P00TGoo0P001Goo000UOol00`00Oomoo`1SOol2002DOol00`00Oomoo`03Ool002Eoo`03001oogoo
065oo`8009Ioo`03001oogoo00=oo`009Goo00<007ooOol0Ggoo0P00V7oo00<007ooOol00goo000U
Ool2001NOol2002IOol20005Ool002Eoo`03001oogoo05]oo`8009aoo`03001oogoo00=oo`009Goo
00<007ooOol0FGoo0P00WWoo00<007ooOol00goo000UOol00`00Oomoo`1GOol2002POol00`00Oomo
o`03Ool002Eoo`8005Ioo`800:5oo`8000Eoo`009Goo00<007ooOol0Dgoo0P00Y7oo00<007ooOol0
0goo0004Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`1AOol2002VOol00`00Oomoo`03
Ool000Aoo`H000Qoo`D0009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo051oo`03001o
ogoo0:Ioo`03001oogoo00=oo`0017oo00<007oo00000Woo00<007ooOol027oo00L007ooOomoo`00
Ool00002Ool00`00Ool00005Ool00`00Oomoo`1?Ool00`00Oomoo`2WOol00`00Oomoo`03Ool000Ao
o`03001oo`00009oo`03001oogoo00Qoo`03001oogoo00=oo`06001oogoo001oo`001Goo0P00CWoo
0P00ZGoo0P001Goo0005Ool01000Ool000002goo00@007ooOomoo`8000=oo`03001oo`0000Eoo`03
001oogoo04aoo`03001oogoo0:Yoo`03001oogoo00=oo`0057oo00D007ooOomoo`0000Aoo`03001o
o`0000Eoo`03001oogoo04Yoo`800:eoo`03001oogoo00=oo`004goo0P000goo0`000goo00<007oo
Ool017oo00<007ooOol0BGoo00<007ooOol0[Goo00<007ooOol00goo0007Ool2000LOol20019Ool0
0`00Oomoo`2]Ool20005Ool000Ioo`04001oogoo000KOol00`00Oomoo`16Ool2002aOol00`00Oomo
o`03Ool000Ioo`04001oogoo000KOol00`00Oomoo`15Ool00`00Oomoo`2aOol00`00Oomoo`03Ool0
00Moo`8001aoo`03001oogoo04Aoo`03001oogoo0;9oo`03001oogoo00=oo`009Goo0P00A7oo00<0
07ooOol0/Woo0P001Goo0006Ool01000Oomoo`006goo00<007ooOol0@Goo0P00]Woo00<007ooOol0
0goo0006Ool4000KOol00`00Oomoo`10Ool00`00Oomoo`2fOol00`00Oomoo`03Ool000Ioo`03001o
ogoo01aoo`03001oogoo03moo`03001oogoo0;Moo`03001oogoo00=oo`001Woo00<007ooOol077oo
0P00?goo00<007ooOol0]goo0P001Goo0007Ool3000KOol00`00Oomoo`0mOol00`00Oomoo`2iOol0
0`00Oomoo`03Ool000Uoo`03001oogoo01Uoo`03001oogoo03aoo`03001oogoo0;Yoo`03001oogoo
00=oo`009Goo00<007ooOol0>goo00<007ooOol0^goo00<007ooOol00goo0007Ool2000LOol00`00
Oomoo`0jOol00`00Oomoo`2lOol00`00Oomoo`03Ool000Ioo`04001oogoo000KOol2000jOol00`00
Oomoo`2lOol20005Ool000Aoo`03001oo`00009oo`03001oogoo01Uoo`03001oogoo03Qoo`03001o
ogoo0;ioo`03001oogoo00=oo`0017oo1P002Goo0`000goo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol0=goo00<007ooOol0_goo00<007ooOol00goo0009Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool00`00Ool00002Ool00`00Ool00005Ool00`00Oomoo`0fOol00`00Oomoo`30Ool00`00Oomo
o`03Ool001Aoo`07001oogooOol007oo00000Woo00<007oo00001Goo0P00=Woo00<007ooOol0`7oo
0P001Goo000DOol01`00Oomoogoo001oo`00009oo`03001oo`0000Eoo`03001oogoo03Aoo`03001o
ogoo0<9oo`03001oogoo00=oo`004goo00<007oo00000Woo00<007oo00000Woo00<007oo00001Goo
00<007ooOol0<goo00<007ooOol0`goo00<007ooOol00goo000DOol00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Oomoo`0bOol00`00Oomoo`34Ool00`00Oomoo`03Ool002Eoo`80
039oo`03001oogoo0<Aoo`8000Eoo`009Goo00<007ooOol0<7oo00<007ooOol0aWoo00<007ooOol0
0goo0006Ool00`00Oomoo`02Ool00`00Oomoo`0GOol00`00Oomoo`0`Ool00`00Oomoo`36Ool00`00
Oomoo`03Ool000Ioo`H001Uoo`03001oogoo02moo`03001oogoo0<Moo`03001oogoo00=oo`001Woo
00H007ooOol007oo000IOol2000_Ool00`00Oomoo`37Ool20005Ool000Ioo`04001oogoo000KOol0
0`00Oomoo`0]Ool00`00Oomoo`39Ool00`00Oomoo`03Ool000Moo`8001aoo`03001oogoo02aoo`03
001oogoo0<Yoo`03001oogoo00=oo`009Goo00<007ooOol0:goo00<007ooOol0bgoo00<007ooOol0
0goo000UOol00`00Oomoo`0ZOol00`00Oomoo`3<Ool00`00Oomoo`03Ool000Qoo`8001]oo`8002Yo
o`03001oogoo0<aoo`8000Eoo`001Woo00@007oo000001]oo`03001oogoo02Uoo`03001oogoo0<eo
o`03001oogoo00=oo`001Woo00@007oo000001]oo`03001oogoo02Qoo`03001oogoo0<ioo`03001o
ogoo00=oo`001Woo10006goo00<007ooOol09goo00<007ooOol0cgoo00<007ooOol00goo0009Ool0
0`00Oomoo`0IOol2000WOol00`00Oomoo`3?Ool20005Ool000Ioo`03001oogoo01aoo`03001oogoo
02Ioo`03001oogoo0=1oo`03001oogoo00=oo`001Woo0P000goo00<007ooOol01Goo0`000goo00<0
07ooOol00Woo00<007ooOol017oo00<007ooOol09Goo00<007ooOol0dGoo00<007ooOol00goo0006
Ool01000Ool007oo0P001goo00<007ooOol00Woo00<007oo00000Woo00<007oo00001Goo00<007oo
Ool097oo00<007ooOol0dWoo00<007ooOol00goo0009Ool00`00Oomoo`08Ool00`00Oomoo`03Ool0
1P00Oomoo`00Ool000Eoo`8002Aoo`03001oogoo0=9oo`8000Eoo`001Woo0`002goo00@007ooOomo
o`8000=oo`03001oo`0000Eoo`03001oogoo02=oo`03001oogoo0==oo`03001oogoo00=oo`001Woo
00<007ooOol02Woo00<007oo00000Woo00<007ooOol00Woo00<007oo00001Goo00<007ooOol08Woo
00<007ooOol0e7oo00<007ooOol00goo0006Ool01000Oomoo`002Woo00@007ooOomoo`<000=oo`03
001oogoo00Aoo`03001oogoo025oo`03001oogoo0=Eoo`03001oogoo00=oo`001Woo10006goo0P00
8Goo00<007ooOol0eGoo0P001Goo0006Ool00`00Oomoo`0LOol00`00Oomoo`0POol00`00Oomoo`3F
Ool00`00Oomoo`03Ool000Moo`<001]oo`03001oogoo01moo`03001oogoo0=Moo`03001oogoo00=o
o`001Woo00<007ooOol077oo00<007ooOol07Woo00<007ooOol0f7oo00<007ooOol00goo0007Ool3
000KOol00`00Oomoo`0NOol00`00Oomoo`3HOol00`00Oomoo`03Ool002Eoo`8001ioo`03001oogoo
0=Qoo`8000Eoo`001goo0P0077oo00<007ooOol07Goo00<007ooOol0fGoo00<007ooOol00goo0006
Ool200000goo001oo`0JOol00`00Oomoo`0LOol00`00Oomoo`3JOol00`00Oomoo`03Ool000Ioo`80
0003Ool007oo01Yoo`03001oogoo01]oo`03001oogoo0=]oo`03001oogoo00=oo`001goo00<007oo
00006goo0P0077oo00<007ooOol0fWoo0P001Goo000UOol00`00Oomoo`0JOol00`00Oomoo`3LOol0
0`00Oomoo`03Ool000Ioo`04001oogoo000KOol00`00Oomoo`0IOol00`00Oomoo`3MOol00`00Oomo
o`03Ool000Ioo`@001]oo`03001oogoo01Uoo`03001oogoo0=eoo`03001oogoo00=oo`001Woo00<0
07ooOol077oo0P006Goo00<007ooOol0gGoo0P001Goo0006Ool00`00Oomoo`0LOol00`00Oomoo`0H
Ool00`00Oomoo`3NOol00`00Oomoo`03Ool000Moo`<000Uoo`8000Aoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo01Moo`03001oogoo0=moo`03001oogoo00=oo`002Goo00<007ooOol02Goo
00H007ooOol007oo0002Ool00`00Ool00005Ool00`00Oomoo`0FOol00`00Oomoo`3POol00`00Oomo
o`03Ool000Ioo`03001oogoo00]oo`07001oogooOol007oo00000Woo00<007oo00001Goo0P005goo
00<007ooOol0ggoo0P001Goo0005Ool4000<Ool01P00Oomoo`00Ool0009oo`03001oo`0000Eoo`03
001oogoo01Eoo`03001oogoo0>5oo`03001oogoo00=oo`001Woo00@007ooOol000Uoo`03001oo`00
009oo`03001oo`00009oo`03001oo`0000Eoo`03001oogoo01Eoo`03001oogoo0>5oo`03001oogoo
00=oo`001Woo00@007ooOol000Yoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo01Aoo`03001oogoo0>9oo`03001oogoo00=oo`001Woo00<007oo000077oo00<007ooOol0
57oo00<007ooOol0hWoo00<007ooOol00goo000UOol2000DOol00`00Oomoo`3ROol20005Ool002Eo
o`03001oogoo01=oo`03001oogoo0>=oo`03001oogoo00=oo`009Goo00<007ooOol04Woo00<007oo
Ool0i7oo00<007ooOol00goo000UOol00`00Oomoo`0BOol00`00Oomoo`3TOol00`00Oomoo`03Ool0
02Eoo`80019oo`03001oogoo0>Aoo`8000Eoo`009Goo00<007ooOol04Goo00<007ooOol0iGoo00<0
07ooOol00goo000UOol00`00Oomoo`0@Ool00`00Oomoo`3VOol00`00Oomoo`03Ool002Eoo`03001o
ogoo011oo`03001oogoo0>Ioo`03001oogoo00=oo`009Goo0P0047oo00<007ooOol0iWoo0P001Goo
000UOol00`00Oomoo`0?Ool00`00Oomoo`3WOol00`00Oomoo`03Ool002Eoo`03001oogoo00ioo`03
001oogoo0>Qoo`03001oogoo00=oo`009Goo00<007ooOol03Woo00<007ooOol0j7oo00<007ooOol0
0goo000UOol2000>Ool00`00Oomoo`3XOol20005Ool002Eoo`03001oogoo00eoo`03001oogoo0>Uo
o`03001oogoo00=oo`009Goo00<007ooOol037oo00<007ooOol0jWoo00<007ooOol00goo000COol2
0004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`3ZOol00`00Oomo
o`03Ool001Eoo`06001oogoo001oo`000Woo00<007oo00001Goo00<007ooOol02goo00<007ooOol0
jgoo00<007ooOol00goo000DOol00`00Oomoo`03Ool01P00Oomoo`00Ool000Eoo`8000aoo`03001o
ogoo0>Yoo`8000Eoo`005Goo00<007ooOol00P000goo00<007oo00001Goo00<007ooOol02Woo00<0
07ooOol0k7oo00<007ooOol00goo000COol00`00Ool00002Ool00`00Oomoo`02Ool00`00Ool00005
Ool00`00Oomoo`0:Ool00`00Oomoo`3/Ool00`00Oomoo`03Ool001Aoo`04001oogooOol30003Ool0
0`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`3/Ool00`00Oomoo`03Ool002Eoo`8000Yoo`03
001oogoo0>aoo`8000Eoo`009Goo00<007ooOol02Goo00<007ooOol0kGoo00<007ooOol00goo000U
Ool00`00Oomoo`09Ool00`00Oomoo`3]Ool00`00Oomoo`03Ool002Eoo`03001oogoo00Qoo`03001o
ogoo0>ioo`03001oogoo00=oo`009Goo0P002Goo00<007ooOol0kGoo0P001Goo000UOol00`00Oomo
o`07Ool00`00Oomoo`3_Ool00`00Oomoo`03Ool002Eoo`03001oogoo00Moo`03001oogoo0>moo`03
001oogoo00=oo`009Goo00<007ooOol01goo00<007ooOol0kgoo00<007ooOol00goo000UOol20007
Ool00`00Oomoo`3_Ool20005Ool002Eoo`03001oogoo00Ioo`03001oogoo0?1oo`03001oogoo00=o
o`009Goo00<007ooOol01Woo00<007ooOol0l7oo00<007ooOol00goo000UOol00`00Oomoo`05Ool0
0`00Oomoo`3aOol00`00Oomoo`03Ool002Eoo`03001oogoo00Eoo`03001oogoo0?5oo`03001oogoo
00=oo`009Goo0P001Goo00<007ooOol0lGoo0P001Goo000UOol00`00Oomoo`04Ool00`00Oomoo`3b
Ool00`00Oomoo`03Ool001Aoo`<0009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Ao
o`03001oogoo0?9oo`03001oogoo00=oo`005Goo00H007ooOol007oo0002Ool00`00Ool00005Ool0
0`00Oomoo`03Ool00`00Oomoo`3cOol00`00Oomoo`03Ool001=oo`@00004Ool007oo0002Ool00`00
Ool00005Ool20004Ool00`00Oomoo`3bOol20005Ool001=oo`03001oo`00009oo`03001oo`00009o
o`03001oo`0000Eoo`03001oogoo0?Uoo`03001oogoo00=oo`0057oo0P000Woo00<007oo00000Woo
00<007oo00001Goo00<007ooOol00goo00<007ooOol0>Goo00<007ooOol0>Goo00<007ooOol0>Goo
00<007ooOol0>Goo00<007ooOol00goo00<007ooOol00goo000EOol01@00Oomoogoo000017oo00<0
07ooOol017oo00<007ooOol00goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol00goo000UOoom0005Ool00001
\
\>"],
  ImageRangeCache->{{{0, 294.563}, {181.625, 0}} -> {-0.0358706, -16.7463, 
  0.000831327, 2.35286}}]
}, Open  ]],

Cell["\<\
We can easily combine the payment\[Hyphen]yield graphs for \
different coupon rates. Here the coupon rates are 0% (a zero\[Hyphen]coupon \
bond), 7%, and 14%. \
\>", "MathCaption",
  CellTags->"0.20"],

Cell[CellGroupData[{

Cell["\<\
Plot[{p[.0, x], p[.07, x], p[.14, x]}, {x, 0, .20},
   FrameLabel -> label1];\
\>", "Input",
  CellLabel->"In[16]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.76191 0.0143431 0.00113265 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -12 -9 ]
[.2619 -0.0125 12 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -53 -21.5625 ]
[.5 -0.0125 53 -9 ]
[-0.0125 .01434 -6 -4.5 ]
[-0.0125 .01434 0 4.5 ]
[-0.0125 .12761 -18 -4.5 ]
[-0.0125 .12761 0 4.5 ]
[-0.0125 .24087 -18 -4.5 ]
[-0.0125 .24087 0 4.5 ]
[-0.0125 .35414 -18 -4.5 ]
[-0.0125 .35414 0 4.5 ]
[-0.0125 .4674 -18 -4.5 ]
[-0.0125 .4674 0 4.5 ]
[-0.0125 .58067 -18 -4.5 ]
[-0.0125 .58067 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -38 ]
[-0.01875 .30902 -18 38 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -114 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Yield) show
99.000000 12.812500 moveto
(to) show
117.000000 12.812500 moveto
(maturity) show
165.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .01434 m
.00625 .01434 L
s
[(0)] -0.0125 .01434 1 0 Mshowa
0 .12761 m
.00625 .12761 L
s
[(100)] -0.0125 .12761 1 0 Mshowa
0 .24087 m
.00625 .24087 L
s
[(200)] -0.0125 .24087 1 0 Mshowa
0 .35414 m
.00625 .35414 L
s
[(300)] -0.0125 .35414 1 0 Mshowa
0 .4674 m
.00625 .4674 L
s
[(400)] -0.0125 .4674 1 0 Mshowa
0 .58067 m
.00625 .58067 L
s
[(500)] -0.0125 .58067 1 0 Mshowa
.125 Mabswid
0 .037 m
.00375 .037 L
s
0 .05965 m
.00375 .05965 L
s
0 .0823 m
.00375 .0823 L
s
0 .10495 m
.00375 .10495 L
s
0 .15026 m
.00375 .15026 L
s
0 .17291 m
.00375 .17291 L
s
0 .19557 m
.00375 .19557 L
s
0 .21822 m
.00375 .21822 L
s
0 .26353 m
.00375 .26353 L
s
0 .28618 m
.00375 .28618 L
s
0 .30883 m
.00375 .30883 L
s
0 .33148 m
.00375 .33148 L
s
0 .37679 m
.00375 .37679 L
s
0 .39944 m
.00375 .39944 L
s
0 .4221 m
.00375 .4221 L
s
0 .44475 m
.00375 .44475 L
s
0 .49005 m
.00375 .49005 L
s
0 .51271 m
.00375 .51271 L
s
0 .53536 m
.00375 .53536 L
s
0 .55801 m
.00375 .55801 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -123.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
99 10.2813 translate
90 rotate
-99 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bond) show
93.000000 12.812500 moveto
(payment) show
135.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01434 m
1 .01434 L
s
.99375 .12761 m
1 .12761 L
s
.99375 .24087 m
1 .24087 L
s
.99375 .35414 m
1 .35414 L
s
.99375 .4674 m
1 .4674 L
s
.99375 .58067 m
1 .58067 L
s
.125 Mabswid
.99625 .037 m
1 .037 L
s
.99625 .05965 m
1 .05965 L
s
.99625 .0823 m
1 .0823 L
s
.99625 .10495 m
1 .10495 L
s
.99625 .15026 m
1 .15026 L
s
.99625 .17291 m
1 .17291 L
s
.99625 .19557 m
1 .19557 L
s
.99625 .21822 m
1 .21822 L
s
.99625 .26353 m
1 .26353 L
s
.99625 .28618 m
1 .28618 L
s
.99625 .30883 m
1 .30883 L
s
.99625 .33148 m
1 .33148 L
s
.99625 .37679 m
1 .37679 L
s
.99625 .39944 m
1 .39944 L
s
.99625 .4221 m
1 .4221 L
s
.99625 .44475 m
1 .44475 L
s
.99625 .49005 m
1 .49005 L
s
.99625 .51271 m
1 .51271 L
s
.99625 .53536 m
1 .53536 L
s
.99625 .55801 m
1 .55801 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .12761 m
.06244 .10318 L
.10458 .08258 L
.14415 .06766 L
.18221 .05644 L
.22272 .04711 L
.26171 .04012 L
.30316 .03433 L
.34309 .03001 L
.3815 .02674 L
.42237 .02402 L
.46172 .02198 L
.49955 .02042 L
.53984 .01912 L
.57861 .01813 L
.61984 .01731 L
.65954 .01669 L
.69774 .01622 L
.73838 .01582 L
.77751 .01552 L
.81909 .01526 L
.85916 .01507 L
.89771 .01493 L
.93871 .0148 L
.97619 .01472 L
s
.02381 .36546 m
.06244 .31392 L
.10458 .2684 L
.14415 .2337 L
.18221 .2062 L
.22272 .18201 L
.26171 .1627 L
.30316 .14563 L
.34309 .13191 L
.3815 .12074 L
.42237 .11066 L
.46172 .10238 L
.49955 .09552 L
.53984 .0892 L
.57861 .08391 L
.61984 .079 L
.65954 .07485 L
.69774 .07131 L
.73838 .06797 L
.77751 .06509 L
.81909 .06235 L
.85916 .05998 L
.89771 .05791 L
.93871 .0559 L
.97619 .05423 L
s
.02381 .60332 m
.06244 .52467 L
.10458 .45422 L
.14415 .39974 L
.18221 .35596 L
.22272 .3169 L
.26171 .28529 L
.30316 .25694 L
.34309 .2338 L
.3815 .21474 L
.42237 .19729 L
.46172 .18279 L
.49955 .17062 L
.53984 .15928 L
.57861 .14968 L
.61984 .14068 L
.65954 .133 L
.69774 .12641 L
.73838 .12011 L
.77751 .11466 L
.81909 .10944 L
.85916 .10488 L
.89771 .10089 L
.93871 .097 L
.97619 .09374 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[16]:=",
  ImageSize->{295.563, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40O003h00Oogoo:7oo003oOolX
Ool00?moobQoo`00bWoo0P00Fgoo003;Ool00`00Oomoo`1IOol0075oo`<0009oo`<000=oo`80009o
o`<000=oo`<000eoo`8000=oo`8000Uoo`06001oo`00Ool007oo10000Woo0P000goo0`0000Aoo`00
0000009oo`<000=oo`8000=oo`03001oogoo05Uoo`00LWoo00<007ooOol00Woo00D007ooOomoo`00
00Eoo`05001oogooOol00002Ool00`00Oomoo`0:Ool01P00Oomoo`00Ool0009oo`03001oogoo00Io
o`06001oo`00Ool007oo0`000Woo00H007ooOol007oo0002Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`05001oo`00Ool0001JOol0079oo`03001oogoo009oo`04001oogooOol30003Ool01@00
Oomoogoo00000Woo00<007ooOol02Woo00<007ooOol00Woo00@007ooOol000Qoo`05001oo`00Ool0
0003Ool01000Oomoo`0017oo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Ool0001JOol0075oo`03001oo`00009oo`8000=oo`<000=oo`03001oogoo009oo`<000]oo`@0
00=oo`8000Uoo`800003Ool007oo009oo`800003Ool0000000800004Ool00000Ool200000goo0000
000200000goo00000002Ool4000017oo000007oo0P00FGoo001`Ool01@00Oomoogoo000037oo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol06Goo00<007ooOol04Goo00<007ooOol0Ggoo001`
Ool200000goo00000002Ool00`00Oomoo`06Ool20005Ool2000hOol00`00Oomoo`1SOol00?moobQo
o`00ogoo:7oo000ZOol00`00Oomoo`0bOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`05000]Ool00`00Oomoo`02Ool00`00Oomo
o`050002Ool00`00Oomoo`0]Ool00`00Oomoo`02Ool01000Oomoogoo0`001Goo000YOol00`00Ool0
000bOol00`00Ool00007Ool00`00Ool00002Ool00`00Ool0000/Ool00`00Ool00008Ool00`00Oomo
o`0/Ool00`00Ool00008Ool01`00Oomoogoo001oo`0002eoo`03001oo`0000Moo`03001oogoo00Eo
o`00:Goo00<007oo0000<Woo00<007oo00001goo00<007oo000017oo00<007ooOol0:Woo00<007oo
000027oo00<007ooOol0;7oo00<007oo000027oo00<007ooOol00goo00<007ooOol0:goo00<007oo
000027oo00<007ooOol017oo000YOol00`00Ool0000bOol00`00Ool00007Ool00`00Ool00002Ool2
000]Ool00`00Ool00008Ool00`00Oomoo`0/Ool00`00Ool00008Ool01000Oomoogoo0P00;Woo00<0
07oo000027oo00<007ooOol017oo000YOol00`00Ool0000bOol00`00Ool00007Ool00`00Ool00002
Ool00`00Oomoo`0/Ool00`00Ool00008Ool00`00Oomoo`0/Ool00`00Ool00008Ool01@00Oomoogoo
0000;goo00<007oo00001goo00<007oo00001Goo000ZOol00`00Oomoo`0bOol00`00Oomoo`07Ool0
1000Oomoogoo0`00;Goo00<007ooOol01Woo0P00;goo00<007ooOol01Woo0P000goo0`00;Woo00<0
07ooOol01goo00<007ooOol017oo003oOolXOol00?moobQoo`00ogoo:7oo003oOolXOol00?moobQo
o`00ogoo:7oo000TOooo0004Ool001ioo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00=o
o`03001oogoo009oo`007Goo00<007oo000017oo00<007ooOol0ngoo00<007ooOol00Woo000MOol0
0`00Ool00004Ool30038Ool^0003Ool30004Ool001eoo`03001oo`0000Aoo`03001oogoo089oodH0
03=oo`03001oogoo009oo`007Goo00<007oo000017oo00<007ooOol0KWoo5000NGoo00<007ooOol0
0Woo000NOol00`00Oomoo`03Ool00`00Oomoo`1JOolD002=Ool00`00Oomoo`02Ool002Aoo`03001o
ogoo051oo`X00:5oo`03001oogoo009oo`0097oo00<007ooOol0B7oo2000Zgoo00<007ooOol00Woo
000TOol20013Ool6002bOol20004Ool002Aoo`03001oogoo03eoo`D00;Uoo`03001oogoo009oo`00
97oo00<007ooOol0>Goo1000_Woo00<007ooOol00Woo000TOol00`00Oomoo`0dOol50032Ool00`00
Oomoo`02Ool002Aoo`03001oogoo02ioo`H00;eoo`D000Eoo`03001oogoo009oo`0097oo00<007oo
Ool0:Woo1000[goo50002Woo00<007ooOol00Woo000TOol2000XOol3002NOolE000MOol20004Ool0
02Aoo`03001oogoo02Aoo`<009Moo`X003=oo`03001oogoo009oo`0097oo00<007ooOol08Goo0`00
T7oo2P00?Goo00<007ooOol00Woo000TOol00`00Oomoo`0OOol20029Ool:0017Ool00`00Oomoo`02
Ool002Aoo`03001oogoo01aoo`<0085oo`X0055oo`03001oogoo009oo`0097oo00<007ooOol06Woo
0P00NWoo2P00Fgoo00<007ooOol00Woo000TOol2000HOol3001bOol:001TOol20004Ool002Aoo`03
001oogoo01Eoo`8006eoo`P006moo`03001oogoo009oo`0097oo00<007ooOol04goo0P00JWoo1@00
KGoo1@001Goo00<007ooOol00Woo000TOol00`00Oomoo`0AOol2001WOol5001XOol:000:Ool00`00
Oomoo`02Ool002Aoo`03001oogoo00moo`8006Aoo`D006=oo`X001Aoo`03001oogoo009oo`0097oo
0P003Woo0P00HGoo1@00GWoo2P007Goo0P0017oo000TOol00`00Oomoo`0;Ool2001NOol5001KOol8
000XOol00`00Oomoo`02Ool002Aoo`03001oogoo00Uoo`8005]oo`D005Yoo`H0031oo`03001oogoo
009oo`0097oo00<007ooOol027oo00<007ooOol0EWoo1@00F7oo1`00=Woo00<007ooOol00Woo000B
Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`06Ool2001EOol4001EOol8000m
Ool00`00Oomoo`02Ool001Aoo`07001oogooOol007oo00000Woo00<007oo000017oo00<007ooOol0
17oo0P00E7oo0`00E7oo1@00AGoo00<007ooOol00Woo000DOol01`00Oomoogoo001oo`00009oo`03
001oo`0000Aoo`<000=oo`03001oogoo051oo`@0051oo`L004Qoo`<000Aoo`0057oo00L007ooOomo
o`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`1COol3001<Ool8001AOol00`00Oomoo`02Ool0
01Aoo`07001oogooOol007oo00000Woo00<007oo000017oo00<007ooOol0DGoo0P00BWoo1@00FGoo
00<007ooOol00Woo000COol20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1>Ool3
0018Ool4001NOol00`00Oomoo`02Ool002Aoo`03001oogoo04aoo`8004Qoo`<0069oo`03001oogoo
009oo`0097oo00<007ooOol0BGoo0`00AWoo1000IGoo00<007ooOol00Woo000TOol20017Ool30015
Ool4001XOol20004Ool002Aoo`03001oogoo04Aoo`8004=oo`D006eoo`03001oogoo009oo`0097oo
00<007ooOol0@Goo0`00@Goo1000LWoo00<007ooOol00Woo000TOol00`00Oomoo`0oOol20011Ool3
001fOol00`00Oomoo`02Ool002Aoo`03001oogoo03eoo`8003moo`@007Uoo`03001oogoo009oo`00
17oo00<007ooOol00Woo00<007ooOol067oo00<007ooOol0>goo0P00?Woo0`00OGoo00<007ooOol0
0Woo0004Ool6000JOol2000jOol2000mOol3001oOol20004Ool000Aoo`03001oo`00009oo`03001o
ogoo01Qoo`03001oogoo03Moo`8003]oo`@008=oo`03001oogoo009oo`0017oo00<007oo00000Woo
00<007ooOol067oo00<007ooOol0=Woo00<007ooOol0>7oo0`00Qgoo00<007ooOol00Woo0005Ool0
1000Ool000006goo00<007ooOol0=7oo0P00>Goo0P00RWoo00<007ooOol00Woo000TOol00`00Oomo
o`0bOol2000hOol3002<Ool00`00Oomoo`02Ool002Aoo`80035oo`8003Qoo`8008ioo`8000Aoo`00
1goo0P006goo00<007ooOol0;Woo0P00=goo0`00TGoo00<007ooOol00Woo0006Ool01000Oomoo`00
6Woo00<007ooOol0;7oo0P00=goo0P00U7oo00<007ooOol00Woo0006Ool01000Oomoo`006Woo00<0
07ooOol0:goo00<007ooOol0=7oo0`00UWoo00<007ooOol00Woo0007Ool2000KOol00`00Oomoo`0Z
Ool00`00Oomoo`0cOol2002IOol00`00Oomoo`02Ool002Aoo`03001oogoo02Qoo`8003Aoo`8009]o
o`03001oogoo009oo`001Woo00@007ooOol001Yoo`8002Qoo`03001oogoo039oo`8009aoo`8000Ao
o`001Woo10006Woo00<007ooOol09Woo00<007ooOol0<Goo0P00Wgoo00<007ooOol00Woo0006Ool0
0`00Oomoo`0KOol00`00Oomoo`0TOol2000bOol2002QOol00`00Oomoo`02Ool000Ioo`03001oogoo
01]oo`03001oogoo02=oo`03001oogoo031oo`800:=oo`03001oogoo009oo`001goo0`002Goo0`00
0goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol08Woo00<007ooOol0;goo0P00YGoo00<0
07ooOol00Woo0009Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool00004
Ool00`00Oomoo`0QOol00`00Oomoo`0^Ool2002WOol00`00Oomoo`02Ool001Aoo`07001oogooOol0
07oo00000Woo00<007oo000017oo0`0087oo00<007ooOol0;Goo0P00Ygoo0`0017oo0007Ool2000;
Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`03001oogoo01moo`03001oogoo02eoo`03
001oogoo0:Uoo`03001oogoo009oo`001Woo00@007ooOol000Uoo`03001oo`00009oo`03001oo`00
009oo`03001oo`0000Aoo`03001oogoo01ioo`03001oogoo02aoo`800:aoo`03001oogoo009oo`00
17oo00<007oo00000Woo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol077oo0P00;Goo0P00[Woo00<007ooOol00Woo0004Ool6000JOol00`00Oomoo`0K
Ool00`00Oomoo`0/Ool00`00Oomoo`2^Ool00`00Oomoo`02Ool000Uoo`03001oogoo01Qoo`03001o
ogoo01Yoo`03001oogoo02]oo`800;5oo`03001oogoo009oo`0097oo0P006Woo00<007ooOol0:goo
00<007ooOol0/7oo0P0017oo000TOol00`00Oomoo`0HOol00`00Oomoo`0ZOol2002dOol00`00Oomo
o`02Ool002Aoo`03001oogoo01Moo`03001oogoo02Uoo`800;Ioo`03001oogoo009oo`0097oo00<0
07ooOol05Woo00<007ooOol0:Goo00<007ooOol0]Woo00<007ooOol00Woo000TOol00`00Oomoo`0E
Ool00`00Oomoo`0XOol2002iOol00`00Oomoo`02Ool002Aoo`8001Eoo`03001oogoo02Qoo`03001o
ogoo0;Qoo`8000Aoo`001Woo00<007ooOol00Woo00<007ooOol05Woo00<007ooOol04goo00<007oo
Ool0:7oo00<007ooOol0^Woo00<007ooOol00Woo0006Ool6000HOol00`00Oomoo`0BOol00`00Oomo
o`0XOol00`00Oomoo`2kOol00`00Oomoo`02Ool000Ioo`06001oogoo001oo`0067oo00<007ooOol0
4Goo00<007ooOol0:7oo00<007ooOol0_7oo00<007ooOol00Woo0006Ool01000Oomoo`006Woo00<0
07ooOol047oo00<007ooOol09goo0P00_goo00<007ooOol00Woo0007Ool2000KOol00`00Oomoo`0?
Ool00`00Oomoo`0WOol00`00Oomoo`2oOol00`00Oomoo`02Ool002Aoo`8000moo`03001oogoo02Mo
o`03001oogoo0;moo`8000Aoo`0097oo00<007ooOol03Goo00<007ooOol09goo00<007ooOol0`Goo
00<007ooOol00Woo0008Ool2000JOol00`00Oomoo`0<Ool00`00Oomoo`0WOol00`00Oomoo`32Ool0
0`00Oomoo`02Ool000Ioo`04001oo`00000JOol00`00Oomoo`0;Ool00`00Oomoo`0WOol00`00Oomo
o`33Ool00`00Oomoo`02Ool000Ioo`04001oo`00000JOol00`00Oomoo`0;Ool00`00Oomoo`0VOol0
0`00Oomoo`34Ool00`00Oomoo`02Ool000Ioo`@001Yoo`03001oogoo00Yoo`03001oogoo02Ioo`03
001oogoo0<Eoo`03001oogoo009oo`002Goo00<007ooOol067oo0P002Woo00<007ooOol09Woo00<0
07ooOol0aGoo0P0017oo0006Ool00`00Oomoo`0KOol00`00Oomoo`08Ool00`00Oomoo`0UOol20039
Ool00`00Oomoo`02Ool000Ioo`8000=oo`03001oogoo01Ioo`03001oogoo00Qoo`03001oogoo02Ao
o`03001oogoo0<Uoo`03001oogoo009oo`001Woo00@007oo001oo`8001Qoo`03001oogoo00Moo`03
001oogoo02Aoo`03001oogoo0<Yoo`03001oogoo009oo`002Goo00<007ooOol01goo0P0017oo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol01Woo00<007ooOol097oo00<007ooOol0bgoo00<0
07ooOol00Woo0006Ool3000<Ool01P00Oomoo`00Ool0009oo`03001oo`0000Aoo`03001oogoo00Eo
o`03001oogoo02Aoo`03001oogoo0<aoo`03001oogoo009oo`001Woo00<007ooOol02goo00L007oo
Oomoo`00Ool00002Ool00`00Ool00004Ool30005Ool00`00Oomoo`0SOol00`00Oomoo`3;Ool30004
Ool000Ioo`04001oogoo000;Ool01P00Oomoo`00Ool0009oo`03001oo`0000Aoo`03001oogoo00Ao
o`03001oogoo02=oo`03001oogoo0<ioo`03001oogoo009oo`001Woo10002Goo00<007oo00000Woo
00<007oo00000Woo00<007oo000017oo00<007ooOol00goo00<007ooOol08goo00<007ooOol0cgoo
00<007ooOol00Woo0006Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`0YOol00`00Oomoo`3?Ool00`00Oomoo`02Ool000Moo`<001Yoo`03001oogoo
02Qoo`03001oogoo0=1oo`03001oogoo009oo`001Woo00<007ooOol06goo0P00:7oo00<007ooOol0
d7oo0P0017oo0007Ool3000JOol00`00Oomoo`0VOol00`00Oomoo`3BOol00`00Oomoo`02Ool002Ao
o`03001oogoo02Eoo`03001oogoo0==oo`03001oogoo009oo`001goo0P006goo00<007ooOol097oo
00<007ooOol0e7oo00<007ooOol00Woo0006Ool200000goo001oo`0IOol00`00Oomoo`0TOol00`00
Oomoo`3DOol00`00Oomoo`02Ool000Ioo`800003Ool007oo01Uoo`03001oogoo02=oo`03001oogoo
0=Eoo`03001oogoo009oo`001goo00<007oo00006Woo0P008goo00<007ooOol0eGoo0P0017oo000T
Ool00`00Oomoo`0QOol00`00Oomoo`3GOol00`00Oomoo`02Ool000Ioo`04001oogoo000JOol00`00
Oomoo`0QOol00`00Oomoo`3GOol00`00Oomoo`02Ool000Ioo`@001Yoo`03001oogoo021oo`03001o
ogoo0=Qoo`03001oogoo009oo`001Woo00<007ooOol06goo00<007ooOol07goo00<007ooOol0fGoo
00<007ooOol00Woo0006Ool00`00Oomoo`0KOol00`00Oomoo`0NOol00`00Oomoo`3JOol00`00Oomo
o`02Ool000Moo`<001Yoo`8001moo`03001oogoo0=Uoo`8000Aoo`002Goo00<007ooOol067oo00<0
07ooOol07Goo00<007ooOol0fgoo00<007ooOol00Woo0006Ool00`00Oomoo`0KOol00`00Oomoo`0L
Ool00`00Oomoo`3LOol00`00Oomoo`02Ool000Eoo`@001]oo`03001oogoo01aoo`03001oogoo0=ao
o`03001oogoo009oo`001Woo00@007ooOol001Yoo`03001oogoo01]oo`03001oogoo0=eoo`03001o
ogoo009oo`001Woo00@007ooOol001Yoo`03001oogoo01Yoo`03001oogoo0=ioo`03001oogoo009o
o`001Woo00<007oo00006goo0P006Woo00<007ooOol0gWoo0P0017oo000TOol00`00Oomoo`0IOol0
0`00Oomoo`3OOol00`00Oomoo`02Ool002Aoo`03001oogoo01Qoo`03001oogoo0>1oo`03001oogoo
009oo`0057oo0`000Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol05goo00<007ooOol0
hGoo00<007ooOol00Woo000EOol01P00Oomoo`00Ool0009oo`03001oo`0000Aoo`03001oogoo01Mo
o`03001oogoo0>5oo`03001oogoo009oo`004goo100000Aoo`00Ool0009oo`03001oo`0000Aoo`<0
01Ioo`03001oogoo0>1oo`<000Aoo`004goo00<007oo00000Woo00<007oo00000Woo00<007oo0000
17oo00<007ooOol05Woo00<007ooOol0hWoo00<007ooOol00Woo000DOol20002Ool00`00Ool00002
Ool00`00Ool00004Ool00`00Oomoo`0EOol00`00Oomoo`3SOol00`00Oomoo`02Ool001Eoo`05001o
ogooOol00004Ool00`00Oomoo`03Ool00`00Oomoo`0DOol00`00Oomoo`3TOol00`00Oomoo`02Ool0
02Aoo`03001oogoo01Aoo`03001oogoo0>Aoo`03001oogoo009oo`0097oo00<007ooOol04goo00<0
07ooOol0iGoo00<007ooOol00Woo000TOol2000COol00`00Oomoo`3UOol20004Ool002Aoo`03001o
ogoo019oo`03001oogoo0>Ioo`03001oogoo009oo`0097oo00<007ooOol04Goo00<007ooOol0igoo
00<007ooOol00Woo000TOol00`00Oomoo`0AOol00`00Oomoo`3WOol00`00Oomoo`02Ool002Aoo`03
001oogoo011oo`03001oogoo0>Qoo`03001oogoo009oo`0097oo00<007ooOol03goo00<007ooOol0
jGoo00<007ooOol00Woo000TOol2000@Ool00`00Oomoo`3XOol20004Ool002Aoo`03001oogoo00io
o`03001oogoo0>Yoo`03001oogoo009oo`0097oo00<007ooOol03Woo00<007ooOol0jWoo00<007oo
Ool00Woo000TOol00`00Oomoo`0=Ool00`00Oomoo`3[Ool00`00Oomoo`02Ool002Aoo`03001oogoo
00aoo`03001oogoo0>aoo`03001oogoo009oo`0097oo00<007ooOol037oo00<007ooOol0k7oo00<0
07ooOol00Woo000TOol2000<Ool00`00Oomoo`3/Ool20004Ool002Aoo`03001oogoo00]oo`03001o
ogoo0>eoo`03001oogoo009oo`0097oo00<007ooOol02Woo00<007ooOol0kWoo00<007ooOol00Woo
000TOol00`00Oomoo`0:Ool00`00Oomoo`3^Ool00`00Oomoo`02Ool002Aoo`03001oogoo00Uoo`03
001oogoo0>moo`03001oogoo009oo`0097oo0P002Woo00<007ooOol0kWoo0P0017oo000TOol00`00
Oomoo`08Ool00`00Oomoo`3`Ool00`00Oomoo`02Ool002Aoo`03001oogoo00Qoo`03001oogoo0?1o
o`03001oogoo009oo`0097oo00<007ooOol01goo00<007ooOol0lGoo00<007ooOol00Woo000DOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`3aOol0
0`00Oomoo`02Ool001=oo`03001oo`00009oo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo
00Ioo`03001oogoo0?9oo`03001oogoo009oo`005Goo00H007ooOol007oo0002Ool00`00Ool00004
Ool30006Ool00`00Oomoo`3`Ool30004Ool001=oo`8000=oo`03001oo`00009oo`03001oo`0000Ao
o`03001oogoo00Eoo`03001oogoo0?=oo`03001oogoo009oo`004goo00<007ooOol00Woo00<007oo
00000Woo00<007oo000017oo00<007ooOol01Goo00<007ooOol0lgoo00<007ooOol00Woo000COol3
0003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`3dOol00`00Oomo
o`02Ool002Aoo`03001oogoo00Aoo`03001oogoo0?Aoo`03001oogoo009oo`0097oo00<007ooOol0
0goo00<007ooOol0mGoo00<007ooOol00Woo000TOol20004Ool00`00Oomoo`3dOol20004Ool002Ao
o`03001oogoo0?]oo`03001oogoo009oo`0097oo00<007ooOol00goo00<007ooOol0>Woo00<007oo
Ool0>Goo00<007ooOol0>Goo00<007ooOol0>Woo00<007ooOol00goo00<007ooOol00Woo000TOooo
0004Ool00001\
\>"],
  ImageRangeCache->{{{0, 294.563}, {181.625, 0}} -> {-0.0352269, -98.6957, 
  0.000827255, 3.47796}}]
}, Open  ]],

Cell[TextData[{
  "Here is the three\[Hyphen]dimensional graph of the bond payment ",
  StyleBox["p[c, y]", "MB"],
  " as a function of the coupon rate ",
  StyleBox["c", "MB"],
  " and yield to maturity ",
  StyleBox["y", "MB"],
  ". The rest of the parameters are held constant. "
}], "MathCaption",
  CellTags->"0.21"],

Cell[CellGroupData[{

Cell["\<\
Plot3D[p[c, y], {y, 0, .20}, {c, 0, .20},
   AxesLabel -> {\"Yield to \\nmaturity \",
      \"  Coupon\", \"  Bond\\npayment\"}];\
\>", "Input",
  CellLabel->"In[17]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -16.7601 -9 ]
[.3345 .12542 1.2399 0 ]
[.50253 .05935 -21.0959 -9 ]
[.50253 .05935 2.90415 0 ]
[.68156 -0.01098 -14.8837 -9 ]
[.68156 -0.01098 3.11632 0 ]
[.29165 .07573 -54.0048 -25.75 ]
[.29165 .07573 3.99522 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 24 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 18 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 24 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.91861 .21225 0 -8.41865 ]
[.91861 .21225 52 4.14385 ]
[.02413 .26501 -6 -2.74223 ]
[.02413 .26501 0 6.25777 ]
[.01447 .32558 -18 -2.79345 ]
[.01447 .32558 0 6.20655 ]
[.00441 .38857 -18 -2.84694 ]
[.00441 .38857 0 6.15306 ]
[-0.00605 .45414 -18 -2.90285 ]
[-0.00605 .45414 0 6.09715 ]
[-0.05457 .39542 -46 -8.10665 ]
[-0.05457 .39542 0 17.6434 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(0.05)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0.1)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.15)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -115.005 -29.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 29.750000 moveto
 460.000000 29.750000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 29.750000 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Yield) show
99.000000 12.812500 moveto
(to) show
63.000000 26.000000 moveto
(maturity) show
117.000000 26.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(0.05)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0.1)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.15)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0.2)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.4187 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Coupon) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03635 .26024 m
.04246 .25785 L
s
[(0)] .02413 .26501 1 -0.39061 Mshowa
.02674 .32092 m
.03287 .3186 L
s
[(200)] .01447 .32558 1 -0.37923 Mshowa
.01673 .38405 m
.02289 .38178 L
s
[(400)] .00441 .38857 1 -0.36735 Mshowa
.00632 .44976 m
.0125 .44756 L
s
[(600)] -0.00605 .45414 1 -0.35492 Mshowa
.125 Mabswid
.03398 .27519 m
.03765 .27376 L
s
.03159 .29028 m
.03526 .28887 L
s
.02917 .30553 m
.03285 .30412 L
s
.02427 .33647 m
.02796 .33508 L
s
.02178 .35217 m
.02547 .35079 L
s
.01927 .36803 m
.02296 .36666 L
s
.01417 .40022 m
.01787 .39888 L
s
.01158 .41657 m
.01528 .41523 L
s
.00896 .43308 m
.01267 .43175 L
s
.00365 .46661 m
.00736 .4653 L
s
.00095 .48363 m
.00467 .48234 L
s
gsave
-0.05457 .39542 -107 -12.1067 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 29.750000 moveto
 460.000000 29.750000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 29.750000 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bond) show
63.000000 26.000000 moveto
(payment) show
105.000000 26.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.812 .704 .746 r
.3752 .77363 .39806 .80578 .43805 .75061 .41563 .72052 Metetra
.793 .711 .774 r
.41563 .72052 .43805 .75061 .47746 .70784 .45546 .67918 Metetra
.774 .717 .799 r
.45546 .67918 .47746 .70784 .51671 .67344 .49511 .64576 Metetra
.756 .721 .82 r
.49511 .64576 .51671 .67344 .55604 .64478 .53484 .61777 Metetra
.74 .724 .837 r
.53484 .61777 .55604 .64478 .59562 .62012 .57482 .59355 Metetra
.726 .726 .85 r
.57482 .59355 .59562 .62012 .63556 .59828 .61517 .57198 Metetra
.715 .727 .86 r
.61517 .57198 .63556 .59828 .67594 .57843 .65596 .55228 Metetra
.706 .728 .868 r
.65596 .55228 .67594 .57843 .7168 .56001 .69725 .53392 Metetra
.698 .729 .874 r
.69725 .53392 .7168 .56001 .7582 .54261 .73907 .5165 Metetra
.692 .73 .879 r
.73907 .5165 .7582 .54261 .80014 .52594 .78146 .49974 Metetra
.688 .73 .883 r
.78146 .49974 .80014 .52594 .84267 .50979 .82445 .48346 Metetra
.684 .731 .886 r
.82445 .48346 .84267 .50979 .88581 .494 .86805 .4675 Metetra
.681 .731 .889 r
.86805 .4675 .88581 .494 .92957 .47845 .91229 .45174 Metetra
.678 .732 .891 r
.91229 .45174 .92957 .47845 .97397 .46304 .95719 .4361 Metetra
.807 .703 .75 r
.35189 .74084 .3752 .77363 .41563 .72052 .39273 .6898 Metetra
.788 .711 .779 r
.39273 .6898 .41563 .72052 .45546 .67918 .43296 .64988 Metetra
.769 .716 .803 r
.43296 .64988 .45546 .67918 .49511 .64576 .47301 .61744 Metetra
.751 .72 .823 r
.47301 .61744 .49511 .64576 .53484 .61777 .51314 .59011 Metetra
.735 .723 .84 r
.51314 .59011 .53484 .61777 .57482 .59355 .55353 .56633 Metetra
.722 .725 .852 r
.55353 .56633 .57482 .59355 .61517 .57198 .59428 .54503 Metetra
.711 .726 .862 r
.59428 .54503 .61517 .57198 .65596 .55228 .63549 .52548 Metetra
.703 .727 .869 r
.63549 .52548 .65596 .55228 .69725 .53392 .6772 .50716 Metetra
.696 .728 .875 r
.6772 .50716 .69725 .53392 .73907 .5165 .71945 .48971 Metetra
.69 .729 .88 r
.71945 .48971 .73907 .5165 .78146 .49974 .76229 .47286 Metetra
.686 .73 .884 r
.76229 .47286 .78146 .49974 .82445 .48346 .80574 .45643 Metetra
.682 .73 .887 r
.80574 .45643 .82445 .48346 .86805 .4675 .84982 .44028 Metetra
.679 .731 .889 r
.84982 .44028 .86805 .4675 .91229 .45174 .89455 .4243 Metetra
.677 .731 .891 r
.89455 .4243 .91229 .45174 .95719 .4361 .93996 .40841 Metetra
.802 .702 .755 r
.32812 .7074 .35189 .74084 .39273 .6898 .36935 .65843 Metetra
.783 .71 .783 r
.36935 .65843 .39273 .6898 .43296 .64988 .40997 .61993 Metetra
.763 .715 .807 r
.40997 .61993 .43296 .64988 .47301 .61744 .4504 .58846 Metetra
.746 .719 .827 r
.4504 .58846 .47301 .61744 .51314 .59011 .49093 .5618 Metetra
.731 .722 .842 r
.49093 .5618 .51314 .59011 .55353 .56633 .53171 .53845 Metetra
.718 .724 .854 r
.53171 .53845 .55353 .56633 .59428 .54503 .57287 .51742 Metetra
.708 .725 .864 r
.57287 .51742 .59428 .54503 .63549 .52548 .61449 .498 Metetra
.7 .726 .871 r
.61449 .498 .63549 .52548 .6772 .50716 .65663 .47971 Metetra
.693 .727 .876 r
.65663 .47971 .6772 .50716 .71945 .48971 .69932 .46221 Metetra
.688 .728 .881 r
.69932 .46221 .71945 .48971 .76229 .47286 .74262 .44527 Metetra
.684 .729 .884 r
.74262 .44527 .76229 .47286 .80574 .45643 .78653 .42868 Metetra
.681 .73 .887 r
.78653 .42868 .80574 .45643 .84982 .44028 .83109 .41233 Metetra
.678 .73 .89 r
.83109 .41233 .84982 .44028 .89455 .4243 .87632 .39612 Metetra
.676 .731 .891 r
.87632 .39612 .89455 .4243 .93996 .40841 .92224 .37996 Metetra
.797 .702 .76 r
.30387 .67329 .32812 .7074 .36935 .65843 .34547 .62639 Metetra
.777 .709 .787 r
.34547 .62639 .36935 .65843 .40997 .61993 .38646 .5893 Metetra
.758 .714 .811 r
.38646 .5893 .40997 .61993 .4504 .58846 .42727 .55881 Metetra
.741 .718 .83 r
.42727 .55881 .4504 .58846 .49093 .5618 .46817 .53281 Metetra
.726 .721 .845 r
.46817 .53281 .49093 .5618 .53171 .53845 .50935 .50989 Metetra
.714 .723 .856 r
.50935 .50989 .53171 .53845 .57287 .51742 .55092 .4891 Metetra
.704 .724 .865 r
.55092 .4891 .57287 .51742 .61449 .498 .59295 .46981 Metetra
.697 .725 .872 r
.59295 .46981 .61449 .498 .65663 .47971 .63552 .45154 Metetra
.691 .727 .878 r
.63552 .45154 .65663 .47971 .69932 .46221 .67866 .43399 Metetra
.686 .728 .882 r
.67866 .43399 .69932 .46221 .74262 .44527 .72241 .41693 Metetra
.682 .728 .885 r
.72241 .41693 .74262 .44527 .78653 .42868 .7668 .40017 Metetra
.679 .729 .888 r
.7668 .40017 .78653 .42868 .83109 .41233 .81185 .38361 Metetra
.677 .73 .89 r
.81185 .38361 .83109 .41233 .87632 .39612 .85759 .36715 Metetra
.675 .73 .892 r
.85759 .36715 .87632 .39612 .92224 .37996 .90403 .35071 Metetra
.791 .7 .765 r
.27913 .63849 .30387 .67329 .34547 .62639 .32107 .59365 Metetra
.771 .707 .792 r
.32107 .59365 .34547 .62639 .38646 .5893 .36241 .55798 Metetra
.752 .713 .815 r
.36241 .55798 .38646 .5893 .42727 .55881 .40359 .52846 Metetra
.736 .716 .833 r
.40359 .52846 .42727 .55881 .46817 .53281 .44487 .50311 Metetra
.722 .719 .847 r
.44487 .50311 .46817 .53281 .50935 .50989 .48643 .4806 Metetra
.71 .721 .858 r
.48643 .4806 .50935 .50989 .55092 .4891 .5284 .46007 Metetra
.701 .723 .867 r
.5284 .46007 .55092 .4891 .59295 .46981 .57085 .44088 Metetra
.694 .725 .874 r
.57085 .44088 .59295 .46981 .63552 .45154 .61385 .42263 Metetra
.688 .726 .879 r
.61385 .42263 .63552 .45154 .67866 .43399 .65744 .40502 Metetra
.684 .727 .883 r
.65744 .40502 .67866 .43399 .72241 .41693 .70165 .38782 Metetra
.68 .728 .886 r
.70165 .38782 .72241 .41693 .7668 .40017 .74652 .37088 Metetra
.677 .728 .888 r
.74652 .37088 .7668 .40017 .81185 .38361 .79207 .35409 Metetra
.675 .729 .891 r
.79207 .35409 .81185 .38361 .85759 .36715 .83832 .33736 Metetra
.673 .73 .892 r
.83832 .33736 .85759 .36715 .90403 .35071 .8853 .32062 Metetra
.785 .699 .77 r
.25388 .60297 .27913 .63849 .32107 .59365 .29614 .56019 Metetra
.765 .706 .797 r
.29614 .56019 .32107 .59365 .36241 .55798 .33781 .52594 Metetra
.746 .711 .819 r
.33781 .52594 .36241 .55798 .40359 .52846 .37934 .49738 Metetra
.73 .715 .836 r
.37934 .49738 .40359 .52846 .44487 .50311 .42099 .47267 Metetra
.717 .718 .85 r
.42099 .47267 .44487 .50311 .48643 .4806 .46294 .45058 Metetra
.706 .72 .861 r
.46294 .45058 .48643 .4806 .5284 .46007 .5053 .43028 Metetra
.697 .722 .869 r
.5053 .43028 .5284 .46007 .57085 .44088 .54817 .4112 Metetra
.691 .724 .875 r
.54817 .4112 .57085 .44088 .61385 .42263 .5916 .39295 Metetra
.685 .725 .88 r
.5916 .39295 .61385 .42263 .65744 .40502 .63564 .37525 Metetra
.681 .726 .884 r
.63564 .37525 .65744 .40502 .70165 .38782 .68032 .3579 Metetra
.678 .727 .887 r
.68032 .3579 .70165 .38782 .74652 .37088 .72567 .34076 Metetra
.676 .728 .889 r
.72567 .34076 .74652 .37088 .79207 .35409 .77172 .32373 Metetra
.674 .729 .891 r
.77172 .32373 .79207 .35409 .83832 .33736 .8185 .30671 Metetra
.672 .729 .893 r
.8185 .30671 .83832 .33736 .8853 .32062 .86602 .28965 Metetra
.778 .698 .775 r
.22811 .56672 .25388 .60297 .29614 .56019 .27065 .52599 Metetra
.758 .705 .801 r
.27065 .52599 .29614 .56019 .33781 .52594 .31264 .49315 Metetra
.74 .71 .823 r
.31264 .49315 .33781 .52594 .37934 .49738 .3545 .46555 Metetra
.725 .714 .84 r
.3545 .46555 .37934 .49738 .42099 .47267 .39651 .44147 Metetra
.712 .717 .853 r
.39651 .44147 .42099 .47267 .46294 .45058 .43884 .41978 Metetra
.702 .719 .863 r
.43884 .41978 .46294 .45058 .5053 .43028 .4816 .3997 Metetra
.694 .721 .87 r
.4816 .3997 .5053 .43028 .54817 .4112 .52489 .38072 Metetra
.688 .722 .876 r
.52489 .38072 .54817 .4112 .5916 .39295 .56875 .36245 Metetra
.683 .724 .881 r
.56875 .36245 .5916 .39295 .63564 .37525 .61324 .34466 Metetra
.679 .725 .884 r
.61324 .34466 .63564 .37525 .68032 .3579 .65839 .32715 Metetra
.676 .726 .887 r
.65839 .32715 .68032 .3579 .72567 .34076 .70423 .3098 Metetra
.674 .727 .89 r
.70423 .3098 .72567 .34076 .77172 .32373 .7508 .29249 Metetra
.672 .728 .891 r
.7508 .29249 .77172 .32373 .8185 .30671 .7981 .27517 Metetra
.671 .729 .893 r
.7981 .27517 .8185 .30671 .86602 .28965 .84618 .25778 Metetra
.771 .696 .781 r
.2018 .52971 .22811 .56672 .27065 .52599 .24459 .49103 Metetra
.751 .703 .806 r
.24459 .49103 .27065 .52599 .31264 .49315 .28687 .45958 Metetra
.734 .708 .827 r
.28687 .45958 .31264 .49315 .3545 .46555 .32906 .43293 Metetra
.719 .712 .843 r
.32906 .43293 .3545 .46555 .39651 .44147 .37141 .40949 Metetra
.707 .715 .855 r
.37141 .40949 .39651 .44147 .43884 .41978 .41411 .38818 Metetra
.697 .718 .865 r
.41411 .38818 .43884 .41978 .4816 .3997 .45727 .36832 Metetra
.69 .72 .872 r
.45727 .36832 .4816 .3997 .52489 .38072 .50097 .34941 Metetra
.684 .721 .878 r
.50097 .34941 .52489 .38072 .56875 .36245 .54527 .33112 Metetra
.68 .723 .882 r
.54527 .33112 .56875 .36245 .61324 .34466 .59021 .31321 Metetra
.677 .724 .885 r
.59021 .31321 .61324 .34466 .65839 .32715 .63584 .29553 Metetra
.674 .725 .888 r
.63584 .29553 .65839 .32715 .70423 .3098 .68218 .27793 Metetra
.673 .727 .89 r
.68218 .27793 .70423 .3098 .7508 .29249 .72926 .26035 Metetra
.671 .727 .892 r
.72926 .26035 .7508 .29249 .7981 .27517 .77711 .24271 Metetra
.67 .728 .893 r
.77711 .24271 .7981 .27517 .84618 .25778 .82574 .22495 Metetra
.763 .695 .786 r
.17493 .49191 .2018 .52971 .24459 .49103 .21794 .45527 Metetra
.744 .701 .811 r
.21794 .45527 .24459 .49103 .28687 .45958 .26049 .42522 Metetra
.727 .706 .831 r
.26049 .42522 .28687 .45958 .32906 .43293 .30298 .39951 Metetra
.713 .71 .846 r
.30298 .39951 .32906 .43293 .37141 .40949 .34567 .37668 Metetra
.701 .714 .858 r
.34567 .37668 .37141 .40949 .41411 .38818 .38873 .35576 Metetra
.693 .716 .867 r
.38873 .35576 .41411 .38818 .45727 .36832 .43228 .33609 Metetra
.686 .718 .874 r
.43228 .33609 .45727 .36832 .50097 .34941 .47639 .31724 Metetra
.681 .72 .879 r
.47639 .31724 .50097 .34941 .54527 .33112 .52113 .29891 Metetra
.677 .722 .883 r
.52113 .29891 .54527 .33112 .59021 .31321 .56653 .28087 Metetra
.675 .723 .886 r
.56653 .28087 .59021 .31321 .63584 .29553 .61264 .26299 Metetra
.673 .725 .889 r
.61264 .26299 .63584 .29553 .68218 .27793 .65948 .24514 Metetra
.671 .726 .891 r
.65948 .24514 .68218 .27793 .72926 .26035 .70709 .22726 Metetra
.67 .727 .892 r
.70709 .22726 .72926 .26035 .77711 .24271 .75548 .20927 Metetra
.669 .728 .894 r
.75548 .20927 .77711 .24271 .82574 .22495 .80469 .19113 Metetra
.755 .693 .792 r
.14749 .45331 .17493 .49191 .21794 .45527 .19068 .41869 Metetra
.736 .699 .816 r
.19068 .41869 .21794 .45527 .26049 .42522 .23347 .39002 Metetra
.719 .704 .835 r
.23347 .39002 .26049 .42522 .30298 .39951 .27624 .36525 Metetra
.706 .708 .85 r
.27624 .36525 .30298 .39951 .34567 .37668 .31926 .34302 Metetra
.696 .712 .861 r
.31926 .34302 .34567 .37668 .38873 .35576 .36268 .32246 Metetra
.688 .715 .869 r
.36268 .32246 .38873 .35576 .43228 .33609 .40661 .30298 Metetra
.682 .717 .875 r
.40661 .30298 .43228 .33609 .47639 .31724 .45113 .28418 Metetra
.678 .719 .88 r
.45113 .28418 .47639 .31724 .52113 .29891 .49631 .26579 Metetra
.675 .721 .884 r
.49631 .26579 .52113 .29891 .56653 .28087 .54217 .2476 Metetra
.672 .723 .887 r
.54217 .2476 .56653 .28087 .61264 .26299 .58876 .2295 Metetra
.671 .724 .889 r
.58876 .2295 .61264 .26299 .65948 .24514 .63611 .21138 Metetra
.669 .725 .891 r
.63611 .21138 .65948 .24514 .70709 .22726 .68425 .19317 Metetra
.668 .726 .893 r
.68425 .19317 .70709 .22726 .75548 .20927 .7332 .17481 Metetra
.667 .727 .894 r
.7332 .17481 .75548 .20927 .80469 .19113 .78298 .15627 Metetra
.745 .69 .798 r
.11945 .41388 .14749 .45331 .19068 .41869 .16279 .38126 Metetra
.727 .697 .821 r
.16279 .38126 .19068 .41869 .23347 .39002 .20579 .35397 Metetra
.712 .702 .839 r
.20579 .35397 .23347 .39002 .27624 .36525 .24883 .33011 Metetra
.7 .707 .853 r
.24883 .33011 .27624 .36525 .31926 .34302 .29215 .30847 Metetra
.69 .71 .863 r
.29215 .30847 .31926 .34302 .36268 .32246 .33592 .28827 Metetra
.683 .713 .871 r
.33592 .28827 .36268 .32246 .40661 .30298 .38023 .26896 Metetra
.678 .716 .877 r
.38023 .26896 .40661 .30298 .45113 .28418 .42516 .25019 Metetra
.675 .718 .882 r
.42516 .25019 .45113 .28418 .49631 .26579 .47077 .23171 Metetra
.672 .72 .885 r
.47077 .23171 .49631 .26579 .54217 .2476 .51709 .21336 Metetra
.67 .722 .888 r
.51709 .21336 .54217 .2476 .58876 .2295 .56417 .19502 Metetra
.669 .723 .89 r
.56417 .19502 .58876 .2295 .63611 .21138 .61203 .1766 Metetra
.667 .725 .892 r
.61203 .1766 .63611 .21138 .68425 .19317 .66071 .15804 Metetra
.667 .726 .893 r
.66071 .15804 .68425 .19317 .7332 .17481 .71022 .13929 Metetra
.666 .727 .895 r
.71022 .13929 .7332 .17481 .78298 .15627 .7606 .12032 Metetra
.736 .688 .805 r
.09081 .37358 .11945 .41388 .16279 .38126 .13424 .34296 Metetra
.718 .694 .827 r
.13424 .34296 .16279 .38126 .20579 .35397 .17742 .31702 Metetra
.704 .7 .844 r
.17742 .31702 .20579 .35397 .24883 .33011 .2207 .29406 Metetra
.693 .704 .856 r
.2207 .29406 .24883 .33011 .29215 .30847 .26432 .27301 Metetra
.685 .708 .866 r
.26432 .27301 .29215 .30847 .33592 .28827 .30842 .25313 Metetra
.679 .712 .873 r
.30842 .25313 .33592 .28827 .38023 .26896 .35311 .23398 Metetra
.674 .714 .879 r
.35311 .23398 .38023 .26896 .42516 .25019 .39844 .21522 Metetra
.671 .717 .883 r
.39844 .21522 .42516 .25019 .47077 .23171 .44449 .19664 Metetra
.669 .719 .886 r
.44449 .19664 .47077 .23171 .51709 .21336 .49127 .1781 Metetra
.668 .721 .889 r
.49127 .1781 .51709 .21336 .56417 .19502 .53884 .1595 Metetra
.667 .722 .891 r
.53884 .1595 .56417 .19502 .61203 .1766 .58722 .14076 Metetra
.666 .724 .893 r
.58722 .14076 .61203 .1766 .66071 .15804 .63644 .12182 Metetra
.665 .725 .894 r
.63644 .12182 .66071 .15804 .71022 .13929 .68653 .10266 Metetra
.665 .726 .895 r
.68653 .10266 .71022 .13929 .7606 .12032 .73751 .08322 Metetra
.725 .685 .811 r
.06152 .33239 .09081 .37358 .13424 .34296 .10501 .30374 Metetra
.708 .692 .832 r
.10501 .30374 .13424 .34296 .17742 .31702 .14834 .27914 Metetra
.695 .697 .848 r
.14834 .27914 .17742 .31702 .2207 .29406 .19185 .25708 Metetra
.686 .702 .86 r
.19185 .25708 .2207 .29406 .26432 .27301 .23574 .23658 Metetra
.679 .706 .869 r
.23574 .23658 .26432 .27301 .30842 .25313 .28017 .21703 Metetra
.674 .71 .875 r
.28017 .21703 .30842 .25313 .35311 .23398 .32521 .198 Metetra
.67 .713 .88 r
.32521 .198 .35311 .23398 .39844 .21522 .37095 .17923 Metetra
.668 .716 .884 r
.37095 .17923 .39844 .21522 .44449 .19664 .41742 .16053 Metetra
.666 .718 .887 r
.41742 .16053 .44449 .19664 .49127 .1781 .46468 .14178 Metetra
.665 .72 .89 r
.46468 .14178 .49127 .1781 .53884 .1595 .51274 .12289 Metetra
.665 .722 .892 r
.51274 .12289 .53884 .1595 .58722 .14076 .56164 .1038 Metetra
.664 .723 .893 r
.56164 .1038 .58722 .14076 .63644 .12182 .61142 .08447 Metetra
.664 .725 .894 r
.61142 .08447 .63644 .12182 .68653 .10266 .66208 .06485 Metetra
.664 .726 .895 r
.66208 .06485 .68653 .10266 .73751 .08322 .71367 .04493 Metetra
.713 .681 .818 r
.03159 .29028 .06152 .33239 .10501 .30374 .07509 .26359 Metetra
.698 .688 .837 r
.07509 .26359 .10501 .30374 .14834 .27914 .11853 .24031 Metetra
.686 .695 .852 r
.11853 .24031 .14834 .27914 .19185 .25708 .16222 .21911 Metetra
.678 .7 .863 r
.16222 .21911 .19185 .25708 .23574 .23658 .20638 .19916 Metetra
.672 .704 .871 r
.20638 .19916 .23574 .23658 .28017 .21703 .25111 .1799 Metetra
.669 .708 .877 r
.25111 .1799 .28017 .21703 .32521 .198 .29651 .16098 Metetra
.666 .712 .882 r
.29651 .16098 .32521 .198 .37095 .17923 .34265 .14218 Metetra
.665 .715 .886 r
.34265 .14218 .37095 .17923 .41742 .16053 .38955 .12334 Metetra
.664 .717 .888 r
.38955 .12334 .41742 .16053 .46468 .14178 .43727 .10435 Metetra
.663 .719 .89 r
.43727 .10435 .46468 .14178 .51274 .12289 .48583 .08515 Metetra
.663 .721 .892 r
.48583 .08515 .51274 .12289 .56164 .1038 .53526 .06568 Metetra
.662 .723 .894 r
.53526 .06568 .56164 .1038 .61142 .08447 .58559 .04592 Metetra
.662 .724 .895 r
.58559 .04592 .61142 .08447 .66208 .06485 .63684 .02583 Metetra
.662 .725 .896 r
.63684 .02583 .66208 .06485 .71367 .04493 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(0.05)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0.1)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.15)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -115.005 -29.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 33.75 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 29.750000 moveto
 460.000000 29.750000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 29.750000 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Yield) show
99.000000 12.812500 moveto
(to) show
63.000000 26.000000 moveto
(maturity) show
117.000000 26.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[17]:=",
  ImageSize->{258, 209.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000dA000`40O003h00Oogoo0goo003oOol3
Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00
ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3
Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00
ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3
Ool00?moo`=oo`00ogoo0goo001FOol2002ZOol005Moo`03001oogoo045oo`03001oogoo009oo`04
001oogooOol3001KOol0039oo`06001oo`00Ool007oo10000Woo0P000goo0`0000Aoo`000000009o
o`<000=oo`8000=oo`03001oogoo041oo`03001oo`0000Moo`03001oogoo05]oo`00<Woo00H007oo
001oo`00Ool30002Ool01P00Oomoo`00Ool0009oo`04001oogoo0004Ool01@00Oomoogoo00000Woo
00D007oo001oo`00045oo`03001oo`0000Qoo`03001oogoo05Yoo`00<Woo00D007oo001oo`0000=o
o`04001oogoo0004Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
o`00045oo`03001oo`0000Qoo`03001oogoo05Yoo`00<Woo0P0000=oo`00Ool00Woo0P0000=oo`00
00000P0000Aoo`00001oo`800003Ool0000000800003Ool00000009oo`@00004Ool00000Ool20010
Ool00`00Ool00007Ool00`00Ool0001KOol003eoo`03001oogoo015oo`03001oogoo04Moo`03001o
ogoo00Moo`03001oogoo00=oo`03001oogoo05Aoo`00CGoo00<007ooOol0FWoo00<007oo0000EGoo
002ZOol00`00Ool0001EOol00:Yoo`03001oo`0005Eoo`00ZWoo00<007oo0000EGoo002VOol20003
Ool00`00Oomoo`1DOol007Uoo`03001oogoo009oo`03001oogoo00D0009oo`03001oogoo01Uoo`D0
05Uoo`00N7oo00<007oo000027oo00L007ooOomoo`00Ool0000GOol500000e;K0000001IOol007Qo
o`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo019oo`D00004D]]Fo5;KD]`3001HOol003=o
o`<0009oo`<000=oo`80009oo`<000=oo`<000eoo`8000=oo`8001Uoo`03001oo`0000Qoo`04001o
ogooOol2000BOol500001E;KD]aBg5;LD]/00U;L00@005;K000005Moo`00=7oo00<007ooOol00Woo
00D007ooOomoo`0000Eoo`05001oogooOol00002Ool00`00Oomoo`0:Ool01P00Oomoo`00Ool0009o
o`03001oogoo01Ioo`03001oo`0000Qoo`05001oogooOol0000AOol400003U;KE_`005;LD]]Fo5;K
D]aBfeKl001Bg5;K001GOol003Aoo`03001oogoo009oo`04001oogooOol30003Ool01@00Oomoogoo
00000Woo00<007ooOol02Woo00<007ooOol00Woo00@007ooOol001Uoo`03001oogoo00Ioo`8000=o
o`<000eoo`@000=Bg005D]]Bg000D]aBf`03D]`015;K001Bg5;L0P00EWoo000cOol00`00Ool00002
Ool20003Ool30003Ool00`00Oomoo`02Ool3000;Ool40003Ool2000eOol400004UKlD]]Bg5;KE_aB
fe;LD]]Fo000D]aBfeKlD]]Bg000E_aBf`<005Eoo`00<Woo00D007ooOomoo`0000aoo`03001oogoo
00Aoo`03001oogoo00Yoo`03001oogoo03Moo`D00003D]/005;K00=Bg006D]]Bg5;LD]aBf`000U;L
00=Bfe;LD]`00`000U;L00<007ooOol0Dgoo000bOol200000goo00000002Ool00`00Oomoo`06Ool2
0005Ool20014Ool2000057oo000005;LD]]Fo000D]aBfeKlD]]Bg5;KE_aBfe;LD]/005;KD]`30000
15;LD]]Fo5;K0P00E7oo002<Ool3000037oo000005;KD]aBfe;LD]]Bg000D]aBf`=Bg004D]]Bg5;L
D]`300001U;LD]]Bg000D]aBf`9Bg08005=oo`00RGoo0`0001Aoo`00000005KlD]]Bg5;KE_aBfe;L
D]/005;KD]aBfeKlD]]Bg5;K0P0000eBg5;K001Bfe;LD]/005;KD]aBfeKlD]/0001COol0065oo`03
001oogoo009oo`03001oogoo00D001Uoo`80000AOol00000001Bg5;K001Bfe;LD]]Bg5;KD]aBfe;L
D]/00002D]`02E;KD]`00000D]]Bg5;KD]`00003D]`01P00D]aBg5;LD]]Bg080059oo`00H7oo00<0
07oo000027oo00<007ooOol05Woo0`0001Eoo`00000005;KD]aBfeKL001Bg5;KE_aBfe;LD]]Fo5;K
D]`005KlD]/00P00015Fo5;KD]aBfeKlD]]Bg000E_aBf`00D]]Fo5;KD]aBfeKl0080055oo`00H7oo
00<007oo000027oo00<007ooOol057oo0P0001Eoo`00000005;KD]aBfe;LD]]Bg5;KD]`005;LD]]B
g5;KD]aBfe;LD]/00`0000mBfe;LD]]Bg5;KD]aBfe;LD]/005;KD]`005;LD]/00U;L0P0000=Bg000
Ool0D7oo001POol00`00Ool00008Ool00`00Oomoo`0AOol300005Goo000005;KD]`005KLD]]Bg5;K
E]aBfe;LD]]Fg000D]aBfeKlD]]Bg00200004U;KD]`005KlD]]Bg5;KE_aBfe;LD]]Fo5;K001Bf`00
D]]Bg0800003D]]Fg5;K008000Ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo03Qoo`00H7oo00<007oo000027oo00<007ooOol03Woo1`00015Bg5;KD]]Bf`00D]]Bg5;K
D]aBfe;LD]]Bg5;K001Bfe;L00<0000AD]aBfe;LD]/005;KD]aBfe;LD]]Bg5;KD]aBfe;L001Bg003
00000e;LD]]Bg002D]`00e;K00000004Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool0000i
Ool0065oo`03001oogoo00Ioo`8000ioo`80000EOol00000001Bg5;KE]aBfe;LD]]Fg5;K001BfeKL
D]]Bg5;KE]aBfe;L00<0000BD]aBfeKlD]]Bg5;KE_aBf`00D]]Fo5;KD]aBfeKlD]]Bg5;K0`0000YB
feKlD]]Fg5;KE_aBfeKLD]/000Aoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo03Moo`00
Mgoo1P0000EBg5;K001Bfe;L00=Bf`0:D]aBfe;KD]/005;KD]aBfe;LD]/200004U;LD]/005;KD]aB
fe;LD]]Bg5;KD]aBf`00D]]Bg5;KD]aBf`<00005D]]Bg000D]aBf`03D]`015;KD]aBg5;L0P000goo
00<007oo00001goo00<007oo00000Woo0P00>Woo001eOol200005Goo00000000D[]Fg5;KD]`005KL
D]]Bg5;KE]aBfe;LD]]Fg000D]aBf`0300004E;KE]aBfeKL001Fo5;KD]aBfeKlD]]Bg5;KE_`005;L
D]/00`0000mBfeKlD]]Fg5;K001BfeKLD]]Fo5;KE]aBfeKlD]/00P000goo00<007oo00001goo00<0
07oo00000Woo00<007ooOol0>Goo001bOol60003D]/01U;LD]]Bfe;KD]`0009Bf`06D]aBfe;KD]]B
g5;K0`00015Bfe;LD]]Bg5;KD]aBfe;L001Bg5;KD]aBfe;LD]]Bg5;K00<00008D]]Bg5;KD]aBfe;L
D]]Bg080009Bg004D]]Bg5;LD]`20002D]`01@00Oomoogoo00002Goo00@007ooOomoo`<003Uoo`00
Kgoo0`0001Eoo`00001B^eKL001Bg5:kE]aBfe;LD[]Fg5;KD]`005KLD]]Bg5;KE]`00P00019BfeKL
001Fg5;KE]aBfeKLD]]Fg5;KE]`005KlD]]Bg5;KE_`200002e;KE_`005KLD]]Fo5;KE]aBfeKlD]/0
0P0000AFo5;KE]aBf`800004E_aBfeKlD]/2001<Ool0049oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo01Uoo`800004Ool000000005D]/00`00D]aBf`02D]/01E;LD]]B
fe;K00000U;K0`000U;K00mBg5;K001Bfe;LD]]Bg5;KD]aBfe;LD]/005;KD]`00`00015Bg5;KD]aB
f`00D]]Bg5;KD]aBfe;LD]]Bg000D]`005;L00800005D]]Bg5;LD]aBf`02D]`00`00Oomoo`1:Ool0
045oo`03001oo`0000Moo`03001oo`00009oo`03001oo`0001Moo`H0000AE]aBfeKLD[]Fg5;KE]aB
^eKL001Bg5:kE]aBfe;LD[]Fg00300004EKLD]]Fg5;KE]aBfeKLD]/005;KE]aBfeKLD]]Fg5;KE]`0
0`00011Fo5;KE]aBfeKlD]]Fg5;K001BfeKLD]]Fo5;KE]aBf`@00009E_aBfeKlD]]Fo5;KE_aBfeKl
008004]oo`00@Goo00<007oo00001goo00<007oo000017oo00<007ooOol04goo1@000U;K00<005;K
D]/01e;K00<005;KD]`00e;K0P000U;K00D005;KD]]Bfe;L00=Bf`08D]aBf`00D]]Bg5;KD]aBf`80
000BD]aBf`00D]]Bg5;KD]aBfe;LD]]Bg5;K001Bfe;LD]]Bg5;K0P0000ABg5;K001Bf`=Bg006D]]B
g5;LD]aBfe;L0P00BWoo0011Ool00`00Ool00007Ool00`00Ool00002Ool2000COol300005Goo0000
05:kE]]B^eKLD[/005:kE]aBfeKLD[]Fg5;KE]aB^`00D]]Bg00200004E;KE]aB^eKLD]/005;KE]aB
feKLD]]Fg5;KE]`005KLD]/00`00015BfeKLD]]Fg000E]aBfeKlD]]Fg5;KE_aBfeKL001Fo5;K00<0
000>D]/005;KE_aBf`00D]]Fo5;KE_aBfeKlD]]Fo0<004Yoo`00@Goo00<007oo00001goo00<007oo
00000Woo00<007ooOol03goo0`0000Aoo`00000000QBf`03001Bfe;K00IBf`<00005D]aBfe;KD]]B
g003D]/01@00D]]Bfe;KD]`00e;K0`00015Bfe;LD]]Bg5;KD]aBfe;L001Bg5;KD]aBfe;LD]]Bg5;K
00<0000;D]]Bg5;KD]`005;LD]]Bg000D]aBf`03D]`01E;K000005;LD]/00P00BGoo0012Ool00`00
Oomoo`07Ool01000Oomoogoo0`003Goo0P000Woo0P00019Ffe:k001B^eKKD[]Fg5:kE]]B^eKL001F
g5:kE]aBfeKLD[/200004EKLD[/005;KE]aB^eKLD]]Fg5:kE]`005KLD]]Fg5;KE]`00P00019BfeKL
001Fg5;KE]aBfeKLD]]Fg5;KE]`005KLD]]Fo5;KE]`200003e;KE]`005KlD]]Fg5;K001BfeKLD]]F
o000E_aBf`0300001e;KE_aBfeKl001oo`0004Qoo`00GGoo0`0000Eoo`00000005:k009Bf`03E]]B
^`0000QBf`03001Bfe;K00<000=Bf`05E]/005;KD]]Bg003D]/01U;LD]]Bf`00D]aBf`80000AE]aB
fe;KD]]Fg000D]aBfe;LD]]Bg5;KD]aBf`00D]]Bg00300003U;LD]]Bg5;KD]`005;LD]]Bg000D]aB
fe;LD]/3000025;KD]aBfe;LD]]Bg5;KD]`20018Ool005]oo`80000EOol00000001B^eKKD[]Ffe:k
E]]B^eKKD[/005:kE]]B^eKLD[]Ffe:k00<0000AD[]Fg5;KE]aB^eKLD]]Fg000E]aBfeKLD[]Fg5;K
E]aB^`03000045;KE]aBfeKLD]]Fg5;KE]`005KLD]]Fg5;KE]aBfeKL0`0000mFg5;KE_aBfeKLD]]F
o5;K001BfeKlD]/005;KE_`00P0000aBfeKl001Fo5;KE_aBfeKlD]]Fo5;KE_`2000_Ool3000EOol0
05Qoo`<00008Ool00000D[]Ff`00E]]B^`9Bf`06E]]B^e;KD]]Ff`001E;K0P000U;K00<005KKD]/0
0U;K00IFfe;KD]]BfeKK0002D]/00e;LD]]Bf`020002D]/00`00E]aBf`02D]/02UKLD]]Bfe;K001B
fe;LD]]Bg5;K0P0000mFg5;K001Bfe;LD]]Bg5;KD]aBfe;LD]/005;KD]`00`00015Bg5;KE]aBf`00
D]]Bg5;KD]aBfe;LD]]Bg5;K001oo`0002moo`03001oogoo01Aoo`00EGoo0`000Woo0P00019Ffe:j
E]]B^UKK001Ffe:kE]]B^eKKD[]Ffe:kE]/005KLD[/200004EKLD[]Ffe:kE]`005KLD[]Fg5;KE]aB
^eKLD]/005:kE]`00`00015Fg5;KE]aBf`00D]]Fg5;KE]aBfeKLD]]Fg5;K001BfeKL0080000>D]]F
o5;KE]aBf`00D]]Fg5;KE_aBfeKLD]]Fo0<0000AE_`005KLD]]Fo5;KE]aBf`00D]]Fo5;KE_aBfeKl
D]]Fo003000QOol20003Ool20003Ool3000017oo000000000goo0P0000=oo`0000000Woo00<007oo
Ool01goo000hOol00`00Oomoo`0HOol30002Ool200002e:kE]]B^eKKD[]Ffe:kE]/005KKD[/00U;K
00AFfe:kD]]Bf`<00003D]]Ffe;K009Bf`05E]]Bfe;K001Ff`03D]/00eKKD]]Bf`030002D]/02EKK
D]]Bfe;KE]]Bf`00D]]Fg003D]/00eKLD]]Bf`030002D]/035KLD]]Bfe;KE]`005;LD]]Bg5;KD]aB
f`80000BD]aBf`00D]/005;KE]aBfe;LD]]Fg5;K001Bfe;LD]]Bg5;K0P0000ABg5;K000001moo`03
001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<007oo00000Woo00<007oo0000
0Woo00<007ooOol01goo000gOol00`00Ool0000FOol30002Ool300004EKK001Ffe:jE]]B^UKKD[YF
fe:j001B^eKKD[]Ffe:kE]/00P00015B^eKK001Fg5:kE]]B^eKLD[]Ffe:k001BfeKLD[]Fg5;K0080
000BE]aBf`00D]]Fg5;KE]aBfeKLD]]Fg5;K001BfeKLD]]Fg5;K0P0000iFg5;K001BfeKlD]]Fg5;K
E_aBfeKL001Fo5;K0`00015BfeKLD]]Fo000E]`005KlD]]Fg5;KE_aBfeKL001Fo5;K00<00007D]]F
o5;KE_`007oo00007Woo00<007ooOol00Woo00H007ooOol007oo0002Ool00`00Ool00002Ool00`00
Ool00002Ool00`00Ool00002Ool00`00Oomoo`07Ool003Moo`03001oo`0001=oo`@000=oo`80000@
D[YF^eJjE]/005KKD[]Ffe:kE]]B^eKKD[/005;KE]/300001EKKD[]Ffe;K00000e;K00UFfe;KD]]B
feKKD]/005;KE]/00P0000IBfeKKD]]Bf`00E]/3D]/01UKKD]]Bfe;KE]/0009Bf`<00003D]]Fg5;K
009Bf`05001Bfe;KD]]Fg003D]/3000025;KE]aBfe;LD]]Fg5;KD]`200001e;KD]aBfeKLD]]Bg5;K
00<00008D]]Fg5;KD]aBfeKLD]]Bg08000Ioo`03001oogoo009oo`03001oogoo00D000]oo`03001o
ogoo00=oo`800004Ool00000Ool60003Ool200000goo00000002000:Ool003Moo`03001oo`00015o
o`8000Eoo`80000?E]]B^UKKD[YFfe:jE]/005KKD[YFfe:jE]]B^UKK00<0000AE]]B^UKKD[]Ffe:j
E]]B^`00D[]Fg5:kE]]B^eKLD[]Ff`03000045KLD[]Fg5;KE]aB^eKL001Fg5;KE]aBfeKLD]]Fg5;K
0`0000iBfeKLD]]Fg5;KE]aBfeKL001Fg5;KE_aBfeKL0P00019BfeKL001Fo5;KE]aBfeKlD]]Fg5;K
E_`005KLD]]Fo5;KE]`200002e;KE_`005KlD]]Fo5;KE_aBfeKlD]/00`0017oo00<007oo000027oo
00<007ooOol02goo00<007oo00008goo000gOol00`00Ool0000>Ool40004Ool200003eJjE]]B^UJk
E[YFfe:jE[]F^P00D[]Ffe:kE]]B^`0200003EKKD[/005;KE]]B^eKKD]]Ffe:kE]]Bf`0000=Bf`09
E]]Bf`00001Ffe;K001BfeKK00=Bf`05E]]Bfe;K001Ff`03D]/01UKK000005;KE]/0009Bf`05E]aB
fe;KD]]Fg002D]/00`00E]aBf`0200004EKLD]]Bfe;K001Bfe;LD]]Fg5;KD]aBfeKLD]/005;KE]`0
0`00015Fg5;KD]aBf`00D]]Bg5;KE]aBfe;LD]]Fg5;K001oo`0000=oo`03001oo`0000Qoo`03001o
ogoo00]oo`<002=oo`00>7oo00<007ooOol02goo0P001Woo0P0000mF^e:j001B^UKKD[YFfe:jE]]B
^UKKD[X005:jE]/00P00015B^UKKD[YFfe:j001B^eKKD[YFfe:kE]]B^UKK001Ffe:k00<0000@D[]F
g5:kE]/005KLD]]Fg5:kE]aBfeKLD[/005;KE]`300003UKLD]]Fg5;KE]`005KLD]]Fg5;KE]aBfeKL
D]/3000045;KE_aBfeKLD]]Fo5;K001BfeKlD]]Fg5;KE_aBfeKL0`00011Fo5;KE_aBfeKlD]]Fo5;K
001BfeKlD]]Fo5;KE_aBf`800003Ool007oo009oo`03001oo`0000Qoo`03001oogoo035oo`00@goo
10001Goo0P001EJj00X005JjE]]B^UJkE[YFfe:jE[]F^P80000@E]]F^eKKD[]FfeJkE]]B^`00D]]F
fe:kE]]BfeKKD[/300002E;KE]]BfeKKD]]Ffe;KE]/00002D]/01EKKD]]Bfe;KE]/00`0000UFfe;K
E]]BfeKKD]]Ffe;K00000e;K00=Fg5;KD]/00P0000ABfeKK001Fg0=Bf`0:E]aBfe;KD]/005;KD]aB
feKLD]/300003U;K001BfeKLD]]Bg5;KE]aBfe;L001Fg5;KD]`400001E;KE]`007oo00000Woo00<0
07oo000027oo00<007ooOol0<Goo0010Ool30007Ool200003eKKE[YF^e:jE]]F^UJkD[X005:jE]]B
^UKKD[YFf`02000045Jj001B^UKKD[YFfe:jE]]B^UKK001Ffe:kE]]B^UKK0P00015B^UKK001Ffe:k
E]aB^eKKD[]Fg5:kE]/005KLD]]Fg5:k0080000?E]]B^`00D]]Fg5;KE]aBfeKLD]]Fg5;K001BfeKL
00<0000@E_aBfeKLD]/005;KE]aBfeKlD]]Fg5;KE_`005KLD]/300003E;KE_`005KLD]/005;KE_aB
feKlD]]Fo5;K00@00007E_aBfeKlD]]Fo5;KE_`00`000Woo00<007ooOol01Woo0P00<goo000nOol2
00000goo00000005Ool200000eJj001F^P07E[X01@00E[]F^UKKD[X00P00011FfeJjE[]F^P00D[]F
feJkE]]B^eKKE[]Ff`00E]]Bf`8000=Ff`0<D]]Ff`00E]]BfeKKD]]Ffe;KE]]Bf`000U;K0P0000iB
feKKD]]Ffe;K001BfeKKD]]Ffe;KE]]BfeKK0`0000]Ffe;KE]aBfeKKD]]Fg5;K001BfeKL00=Bf`03
E]aBf`0000800004D]]Bg5;KE]`2000025;KE]`005;LD]]Fg5;KD]`200003U;KD]`005KLD]]Bg5;K
E]aBfe;LD]/007oo0010Ool003aoo`8000Qoo`80000?F[YF^EZjE[T005:jE]]F^UJkD[YFfeJjE[/0
05KK0080000?D[YFfeJjE]]B^UKKE[X005:jE]]B^UKKD[YFfe:j00<0000@D[]Ffe:jE]]B^eKKD[YF
f`00E]]B^eKLD[]Ffe:kE]`300003UKLD]]Ffe:kE]aBfeKKD[/005;KE]aBfeKLD]/200004EKLD]/0
05;KE_aBfeKLD]]Fo5;KE]aBf`00D]]Fg5;KE_`00P0000ABfeKl001Fg0<00008E]aBf`00D]]Fg000
E_aBf`80000AE_aBfeKlD]/005;KE_aBfeKlD]]Fo5;KE_aBf`00Ool0000oOol003aoo`8000Ioo`80
00MF^P03001F^UJj00EF^P80000?E[]F^UKKE[YF^eJjE]]F^UJk001Ffe:kE]]F^eKK0080009Ff`05
001FfeKKE]]Bf`03E]/01e;K001BfeKKD]]Ffe;K0080009Ff`0=001BfeKKD]]Ffe;KE]]BfeKKD]/0
05;KE]/00P0000mBfeKKD]]Ff`00E]aBfeKKD]]Fg5;KE]]BfeKL00000U;K0P0000=Ffe;KE]`00`00
00QFg5;KD]aBfeKL001Bg5;K0`00011BfeKLD]]Bg5;KE]aBf`00D]]Fg5;KD]aBfeKLD]]Bg0@003io
o`00=goo00<007ooOol00Woo00<007oo000017oo010005ZjE[UJ^UJiF[YF^EZjE[UJ^P00E[]B^UKK
E[YF^`80000?E[YFfP00E]]F^UKKD[YFfeJjE]]B^UKK001Ffe:j0080000AE]]B^UKKE[X005:jE]]B
^eKKD[YFfe:kE]]B^P00D[]Ff`0200003U;KE]]B^eKKD]/005:kE]aBfeKKD[]Fg5;KE]/3000045KL
D]]Fg5;KE]aBfeKL001Fg5;KE_aBfeKLD]]Fo5;K0`0000=BfeKL00000P0000UFg5;K001BfeKLD]]F
o5;KE]`00P00015BfeKl001Fo5;KE_aBfeKlD]]Fo5;K001BfeKlD]]Fo5;K00800004E_aBf`00000n
Ool003Ioo`03001oo`0000=oo`05001oogoo001oo`0200000eZi001F^P08E[X00`00E[YF^P020004
E[X02`00E[YF^eJjE]]F^UJkE[YFfeJjE[/00P0000EF^UKKE]]FfeJj009Ff`03001BfeKK009Ff`04
D]]FfeKKE]/300000eKKD]]Ff`02E]/02E;KE]/005KKD]]Ffe;KE]]Bf`0200004EKKD]/005;KE]]B
feKKD]]Ffe;KE]/005KLD]]Ffe;KE]`00P0000=BfeKK00000P0000UFg5;KE]]BfeKLD]/005;KE]`0
0`00011Fg000E]]Bf`00D]]Bg5;KE]aBfe;LD]]Fg000D]aBf`<00007D]]Fg5;KD]`007oo0000?Goo
000fOol00`00Ool00002Ool300004Goo000005JIF[YFVEZi001J^UJiF[YF^EZjE[UJ^UJiF[X00P00
00mF^U[KE[YFfUJjF]]F^P00D[YFfeJjE]]B^UKKE[X00P00011Jf`00E]]B^UKKE[YFfe:jE]]F^P00
D[YFfe:kE]]B^P80000>E]]B^P00D]]Ffe:kE]]BfeKKD[]Ff`00E]]B^`<0000@D]]Fg5;KE]/005KL
D]]Fg5;KE]aBfeKLD]/005;KE]`300000eKLD]/00002000025;KE_aBfeKLD]]Fo5;KE]`3000045Kl
D]]Fo5;KE_`005KlD]/005;KE_aBfeKlD]]Fo5;K0`0000]BfeKlD]]Fo5;KE_aBfeKl001oo`0003ao
o`00=Woo00<007oo00000Woo00@007oo000000MJ^@03001F^UJj00AF^P800003F[X005Jj00MF^P05
001F^UJkE[YFf`02000015JjE]]F^P000UKK00UF^UKKE]]FfeJjE]/005KKD]/00`001EKK00@005KK
E]]Bf`=Ff`05D]/00000001Bf`03E]/035;KE]]FfeKK001Ffe;KE]]BfeKKD]]Ff`<00003E]]Bf`00
00800009D]]Ffe;K001BfeKKD]]Fg5;K0080000AE]aBf`00D]]Fg5;KE]]Bf`00D]]Ff`00E]aBfe;L
D]]Fg00200002e;KE]`005;LD]]Fg5;KD]aBfeKLD]/00`00?7oo000fOol00`00Ool00002Ool20000
3UJIF[UFVEZjEYUJ^EJIF[YFV@00E[UJ^UJiF[X200003eJiF[YF^@00E[YFfUJjF]]F^UKJE[YJf`00
E]]B^P0200003UKKE[YJfeJjE]]F^P00E[YFfe:jE]]F^UKKD[X300003U:jE]]B^UKKD[YFfe:jE]/0
05KKD]]Ffe:kE]/200004E:jE]/005KKD]]Fg5;KE]]BfeKLD]]Ff`00E]aBfeKLD]/00P0000=Fg5;K
00000P0000UBfeKlD]]Fg5;KE_`005KLD]/00`00011BfeKlD]]Fg000E_aBfeKlD]]Fo5;K001BfeKl
001Fo0<0000=E_aBfeKlD]/005;KE_aBfeKlD]]Fo5;KE_`00P0000=oo`00Ool0>Woo000gOol01`00
Oomoogoo001oo`0000UJ^@0;001F^P00001J^UJiF[YJ^EZjE[T00008E[X200002UJjE]YF^UKKE[YF
fUJjE]]F^P000UKK00MF^UKK000005JjE]/00009E]/00`00E]]Ff`020004E]/01000E]]Ffe;K0eKK
00IBfeKKE]/005;KE]/200003E;K00000000D]/005;KE]]BfeKKD]]Ffe;K00<0000?D]]Ffe;KE]aB
feKKD]]Fg000E]]BfeKLD]]Ffe;K00@0000>E]aBfeKLD]]Fg5;KE]aBf`00D]]Bg5;KE]aBf`800005
E]aBf`00Ool0000jOol003]oo`<0000JF[YFVEZiEYUJ^UJIF[UFVEZjEYT005JiF]YF^EZjE[UJfUJi
F[X005[KE[YFfUJjF]]F^P80000>F]X005KKE[YJfeJjE]]F^U[KE[YFf`00E]]F^P80000>E]]F^UKK
E[YFf`00E]]B^UKKD[YFfe:jE]]B^P<0000@D]]Ffe:jE]]BfeKKD[X005;KE]]BfeKLD]]Ffe;KE]`6
00002U;KE]aBfeKL001Fo5;KE]aBfeKl0P0000mBfeKl001Fg5;KE_aBfeKLD]]Fo5;K001BfeKlD]/0
1@0000eBf`00D]]Fo5;KE_aBfeKlD]]Fo000E_aBf`03000015;KE_aBfeKl0`00>Woo000kOol01000
Oomoo`001eZi0P0000]J^@00E[UJ^UZiF[YF^EZjF[UJ^P0000=F^P80000>E[YJfUJjF[X005KKE[YF
fUJjE]]F^UKJE[YFf`800009E]YFfeJjE]]FfUKKE[YFf`0000EFf`80009Ff`03001FfeKK00IFf`04
001FfeKKD]/2E]/500001E;KE]]FfeKKD]/00eKK00<005KKD]/00P000eKK00YBfeKK001Fg5;KE]]B
feKLD]]Ff`@0000?D]]Fg5;KE]/005KLD]/005;KE]aBfeKLD]]Fg5;K00<0000;D]]Fg5;KE]aBfeKL
D]]Fg000Ool0000iOol003Yoo`0J001oogooOol005JIF[YFVEZiEYUJ^P00F[UJV5ji001J^UJiF]YF
^EZjE[UJfUJi001F^P80000>F]YF^U[JE[YJfUJjF]X005KKE[YJfeJjE]]F^P80000>F]/005KKE[YF
feJjE]]F^UKKE[YFf`00E]]B^P80000@E]]F^UKKE]X005:jE]]BfeKKD[YFfe;KE]/005KLD]/50000
2e;KE]aBf`00D]]Fg5;KE]aBfeKLD]/00`0000eBfeKLD]]Fo5;KE]aBf`00D]]Fg5;KE_aBf`020000
4EKlD]/005;KE_aBfeKlD]]Fo000E_`005KlD]]Fo5;KE_`00P0000aBfeKl001Fo5;KE_aBfeKlD]]F
o5;K0002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`050002Ool00`00Oomoo`0QOol0
03Yoo`<0009oo`04001J^EZiF[T20005F[T06000F[YF^EZjF[UJ^UJiF[YJ^@00E[YJ^UJjF]YF^UZj
E[YJfUJj001F^UKKE[YFfP80000>E[YFfUJjF]X005KKE]YFfeJjE]]FfUKKE[YFf`8000MFf`03001F
feKK00EFf`D000IFf`03001Ffe;K00=Ff`80009Ff`05001FfeKKE]]Bf`03E]/015;K001BfeKL0P00
00=FfeKLD]/00UKK00`005;KE]]BfeKLD]]Ff`00E]`005KLD]/200003EKLD]]Fg5;K001BfeKLD]]F
g5;KE]aBfeKL00@000Aoo`03001oo`0000Qoo`07001oogooOol007oo00008Woo000[Ool30003Ool0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00@005Zi0000009J^@0<FYQN^EZiF[UJV000E[UJ^UJi
F]YF^EZj0P0000eJ^@00E[YJfUJjF]YF^U[JE[YJfUJj001F^P0200003U[KE[YJfeJjF]]F^U[K001F
feJjE]]F^UKKE[X200003e[K001FfeJjE]]FfUKKE[YFfeKJ001B^UKKD]]Ff`05000035KLD]]Ffe;K
E]aBfeKKD]]Fg000E]aBf`80000=E]]BfeKlD]]Ff`00E_aBfeKLD]]Fo5;KE]`00`0000mFg5;KE_aB
feKLD]]Fo000E_aBfeKlD]]Fo5;KE_`0100000eBfeKlD]]Fo5;KE_aBf`00D]]Fo5;KE_aBf`020000
1EKlD]/007oo00000goo00<007oo000027oo00<007ooOol00goo00<007ooOol087oo000[Ool00`00
Oomoo`02Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00F[UJ^@08F[T01000
F[UJ^UJi0P0001eJ^UZiF[UJ^@00E[YJ^UJjF]YF^UZjE[YJfUJj001F^U[JE[YFfUJjF]YF^UKJE[X0
05JjE]]FfUKK00800004E]YFfeKJ0008E]/00`00E]]Ff`040003E]/00`00E]]Ff`06E]/30007E]/0
0`00D]]Ff`02E]/02E;K000005KKD]/005KKE]aBf`02E]/01eKLD]]Ff`00E]aBfeKK00@0000=E]]F
g000E]aBfeKLD]]Fg5;KE]`005KLD]/00`0000MBfeKLD]]Fg000Ool00003Ool00`00Ool00008Ool0
1000Oomoogoo0P008goo000/Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`8000Eoo`04
001J^EZHG[T2F[T01UZHG[UJ^EZi001JfP80000>E[UJfUZiF[YF^E[JF[T005JjF]YF^U[JE[YJfP80
000=E[T005JjF]]F^U[KE[YJfeJjF]]F^P00E[X00P0000iJfeJjF]]F^U[KE[X005KJE]]F^UKKE]YF
feJj10000eKK00YB^UKKE]/005;KE]aBfeKKD]]Fg080000>D]]Ff`00E]]BfeKlD]]Ffe;KE_aBf`00
D]]Fo080000=D]]Fo5;KE]aBf`00D]]Fg5;KE_aBfeKLD]/0100000iFo5;KE_aBf`00D]/005;KE_aB
feKlD]]Fo5;K0`0000QBfeKlD]]Fo5;KE_aBfeKl0`000Woo00<007oo000027oo00D007ooOomoo`00
02Aoo`00;7oo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`04Ool00`00F[UJ
^@08F[T01000F[UJ^EZj0eZi00QJ^UZiF[T005[JE[YJ^UJj0P000UZj00]JfUZj001F^U[JE[YFfUJj
F]YF^UKJ0080000:E]YFfeKJE]]FfUKKE]YFfeKJ0004E]/300000eKK001Ff`07E]/00`00E]]Ff`03
0004E]/00`00E]]Ff`06E]/30003E]/01E;KE]]FfeKK00000UKK00=Fg5;KE]/00P0000EBfeKK001F
g5;K009Ff`09E]aBf`00E]/005;KE]aBfeKL0080000<D]]Fg000E]aBfeKLD]]Fg5;KE]aBf`000Woo
00@007ooOol000Qoo`8000=oo`<0029oo`00:goo00<007oo00000Woo00<007oo00000Woo00<007oo
00000Woo0P001Woo00D005ZiF[UJV5ji009J^@0@FYP00000G[T005[JF[UJ^UJiF]YJ^EZjE[UJfP00
F]X200003EJiF]YF^E[JE[UJfUJi001F^U[KE[YJfeJj0080000=F]]F^P00E[YJfeJjF]]F^U[KE[YJ
f`00E]/00`0000QJfeKJE]]F^U[K001Ffe:j0eKK00=B^UKK00000P000eKK00]BfeKKE]]Ffe;K001B
feKKD]]Fo5;K0080000>E_aBf`00D]]Fo5;KE]aBfeKlD]]Fg000E_aBf`80000@E_aBfeKlD]/005;K
E_aBfeKlD]]Fo000E_`005KlD]/200003EKlD]]Fo5;KE_`005KlD]]Fo5;KE_aBfeKl00800003Ool0
07oo03Aoo`00;7oo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Uoo`03001J^EZi00=J
^@06001J^EjiF[UN^@000UZi00EJ^UZiF[UJ^EZj009J^@03001JfUZj009J^P09F]YJ^UZjF[YJfUZj
001F^U[J0080000<E]YJfUJjF]YFfP00E]YFfeKJE]]FfUKK10000UKK00IFfUKKE]]FfeKJ0005E]/2
0002E]/00`00E]]Ff`06E]/00`00E]]Ff`030004E]/00`00E]]Bf`03E]/00e;KE]]Ff`0300000eKK
E]aBf`02E]/01UKLD]/005KKE]aBf`9Ff`03E]`000000080000=D]]Fg5;KE]aBfeKLD]/005;KE]aB
feKLD]/00P0000=Fg5;K00000P00=7oo0002Ool30008Ool2000ZOol00`00Oomoo`08Ool04P00F[UJ
^EZH001J^5jiF[QN^EZhG[T005[JF[UJ^UJiF]YJ^@80000<G]X005[JE[UJfUJiF]YF^E[JE[UJfUJi
0P0000]JfUJjF]]F^U[JE[YJf`00F]]F^U[K00@0000<E[YJf`00F]]FfUKKE[YJfeKJE]]F^P000UKK
0P000UKK00EFfUKKE]/005;K00=Ff`03D]]FfeKK00<0000>D]]Ffe;KE_aBfeKKD]]Fo000E]aBfeKl
D]]Fg080000>D]]Fg000E_aBfeKlD]]Fo5;KE_`005KlD]]Fo0D0000=E_`005KlD]]Fo5;KE_aBfeKl
D]/005;KE_`00P0000EBfeKlD]]Fo000009oo`03001oogoo035oo`000goo00<007ooOol027oo00<0
07ooOol0:7oo0P002Goo00`005Zi000005ZiG[UJ^EjiF[UN^EZi0003F[T00eZj00000004F[T00`00
F]YJ^P02F[X00e[JF[YJ^P0200002UZi001FfU[JE[YJfUKJF]YF^U[J1@0000IJfeKJE]YFfU[K0003
E]/015KJE]]FfeKK0`001eKK00<005KKE]/00eKK0P000UKK00<005KKE]/01UKK00<005KKE]/00`00
15KK00H005;KE]]FfeKLD]/2E]/400003eKLD]]FfeKKE]`005KK001Fg5;KE]aBfeKLD]]Fg0030000
2UKLD]]Fg5;KE]aBfeKL001oo`00<goo0003Ool30002Ool40002Ool02000Oomoo`00Ool007oo0002
Ool200000goo00000002Ool00`00Oomoo`02000EOol00`00Oomoo`09Ool03@00G[UJ^5jiF[QN^EZh
G[UJ^5jiF[P005Ji0080000HG]YJ^EkJF[UNfUZiG]X005[JE[UJfUJiF]X005[JF[UJfP00F]]F^U[J
E[YJfeJj1@0000eF^U[KE[YJfeJjF]]F^P00E[YJfeKJE]]F^P0200000e[KE[X00002E]/02EKJE]]F
feKKE]YFf`00E]]Bf`020005E]/02000E_aBfeKKD]]Fo5;KE]/300003EKLD]]Fo5;KE]aBfeKlD]/0
05;KE_aBfeKl0080000?D]]Fo000E_aBfeKlD]]Fo5;K001Bf`00D]]Fo5;K00@0000<E_aBf`00D]]F
o5;KE_aBfeKlD]/007oo0P00<Woo0003Ool01@00Oomoo`00Ool00`000Woo00/007oo001oo`00Ool0
07oo001oo`0000Aoo`06001oogoo001oo`000Woo00<007ooOol04Woo0P002goo00`005jiF[UN^EZi
G[UJ^EjiF[UN^EZi0009F[T00`00F[YJfP02F[X02@00F]YJ^E[JF[YJfP00F]YFfP0300001UKJ0000
05[J001Jf`=FfP07F]]FfUKJE]X005KJE]/00P0000IFfUKKE]]FfeKJ0007E]/30007E]/00`00E]]F
f`03E]/20002E]/00`00E]]Ff`06E]/00`00E]aBf`020005E]/01@00E]]FfeKLD]/00UKK1@0000iB
feKKE]]Fg5;KE]/005KLD]]Fg5;KE]aBfeKL0P000Woo00<007ooOol0;goo0003Ool01000Oomoo`00
0goo00d007ooOol007oo001oo`00Ool007oo001oo`030002Ool01P00Oomoo`00Ool001Moo`03001o
ogoo00]oo`08001N^EZhG[UJ^5jiF[QN^@80000=F[P005ZiG]YJ^EkJF[UNfUZiG]YJ^@00E[T00P00
00IJfUZiF]YJ^E[JF[T300004EJjF]X00000E[YJfUJj001F^U[KE[YJfeJjF]]F^U[KE[X00P0000QJ
feKJF]]F^U[KE]YJf`000eKK00MFfUKK000005KJF]/00008E]/00`00D]]Fo00200003E;KE_aFfeKK
D]/005;KE]aBfeKlD]]Fg5;K00<0000=D]]Fo5;KE_aBfeKlD]/005;KE_aBfeKlD]/00`0000mBf`00
D]]Fo5;KE_aBfeKlD]]Fo000E_aBfeKlD]/00P0000EFo5;K001oo`00035oo`000Woo10000goo0P00
00Aoo`00001oo`@00004Ool007ooOol300000goo0000000200000goo000000020006Ool30002Ool0
0`00Oomoo`02Ool01@00Oomoogoo00003goo00`005jiF[UN^EZiG[T005jiG[QN^Ejh0009F[T01P00
F[YJfUZiF]YJ^P<00003F[X005Jj00800003F]YJ^U[J009JfP04F[X005KJF]/3E]X01U[K000005KJ
001FfP=Ff`05E]YFfeKKE]/00002E]/20005E]/00`00E]]Ff`05E]/30007E]/00`00E]]Ff`03E]/2
0002E]/00`00E]]Ff`06E]/00`00D]]Ff`0200000e;KE]]Ff`020002E]/02EKLD]]FfeKKE]aBf`00
D]]Fg00200001UKKE_aBfeKL001oo`80031oo`008Goo00<007ooOol01goo00H007ooOol007oo0002
Ool00`00Ool00002Ool2000>Ool04`00F[QN^EZhG[T005jiF[QN^EZhG[UJ^000F[UNfUZiG]YJ^EkJ
00800003F[T005Zi00<0000CF[UJfUZiF]YJ^@00E[YJfUJjF]YF^U[JE[YJfUJj001F^U[KE[X00P00
00aJfeJjF]]FfP00E[YJfeKJF]]F^U[KE]X3000025KJE]]FfU[KE]YFfeKJ0005E]/200001EKkE]/0
05;KE_`00UKK00MBfeKlE]]Ff`00E_aBf`0200003EKlE]]Fo5;K001BfeKlD]]Fo5;KE_aBfeKl00<0
000?E_aBfeKlD]]Fo000E_`005KlD]]Fo5;KE_aBfeKl00<00008E_aBfeKlD]]Fo5;KE_`0009oo`03
001oogoo02eoo`00:Goo100000Aoo`00Ool0009oo`03001oo`00009oo`03001oogoo00ioo`0<001J
^@00001N^EjhG[UN^5jiG[QN^@0015Zi0P0000=N^EZi00000P0000IJ^U[JF[UJfUZjF]X200000eZi
001J^P03F]X01UZjF]YJfU[J001FfP800009E]YJfUKJF]YFfU[J001FfeKJ00=Ff`800003E]YJf`00
00QFf`03001FfeKK008000EFf`03001FfeKK00EFf`<000MFf`03001FfeKK00=Ff`80009Ff`07001B
feKKE]]Fg5;KE]/00P0000=BfeKKE]/0100000]Fg5;K001FfeKlD]]Fg5KKE_aBf`00009oo`03001o
ogoo00Aoo`03001oogoo009oo`04001oogooOol3000MOol002Uoo`03001oo`00009oo`03001oo`00
009oo`03001oo`00009oo`03001oogoo00moo`0=001J^5jiF[QN^EZhG[UJ^5jiF[QN^@00G]X00P00
00]J^@00000005ZiG]T005[JF[UJfUZi0080000JG]YJ^EkJ001JfUJjF]YF^U[JE[YJfUJjF]X005[K
E]YJfeJjF]]FfU[KE[YJf`00F]]F^P80000=F]]FfU[KE]YJf`00F]]FfUKKE]YJfeKJE]/00`0000=F
feKJE_/00UKK00IFfUKk001Ffe;KE_`2E]/20002E]/02`00E_aFfeKlD]]Fo5KKE_`005KlD]/00`00
00aBfeKlD]]Fo000E_aBfeKlD]]Fo5;KE_`400003U;KE_aBfeKlD]]Fo5;K001BfeKlD]]Fo5;KE_`2
00000goo00000004Ool00`00Ool00007Ool00`00Oomoo`0MOol002Yoo`80009oo`03001oo`00009o
o`03001oo`00009oo`80015oo`0=001N^5jiG[QN^EjhG[UN^5jiG[QN^@00G[T00P0000QJ^EjiF[UN
^EZiG[T005[J0P0000UJ^E[JF[UJfUZiF]X005[JF[X00e[J00iJ^P00001JfP00F]YFfU[JE]YJfUKJ
F]YFfU[J0P0000QFfUKKE]YJfeKJE]]FfP001EKK0P000UKK00<005KKE]/01UKK00<005KKE]/00P00
15KK00<005KKE]/01EKK0`0025KK00<005KLD]/00UKK0`0000=Ff`00D]/00UKK00QFg5;KE]]FfeKL
001Fg5KK100000=Fo5;K00000Woo00L007ooOomoo`00Ool00008Ool00`00Oomoo`0LOol002]oo`05
001oogooOol00004Ool01@00Oomoogoo00004Woo00X005jiF[QN^EZhG[UJ^5jiF[QN^@<0000GG]UJ
^EkIF[UNfEZiG]UJ^EkI001NfUZiG]YJ^EkJF[UNfUZiG]X005[JE[YJfP0200002eZiF]YJ^U[J001J
feKJF]]F^U[KE]X00P0000eJf`00F]]FfU[KE]YJfeKJF]]FfP00E]YJf`0200001UKJF]]FfU[KE]X0
009Ff`05E]YFneKKE]]FfP0300000eKKE_aFf`02E]/01eKlE]/005;KE_aFfeKl0080000>E]]Fn`00
E_aBfeKlD]]Fo5;KE_aBf`00D]]Fo0800003D]]Fo5;K00800008E_aBfeKlD]]Fo5;KE_aBf`<0000:
D]]Fo5;KE_aBfeKlD]/007oo0003Ool00`00Ool00008Ool00`00Oomoo`0LOol003Qoo`03001oogoo
015oo`06001N^EjhG[UN^5ji0`000Ujh00P005ZiG[UJ^EjiF[UN^EZi0P0000aNf@00F]YJ^E[JF[UJ
fUZiF]YJ^@00F]X20006F]X01@00E]YJfUKJF]X00P0015[J00P005[KE]YFfeKJF]]FfUKK0`001eKK
00<005KKE]/00eKK0P000UKK00<005KKE]/01EKK00<005KKE]/00P001EKK00<005KKE]/01EKK0`00
00IFg5KKE]]FfeKLE]/200001EKLD]]FfeKKE]`00P0000aFf`00D]]Fg5KKE_aBfeKLE]]Fo000Ool2
0002Ool00`00Ool00007Ool00`00Ool0000MOol003Moo`8001Aoo`03001N^@0000@0000TH]UN^5ji
G[P005ZiG]UJ^EkIF[T005ZhG]UJ^@00F[UNfUZiG]YJ^EkJF[UNfUZi001J^U[JF[UJfUZjF]YJ^E[J
F[X005Jj0P0000aJfeJjF]]FfU[KE[X005KJF]]FfU[KE]X200003U[KE]X005KJF]]FfU[KE]YJfeKJ
F]/005KkE]/200001E[kE]]FfeKJ00000eKK00AFo5KKE]]Ff`<0000=D]]Fo5KKE_]BfeKlE]/005;K
E_aBfeKlD]/00P0000eFo5;K001BfeKlD]]Fo5;KE_aBf`00D]]Fo003000035KlD]]Fo5;K001BfeKl
D]]Fo5;KE_aBf`800003Ool007oo009oo`03001oogoo00Moo`03001oogoo01aoo`00=goo00<007oo
Ool04Woo0`0000=N^Ejh00001ejh00L005ZiG[UJ^@00G[UNf@03G[T01`00F[UJfUZiF]YJ^E[J0080
0003F[T005[J00QJfP03001JfU[J00MJfP03001FfU[K00800006E]YJfeKJF]]FfP001eKK0`001eKK
00<005KKE]/00UKK0P000UKK00<005KKE]/01UKK00<005KKE]/00P001EKK00<005KKE]`00eKK00IF
g000000005KlD]/2E]/02EKlD]]Ff`00E_aBfeKLE]]Fo002000015KKE_`00000;7oo000gOol2000@
Ool30002Ool03@00F[P005jhH]UN^5jiG[QRfEjhG[T005kI0080000;F[QNfEZiG]UJ^5kIF[T005Zi
G]YJ^@0200002ekJF[UNfUZi001J^U[JF[UJfUZjF]X00P0000]J^P00E[YJfeKJF]]F^U[KE]YJfeJj
0080000=F]]FfU[KE]YJfeKJF]/005[KE]YJfeKJF]/00P0000AFfU[K001Jn`9Ff`07E]YJneKKE]/0
05KlE]/00P0000eFneKKE_]FfeKk001Fne;KE_aFfeKkD]]Fo00300002UKlE]]Fo5;KE_aFfeKl001F
o5;K100000eFo000001BfeKlD]]Fo5;KE_aBfeKl001Fo00300001UKlD]]Fo5;KE_`002aoo`003Woo
10000goo0P0000=oo`0000000Woo00<007ooOol00`001Goo0P0017oo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol037oo0`001Woo00<005jhG[P025jh00@005jiG[UNf@=N^@05G]UN^Eji001J
fP0200000e[IG]YJ^@02F]T00ekJ001JfP03F]X20004F]X00`00F]YJfP04F]X200002e[J001FfU[K
E]YJfeKJF]]FfU[K00000UKK0P0000EJfeKJE]]Ff`0000MFf`<000QFf`03001FfeKK00@0009Ff`03
001FfeKK00EFf`<00003E]]Fg5KK009Ff`06E]`00000E]]Fo5;K0UKK00aFo000000005KlD]]Fg5KK
E_aBfeKLE]/2000[Ool000moo`06001oogoo001oo`000Woo00<007oo00000Woo00<007oo00000Woo
00<007ooOol00goo00<007oo00000Woo00<007oo00000Woo00<007oo00000goo00<007ooOol02Goo
0`002Woo024005jhG[UN^6;IG[QN^EjhH]T006:h001NfEZiG]UJ^5kIF[UNfEZhG]T005kJF[UNfUZi
G]YJ^EkJF[UNfP00F]X00P0000]J^EkJF[YJfUZiG]X005[KE[YJfeKJ0080000<F]]JfU[JE[X005KJ
F]]FfU[KE]YJfeKJ0`0000YFfU[kE]YJfeKJF_]FfP00E]YJn`9Ff`80000;E]]Jf`00E_]FfeKkE]]F
neKKE_]Ff`03000035KKE_aFfeKkE]]Fo5KK001BfeKlE]]Fo080000=E]]Fo000E_aBfeKlD]]Fo5;K
E_`005KlD]/0100000]Fo5;K001BfeKlD]]Fo5;KE_aBfeKl008002]oo`003goo00H007ooOol007oo
0002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00Ool00002Ool00`00Ool0
0002Ool00`00Ool00003Ool20008Ool2000=Ool00`00G[QN^005G[P01000G[QN^0000eji00ANfEji
G[UN^@800004G[T005kJF[T2F]T01UkJF[UJfE[IG]X000UJfP04001JfP000006F]X01P00F]]FfU[K
E]YJf`800005E]YJfP00F]]FfP02E]/015[KE]YFf`000UKK0P001EKK00<005KKE]/00eKK0P000UKK
00<005KKE]/01EKK00<005KKE]/00P0015KK00D005KKE]]FfeKL00=Ff`<00003E]]Fo5KK009Ff`08
E_aFf`00E]]Fo5;KE]aFf`800003Ool007oo02Yoo`003goo0`000goo0P0000=oo`0000000P000goo
0`001Goo0P000goo00<007oo00000Woo00<007oo00000Woo00<007ooOol01Goo0`0047oo00D006;I
G[QN^Ejh0080000FH[QN^6;IG[P005ZhG]UJ^EkIF[P005jhG]UN^5kI001NfUZiG]YJ^EkJF[T20000
3ekJ001NfUZjF]YJ^EkJF[YJfUZiG]X005[JE[YJf`02F]X01eJjF]]JfU[J001JfeKJ0080000<F]]F
fU[KE]X005KJF]]FfU[kE]YJfeKJ0`0000]FfU[kE]]JfeKJF_]Ffe[K001FneKK0080000<F_]FfeKk
E]/005KKE_]FfeKlE]]FneKK0`0000aBfeKlE]]Fo5;KE_aFf`00D]]Fo5;KE_`200003EKK000005Kl
D]]Fo5;KE_aBfeKl001Fo5;K00<000=oo`03001oogoo02Uoo`003goo00@007ooOol000ioo`03001o
ogoo00=oo`03001oogoo009oo`03001oo`00009oo`03001oo`00009oo`03001oogoo009oo`<001Ao
o`04001N^5jh0003G[P01F:hG[QN^5jh00000eji00/005jiG[UN^EkIG[T005[IG]YJ^E[I00800005
F[UNfEkIG]T00006F]X200000e[J001JfP08F]X200000e[JF]]FfP02F]X01e[KE]X005KKF]]FfUKK
00800003E]YJf`0000QFf`<000MFf`03001FfeKK009Ff`80009Ff`03001FfeKK00EFf`03001Fg5KK
00800005E_]FfeKKE]/00003E]/015KlE]]FfeKK0`001Woo00<007ooOol0:Goo000>Ool4000>Ool2
0006Ool20003Ool00`00Oomoo`02Ool01000Oomoogoo1@005goo00d005jh001N^6:hG[QRfEjhH[QN
^6;I001Nf@0200002EjhG]UN^5kIG[QNfEjh001J^@0200002ekJF[UNfUZiG]YJ^@00F[UNfUZjF]X0
0P0000QJfEkJF[UNfP00F]YF^U[K0U[J00mF^P00001JfP00F]]FfU[KE]YJfeKJF]/005[kE]X00P00
00]JneKJF]]FfU[k001JfeKJF_]Ffe[K0080000=E]YJf`00F_]FfeKkE]]JneKKE_/005KlE]/00P00
00aFo5KKE_]FfeKl001Fo5;KE_aFfeKlD]/3000035;KE_aFfeKlD]]Fo5KK001BfeKlD]]Fo08000Uo
o`03001oogoo02Uoo`00=Woo0P006goo00D005jhG[QN^6:h00=N^005H[QN^5jh001Nf@03G[T01ekI
G[UN^EjiG]UN^@00009Nf@05F[UNfEkIG]UJ^@02G]T01000F]X000001U[J00<005[JF]X00U[J0P00
15[J00D005[JF]YJfeKJ009JfP0<F]/00000E]]JfeKJF]]Ffe[KE]YJf`000UKK0P0000EJfeKKE]]F
f`0000MFf`<000MFf`03001FfeKK00@0009Ff`03001FneKK009Ff`06E_]FfeKK001Fo5KK0P002goo
00<007ooOol0:Goo000gOol00`00Oomoo`0JOol0;000G[QRfEjhH[QN^6;IG[QR^000H]P005kIG[QN
fEjhG]UN^5kIG[P005jh001J^EkJF[UNfUZiG]YJ^EkJF[T005ZiG]YJfEkJF[UNfU[IG]YJ^@00F]X2
0006F]X01P00E]YJfeKJF]]FfP80000:F]/005[kE]YJfeKJF_]FfU[KE]X3000035KJF_]FfU[KE]YJ
neKJ001Ffe[kE]]Fn`80000:E]]Jn`00E_aFfeKkE]]Fo5KKE_/300003UKlE]]Fo5KKE_aFfeKl001F
o5;KE_aFfeKlD]/3000=Ool00`00Oomoo`0YOol003Qoo`8001Yoo`03001R^5jh009N^009H[QN^5jh
001R^5jhH[P005kI00=N^@07G]UN^@00G[UNfEjh00000UkI00QJ^EkIG]UNfEZi001Nf@002E[J00<0
05[JF]X01e[J00<005KJF]X00P000e[J00MJf`00F]]Ffe[KE]YJf`02000015KJF]/005[K0eKK00AJ
feKKE]/0009Ff`8000EFf`03001FfeKK009Ff`80009Ff`03001FfeKK00EFf`03001FfeKk00@0009o
o`03001oogoo00aoo`03001oogoo02Qoo`00>Woo00<007ooOol067oo00D006:hG[QRfEjh0080000Q
H]QN^6;HG[MRf000G]UN^5kIG[P005jhH]UN^6;IG[P005ZiG]YJ^EkJF[T005ZiG]YJ^@00F[UNfU[I
G]YJ^EkJ00800003F[T005[J00QJfP80000:F_]FfU[KE]YJneKJF]/005[kE]X2000035[kE]YJfeKJ
001FfU[KE]YJneKJF]]FfP<0000:E]YJneKKF_]FfU[kE]/005KKE_`2000035KKF_aFfeKk001Fo5KK
E_aFfeKlE]]Fo0<000Ioo`03001oogoo00aoo`03001oogoo02Qoo`00>goo00<007ooOol067oo00@0
06:hG[P0009R^00AG[QR^6:hH[QN^000G[UNfEji001N^EkIG[QNfEjiG]T00003G]T20004G]T00`00
F]YJfP02F]X200001EkJF]YNfU[I00001U[J0P0000=JfP00F]X00U[J00EJfe[JF]YJfU[K0080009J
f`08E]YJfe[KF]]FfP00E]]Jf`9Ff`80009Ff`03001FfeKK00EFf`<000MFf`03001FfeKK009Ff`80
00Yoo`03001oogoo00]oo`03001oogoo02Qoo`00?7oo00<007ooOol05goo02<005jh001N]f;HG[QR
f5jgH]QN^6;HG[L005jh001N^6;IG[QRfEjhH]UN^6;I001NfP00G]UJ^EkJF[UNfEZiG]X005kJ0080
0007F]UNfUZiG]YJfEkJ000015[J0P000U[J00QNfP00F]]FfU[kE]YJfeKJ0P0000aJf`00F_]FfU[K
E]YJneKJF]/005[kE]X200002U[kE]YJneKJF_/005[kE]YJneKK0P0000eJneKK001Ffe[lE]]FneKK
F_aFf`00E]]Fo002000=Ool00`00Oomoo`0:Ool00`00Oomoo`0XOol003eoo`8001Qoo`04001R^6:h
G[P3H[P04EjhH[QR^6:hG[P005jiG]UN^5kIG[UNfEjhG]UN^EkI00002EkI00`005kJF]UNfU[JG]YJ
fEkJF]YNfP00F]X20006F]X01000F]]JfU[J0P0015[J00D005[KF]]JfeKJ00=Jf`800003E]]JfeKK
009Ff`03F]]Ff`00009Ff`8000EFf`03001FfeKK00AFf`<0011oo`03001oogoo00Uoo`03001oogoo
02Qoo`00?goo00<007ooOol05Woo01@005jhH]QN]f;HG[QRf5jgH]QN^000G[L005jhH]UN^6;IG[QR
fEjh0P0001MRf@00G]YJ^EkIF[UNfUZiG]T005kI001NfUZiG]YJfEkJF[UNfU[IG]X005kJ00=JfP06
G]YJfU[JF]X005KJ0P0000aJne[JF]]FfU[kF]X005KJF_]FfU[KE]X200002U[K001JneKJF_]FfU[k
E]YJneKJ0P0000YJneKJF_]Ffe[kE]YJn`00E_]Ff`@001=oo`03001oogoo00Uoo`03001oogoo02Qo
o`00@7oo00<007ooOol05Woo00@006:hH[QN^0=R^003G[P006:h009R^00<001N^EkIG[QNfEji001N
^5kIG[QRf@001EkI00/005kIG]UNf@00G]YJfEkJF]YNfU[I00800003G]X005[J00MJfP03001JfU[J
00MJfP03001FfU[K00800005F]YJfe[JF]/00002E]/00e[KE]]Ff`0200000eKK001Ff`07E]/2000H
Ool00`00Oomoo`08Ool00`00Oomoo`0XOol0045oo`03001oogoo01Ioo`05001N^6;HG[MRf0020000
4ejgH]QR]f;H001RfEjhH]UN^000G[QRfEjhH]UN^000F[UNfUZi00800009G]UN^EkIG[T005[IG]YJ
^EkJ00800006F[UNfU[IG]X005kJ0e[J00eNfP00001Jf@00F]YJfeKJF_]JfU[KE]YJn`0300002U[k
E]YJfeKJF_]FfU[K001JneKJ0P0000YJneKJF_]FfP00E]]JneKJF_]Ff`8001]oo`03001oogoo00Qo
o`03001oogoo02Moo`00@Woo0P005Woo00D006:hH[QR^00000MR^00>001Nf@00001N^5kIG[QRfEjh
G]UN^000G]T000MNf@0;001JfP00001NfUkIG]YJfEkJG]T00004F]X01P00F]YJfUkJF]X000EJfP80
009JfP08001JfU[KF]YJfe[JF]]JfP<00008E]]JfeKKF]]Ffe[KE]/0009Ff`8001ioo`03001oogoo
00Moo`03001oogoo02Moo`00A7oo00<007ooOol057oo02d006;H001Rf5jgH]QR]f;HG[MRf6:gH]P0
06;IG[QRfEjhH]UN^6;IG[QRfEjh001N^EkIG[UNfEjiG]UN^EkIG[T005[IG]YJ^EkJF]UNfUZiG]YJ
f@00F]X00P0000UNfU[IG]YJfUkJF]T005[JF]/00P0000YJfU[KF]YJne[J001FfU[kE]YJf`80000:
F]YJn`00F_]FfU[kE]YJneKJF_/3000POol00`00Oomoo`07Ool00`00Oomoo`0WOol004Eoo`03001o
ogoo01Aoo`03001R^6:h00MR^00>001R^000G]UN^6;IG[QNfEjhH]UN^000H[P000MNf@0=001Nf@00
G]UNfU[IG]YNfEkJF]UNfUkI00000e[J00INfU[JF]YJfUkJF]X20007F]X00`00F]]JfP0200002U[K
F]YJfe[JF]/005[KE]]JfeKK0P0097oo00<007ooOol01Woo00<007ooOol09goo0016Ool00`00Oomo
o`0DOol0:000H]QR]f;HG[MRf6:gH]P006;HH[L005jhH]UN^6;IG[QRfEjh001N^6;IG[P005jiG]UN
^EkIG[T005jiH]UN^000F]UNfUZiG]YJfEkJ0P0000QJf@00F]UNfU[JG]YJfEkJ0P0000YJf@00F]YJ
fe[JF_]JfU[KF]YJn`80000:E]YJne[JF_]FfU[kF]X005KJF_/2000WOol00`00Oomoo`05Ool00`00
Oomoo`0WOol004Moo`8001Aoo`03001R^6:h00AR^003001R^6:g009R^005001N^5kIG[QRf@020000
1F:hH]QN^6;H00000ekI0P0015kI00D005kJG]UNfU[I00800005G]YNfEkIG]T00003F]X2000015kJ
F]YNfP001U[J0P0000YJfP00F]]JfU[KF]YJfe[JF]]JfP8002Uoo`03001oogoo00Eoo`03001oogoo
02Moo`00BGoo00<007ooOol04Woo02<005jgH]QR]f;H001Rf6:gH]QR]f;HH[L005jhH]T006;IG[QR
fEjhH]UN^6;I001Nf@00H]UN^F;IG[QRfEjiH]T005kJ00800008F]UNfU[IG]YJfEkJ001NfP80000:
F]YNfU[IG_YJfUkJ001Jne[JF]/20003F]X01`00F]YJneKJF_]JfU[k008002aoo`03001oogoo00Ao
o`03001oogoo02Moo`00BWoo00<007ooOol04Woo00H006:hH[P006:hH[L3H[P03f:gH[P006;I001R
f6:hH]QN^6;HH[QRf5jhH]P00009G]T01000G]UNfEkJ0ekI00iNfUkIG]T005kJF]YNfU[JG]YJfUkJ
F]X005[J0P001U[J00@005[JF]]JfP8002moo`03001oogoo00Aoo`03001oogoo02Ioo`00Bgoo00<0
07ooOol04Goo01l006;H001Rf6:gH]QR]f;HH[MRf6:gH]P006;IG[QRfEjhH]UN^6;IG[QRf@00H]T0
06;IG[QRfEjiH]UN^00200005f;I001NfU[IG]YJfEkJF]UNfP00G]X005kJF]UNnU[JG]YJfEkjF]X0
05[JG_/00e[J00ENne[JF]X005[k0080039oo`03001oogoo00=oo`03001oogoo02Ioo`00C7oo0P00
4Woo00<006:hH[L00f:h019R]f:hH[QR^000H[L006;HG[QRf6:hH]QN^6;H001Rf6:h0005G]T01P00
G]UNfEkIH]T0009Nf@04G]YNfEkI0003G]T01P00G]YJfUkJF]YNfP800003G]X005[J00MJfP03001o
ogoo039oo`03001oogoo00=oo`03001oogoo02Ioo`00CWoo00<007ooOol047oo014006;HH[MRf6:g
H]QR]f;H001Vf6:gI]P006;IG[QRfEjh0080000BH]UN^6;HG[P005jiH]UN^000G]QRfEjhH]UNf000
F]UNfU[I0P00015NfUkIG]YNf@00F]YNfU[IG_X005kJF]UNnU[I001JfUkk00=JfP8003Ioo`03001o
ogoo009oo`03001oogoo02Ioo`00Cgoo00<007ooOol03goo00@006:hH[QR]`=R^00:001R]f:gH]QR
]`00H[QRf5jh0002H]P01V:hH]QRf6;H001Nf@8000=Nf@07H]UNfEkIG]T005kI00001ekI00@005[J
000000=NfP04F]YNfUkJ0002F]X2000iOol01@00Oomoogoo0000:7oo001@Ool00`00Oomoo`0?Ool0
=P00H[MRf6:gH]P006KHH[MVf6:gI]QR]`00G[P005jhH]UN^6;HG[QRfEjhH]P006;IG]QRfEjhH]UN
f6;IG[QRfEkH001NfEkJG]UNfUkIG]YNfEkJG]T005[IG]YJfEkjF]UNfU[IG_YJf@8003aoo`04001o
ogoo000XOol0055oo`80011oo`04001R^6:h0002H[L01f;HH[MR]f:gH]QR]`00009Rf009H[QRf6;H
H]QR^6;H001Rf000009Nf@05H]UNfEkIG]URf@0200000ekI001Nf@05G]T200001EkI001NfUkJF]X0
0ekJ0P00?Woo00@007ooOol002Qoo`00Dgoo00<007ooOol03Goo02L006;H001Vf6:gI]QR]fKHH[MV
f6:g001R]`00G[QRf5jhH]UN^6;H001Rf6:hH]P006;IG]QRfEjhH]T006;IG[QRfEkH001NfEkJG]T0
0P0000QRfUkIG]UNf@00F]UNfU[I0P00@Goo00<007oo0000:7oo001DOol00`00Oomoo`0=Ool01000
H[MR]f;H0f:g00MRf6:g001R]fKGH[L00002H]P01F:hH]P006;HH[P00V;H00d005kIG]UNfF;I001R
fEkIH]UNf6;I001Nf@020006G]T01000G]X00000A7oo00<007oo00009goo001EOol00`00Oomoo`0=
Ool06@00I]QR]fKHH[MVf6:g001R]fKHH[MVf000H]UN^6;H001Rf6:hH]QR^6;HH[P005jh00800008
H]UN^6;IG]QRfEjhH]T0009Nf@05H]YNfEkIG]URfP02G]T00`00Oomoo`15Ool2000WOol005Ioo`80
00eoo`0B001R]f:gH[MRf6:g001R]fKGH[MV]f:gI]L006;H001Rf6:h0f;H00mR^6;HH]P005kHH]UN
fF;IG]QRfEkIH]T006;I00001ekI00<007ooOol0AWoo0P009goo001HOol00`00Oomoo`0;Ool09000
H[MVf6:gI]P006KHH[MVf6:gI]QR]fKH001Rf6:hH]QR^6;HH[QRf6:h001R^000G[QRfEkHH]UN^6;I
001RfEjhH]T0009Nf@04H]YNfEkI0019Ool2000WOol005Uoo`03001oogoo00]oo`0>001R]f:g001V
ef:gI[MR]fKGH[MV]`00I]L000=Rf004H[QRf6;H0003H]P02`00G]QRfEkIH]T006;IH]QRfF;H0000
0ekI0P00AWoo1000:Goo001JOol00`00Oomoo`0:Ool09P00I]P006KHH[MVf6:gI]QR]fKH001Vf6:g
I]L006;HH[QRf6:h001R^6;HH[MVf000H]UN^6;I001RfEjhH]UNf6;IG[P005kI0014Ool4000]Ool0
05]oo`8000]oo`0;001Vef:gI[MR]fKGH[MV]`00I]MR]`02I[L01@00H[QRf6;H00001V;H00`006;I
001RfF;HH]URf6;IH]QRfF;H0011Ool4000aOol005eoo`03001oogoo00Uoo`0P001Vf6:gI]QR]fKH
001Vf6:gI]MR]fKHH[L006:h001R^6;HH[MVf6:hH]QR]fKH001RfEjhH]UNf6;IG[QRf@8003ioo`@0
03Eoo`00GWoo00<007ooOol02Goo00L006KGH[MV]f:g001R]`02I[L01FKGH[MV]fJg000026;H00T0
06;H001RfF;HH]URf6;I0000?7oo1000>Goo001OOol00`00Oomoo`08Ool07P00H[MVf6:g001R]fKG
H[MVf6:gI]MR]`00H[L006:gI]QR^6;HH[MVf000I]QR]fKH001RfEjhH]T003Uoo`@003eoo`00H7oo
0P002Goo00@006:g001R]`9V]`05I]MR]fJgI[L00002I[L00`00H]QRf003H]P01`00H]QRf6KHH]P0
06;H008003Ioo`@0045oo`00HWoo00<007ooOol01goo01T006:gI]MR]fKHH[MVef:gI]P006KGH[IV
e`00H]QR]fKH001Vf6:gI]QR]fKHH[L0000dOol40015Ool006=oo`03001oogoo00Moo`04001V]fKG
H[L2I[L01fKG001V]fJgI]MV]`00009Rf004001Rf6;HI]P3H]P00`00Oomoo`0_Ool40019Ool006Ao
o`03001oogoo00Ioo`0=001Vf6:gI]MR]fKH001Vef:fI]MR]fKGH[H00P0000MVf6:gI]QR]fKHH[L0
000^Ool4001=Ool006Eoo`8000Moo`05001V]fJgI]L00002I[L01VKGI[MV]fJgI]L0009Rf005I]QR
f6;HH]P0000[Ool4001AOol006Moo`03001oogoo00Eoo`0C001Vf6:g001R]VKGH[MVef:fI]L006KG
001Vf6:gI]QR]fKH00009goo1000EGoo001XOol00`00Oomoo`04Ool01@00H[L006JgI]L00fJg00IV
e`00I]MV]fKG0002H]P00fKH001oo`0SOol4001IOol006Uoo`03001oogoo00Aoo`0@001R]VKGH[MV
ef:fI]MR]`00H[IVefJfI]L006KH000QOol4001MOol006Yoo`8000Eoo`0>001V]fJgI[MVefJg001V
]fKGI[MVefJgI]L001ioo`@0065oo`00K7oo00<007ooOol00goo00`006:fI]MR]`00H[IVefJfI]MR
]VKG000KOol4001UOol006eoo`03001oogoo009oo`0;001VefJg001V]fKGI[MVefJgI]L0000HOol4
001YOol006ioo`03001oogoo009oo`0:001Ve`00I]MV]VKGH[IVefJf000DOol4001]Ool006moo`80
00=oo`08001VefJgI]MV]fKGI[L0015oo`@0075oo`00LGoo00X007ooOomoo`00I]MR]VKGI[H000io
o`@007Eoo`00LWoo00P007ooOol006JgI]MV]`002goo1000NGoo001cOol01`00Oomoo`00I[IVe`00
00Moo`@007eoo`00M7oo0`0000=Ve`00Ool00goo1000PGoo001fOol200000goo000000020025Ool0
07Moo`8008Uoo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00
ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3
Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00
ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3
Ool00?moo`=oo`00ogoo0goo0000\
\>"],
  ImageRangeCache->{{{0, 257}, {208.25, 0}} -> {-0.320191, -0.195021, 
  0.00583051, 0.00583051}}]
}, Open  ]],

Cell["\<\
We define a function representing the bond payment as a function of \
the bond object and yield to maturity. \
\>", "MathCaption",
  CellTags->"0.22"],

Cell["\<\
bp[bond_Bond, x_] := Payment[bond, settlement1, x] /. USDollar -> 1;\
\>", "Input",
  CellLabel->"In[18]:="],

Cell[TextData[{
  "We can compare the payment\[Hyphen]yield curves for ",
  StyleBox["bond3", "MB"],
  ", ",
  StyleBox["bond10", "MB"],
  ", and ",
  StyleBox["bond30", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.23"],

Cell[CellGroupData[{

Cell["\<\
Plot[{bp[bond3, x], bp[bond10, x], bp[bond30, x]},
   {x, 0, .2}, FrameLabel -> label1];\
\>", "Input",
  CellLabel->"In[19]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.76191 -0.0696869 0.000168251 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -12 -9 ]
[.2619 -0.0125 12 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -53 -21.5625 ]
[.5 -0.0125 53 -9 ]
[-0.0125 .01444 -18 -4.5 ]
[-0.0125 .01444 0 4.5 ]
[-0.0125 .09856 -24 -4.5 ]
[-0.0125 .09856 0 4.5 ]
[-0.0125 .18269 -24 -4.5 ]
[-0.0125 .18269 0 4.5 ]
[-0.0125 .26682 -24 -4.5 ]
[-0.0125 .26682 0 4.5 ]
[-0.0125 .35094 -24 -4.5 ]
[-0.0125 .35094 0 4.5 ]
[-0.0125 .43507 -24 -4.5 ]
[-0.0125 .43507 0 4.5 ]
[-0.0125 .51919 -24 -4.5 ]
[-0.0125 .51919 0 4.5 ]
[-0.0125 .60332 -24 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -38 ]
[-0.01875 .30902 -24 38 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -114 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Yield) show
99.000000 12.812500 moveto
(to) show
117.000000 12.812500 moveto
(maturity) show
165.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .01444 m
.00625 .01444 L
s
[(500)] -0.0125 .01444 1 0 Mshowa
0 .09856 m
.00625 .09856 L
s
[(1000)] -0.0125 .09856 1 0 Mshowa
0 .18269 m
.00625 .18269 L
s
[(1500)] -0.0125 .18269 1 0 Mshowa
0 .26682 m
.00625 .26682 L
s
[(2000)] -0.0125 .26682 1 0 Mshowa
0 .35094 m
.00625 .35094 L
s
[(2500)] -0.0125 .35094 1 0 Mshowa
0 .43507 m
.00625 .43507 L
s
[(3000)] -0.0125 .43507 1 0 Mshowa
0 .51919 m
.00625 .51919 L
s
[(3500)] -0.0125 .51919 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(4000)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03126 m
.00375 .03126 L
s
0 .04809 m
.00375 .04809 L
s
0 .06491 m
.00375 .06491 L
s
0 .08174 m
.00375 .08174 L
s
0 .11539 m
.00375 .11539 L
s
0 .13221 m
.00375 .13221 L
s
0 .14904 m
.00375 .14904 L
s
0 .16587 m
.00375 .16587 L
s
0 .19952 m
.00375 .19952 L
s
0 .21634 m
.00375 .21634 L
s
0 .23317 m
.00375 .23317 L
s
0 .24999 m
.00375 .24999 L
s
0 .28364 m
.00375 .28364 L
s
0 .30047 m
.00375 .30047 L
s
0 .31729 m
.00375 .31729 L
s
0 .33412 m
.00375 .33412 L
s
0 .36777 m
.00375 .36777 L
s
0 .38459 m
.00375 .38459 L
s
0 .40142 m
.00375 .40142 L
s
0 .41824 m
.00375 .41824 L
s
0 .45189 m
.00375 .45189 L
s
0 .46872 m
.00375 .46872 L
s
0 .48554 m
.00375 .48554 L
s
0 .50237 m
.00375 .50237 L
s
0 .53602 m
.00375 .53602 L
s
0 .55284 m
.00375 .55284 L
s
0 .56967 m
.00375 .56967 L
s
0 .58649 m
.00375 .58649 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -129.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
99 10.2813 translate
90 rotate
-99 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bond) show
93.000000 12.812500 moveto
(payment) show
135.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01444 m
1 .01444 L
s
.99375 .09856 m
1 .09856 L
s
.99375 .18269 m
1 .18269 L
s
.99375 .26682 m
1 .26682 L
s
.99375 .35094 m
1 .35094 L
s
.99375 .43507 m
1 .43507 L
s
.99375 .51919 m
1 .51919 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03126 m
1 .03126 L
s
.99625 .04809 m
1 .04809 L
s
.99625 .06491 m
1 .06491 L
s
.99625 .08174 m
1 .08174 L
s
.99625 .11539 m
1 .11539 L
s
.99625 .13221 m
1 .13221 L
s
.99625 .14904 m
1 .14904 L
s
.99625 .16587 m
1 .16587 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .21634 m
1 .21634 L
s
.99625 .23317 m
1 .23317 L
s
.99625 .24999 m
1 .24999 L
s
.99625 .28364 m
1 .28364 L
s
.99625 .30047 m
1 .30047 L
s
.99625 .31729 m
1 .31729 L
s
.99625 .33412 m
1 .33412 L
s
.99625 .36777 m
1 .36777 L
s
.99625 .38459 m
1 .38459 L
s
.99625 .40142 m
1 .40142 L
s
.99625 .41824 m
1 .41824 L
s
.99625 .45189 m
1 .45189 L
s
.99625 .46872 m
1 .46872 L
s
.99625 .48554 m
1 .48554 L
s
.99625 .50237 m
1 .50237 L
s
.99625 .53602 m
1 .53602 L
s
.99625 .55284 m
1 .55284 L
s
.99625 .56967 m
1 .56967 L
s
.99625 .58649 m
1 .58649 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .14904 m
.06244 .14429 L
.10458 .13926 L
.14415 .13467 L
.18221 .13037 L
.22272 .12592 L
.26171 .12175 L
.30316 .11744 L
.34309 .11341 L
.3815 .10963 L
.42237 .10571 L
.46172 .10204 L
.49955 .0986 L
.53984 .09504 L
.57861 .0917 L
.61984 .08824 L
.65954 .08499 L
.69774 .08195 L
.73838 .0788 L
.77751 .07584 L
.81909 .07278 L
.85916 .06991 L
.89771 .06721 L
.93871 .06442 L
.97619 .06193 L
s
.02381 .26682 m
.06244 .24677 L
.10458 .22657 L
.14415 .20905 L
.18221 .19342 L
.22272 .17798 L
.26171 .1642 L
.30316 .15062 L
.34309 .13849 L
.3815 .12764 L
.42237 .1169 L
.46172 .10729 L
.49955 .09866 L
.53984 .0901 L
.57861 .08241 L
.61984 .07478 L
.65954 .06794 L
.69774 .06177 L
.73838 .05564 L
.77751 .05012 L
.81909 .04463 L
.85916 .03969 L
.89771 .03522 L
.93871 .03077 L
.97619 .02694 L
s
.02381 .60332 m
.06244 .5095 L
.10458 .426 L
.14415 .36187 L
.18221 .31066 L
.22272 .26525 L
.26171 .22874 L
.30316 .1962 L
.34309 .16982 L
.3815 .1482 L
.42237 .12854 L
.46172 .11228 L
.49955 .09871 L
.53984 .08612 L
.57861 .07552 L
.61984 .06562 L
.65954 .05721 L
.69774 .05001 L
.73838 .04317 L
.77751 .03726 L
.81909 .03161 L
.85916 .02669 L
.89771 .02239 L
.93871 .01821 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{295.563, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40O003h00Oogoo:7oo003oOolX
Ool00?moobQoo`00cGoo0P00F7oo003>Ool00`00Oomoo`1FOol007Aoo`<0009oo`<000=oo`80009o
o`<000=oo`<000eoo`8000=oo`8000Uoo`06001oo`00Ool007oo10000Woo0P000goo0`0000Aoo`00
0000009oo`<000=oo`8000=oo`03001oogoo05Ioo`00MGoo00<007ooOol00Woo00D007ooOomoo`00
00Eoo`05001oogooOol00002Ool00`00Oomoo`0:Ool01P00Oomoo`00Ool0009oo`03001oogoo00Io
o`06001oo`00Ool007oo0`000Woo00H007ooOol007oo0002Ool01000Oomoo`0017oo00D007ooOomo
o`00009oo`05001oo`00Ool0001GOol007Eoo`03001oogoo009oo`04001oogooOol30003Ool01@00
Oomoogoo00000Woo00<007ooOol02Woo00<007ooOol00Woo00@007ooOol000Qoo`05001oo`00Ool0
0003Ool01000Oomoo`0017oo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Ool0001GOol007Aoo`03001oo`00009oo`8000=oo`<000=oo`03001oogoo009oo`<000]oo`@0
00=oo`8000Uoo`800003Ool007oo009oo`800003Ool0000000800004Ool00000Ool200000goo0000
000200000goo00000002Ool4000017oo000007oo0P00EWoo001cOol01@00Oomoogoo000037oo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol06Goo00<007ooOol04Goo00<007ooOol0G7oo001c
Ool200000goo00000002Ool00`00Oomoo`06Ool20005Ool2000hOol00`00Oomoo`1POol00?moobQo
o`00ogoo:7oo003oOolXOol002ioo`03001oogoo035oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo02aoo`03001oogoo009oo`03001oogoo00D002aoo`03001oogoo009o
o`03001oogoo00D0009oo`03001oogoo02eoo`03001oogoo009oo`04001oogooOol30003Ool002eo
o`03001oo`00035oo`03001oo`0000Moo`03001oo`00009oo`03001oo`0002aoo`03001oo`0000Qo
o`03001oogoo02]oo`03001oo`0000Qoo`07001oogooOol007oo0000;Goo00<007oo00001goo00<0
07ooOol00goo000]Ool00`00Ool0000aOol00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`0Z
Ool00`00Ool00008Ool00`00Oomoo`0[Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`0[
Ool00`00Ool00008Ool00`00Oomoo`02Ool002eoo`03001oo`00035oo`03001oo`0000Moo`03001o
o`00009oo`8002eoo`03001oo`0000Qoo`03001oogoo02]oo`03001oo`0000Qoo`04001oogooOol2
000^Ool00`00Ool00008Ool00`00Oomoo`02Ool002eoo`03001oo`00035oo`03001oo`0000Moo`03
001oo`00009oo`03001oogoo02aoo`03001oo`0000Qoo`03001oogoo02]oo`03001oo`0000Qoo`05
001oogooOol0000_Ool00`00Ool00007Ool00`00Ool00003Ool002ioo`03001oogoo035oo`03001o
ogoo00Moo`04001oogooOol3000]Ool00`00Oomoo`06Ool2000^Ool00`00Oomoo`06Ool20003Ool3
000^Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00?moobQoo`00ogoo:7oo003oOolXOol00?moobQo
o`00ogoo:7oo000YOook0003Ool002Uoo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo005o
o`006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool0>7oo00<007ooOol0>Goo00<007ooOol0>7oo00<007ooOol0>Goo00<007ooOol00goo00<007oo
Ool00Goo000HOol00`00Ool00002Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`3gOol0
0`00Oomoo`01Ool001Yoo`06001oogoo001oo`000Woo00<007oo000017oo0P00kWoo1@000goo0`00
0goo000HOol20003Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`3SOol:000:Ool00`00
Oomoo`01Ool001Qoo`03001oogoo009oo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo0=Uo
o`X001Aoo`03001oogoo005oo`0067oo0`000goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool0d7oo2@0057oo1@001Goo00<007ooOol00Goo000YOol20039Ool8000COol:0009Ool20003Ool0
02Uoo`03001oogoo0<9oo`H0015oo`X001Aoo`03001oogoo005oo`00:Goo00<007ooOol0^goo1`00
3Woo2@007Woo00<007ooOol00Goo000YOol00`00Oomoo`2dOol7000=Ool8000WOol00`00Oomoo`01
Ool002Uoo`800:moo`H000ioo`H002ioo`8000=oo`00:Goo00<007ooOol0ZGoo1@003Goo1`00=Goo
00<007ooOol00Goo000YOol00`00Oomoo`2UOol4000;Ool7000lOol00`00Oomoo`01Ool002Uoo`03
001oogoo0:1oo`D000Uoo`H004=oo`03001oogoo005oo`00:Goo00<007ooOol0Vgoo1@001goo1`00
=Goo3`001Goo00<007ooOol00Goo000YOol2002GOol50005Ool7000bOol:000COol20003Ool002Uo
o`03001oogoo095oo`D000Eoo`D0031oo`T001ioo`03001oogoo005oo`00:Goo00<007ooOol0SGoo
10001Goo1@0087oo5@009goo00<007ooOol00Goo000YOol00`00Oomoo`2:Ool30004Ool5000KOol:
000lOol00`00Oomoo`01Ool002Uoo`8008Moo`@0009oo`D001Ioo`X004Eoo`8000=oo`00:Goo00<0
07ooOol0Pgoo0`0000=oo`0000000`0027oo4`00D7oo00<007ooOol00Goo000BOol50002Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`20Ool70003Ool:001SOol00`00
Oomoo`01Ool001Aoo`07001oogooOol007oo00000Woo00<007oo00000Woo00<007oo000017oo00<0
07ooOol0O7oo3P00KGoo00<007ooOol00Goo000DOol01`00Oomoogoo001oo`00009oo`03001oo`00
009oo`03001oo`0000Aoo`8007Moo`X007Eoo`<000=oo`0057oo00L007ooOomoo`00Ool00002Ool0
0`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`1/Ool=001nOol00`00Oomoo`01Ool001Aoo`07
001oogooOol007oo00000Woo00<007oo00000Woo00<007oo000017oo00<007ooOol0HWoo2P000goo
1`00PGoo00<007ooOol00Goo000COol20004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`1HOol:000:Ool60025Ool00`00Oomoo`01Ool002Uoo`80051oo`T0011oo`@0
0003Ool0000008Moo`8000=oo`00:Goo00<007ooOol0A7oo2`005Goo10000Woo0`00RWoo00<007oo
Ool00Goo000YOol00`00Oomoo`0jOol:000KOol50004Ool2002=Ool00`00Oomoo`01Ool002Uoo`03
001oogoo031oo`X0025oo`@000Moo`8008moo`03001oogoo005oo`00:Goo0P009goo2P00:7oo0`00
2Goo0P00T7oo0P000goo000YOol00`00Oomoo`0MOol9000_Ool3000:Ool2002COol00`00Oomoo`01
Ool002Uoo`03001oogoo019oo`/003Eoo`<000]oo`8009Eoo`03001oogoo005oo`00:Goo00<007oo
Ool02Woo2000?Goo0`0037oo0P00Ugoo00<007ooOol00Goo000YOol00`00Oomoo`06Ool40011Ool4
000=Ool2002IOol00`00Oomoo`01Ool002Uoo`8000Aoo`<0049oo`<000moo`8009Yoo`8000=oo`00
:Goo00<007ooOol0A7oo10004Goo00<007ooOol0Vgoo00<007ooOol00Goo000YOol00`00Oomoo`10
Ool4000COol2002NOol00`00Oomoo`01Ool002Uoo`03001oogoo03eoo`<001Ioo`03001oogoo09io
o`03001oogoo005oo`00:Goo0P00?7oo0P005goo0P00X7oo0P000goo0002Ool00`00Oomoo`02Ool0
0`00Oomoo`0OOol00`00Oomoo`0hOol3000HOol00`00Oomoo`2QOol00`00Oomoo`01Ool0009oo`H0
00Yoo`D0009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo03Ioo`80
01Uoo`800:Aoo`03001oogoo005oo`000Woo00<007oo00000Woo00<007ooOol02Woo00L007ooOomo
o`00Ool00002Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`0cOol3000IOol2002VOol0
0`00Oomoo`01Ool0009oo`03001oo`00009oo`03001oogoo00Yoo`03001oogoo00=oo`06001oogoo
001oo`000Woo00<007oo000017oo0P00<Woo0P006goo00<007ooOol0Y7oo0`000goo0003Ool01000
Ool000003Goo00@007ooOomoo`8000=oo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo02io
o`<001]oo`800:Uoo`03001oogoo005oo`0057oo00D007ooOomoo`0000Aoo`03001oo`00009oo`03
001oo`0000Aoo`03001oogoo02aoo`8001aoo`800:]oo`03001oogoo005oo`004goo0P000goo0`00
0goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0:Goo0`007Goo00<007ooOol0Zgoo00<0
07ooOol00Goo0005Ool2000ROol2000XOol2000OOol00`00Oomoo`2[Ool20003Ool000Aoo`04001o
ogoo000QOol00`00Oomoo`0UOol2000OOol2002_Ool00`00Oomoo`01Ool000Aoo`04001oogoo000Q
Ool00`00Oomoo`0SOol2000POol00`00Oomoo`2_Ool00`00Oomoo`01Ool000Eoo`80029oo`03001o
ogoo021oo`<0025oo`03001oogoo0;1oo`03001oogoo005oo`00:Goo0P007goo0P008goo00<007oo
Ool0/7oo0P000goo0004Ool01000Oomoo`008Goo00<007ooOol06goo0`0097oo00<007ooOol0/Woo
00<007ooOol00Goo0004Ool4000QOol00`00Oomoo`0IOol2000UOol2002eOol00`00Oomoo`01Ool0
00Aoo`03001oogoo029oo`03001oogoo01Ioo`<002Ioo`03001oogoo0;Eoo`03001oogoo005oo`00
17oo00<007ooOol08Woo00<007ooOol057oo0P00:7oo00<007ooOol0]Woo00<007ooOol00Goo0005
Ool3000QOol2000COol2000YOol00`00Oomoo`2fOol20003Ool000Moo`03001oogoo01moo`03001o
ogoo011oo`8002Yoo`03001oogoo0;Qoo`03001oogoo005oo`00:Goo00<007ooOol03Woo0P00:goo
00<007ooOol0^Goo00<007ooOol00Goo0005Ool2000ROol00`00Oomoo`0<Ool2000/Ool00`00Oomo
o`2jOol00`00Oomoo`01Ool000Aoo`04001oogoo000QOol2000;Ool2000/Ool2002lOol20003Ool0
009oo`03001oo`00009oo`03001oogoo01moo`03001oogoo00Qoo`8002eoo`03001oogoo0;eoo`03
001oogoo005oo`000Woo1P002goo0`000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol01Woo0P00;Woo00<007ooOol0_Woo00<007ooOol00Goo0007Ool00`00Oomoo`09
Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`04
Ool2000_Ool00`00Oomoo`2oOol00`00Oomoo`01Ool001Aoo`07001oogooOol007oo00000Woo00<0
07oo00000Woo00<007oo000017oo0P0017oo00<007ooOol0;Woo00<007ooOol0_Woo0`000goo000D
Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo03=oo`03
001oogoo0<5oo`03001oogoo005oo`004goo00<007oo00000Woo00<007oo00000Woo00<007oo0000
0Woo00<007oo000017oo00<007ooOol0<Woo00<007ooOol0`Woo00<007ooOol00Goo000DOol00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0aOol00`00
Oomoo`33Ool00`00Oomoo`01Ool002Uoo`80035oo`03001oogoo0<=oo`8000=oo`00:Goo00<007oo
Ool0;goo00<007ooOol0aGoo00<007ooOol00Goo0004Ool00`00Oomoo`02Ool00`00Oomoo`0MOol0
0`00Oomoo`0_Ool00`00Oomoo`35Ool00`00Oomoo`01Ool000Aoo`H001moo`03001oogoo02ioo`03
001oogoo0<Ioo`03001oogoo005oo`0017oo00H007ooOol007oo000OOol2000^Ool00`00Oomoo`36
Ool20003Ool000Aoo`04001oogoo000QOol00`00Oomoo`0/Ool00`00Oomoo`38Ool00`00Oomoo`01
Ool000Eoo`80029oo`03001oogoo02]oo`03001oogoo0<Uoo`03001oogoo005oo`00:Goo00<007oo
Ool0:Woo00<007ooOol0bWoo00<007ooOol00Goo000YOol00`00Oomoo`0YOol00`00Oomoo`3;Ool0
0`00Oomoo`01Ool000Ioo`80025oo`8002Yoo`03001oogoo0<Yoo`8000=oo`0017oo00@007oo0000
025oo`03001oogoo02Qoo`03001oogoo0<aoo`03001oogoo005oo`0017oo00@007oo0000025oo`03
001oogoo02Moo`03001oogoo0<eoo`03001oogoo005oo`0017oo10008Goo00<007ooOol09goo00<0
07ooOol0cGoo00<007ooOol00Goo0007Ool00`00Oomoo`0OOol2000WOol00`00Oomoo`3=Ool20003
Ool000Aoo`03001oogoo029oo`03001oogoo02Eoo`03001oogoo0<moo`03001oogoo005oo`0017oo
0P000goo00<007ooOol01goo0`000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol097oo00<007ooOol0d7oo00<007ooOol00Goo0004Ool01000Ool007oo0P002Goo00<0
07ooOol00Woo00<007oo00000Woo00<007oo00000Woo00<007oo000017oo00<007ooOol097oo00<0
07ooOol0d7oo00<007ooOol00Goo0007Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool01P00Oomoo`00
Ool0009oo`03001oo`0000Aoo`8002Aoo`03001oogoo0<moo`<000=oo`0017oo0`003Goo00@007oo
Oomoo`8000=oo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo029oo`03001oogoo0=9oo`03
001oogoo005oo`0017oo00<007ooOol037oo00<007oo00000Woo00<007ooOol00Woo00<007oo0000
0Woo00<007oo000017oo00<007ooOol08Woo00<007ooOol0dWoo00<007ooOol00Goo0004Ool01000
Oomoo`0037oo00@007ooOomoo`<000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo025o
o`03001oogoo0==oo`03001oogoo005oo`0017oo10008Goo0P008Goo00<007ooOol0dgoo0P000goo
0004Ool00`00Oomoo`0ROol00`00Oomoo`0POol00`00Oomoo`3DOol00`00Oomoo`01Ool000Eoo`<0
025oo`03001oogoo01moo`03001oogoo0=Eoo`03001oogoo005oo`0017oo00<007ooOol08Woo00<0
07ooOol07Woo00<007ooOol0eWoo00<007ooOol00Goo0005Ool3000QOol00`00Oomoo`0NOol00`00
Oomoo`3FOol00`00Oomoo`01Ool002Uoo`8001ioo`03001oogoo0=Ioo`8000=oo`001Goo0P008Woo
00<007ooOol07Goo00<007ooOol0egoo00<007ooOol00Goo0004Ool200000goo001oo`0POol00`00
Oomoo`0LOol00`00Oomoo`3HOol00`00Oomoo`01Ool000Aoo`800003Ool007oo021oo`03001oogoo
01]oo`03001oogoo0=Uoo`03001oogoo005oo`001Goo00<007oo00008Goo0P0077oo00<007ooOol0
f7oo0P000goo000YOol00`00Oomoo`0JOol00`00Oomoo`3JOol00`00Oomoo`01Ool000Aoo`04001o
ogoo000QOol00`00Oomoo`0IOol00`00Oomoo`3KOol00`00Oomoo`01Ool000Aoo`@0025oo`03001o
ogoo01Uoo`03001oogoo0=]oo`03001oogoo005oo`0017oo00<007ooOol08Woo0P006Goo00<007oo
Ool0fgoo0P000goo0004Ool00`00Oomoo`0ROol00`00Oomoo`0HOol00`00Oomoo`3LOol00`00Oomo
o`01Ool000Eoo`<000]oo`8000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo01Moo`03001oogoo0=eoo`03001oogoo005oo`001goo00<007ooOol02goo00H007ooOol0
07oo0002Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`0FOol00`00Oomoo`3NOol00`00
Oomoo`01Ool000Aoo`03001oogoo00eoo`07001oogooOol007oo00000Woo00<007oo00000Woo00<0
07oo000017oo0P005goo00<007ooOol0g7oo0`000goo0003Ool4000>Ool01P00Oomoo`00Ool0009o
o`03001oo`00009oo`03001oo`0000Aoo`03001oogoo01Eoo`03001oogoo0=moo`03001oogoo005o
o`0017oo00@007ooOol000]oo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001o
o`0000Aoo`03001oogoo01Eoo`03001oogoo0=moo`03001oogoo005oo`0017oo00@007ooOol000ao
o`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo01Ao
o`03001oogoo0>1oo`03001oogoo005oo`0017oo00<007oo00008Woo0P005Goo00<007ooOol0ggoo
0P000goo000YOol00`00Oomoo`0COol00`00Oomoo`3QOol00`00Oomoo`01Ool002Uoo`03001oogoo
01=oo`03001oogoo0>5oo`03001oogoo005oo`00:Goo00<007ooOol04Woo00<007ooOol0hWoo00<0
07ooOol00Goo000YOol00`00Oomoo`0BOol00`00Oomoo`3ROol00`00Oomoo`01Ool002Uoo`80019o
o`03001oogoo0>9oo`8000=oo`00:Goo00<007ooOol04Goo00<007ooOol0hgoo00<007ooOol00Goo
000YOol00`00Oomoo`0@Ool00`00Oomoo`3TOol00`00Oomoo`01Ool002Uoo`03001oogoo011oo`03
001oogoo0>Aoo`03001oogoo005oo`00:Goo0P0047oo00<007ooOol0i7oo0P000goo000YOol00`00
Oomoo`0?Ool00`00Oomoo`3UOol00`00Oomoo`01Ool002Uoo`03001oogoo00ioo`03001oogoo0>Io
o`03001oogoo005oo`00:Goo00<007ooOol03Woo00<007ooOol0iWoo00<007ooOol00Goo000YOol2
000>Ool00`00Oomoo`3VOol20003Ool002Uoo`03001oogoo00eoo`03001oogoo0>Moo`03001oogoo
005oo`004goo0P0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
37oo00<007ooOol0j7oo00<007ooOol00Goo000EOol01P00Oomoo`00Ool0009oo`03001oo`00009o
o`03001oo`0000Aoo`03001oogoo00aoo`03001oogoo0>Qoo`03001oogoo005oo`0057oo00<007oo
Ool00goo00H007ooOol007oo0002Ool00`00Ool00004Ool2000<Ool00`00Oomoo`3WOol30003Ool0
01Eoo`03001oogoo008000=oo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo00]oo`03001o
ogoo0>Uoo`03001oogoo005oo`004goo00<007oo00000Woo00<007ooOol00Woo00<007oo00000Woo
00<007oo000017oo00<007ooOol02Woo00<007ooOol0jWoo00<007ooOol00Goo000DOol01000Oomo
ogoo0`000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol02Woo00<007ooOol0jWoo00<0
07ooOol00Goo000YOol2000;Ool00`00Oomoo`3YOol20003Ool002Uoo`03001oogoo00Uoo`03001o
ogoo0>]oo`03001oogoo005oo`00:Goo00<007ooOol02Goo00<007ooOol0jgoo00<007ooOol00Goo
000YOol00`00Oomoo`08Ool00`00Oomoo`3/Ool00`00Oomoo`01Ool002Uoo`03001oogoo00Qoo`03
001oogoo0>aoo`03001oogoo005oo`00:Goo0P002Goo00<007ooOol0jgoo0P000goo000YOol00`00
Oomoo`07Ool00`00Oomoo`3]Ool00`00Oomoo`01Ool002Uoo`03001oogoo00Moo`03001oogoo0>eo
o`03001oogoo005oo`00:Goo00<007ooOol01goo00<007ooOol0kGoo00<007ooOol00Goo000YOol2
0007Ool00`00Oomoo`3]Ool20003Ool002Uoo`03001oogoo00Ioo`03001oogoo0>ioo`03001oogoo
005oo`00:Goo00<007ooOol01Goo00<007ooOol0kgoo00<007ooOol00Goo000YOol00`00Oomoo`05
Ool00`00Oomoo`3_Ool00`00Oomoo`01Ool002Uoo`8000Ioo`03001oogoo0>ioo`8000=oo`00:Goo
00<007ooOol017oo00<007ooOol0l7oo00<007ooOol00Goo000DOol30002Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`3`Ool00`00Oomoo`01Ool0
01Eoo`06001oogoo001oo`000Woo00<007oo00000Woo00<007oo000017oo00<007ooOol00goo00<0
07ooOol0lGoo00<007ooOol00Goo000COol4000017oo001oo`000Woo00<007oo00000Woo00<007oo
000017oo0P0017oo00<007ooOol0kgoo0`000goo000COol00`00Ool00002Ool00`00Ool00002Ool0
0`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`3gOol00`00Oomoo`01Ool001Aoo`80009oo`03
001oo`00009oo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo00=oo`03001oogoo03Qoo`03
001oogoo03Uoo`03001oogoo03Qoo`03001oogoo03Uoo`03001oogoo00=oo`03001oogoo005oo`00
5Goo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001o
ogoo00=oo`03001oogoo005oo`00:Goon`000goo003oOolXOol00001\
\>"],
  ImageRangeCache->{{{0, 294.563}, {181.625, 0}} -> {-0.0396186, -189.355, 
  0.000839113, 23.7489}}]
}, Open  ]],

Cell["\<\
It is interesting to look at the bond payment as a function of the \
length of time between the settlement and maturity. \
\>", "Text",
  CellTags->"0.24"],

Cell[TextData[{
  "Let ",
  StyleBox["abc", "MB"],
  " be a bond that pays semiannual interest and matures on September 15, \
2003. The redemption value is 100 units and the coupon rate is ",
  StyleBox["c", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.25"],

Cell[CellGroupData[{

Cell["abc = Bond[{c, {9, 15, 2023}, 100, 2}]", "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(Bond[{c, {9, 15, 2023}, 100, 2}]\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
We assume a 7% yield to maturity. We create a table of bond \
payments for different times to maturity. \
\>", "MathCaption",
  CellTags->"0.26"],

Cell["\<\
p[c_] = Table[{t, Payment[abc, {9, 15, 1993 + t}, 7/100]}, {t, 0, 30}];\
\>", "Input",
  CellLabel->"In[21]:="],

Cell["Here is another label. ", "MathCaption",
  CellTags->"0.27"],

Cell["label2 = {\"Time in years\", \"Bond payment\"};", "Input",
  CellLabel->"In[22]:="],

Cell[TextData[{
  "For a 10% coupon rate, ",
  StyleBox["abc", "MB"],
  " is a premium bond. Its payment decreases over time. "
}], "MathCaption",
  CellTags->"0.28"],

Cell[CellGroupData[{

Cell["\<\
graph1 = ListPlot[p[10 Percent],
   PlotJoined -> True, FrameLabel -> label2];\
\>", "Input",
  CellLabel->"In[23]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 -1.55837 0.0157309 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -41 -21.5625 ]
[.5 -0.0125 41 -9 ]
[-0.0125 .01472 -18 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09337 -18 -4.5 ]
[-0.0125 .09337 0 4.5 ]
[-0.0125 .17202 -18 -4.5 ]
[-0.0125 .17202 0 4.5 ]
[-0.0125 .25068 -18 -4.5 ]
[-0.0125 .25068 0 4.5 ]
[-0.0125 .32933 -18 -4.5 ]
[-0.0125 .32933 0 4.5 ]
[-0.0125 .40799 -18 -4.5 ]
[-0.0125 .40799 0 4.5 ]
[-0.0125 .48664 -18 -4.5 ]
[-0.0125 .48664 0 4.5 ]
[-0.0125 .5653 -18 -4.5 ]
[-0.0125 .5653 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -38 ]
[-0.01875 .30902 -18 38 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -102 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
93.000000 12.812500 moveto
(in) show
111.000000 12.812500 moveto
(years) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(100)] -0.0125 .01472 1 0 Mshowa
0 .09337 m
.00625 .09337 L
s
[(105)] -0.0125 .09337 1 0 Mshowa
0 .17202 m
.00625 .17202 L
s
[(110)] -0.0125 .17202 1 0 Mshowa
0 .25068 m
.00625 .25068 L
s
[(115)] -0.0125 .25068 1 0 Mshowa
0 .32933 m
.00625 .32933 L
s
[(120)] -0.0125 .32933 1 0 Mshowa
0 .40799 m
.00625 .40799 L
s
[(125)] -0.0125 .40799 1 0 Mshowa
0 .48664 m
.00625 .48664 L
s
[(130)] -0.0125 .48664 1 0 Mshowa
0 .5653 m
.00625 .5653 L
s
[(135)] -0.0125 .5653 1 0 Mshowa
.125 Mabswid
0 .03045 m
.00375 .03045 L
s
0 .04618 m
.00375 .04618 L
s
0 .06191 m
.00375 .06191 L
s
0 .07764 m
.00375 .07764 L
s
0 .1091 m
.00375 .1091 L
s
0 .12483 m
.00375 .12483 L
s
0 .14056 m
.00375 .14056 L
s
0 .15629 m
.00375 .15629 L
s
0 .18775 m
.00375 .18775 L
s
0 .20349 m
.00375 .20349 L
s
0 .21922 m
.00375 .21922 L
s
0 .23495 m
.00375 .23495 L
s
0 .26641 m
.00375 .26641 L
s
0 .28214 m
.00375 .28214 L
s
0 .29787 m
.00375 .29787 L
s
0 .3136 m
.00375 .3136 L
s
0 .34506 m
.00375 .34506 L
s
0 .36079 m
.00375 .36079 L
s
0 .37653 m
.00375 .37653 L
s
0 .39226 m
.00375 .39226 L
s
0 .42372 m
.00375 .42372 L
s
0 .43945 m
.00375 .43945 L
s
0 .45518 m
.00375 .45518 L
s
0 .47091 m
.00375 .47091 L
s
0 .50237 m
.00375 .50237 L
s
0 .5181 m
.00375 .5181 L
s
0 .53383 m
.00375 .53383 L
s
0 .54956 m
.00375 .54956 L
s
0 .58103 m
.00375 .58103 L
s
0 .59676 m
.00375 .59676 L
s
0 .61249 m
.00375 .61249 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -123.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
99 10.2813 translate
90 rotate
-99 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bond) show
93.000000 12.812500 moveto
(payment) show
135.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09337 m
1 .09337 L
s
.99375 .17202 m
1 .17202 L
s
.99375 .25068 m
1 .25068 L
s
.99375 .32933 m
1 .32933 L
s
.99375 .40799 m
1 .40799 L
s
.99375 .48664 m
1 .48664 L
s
.99375 .5653 m
1 .5653 L
s
.125 Mabswid
.99625 .03045 m
1 .03045 L
s
.99625 .04618 m
1 .04618 L
s
.99625 .06191 m
1 .06191 L
s
.99625 .07764 m
1 .07764 L
s
.99625 .1091 m
1 .1091 L
s
.99625 .12483 m
1 .12483 L
s
.99625 .14056 m
1 .14056 L
s
.99625 .15629 m
1 .15629 L
s
.99625 .18775 m
1 .18775 L
s
.99625 .20349 m
1 .20349 L
s
.99625 .21922 m
1 .21922 L
s
.99625 .23495 m
1 .23495 L
s
.99625 .26641 m
1 .26641 L
s
.99625 .28214 m
1 .28214 L
s
.99625 .29787 m
1 .29787 L
s
.99625 .3136 m
1 .3136 L
s
.99625 .34506 m
1 .34506 L
s
.99625 .36079 m
1 .36079 L
s
.99625 .37653 m
1 .37653 L
s
.99625 .39226 m
1 .39226 L
s
.99625 .42372 m
1 .42372 L
s
.99625 .43945 m
1 .43945 L
s
.99625 .45518 m
1 .45518 L
s
.99625 .47091 m
1 .47091 L
s
.99625 .50237 m
1 .50237 L
s
.99625 .5181 m
1 .5181 L
s
.99625 .53383 m
1 .53383 L
s
.99625 .54956 m
1 .54956 L
s
.99625 .58103 m
1 .58103 L
s
.99625 .59676 m
1 .59676 L
s
.99625 .61249 m
1 .61249 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .60332 m
.05556 .59722 L
.0873 .59069 L
.11905 .5837 L
.15079 .57621 L
.18254 .56818 L
.21429 .55958 L
.24603 .55037 L
.27778 .54051 L
.30952 .52994 L
.34127 .51862 L
.37302 .50649 L
.40476 .4935 L
.43651 .47958 L
.46825 .46467 L
.5 .4487 L
.53175 .43159 L
.56349 .41327 L
.59524 .39363 L
.62698 .3726 L
.65873 .35008 L
.69048 .32594 L
.72222 .30009 L
.75397 .2724 L
.78571 .24273 L
.81746 .21096 L
.84921 .17692 L
.88095 .14045 L
.9127 .10139 L
.94444 .05954 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[23]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00:]oo`8007=oo`00[7oo00<007ooOol0LGoo001kOol30002Ool300001Woo001oo`00Ool0009o
o`8000aoo`<00003Ool00000009oo`03001oogoo00Qoo`03001oogoo009oo`80009oo`@00004Ool0
00000002Ool2001OOol007aoo`03001oogoo009oo`0:001oogoo001oo`00Ool007oo000?Ool01@00
Oomoogoo00000Woo00<007ooOol01goo00<007oo00000Woo00<007ooOol00Woo0`000goo00<007oo
Ool00goo00<007ooOol0G7oo001lOol00`00Oomoo`02Ool02@00Oomoo`00Ool007oo001oo`03000=
Ool01@00Oomoogoo00000Woo00<007ooOol01goo00<007oo00000Woo0`0017oo00D007ooOomoo`00
00Aoo`03001oogoo05eoo`00O7oo00@007ooOomoo`80009oo`800004Ool007ooOol3000<Ool20002
Ool40009Ool2000017oo000007oo0`000goo0P000Woo10000Woo0P00GWoo001jOol01@00Ool007oo
0000XGoo001jOol50002Ool00`00Oomoo`0FOol00`00Oomoo`23Ool00?moob5oo`00ogoo8Goo003o
OolQOol002]oo`03001oogoo02Aoo`03001oogoo01moo`D0009oo`03001oogoo01ioo`D0009oo`03
001oogoo01ioo`<000=oo`03001oogoo01ioo`<000=oo`03001oogoo01ioo`8000Aoo`03001oogoo
00Eoo`00:Woo00<007oo000097oo00<007oo00008Woo00L007ooOomoo`00Ool0000QOol01`00Oomo
ogoo001oo`0001moo`03001oogoo009oo`03001oo`0001moo`03001oogoo009oo`03001oo`00025o
o`06001oogoo001oo`001Woo000ZOol00`00Ool0000VOol00`00Oomoo`0POol01`00Oomoogoo001o
o`00025oo`03001oogoo00=oo`03001oogoo01ioo`07001oogooOol007oo000087oo00<007ooOol0
0goo00<007ooOol07Woo00L007ooOomoo`00Ool00006Ool002Yoo`03001oo`0002Aoo`8002=oo`07
001oogooOol007oo00008Goo00@007ooOomoo`80025oo`07001oogooOol007oo000087oo00@007oo
Oomoo`80029oo`06001oogoo001oo`001Woo000ZOol00`00Ool0000TOol00`00Oomoo`0ROol01`00
Oomoogoo001oo`00025oo`05001oogooOol0000QOol00`00Ool00002Ool00`00Ool0000OOol00`00
Ool00002Ool00`00Oomoo`0OOol00`00Ool00002Ool00`00Ool00006Ool002]oo`03001oogoo02=o
o`<0025oo`8000Aoo`03001oogoo01moo`8000=oo`<0021oo`03001oogoo009oo`03001oogoo01mo
o`04001oogooOol3000POol00`00Oomoo`02Ool00`00Oomoo`05Ool00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo000UOooh0003Ool002Eoo`03001oogoo00=oo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00=o
o`03001oogoo005oo`004goo1@000Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo
00<007ooOol097oo00<007ooOol097oo00<007ooOol09Goo00<007ooOol097oo00<007ooOol097oo
00<007ooOol097oo00<007ooOol00goo00<007ooOol00Goo000EOol01`00Oomoogoo001oo`00009o
o`03001oo`0000Aoo`03001oogoo0?Aoo`03001oogoo005oo`005Goo00L007ooOomoo`00Ool00002
Ool00`00Ool00004Ool3003^Ool01000Oomoogoo0`000goo000EOol01`00Oomoogoo001oo`00009o
o`03001oo`0000Aoo`03001oogoo0>eoo`03001oogoo00Aoo`03001oogoo005oo`005Goo00L007oo
Oomoo`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`3]Ool00`00Oomoo`04Ool00`00Oomoo`01
Ool001Aoo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0>aoo`03001oogoo00Eo
o`03001oogoo005oo`009Goo0P00k7oo00<007ooOol01Goo0P000goo000UOol00`00Oomoo`3ZOol0
0`00Oomoo`07Ool00`00Oomoo`01Ool002Eoo`03001oogoo0>Yoo`03001oogoo00Moo`03001oogoo
005oo`009Goo00<007ooOol0jGoo00<007ooOol027oo00<007ooOol00Goo000UOol2003YOol00`00
Oomoo`08Ool20003Ool002Eoo`03001oogoo0>Moo`03001oogoo00Yoo`03001oogoo005oo`009Goo
00<007ooOol0igoo00<007ooOol02Woo00<007ooOol00Goo000UOol2003WOol00`00Oomoo`0:Ool2
0003Ool002Eoo`03001oogoo0>Eoo`03001oogoo00aoo`03001oogoo005oo`009Goo00<007ooOol0
i7oo00<007ooOol03Goo00<007ooOol00Goo000UOol00`00Oomoo`3TOol00`00Oomoo`0=Ool00`00
Oomoo`01Ool002Eoo`800>Aoo`03001oogoo00eoo`8000=oo`009Goo00<007ooOol0hWoo00<007oo
Ool03goo00<007ooOol00Goo000COol50002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`3QOol00`00Oomoo`0@Ool00`00Oomoo`01Ool001Eoo`07001oogooOol007oo00000Woo00<007oo
000017oo00<007ooOol0h7oo00<007ooOol04Goo00<007ooOol00Goo000EOol01`00Oomoogoo001o
o`0000Aoo`03001oogoo009oo`<00>1oo`03001oogoo00moo`<000=oo`005Goo00L007ooOomoo`00
Ool00002Ool20005Ool00`00Oomoo`3OOol00`00Oomoo`0BOol00`00Oomoo`01Ool001Eoo`07001o
ogooOol007oo00000Woo00<007ooOol017oo00<007ooOol0gWoo00<007ooOol04goo00<007ooOol0
0Goo000DOol20004Ool01000Oomoogoo0`0017oo00<007ooOol0gGoo00<007ooOol057oo00<007oo
Ool00Goo000UOol2003MOol00`00Oomoo`0DOol20003Ool002Eoo`03001oogoo0=aoo`03001oogoo
01Eoo`03001oogoo005oo`009Goo00<007ooOol0fgoo00<007ooOol05Woo00<007ooOol00Goo000U
Ool00`00Oomoo`3JOol00`00Oomoo`0GOol00`00Oomoo`01Ool002Eoo`800=Yoo`03001oogoo01Mo
o`8000=oo`009Goo00<007ooOol0f7oo00<007ooOol06Goo00<007ooOol00Goo000UOol00`00Oomo
o`3HOol00`00Oomoo`0IOol00`00Oomoo`01Ool002Eoo`03001oogoo0=Moo`03001oogoo01Yoo`03
001oogoo005oo`009Goo0P00egoo00<007ooOol06Woo0P000goo000UOol00`00Oomoo`3EOol00`00
Oomoo`0LOol00`00Oomoo`01Ool002Eoo`03001oogoo0=Aoo`03001oogoo01eoo`03001oogoo005o
o`009Goo00<007ooOol0e7oo00<007ooOol07Goo00<007ooOol00Goo000UOol2003DOol00`00Oomo
o`0MOol20003Ool002Eoo`03001oogoo0=9oo`03001oogoo01moo`03001oogoo005oo`001Goo00<0
07ooOol00Woo00<007ooOol01Woo2P000Woo00<007ooOol00goo00<007ooOol0dGoo00<007ooOol0
87oo00<007ooOol00Goo0005Ool6000:Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Aoo`03
001oogoo0=5oo`03001oogoo021oo`03001oogoo005oo`001Goo00<007oo00000Woo00<007ooOol0
27oo00<007ooOol00Woo00L007ooOomoo`00Ool00004Ool3003@Ool00`00Oomoo`0OOol30003Ool0
00Eoo`03001oo`00009oo`03001oogoo00Qoo`03001oogoo009oo`07001oogooOol007oo000017oo
00<007ooOol0cgoo00<007ooOol08Woo00<007ooOol00Goo0006Ool01000Ool000002goo00<007oo
Ool00Woo00L007ooOomoo`00Ool00004Ool00`00Oomoo`3>Ool00`00Oomoo`0SOol00`00Oomoo`01
Ool001Aoo`8000=oo`8000Aoo`03001oogoo00=oo`800<ioo`03001oogoo02=oo`8000=oo`009Goo
00<007ooOol0c7oo00<007ooOol09Goo00<007ooOol00Goo0008Ool2000KOol00`00Oomoo`3;Ool0
0`00Oomoo`0VOol00`00Oomoo`01Ool000Moo`04001oogoo000JOol00`00Oomoo`3:Ool00`00Oomo
o`0WOol00`00Oomoo`01Ool000Moo`04001oogoo000JOol2003:Ool00`00Oomoo`0WOol20003Ool0
00Qoo`8001]oo`03001oogoo0<Qoo`03001oogoo02Uoo`03001oogoo005oo`009Goo00<007ooOol0
agoo00<007ooOol0:Woo00<007ooOol00Goo0007Ool01000Oomoo`006Woo00<007ooOol0aWoo00<0
07ooOol0:goo00<007ooOol00Goo0007Ool4000JOol20036Ool00`00Oomoo`0[Ool20003Ool000Mo
o`03001oogoo01]oo`03001oogoo0<Aoo`03001oogoo02eoo`03001oogoo005oo`001goo00<007oo
Ool06goo00<007ooOol0`goo00<007ooOol0;Woo00<007ooOol00Goo0008Ool3000JOol00`00Oomo
o`32Ool00`00Oomoo`0_Ool00`00Oomoo`01Ool000Yoo`03001oogoo01Qoo`800<9oo`03001oogoo
02moo`8000=oo`009Goo00<007ooOol0`7oo00<007ooOol0<Goo00<007ooOol00Goo0008Ool20009
Ool:0002Ool00`00Oomoo`03Ool00`00Oomoo`2oOol00`00Oomoo`0bOol00`00Oomoo`01Ool000Mo
o`04001oogoo000:Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo0;ioo`03
001oogoo03=oo`03001oogoo005oo`001Goo00<007oo00000Woo00<007ooOol027oo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol00Woo0`00_Goo00<007ooOol0<Woo0`000goo0005Ool6000:
Ool00`00Oomoo`02Ool01000Oomoogoo0P001Goo00<007ooOol0_7oo00<007ooOol0=Goo00<007oo
Ool00Goo000:Ool00`00Oomoo`08Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00<007ooOol0
^Woo0P00>7oo00<007ooOol00Goo000DOol20003Ool20003Ool30004Ool00`00Oomoo`2iOol00`00
Oomoo`0hOol00`00Oomoo`01Ool002Eoo`800;Uoo`03001oogoo03Qoo`8000=oo`009Goo00<007oo
Ool0]goo00<007ooOol0>Woo00<007ooOol00Goo000UOol00`00Oomoo`2fOol00`00Oomoo`0kOol0
0`00Oomoo`01Ool002Eoo`03001oogoo0;Eoo`03001oogoo03aoo`03001oogoo005oo`009Goo0P00
]Goo00<007ooOol0?7oo0P000goo0007Ool00`00Oomoo`02Ool00`00Oomoo`0FOol00`00Oomoo`2b
Ool20010Ool00`00Oomoo`01Ool000Moo`H001Qoo`03001oogoo0;5oo`03001oogoo041oo`03001o
ogoo005oo`001goo00H007ooOol007oo000HOol00`00Oomoo`2`Ool00`00Oomoo`11Ool00`00Oomo
o`01Ool000Moo`04001oogoo000JOol2002`Ool00`00Oomoo`11Ool20003Ool000Qoo`8001]oo`03
001oogoo0:ioo`03001oogoo04=oo`03001oogoo005oo`009Goo00<007ooOol0[Goo00<007ooOol0
A7oo00<007ooOol00Goo000UOol2002]Ool00`00Oomoo`14Ool20003Ool000Uoo`8001Yoo`03001o
ogoo0:Yoo`8004Qoo`03001oogoo005oo`001goo00@007oo000000Qoo`D00004Ool000000003Ool0
0`00Oomoo`03Ool00`00Oomoo`2YOol00`00Oomoo`18Ool00`00Oomoo`01Ool000Moo`04001oo`00
000:Ool01@00Oomoogoo000017oo00<007oo000017oo00<007ooOol0Z7oo00<007ooOol0BGoo00<0
07ooOol00Goo0007Ool4000:Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Aoo`<00:Moo`03
001oogoo04Qoo`<000=oo`002Woo00<007ooOol027oo00<007ooOol00Woo00L007ooOomoo`00Ool0
0004Ool00`00Oomoo`2UOol2001=Ool00`00Oomoo`01Ool000Moo`03001oogoo00]oo`07001oogoo
Ool007oo00000Woo00<007oo000017oo00<007ooOol0Y7oo00<007ooOol0CGoo00<007ooOol00Goo
0007Ool20003Ool00`00Oomoo`05Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`2SOol00`00Oomoo`1>Ool00`00Oomoo`01Ool000Moo`04001oo`00Ool2000HOol2002ROol2001@
Ool20003Ool000Yoo`03001oogoo01Qoo`03001oogoo0:1oo`03001oogoo055oo`03001oogoo005o
o`001goo0`006goo00<007ooOol0Wgoo00<007ooOol0DWoo00<007ooOol00Goo0007Ool00`00Oomo
o`0KOol00`00Oomoo`2MOol2001EOol00`00Oomoo`01Ool000Moo`04001oogoo000JOol2002MOol0
0`00Oomoo`1DOol20003Ool000Moo`@001Yoo`03001oogoo09]oo`03001oogoo05Ioo`03001oogoo
005oo`001goo00<007ooOol06goo00<007ooOol0VGoo0P00FGoo00<007ooOol00Goo0008Ool3000J
Ool00`00Oomoo`2HOol00`00Oomoo`1IOol00`00Oomoo`01Ool000Moo`03001oogoo01]oo`8009Mo
o`8005]oo`8000=oo`0027oo0`006Woo00<007ooOol0UGoo00<007ooOol0G7oo00<007ooOol00Goo
000UOol00`00Oomoo`2COol2001OOol00`00Oomoo`01Ool000Qoo`8001]oo`03001oogoo095oo`80
065oo`03001oogoo005oo`001goo0P0000=oo`00Ool06Goo0P00TGoo00<007ooOol0H7oo0P000goo
0007Ool200000goo001oo`0IOol00`00Oomoo`2>Ool2001TOol00`00Oomoo`01Ool000Qoo`03001o
o`0000Qoo`D00004Ool000000003Ool00`00Oomoo`03Ool00`00Oomoo`2=Ool00`00Oomoo`1TOol0
0`00Oomoo`01Ool001Eoo`05001oogooOol00004Ool00`00Ool00004Ool00`00Oomoo`2;Ool2001W
Ool00`00Oomoo`01Ool000Moo`04001oogoo000:Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool30029Ool2001WOol30003Ool000Moo`@000Yoo`03001oogoo009oo`04001oogooOol2
0005Ool00`00Oomoo`28Ool00`00Oomoo`1YOol00`00Oomoo`01Ool000Moo`03001oogoo00]oo`07
001oogooOol007oo00000Woo00<007ooOol017oo00<007ooOol0QWoo0P00K7oo00<007ooOol00Goo
0007Ool00`00Oomoo`0:Ool20004Ool01000Oomoogoo0`0017oo00<007ooOol0QGoo00<007ooOol0
K7oo00<007ooOol00Goo0008Ool3000JOol20024Ool2001^Ool20003Ool000Yoo`03001oogoo01Qo
o`03001oogoo085oo`80075oo`03001oogoo005oo`001goo00<007ooOol06goo00<007ooOol0P7oo
00<007ooOol0LGoo00<007ooOol00Goo0006Ool4000KOol2001oOol2001cOol20003Ool000Moo`04
001oogoo000JOol00`00Oomoo`1lOol2001fOol00`00Oomoo`01Ool000Moo`04001oogoo000JOol0
0`00Oomoo`1jOol2001hOol00`00Oomoo`01Ool000Moo`03001oo`0001]oo`03001oogoo07Uoo`03
001oogoo07Qoo`03001oogoo005oo`009Goo0P00N7oo0P00NWoo0P000goo000UOol00`00Oomoo`1e
Ool2001mOol00`00Oomoo`01Ool002Eoo`03001oogoo07=oo`8007moo`03001oogoo005oo`009Goo
00<007ooOol0L7oo0`00PGoo00<007ooOol00Goo000UOol2001_Ool20023Ool20003Ool002Eoo`03
001oogoo06]oo`<008Ioo`03001oogoo005oo`004goo1@0000=oo`00000017oo00<007ooOol00goo
00<007ooOol0JGoo0P00RGoo00<007ooOol00Goo000EOol00`00Oomoo`03Ool01P00Oomoo`00Ool0
00Aoo`03001oogoo06Moo`8008]oo`03001oogoo005oo`005Goo00<007ooOol00Woo00L007ooOomo
o`00Ool00004Ool3001UOol2002;Ool30003Ool001Eoo`03001oogoo00=oo`06001oogoo001oo`00
17oo00<007ooOol0Hgoo0P00Sgoo00<007ooOol00Goo000EOol01`00Oomoogoo001oo`00009oo`03
001oo`0000Aoo`03001oogoo061oo`<0095oo`03001oogoo005oo`0057oo0P0017oo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol0GWoo0P00U7oo00<007ooOol00Goo000UOol2001LOol3002E
Ool20003Ool002Eoo`03001oogoo05Qoo`<009Uoo`03001oogoo005oo`009Goo00<007ooOol0EWoo
0P00W7oo00<007ooOol00Goo000UOol00`00Oomoo`1COol3002NOol00`00Oomoo`01Ool002Eoo`80
055oo`<00:1oo`8000=oo`009Goo00<007ooOol0CWoo0P00Y7oo00<007ooOol00Goo000UOol00`00
Oomoo`1<Ool2002VOol00`00Oomoo`01Ool002Eoo`03001oogoo04Uoo`<00:Qoo`03001oogoo005o
o`009Goo0P00AWoo1000ZWoo0P000goo000UOol00`00Oomoo`11Ool4002_Ool00`00Oomoo`01Ool0
02Eoo`03001oogoo03moo`800;=oo`03001oogoo005oo`009Goo00<007ooOol0?7oo0`00]Goo00<0
07ooOol00Goo000UOol2000jOol3002gOol20003Ool002Eoo`03001oogoo03Eoo`@00;]oo`03001o
ogoo005oo`004goo1@0000=oo`00000017oo00<007ooOol00goo00<007ooOol0<Goo1000_goo00<0
07ooOol00Goo000EOol00`00Oomoo`03Ool01P00Oomoo`00Ool000Aoo`03001oogoo02eoo`@00<=o
o`03001oogoo005oo`005Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo0`00:Goo
1000aGoo0`000goo000EOol00`00Oomoo`03Ool00`00Oomoo`020005Ool00`00Oomoo`0UOol4003;
Ool00`00Oomoo`01Ool001Eoo`07001oogooOol007oo00000Woo00<007ooOol017oo00<007ooOol0
8Goo1000cgoo00<007ooOol00Goo000DOol20004Ool01000Oomoogoo0`0017oo0P007Woo1000dWoo
0P000goo000UOol00`00Oomoo`0JOol3003GOol00`00Oomoo`01Ool002Eoo`03001oogoo01Ioo`@0
0=Yoo`03001oogoo005oo`009Goo00<007ooOol047oo1P00gWoo00<007ooOol00Goo000UOol2000;
Ool6003SOol20003Ool002Eoo`03001oogoo00Ioo`@00>Yoo`03001oogoo005oo`009Goo00<007oo
Ool00goo0`00kWoo00<007ooOol00Goo000UOol00`00Oomoo`3dOol00`00Oomoo`01Ool002Eoo`80
00Aoo`03001oogoo02Aoo`03001oogoo02Aoo`03001oogoo02Eoo`03001oogoo02Aoo`03001oogoo
02Aoo`03001oogoo02Aoo`03001oogoo009oo`8000=oo`009Goon0000goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.58415, 92.7069, 0.127832, 
  0.257974}}]
}, Open  ]],

Cell[TextData[{
  "For a 7% coupon rate, ",
  StyleBox["abc", "MB"],
  " is a par bond. Its payment does not change over time. "
}], "MathCaption",
  CellTags->"0.29"],

Cell[CellGroupData[{

Cell["\<\
graph2 = ListPlot[p[7 Percent],
   PlotJoined -> True, FrameLabel -> label2];\
\>", "Input",
  CellLabel->"In[24]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 0.00294302 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -41 -21.5625 ]
[.5 -0.0125 41 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -12 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -38 ]
[-0.01875 .30902 -18 38 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -102 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
93.000000 12.812500 moveto
(in) show
111.000000 12.812500 moveto
(years) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(50)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(100)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(150)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(200)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -123.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
99 10.2813 translate
90 rotate
-99 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bond) show
93.000000 12.812500 moveto
(payment) show
135.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .30902 m
.05556 .30902 L
.0873 .30902 L
.11905 .30902 L
.15079 .30902 L
.18254 .30902 L
.21429 .30902 L
.24603 .30902 L
.27778 .30902 L
.30952 .30902 L
.34127 .30902 L
.37302 .30902 L
.40476 .30902 L
.43651 .30902 L
.46825 .30902 L
.5 .30902 L
.53175 .30902 L
.56349 .30902 L
.59524 .30902 L
.62698 .30902 L
.65873 .30902 L
.69048 .30902 L
.72222 .30902 L
.75397 .30902 L
.78571 .30902 L
.81746 .30902 L
.84921 .30902 L
.88095 .30902 L
.9127 .30902 L
.94444 .30902 L
.97619 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[24]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00:Yoo`8007Aoo`00Zgoo00<007ooOol0LWoo001jOol30002Ool300001Woo001oo`00Ool0009o
o`8000aoo`<00003Ool00000009oo`03001oogoo00Qoo`03001oogoo009oo`80009oo`@00004Ool0
00000002Ool2001POol007]oo`03001oogoo009oo`0:001oogoo001oo`00Ool007oo000?Ool01@00
Oomoogoo00000Woo00<007ooOol01goo00<007oo00000Woo00<007ooOol00Woo0`000goo00<007oo
Ool00goo00<007ooOol0GGoo001kOol00`00Oomoo`02Ool02@00Oomoo`00Ool007oo001oo`03000=
Ool01@00Oomoogoo00000Woo00<007ooOol01goo00<007oo00000Woo0`0017oo00D007ooOomoo`00
00Aoo`03001oogoo05ioo`00Ngoo00@007ooOomoo`80009oo`800004Ool007ooOol3000<Ool20002
Ool40009Ool2000017oo000007oo0`000goo0P000Woo10000Woo0P00Ggoo001iOol01@00Ool007oo
0000XWoo001iOol50002Ool00`00Oomoo`0FOol00`00Oomoo`24Ool00?moob5oo`00ogoo8Goo003o
OolQOol002]oo`03001oogoo02Aoo`03001oogoo021oo`D0009oo`03001oogoo01aoo`D0009oo`03
001oogoo01ioo`<000=oo`03001oogoo01ioo`<000=oo`03001oogoo01ioo`8000Aoo`03001oogoo
00Ioo`00:Woo00<007oo000097oo00<007oo00008goo00L007ooOomoo`00Ool0000OOol01`00Oomo
ogoo001oo`0001moo`03001oogoo009oo`03001oo`0001moo`03001oogoo009oo`03001oo`00025o
o`06001oogoo001oo`001goo000ZOol00`00Ool0000VOol00`00Oomoo`0QOol01`00Oomoogoo001o
o`0001moo`03001oogoo00=oo`03001oogoo01ioo`07001oogooOol007oo000087oo00<007ooOol0
0goo00<007ooOol07Woo00L007ooOomoo`00Ool00007Ool002Yoo`03001oo`0002Aoo`8002Aoo`07
001oogooOol007oo00007goo00@007ooOomoo`80025oo`07001oogooOol007oo000087oo00@007oo
Oomoo`80029oo`06001oogoo001oo`001goo000ZOol00`00Ool0000TOol00`00Oomoo`0SOol01`00
Oomoogoo001oo`0001moo`05001oogooOol0000QOol00`00Ool00002Ool00`00Ool0000OOol00`00
Ool00002Ool00`00Oomoo`0OOol00`00Ool00002Ool00`00Ool00007Ool002]oo`03001oogoo02=o
o`<0029oo`8000Aoo`03001oogoo01eoo`8000=oo`<0021oo`03001oogoo009oo`03001oogoo01mo
o`04001oogooOol3000POol00`00Oomoo`02Ool00`00Oomoo`06Ool00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo000VOoof0004Ool002Ioo`03001oogoo00=oo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00=o
o`03001oogoo009oo`0087oo00<007ooOol00goo00<007ooOol00goo00<007ooOol097oo00<007oo
Ool097oo00<007ooOol08goo00<007ooOol097oo00<007ooOol097oo00<007ooOol097oo00<007oo
Ool00goo00<007ooOol00Woo000OOol00`00Ool00004Ool00`00Oomoo`3bOol00`00Oomoo`02Ool0
01moo`03001oo`0000Aoo`<00?1oo`<000Aoo`007goo00<007oo000017oo00<007ooOol0lWoo00<0
07ooOol00Woo000OOol00`00Ool00004Ool00`00Oomoo`3bOol00`00Oomoo`02Ool0021oo`03001o
ogoo00=oo`03001oogoo0?9oo`03001oogoo009oo`009Woo00<007ooOol0lWoo00<007ooOol00Woo
000VOol00`00Oomoo`3bOol00`00Oomoo`02Ool002Ioo`03001oogoo0?9oo`03001oogoo009oo`00
9Woo0P00lWoo0P0017oo000VOol00`00Oomoo`3bOol00`00Oomoo`02Ool002Ioo`03001oogoo0?9o
o`03001oogoo009oo`009Woo00<007ooOol0lWoo00<007ooOol00Woo000VOol00`00Oomoo`3bOol0
0`00Oomoo`02Ool002Ioo`03001oogoo0?9oo`03001oogoo009oo`009Woo00<007ooOol0lWoo00<0
07ooOol00Woo000VOol2003bOol20004Ool002Ioo`03001oogoo0?9oo`03001oogoo009oo`009Woo
00<007ooOol0lWoo00<007ooOol00Woo000VOol00`00Oomoo`3bOol00`00Oomoo`02Ool002Ioo`03
001oogoo0?9oo`03001oogoo009oo`009Woo00<007ooOol0lWoo00<007ooOol00Woo000VOol00`00
Oomoo`3bOol00`00Oomoo`02Ool002Ioo`800?9oo`8000Aoo`009Woo00<007ooOol0lWoo00<007oo
Ool00Woo000VOol00`00Oomoo`3bOol00`00Oomoo`02Ool002Ioo`03001oogoo0?9oo`03001oogoo
009oo`009Woo00<007ooOol0lWoo00<007ooOol00Woo000VOol00`00Oomoo`3bOol00`00Oomoo`02
Ool002Ioo`03001oogoo0?9oo`03001oogoo009oo`009Woo00<007ooOol0lWoo00<007ooOol00Woo
000VOol2003bOol20004Ool002Ioo`03001oogoo0?9oo`03001oogoo009oo`009Woo00<007ooOol0
lWoo00<007ooOol00Woo000VOol00`00Oomoo`3bOol00`00Oomoo`02Ool002Ioo`03001oogoo0?9o
o`03001oogoo009oo`006goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0lWoo00<007oo
Ool00Woo000JOol00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`3bOol00`00Oomoo`02Ool0
01aoo`06001oogoo001oo`0017oo0`00l7oo0`0017oo0006Ool00`00Oomoo`02Ool00`00Oomoo`0<
Ool20003Ool00`00Ool00004Ool00`00Oomoo`3bOol00`00Oomoo`02Ool000Ioo`H000ioo`03001o
ogoo009oo`03001oo`0000Aoo`03001oogoo0?9oo`03001oogoo009oo`001Woo00<007oo00000Woo
00<007ooOol037oo0`000goo00<007ooOol00goo00<007ooOol0lWoo00<007ooOol00Woo0006Ool0
0`00Ool00002Ool00`00Oomoo`0HOol00`00Oomoo`3bOol00`00Oomoo`02Ool000Moo`04001oo`00
000KOol00`00Oomoo`3bOol00`00Oomoo`02Ool002Ioo`03001oogoo0?9oo`03001oogoo009oo`00
9Woo0P00lWoo0P0017oo0009Ool2000KOol00`00Oomoo`3bOol00`00Oomoo`02Ool000Qoo`04001o
ogoo000JOol00`00Oomoo`3bOol00`00Oomoo`02Ool000Qoo`04001oogoo000JOol00`00Oomoo`3b
Ool00`00Oomoo`02Ool000Uoo`8001]oo`03001oogoo0?9oo`03001oogoo009oo`009Woo00<007oo
Ool0lWoo00<007ooOol00Woo0008Ool01000Oomoo`006Woo00<007ooOol0lWoo00<007ooOol00Woo
0008Ool4000JOol2003bOol20004Ool000Qoo`03001oogoo01]oo`03001oogoo0?9oo`03001oogoo
009oo`0027oo00<007ooOol06goo00<007ooOol0lWoo00<007ooOol00Woo0009Ool3000JOol00`00
Oomoo`3bOol00`00Oomoo`02Ool000]oo`03001oogoo01Qoo`03001oogoo0?9oo`03001oogoo009o
o`009Woo00<007ooOol0lWoo00<007ooOol00Woo0009Ool2000KOol00`00Oomoo`3bOol00`00Oomo
o`02Ool000Qoo`04001oogoo000JOol2003bOol20004Ool000Ioo`03001oo`00009oo`03001oogoo
01Qoo`03001oogoo0?9oo`03001oogoo009oo`001Woo1P006Woo00<007ooOol0lWoo00<007ooOol0
0Woo000;Ool00`00Oomoo`0HOol00`00Oomoo`3bOol00`00Oomoo`02Ool002Ioo`03001oogoo0?9o
o`03001oogoo009oo`009Woo00<007ooOol0lWoo00<007ooOol00Woo000VOol00`00Oomoo`3bOol0
0`00Oomoo`02Ool002Ioo`03001oogoo0?9oo`03001oogoo009oo`009Woo0P00lWoo0P0017oo000V
Ool00`00Oomoo`3bOol00`00Oomoo`02Ool000Qoo`03001oogoo009oo`03001oogoo01Ioo`03001o
ogoo0?9oo`03001oogoo009oo`0027oo1P0067oo00<007ooOol0lWoo00<007ooOol00Woo0008Ool0
1P00Oomoo`00Ool001Qoo`03001oogoo0?9oo`03001oogoo009oo`0027oo00@007ooOol000Qoo`D0
009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0?9oo`03001oogoo009oo`002Goo0P00
2goo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`3bOol00`00Oomoo`02Ool0
01Ioo`07001oogooOol007oo00000Woo00<007oo000017oo0`000goojP000goo0`0017oo000FOol0
1`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`03001oogoo0?9oo`03001oogoo009oo`002Woo
0P002Woo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`3bOol00`00Oomoo`02
Ool000Qoo`04001oo`000009Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`3b
Ool00`00Oomoo`02Ool000Qoo`04001oo`00000JOol00`00Oomoo`3bOol00`00Oomoo`02Ool000Qo
o`@001Yoo`03001oogoo0?9oo`03001oogoo009oo`002goo00<007ooOol067oo00<007ooOol0lWoo
00<007ooOol00Woo0008Ool00`00Oomoo`0KOol2003bOol20004Ool000Qoo`8000=oo`03001oogoo
01Ioo`03001oogoo0?9oo`03001oogoo009oo`0027oo00@007oo001oo`8001Qoo`03001oogoo0?9o
o`03001oogoo009oo`002goo00<007ooOol067oo00<007ooOol0lWoo00<007ooOol00Woo0008Ool3
000KOol00`00Oomoo`3bOol00`00Oomoo`02Ool000Qoo`03001oogoo01]oo`03001oogoo0?9oo`03
001oogoo009oo`0027oo00@007ooOol001Yoo`03001oogoo0?9oo`03001oogoo009oo`0027oo1000
6Woo0P00lWoo0P0017oo0008Ool00`00Oomoo`0KOol00`00Oomoo`3bOol00`00Oomoo`02Ool000Uo
o`<001Yoo`03001oogoo0?9oo`03001oogoo009oo`0027oo00<007ooOol06goo00<007ooOol0lWoo
00<007ooOol00Woo0009Ool3000JOol00`00Oomoo`3bOol00`00Oomoo`02Ool002Ioo`03001oogoo
0?9oo`03001oogoo009oo`002Goo0P006goo00<007ooOol0lWoo00<007ooOol00Woo0008Ool20000
0goo001oo`0IOol00`00Oomoo`3bOol00`00Oomoo`02Ool000Qoo`800003Ool007oo01Uoo`800?9o
o`8000Aoo`002Goo00<007oo00006Woo00<007ooOol0lWoo00<007ooOol00Woo000VOol00`00Oomo
o`3bOol00`00Oomoo`02Ool000Qoo`04001oogoo000JOol00`00Oomoo`3bOol00`00Oomoo`02Ool0
00Qoo`@001Yoo`03001oogoo0?9oo`03001oogoo009oo`0027oo00<007ooOol06goo00<007ooOol0
lWoo00<007ooOol00Woo0008Ool00`00Oomoo`0KOol00`00Oomoo`3bOol00`00Oomoo`02Ool000Uo
o`<001Yoo`800?9oo`8000Aoo`002goo00<007ooOol067oo00<007ooOol0lWoo00<007ooOol00Woo
0008Ool00`00Oomoo`0KOol00`00Oomoo`3bOol00`00Oomoo`02Ool000Moo`@001]oo`03001oogoo
0?9oo`03001oogoo009oo`0027oo00@007ooOol001Yoo`03001oogoo0?9oo`03001oogoo009oo`00
27oo00@007ooOol000Qoo`D0009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0?9oo`03
001oogoo009oo`0027oo00<007oo00002goo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool0
0`00Oomoo`3bOol00`00Oomoo`02Ool001Ioo`03001oogoo00=oo`06001oogoo001oo`0017oo0`00
l7oo0`0017oo000FOol01000Oomoogoo0P000goo00<007oo000017oo00<007ooOol0lWoo00<007oo
Ool00Woo000FOol01@00Oomoogoo000017oo00<007oo000017oo00<007ooOol0lWoo00<007ooOol0
0Woo000EOol20003Ool30003Ool00`00Oomoo`03Ool00`00Oomoo`3bOol00`00Oomoo`02Ool002Io
o`03001oogoo0?9oo`03001oogoo009oo`009Woo00<007ooOol0lWoo00<007ooOol00Woo000VOol0
0`00Oomoo`3bOol00`00Oomoo`02Ool002Ioo`800?9oo`8000Aoo`009Woo00<007ooOol0lWoo00<0
07ooOol00Woo000VOol00`00Oomoo`3bOol00`00Oomoo`02Ool002Ioo`03001oogoo0?9oo`03001o
ogoo009oo`009Woo00<007ooOol0lWoo00<007ooOol00Woo000VOol00`00Oomoo`3bOol00`00Oomo
o`02Ool002Ioo`03001oogoo0?9oo`03001oogoo009oo`009Woo0P00lWoo0P0017oo000VOol00`00
Oomoo`3bOol00`00Oomoo`02Ool002Ioo`03001oogoo0?9oo`03001oogoo009oo`009Woo00<007oo
Ool0lWoo00<007ooOol00Woo000VOol00`00Oomoo`3bOol00`00Oomoo`02Ool002Ioo`03001oogoo
0?9oo`03001oogoo009oo`009Woo00<007ooOol0lWoo00<007ooOol00Woo000VOol00`00Oomoo`3b
Ool00`00Oomoo`02Ool002Ioo`800?9oo`8000Aoo`009Woo00<007ooOol0lWoo00<007ooOol00Woo
000VOol00`00Oomoo`3bOol00`00Oomoo`02Ool002Ioo`03001oogoo0?9oo`03001oogoo009oo`00
9Woo00<007ooOol0lWoo00<007ooOol00Woo000VOol00`00Oomoo`3bOol00`00Oomoo`02Ool002Io
o`03001oogoo0?9oo`03001oogoo009oo`009Woo0P00lWoo0P0017oo000VOol00`00Oomoo`3bOol0
0`00Oomoo`02Ool002Ioo`03001oogoo0?9oo`03001oogoo009oo`009Woo00<007ooOol0lWoo00<0
07ooOol00Woo000VOol00`00Oomoo`3bOol00`00Oomoo`02Ool001Eoo`<000=oo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo0?9oo`03001oogoo009oo`005Goo00<007ooOol00Woo00<007oo
00000Woo00<007oo000017oo00<007ooOol0lWoo00<007ooOol00Woo000FOol01`00Oomoogoo001o
o`00009oo`03001oo`0000Aoo`<00?1oo`<000Aoo`005Woo00L007ooOomoo`00Ool00002Ool00`00
Ool00004Ool00`00Oomoo`3bOol00`00Oomoo`02Ool001Eoo`03001oo`00009oo`03001oo`00009o
o`03001oo`0000Aoo`03001oogoo00=oo`03001oogoo02Aoo`03001oogoo02Aoo`03001oogoo02=o
o`03001oogoo02Aoo`03001oogoo02Aoo`03001oogoo02Aoo`03001oogoo00=oo`03001oogoo009o
o`005Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol00Woo000VOoof0004Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.69966, -39.1536, 
  0.128574, 1.38691}}]
}, Open  ]],

Cell[TextData[{
  "For a 3% coupon rate, ",
  StyleBox["abc", "MB"],
  " is a discount bond. Its payment increases over time. "
}], "MathCaption",
  CellTags->"0.30"],

Cell[CellGroupData[{

Cell["\<\
graph3 = ListPlot[p[4 Percent],
   PlotJoined -> True, FrameLabel -> label2];\
\>", "Input",
  CellLabel->"In[25]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 -0.969769 0.0157309 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -41 -21.5625 ]
[.5 -0.0125 41 -9 ]
[-0.0125 .05274 -12 -4.5 ]
[-0.0125 .05274 0 4.5 ]
[-0.0125 .13139 -12 -4.5 ]
[-0.0125 .13139 0 4.5 ]
[-0.0125 .21005 -12 -4.5 ]
[-0.0125 .21005 0 4.5 ]
[-0.0125 .2887 -12 -4.5 ]
[-0.0125 .2887 0 4.5 ]
[-0.0125 .36736 -12 -4.5 ]
[-0.0125 .36736 0 4.5 ]
[-0.0125 .44601 -12 -4.5 ]
[-0.0125 .44601 0 4.5 ]
[-0.0125 .52466 -12 -4.5 ]
[-0.0125 .52466 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -38 ]
[-0.01875 .30902 -18 38 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -102 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
93.000000 12.812500 moveto
(in) show
111.000000 12.812500 moveto
(years) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .05274 m
.00625 .05274 L
s
[(65)] -0.0125 .05274 1 0 Mshowa
0 .13139 m
.00625 .13139 L
s
[(70)] -0.0125 .13139 1 0 Mshowa
0 .21005 m
.00625 .21005 L
s
[(75)] -0.0125 .21005 1 0 Mshowa
0 .2887 m
.00625 .2887 L
s
[(80)] -0.0125 .2887 1 0 Mshowa
0 .36736 m
.00625 .36736 L
s
[(85)] -0.0125 .36736 1 0 Mshowa
0 .44601 m
.00625 .44601 L
s
[(90)] -0.0125 .44601 1 0 Mshowa
0 .52466 m
.00625 .52466 L
s
[(95)] -0.0125 .52466 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(100)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .06847 m
.00375 .06847 L
s
0 .0842 m
.00375 .0842 L
s
0 .09993 m
.00375 .09993 L
s
0 .11566 m
.00375 .11566 L
s
0 .14712 m
.00375 .14712 L
s
0 .16285 m
.00375 .16285 L
s
0 .17859 m
.00375 .17859 L
s
0 .19432 m
.00375 .19432 L
s
0 .22578 m
.00375 .22578 L
s
0 .24151 m
.00375 .24151 L
s
0 .25724 m
.00375 .25724 L
s
0 .27297 m
.00375 .27297 L
s
0 .30443 m
.00375 .30443 L
s
0 .32016 m
.00375 .32016 L
s
0 .33589 m
.00375 .33589 L
s
0 .35162 m
.00375 .35162 L
s
0 .38309 m
.00375 .38309 L
s
0 .39882 m
.00375 .39882 L
s
0 .41455 m
.00375 .41455 L
s
0 .43028 m
.00375 .43028 L
s
0 .46174 m
.00375 .46174 L
s
0 .47747 m
.00375 .47747 L
s
0 .4932 m
.00375 .4932 L
s
0 .50893 m
.00375 .50893 L
s
0 .5404 m
.00375 .5404 L
s
0 .55613 m
.00375 .55613 L
s
0 .57186 m
.00375 .57186 L
s
0 .58759 m
.00375 .58759 L
s
0 .03701 m
.00375 .03701 L
s
0 .02128 m
.00375 .02128 L
s
0 .00555 m
.00375 .00555 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -123.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
99 10.2813 translate
90 rotate
-99 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bond) show
93.000000 12.812500 moveto
(payment) show
135.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05274 m
1 .05274 L
s
.99375 .13139 m
1 .13139 L
s
.99375 .21005 m
1 .21005 L
s
.99375 .2887 m
1 .2887 L
s
.99375 .36736 m
1 .36736 L
s
.99375 .44601 m
1 .44601 L
s
.99375 .52466 m
1 .52466 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .06847 m
1 .06847 L
s
.99625 .0842 m
1 .0842 L
s
.99625 .09993 m
1 .09993 L
s
.99625 .11566 m
1 .11566 L
s
.99625 .14712 m
1 .14712 L
s
.99625 .16285 m
1 .16285 L
s
.99625 .17859 m
1 .17859 L
s
.99625 .19432 m
1 .19432 L
s
.99625 .22578 m
1 .22578 L
s
.99625 .24151 m
1 .24151 L
s
.99625 .25724 m
1 .25724 L
s
.99625 .27297 m
1 .27297 L
s
.99625 .30443 m
1 .30443 L
s
.99625 .32016 m
1 .32016 L
s
.99625 .33589 m
1 .33589 L
s
.99625 .35162 m
1 .35162 L
s
.99625 .38309 m
1 .38309 L
s
.99625 .39882 m
1 .39882 L
s
.99625 .41455 m
1 .41455 L
s
.99625 .43028 m
1 .43028 L
s
.99625 .46174 m
1 .46174 L
s
.99625 .47747 m
1 .47747 L
s
.99625 .4932 m
1 .4932 L
s
.99625 .50893 m
1 .50893 L
s
.99625 .5404 m
1 .5404 L
s
.99625 .55613 m
1 .55613 L
s
.99625 .57186 m
1 .57186 L
s
.99625 .58759 m
1 .58759 L
s
.99625 .03701 m
1 .03701 L
s
.99625 .02128 m
1 .02128 L
s
.99625 .00555 m
1 .00555 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.05556 .02081 L
.0873 .02734 L
.11905 .03433 L
.15079 .04183 L
.18254 .04985 L
.21429 .05845 L
.24603 .06766 L
.27778 .07753 L
.30952 .0881 L
.34127 .09942 L
.37302 .11155 L
.40476 .12454 L
.43651 .13846 L
.46825 .15336 L
.5 .16933 L
.53175 .18644 L
.56349 .20477 L
.59524 .2244 L
.62698 .24543 L
.65873 .26796 L
.69048 .29209 L
.72222 .31794 L
.75397 .34563 L
.78571 .3753 L
.81746 .40708 L
.84921 .44112 L
.88095 .47758 L
.9127 .51665 L
.94444 .55849 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[25]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00:Yoo`8007Aoo`00Zgoo00<007ooOol0LWoo001jOol30002Ool300001Woo001oo`00Ool0009o
o`8000aoo`<00003Ool00000009oo`03001oogoo00Qoo`03001oogoo009oo`80009oo`@00004Ool0
00000002Ool2001POol007]oo`03001oogoo009oo`0:001oogoo001oo`00Ool007oo000?Ool01@00
Oomoogoo00000Woo00<007ooOol01goo00<007oo00000Woo00<007ooOol00Woo0`000goo00<007oo
Ool00goo00<007ooOol0GGoo001kOol00`00Oomoo`02Ool02@00Oomoo`00Ool007oo001oo`03000=
Ool01@00Oomoogoo00000Woo00<007ooOol01goo00<007oo00000Woo0`0017oo00D007ooOomoo`00
00Aoo`03001oogoo05ioo`00Ngoo00@007ooOomoo`80009oo`800004Ool007ooOol3000<Ool20002
Ool40009Ool2000017oo000007oo0`000goo0P000Woo10000Woo0P00Ggoo001iOol01@00Ool007oo
0000XWoo001iOol50002Ool00`00Oomoo`0FOol00`00Oomoo`24Ool00?moob5oo`00ogoo8Goo003o
OolQOol002]oo`03001oogoo02Aoo`03001oogoo021oo`D0009oo`03001oogoo01aoo`D0009oo`03
001oogoo01ioo`<000=oo`03001oogoo01ioo`<000=oo`03001oogoo01ioo`8000Aoo`03001oogoo
00Ioo`00:Woo00<007oo000097oo00<007oo00008goo00L007ooOomoo`00Ool0000OOol01`00Oomo
ogoo001oo`0001moo`03001oogoo009oo`03001oo`0001moo`03001oogoo009oo`03001oo`00025o
o`06001oogoo001oo`001goo000ZOol00`00Ool0000VOol00`00Oomoo`0QOol01`00Oomoogoo001o
o`0001moo`03001oogoo00=oo`03001oogoo01ioo`07001oogooOol007oo000087oo00<007ooOol0
0goo00<007ooOol07Woo00L007ooOomoo`00Ool00007Ool002Yoo`03001oo`0002Aoo`8002Aoo`07
001oogooOol007oo00007goo00@007ooOomoo`80025oo`07001oogooOol007oo000087oo00@007oo
Oomoo`80029oo`06001oogoo001oo`001goo000ZOol00`00Ool0000TOol00`00Oomoo`0SOol01`00
Oomoogoo001oo`0001moo`05001oogooOol0000QOol00`00Ool00002Ool00`00Ool0000OOol00`00
Ool00002Ool00`00Oomoo`0OOol00`00Ool00002Ool00`00Ool00007Ool002]oo`03001oogoo02=o
o`<0029oo`8000Aoo`03001oogoo01eoo`8000=oo`<0021oo`03001oogoo009oo`03001oogoo01mo
o`04001oogooOol3000POol00`00Oomoo`02Ool00`00Oomoo`06Ool00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo000VOoof0004Ool002Ioo`03001oogoo00=oo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00=o
o`03001oogoo009oo`009Woo0P0017oo00<007ooOol097oo00<007ooOol097oo00<007ooOol08goo
00<007ooOol097oo00<007ooOol097oo00<007ooOol097oo00<007ooOol00Woo0P0017oo000VOol0
0`00Oomoo`3bOol00`00Oomoo`02Ool002Ioo`03001oogoo00=oo`@00>]oo`03001oogoo009oo`00
9Woo0P0027oo1P00i7oo0P0017oo000VOol00`00Oomoo`0=Ool4003QOol00`00Oomoo`02Ool002Io
o`03001oogoo015oo`<00=ioo`03001oogoo009oo`009Woo00<007ooOol057oo1000fWoo00<007oo
Ool00Woo000VOol2000IOol6003COol20004Ool002Ioo`03001oogoo01ioo`H00<ioo`03001oogoo
009oo`006Woo0P0017oo00<007ooOol00goo00<007ooOol097oo1000bWoo00<007ooOol00Woo000J
Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`0XOol40036Ool00`00Oomoo`02Ool001Yo
o`03001oo`0000Aoo`03001oogoo009oo`<002aoo`800<9oo`<000Aoo`006Woo0P000goo0P001Goo
00<007ooOol0;Woo0P00`Woo00<007ooOol00Woo000JOol00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`0`Ool3002oOol00`00Oomoo`02Ool001]oo`80009oo`<000Aoo`03001oogoo03=oo`@0
0;]oo`03001oogoo009oo`009Woo0P00>7oo1000]Woo0P0017oo000VOol00`00Oomoo`0kOol4002c
Ool00`00Oomoo`02Ool002Ioo`03001oogoo03moo`@00:moo`03001oogoo009oo`009Woo00<007oo
Ool0@goo0P00[Goo00<007ooOol00Woo000VOol20016Ool3002YOol20004Ool002Ioo`03001oogoo
04Qoo`<00:Moo`03001oogoo009oo`009Woo00<007ooOol0Bgoo0P00YGoo00<007ooOol00Woo000V
Ool00`00Oomoo`1=Ool3002ROol00`00Oomoo`02Ool002Ioo`80055oo`<009ioo`8000Aoo`009Woo
00<007ooOol0Dgoo0P00WGoo00<007ooOol00Woo000VOol00`00Oomoo`1EOol2002KOol00`00Oomo
o`02Ool002Ioo`03001oogoo05Moo`<009Qoo`03001oogoo009oo`009Woo0P00Fgoo0P00UGoo0P00
17oo000KOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1LOol3002COol00`00Oomoo`02
Ool001]oo`07001oogooOol007oo000017oo00<007ooOol0Ggoo0`00T7oo00<007ooOol00Woo000K
Ool01`00Oomoogoo001oo`0000Aoo`<0069oo`8008aoo`<000Aoo`0077oo00H007ooOol007oo0004
Ool00`00Oomoo`1TOol3002;Ool00`00Oomoo`02Ool001Yoo`03001oo`00009oo`03001oo`0000Ao
o`03001oogoo06Moo`8008Uoo`03001oogoo009oo`006Woo0`000goo00<007ooOol00goo00<007oo
Ool0JGoo0P00Qgoo00<007ooOol00Woo000VOol2001/Ool20024Ool20004Ool002Ioo`03001oogoo
06eoo`8008=oo`03001oogoo009oo`009Woo00<007ooOol0Kgoo0P00PGoo00<007ooOol00Woo000V
Ool00`00Oomoo`1aOol2001oOol00`00Oomoo`02Ool002Ioo`8007Aoo`8007aoo`8000Aoo`001Woo
00<007ooOol00Woo00<007ooOol067oo00<007ooOol0MGoo0P00Ngoo00<007ooOol00Woo0006Ool6
000JOol00`00Oomoo`1gOol00`00Oomoo`1hOol00`00Oomoo`02Ool000Ioo`03001oo`00009oo`03
001oogoo01Qoo`03001oogoo07Qoo`8007Qoo`03001oogoo009oo`001Woo00<007oo00000Woo00<0
07ooOol067oo0P00Ngoo0P00MGoo0P0017oo0007Ool01000Ool000006goo00<007ooOol0O7oo0P00
M7oo00<007ooOol00Woo000VOol00`00Oomoo`1nOol2001bOol00`00Oomoo`02Ool002Ioo`03001o
ogoo081oo`80071oo`03001oogoo009oo`002Goo0P006goo0P00Pgoo0P00KGoo0P0017oo0008Ool0
1000Oomoo`006Woo00<007ooOol0Q7oo0P00K7oo00<007ooOol00Woo0008Ool01000Oomoo`003goo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol0QWoo0P00JWoo00<007ooOol00Woo0009Ool2
000@Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo08Qoo`8006Qoo`03001oogoo009oo`006goo
00<007ooOol00goo00<007ooOol00Woo0`00RWoo00<007ooOol0Hgoo0`0017oo0008Ool01000Oomo
o`0047oo00<007ooOol00P001Goo00<007ooOol0Rgoo0P00IGoo00<007ooOol00Woo0008Ool4000>
Ool00`00Ool00002Ool00`00Oomoo`04Ool00`00Oomoo`2=Ool2001SOol00`00Oomoo`02Ool000Qo
o`03001oogoo00moo`<0009oo`<000Aoo`03001oogoo08moo`03001oogoo061oo`03001oogoo009o
o`0027oo00<007ooOol06goo0P00TGoo0P00Ggoo0P0017oo0009Ool3000JOol00`00Oomoo`2BOol0
0`00Oomoo`1MOol00`00Oomoo`02Ool000]oo`03001oogoo01Qoo`03001oogoo09=oo`8005eoo`03
001oogoo009oo`009Woo0P00UWoo0P00FWoo0P0017oo0009Ool2000KOol00`00Oomoo`2GOol00`00
Oomoo`1HOol00`00Oomoo`02Ool000Qoo`04001oogoo000JOol00`00Oomoo`2HOol00`00Oomoo`1G
Ool00`00Oomoo`02Ool000Ioo`03001oo`00009oo`03001oogoo01Qoo`03001oogoo09Uoo`03001o
ogoo05Ioo`03001oogoo009oo`001Woo1P006Woo0P00Vgoo0P00EGoo0P0017oo000;Ool00`00Oomo
o`0HOol00`00Oomoo`2LOol00`00Oomoo`1COol00`00Oomoo`02Ool002Ioo`03001oogoo09eoo`03
001oogoo059oo`03001oogoo009oo`009Woo00<007ooOol0WWoo00<007ooOol0DGoo00<007ooOol0
0Woo000VOol2002POol00`00Oomoo`1?Ool20004Ool002Ioo`03001oogoo0:1oo`80051oo`03001o
ogoo009oo`006goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0XWoo00<007ooOol0CGoo
00<007ooOol00Woo000JOol00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`2SOol00`00Oomo
o`1<Ool00`00Oomoo`02Ool000Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oo`00009oo`03
001oo`0000Aoo`<00:Aoo`8004Yoo`<000Aoo`0027oo1P003Goo00L007ooOomoo`00Ool00004Ool0
0`00Oomoo`2VOol00`00Oomoo`19Ool00`00Oomoo`02Ool000Qoo`06001oogoo001oo`0037oo00<0
07oo00000Woo00<007oo000017oo00<007ooOol0Ygoo00<007ooOol0B7oo00<007ooOol00Woo0008
Ool01000Oomoo`003goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0Z7oo0P00B7oo00<0
07ooOol00Woo0009Ool2000KOol2002[Ool00`00Oomoo`14Ool20004Ool002Ioo`03001oogoo0:]o
o`03001oogoo04Aoo`03001oogoo009oo`009Woo00<007ooOol0[7oo0P00A7oo00<007ooOol00Woo
000:Ool2000JOol00`00Oomoo`2^Ool00`00Oomoo`11Ool00`00Oomoo`02Ool000Qoo`04001oo`00
000JOol2002`Ool00`00Oomoo`0oOol20004Ool000Qoo`04001oo`00000JOol00`00Oomoo`2`Ool0
0`00Oomoo`0oOol00`00Oomoo`02Ool000Qoo`@001Yoo`03001oogoo0;5oo`03001oogoo03ioo`03
001oogoo009oo`002goo00<007ooOol067oo0P00/goo0P00?Goo0P0017oo0008Ool00`00Oomoo`0K
Ool00`00Oomoo`2dOol00`00Oomoo`0kOol00`00Oomoo`02Ool000Qoo`8000=oo`03001oogoo01Io
o`03001oogoo0;Eoo`03001oogoo03Yoo`03001oogoo009oo`0027oo00@007oo001oo`8001Qoo`03
001oogoo0;Ioo`03001oogoo03Uoo`03001oogoo009oo`002goo00<007ooOol067oo0P00^7oo00<0
07ooOol0=goo0P0017oo0008Ool3000KOol00`00Oomoo`2hOol00`00Oomoo`0gOol00`00Oomoo`02
Ool000Qoo`03001oogoo011oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0;Uoo`03001o
ogoo03Ioo`03001oogoo009oo`0027oo00@007ooOol000ioo`03001oo`00009oo`03001oo`0000Ao
o`03001oogoo0;Yoo`03001oogoo03Eoo`03001oogoo009oo`0027oo10003Woo00<007oo000017oo
00<007ooOol00Woo0`00^goo00<007ooOol0<Woo0`0017oo0008Ool00`00Oomoo`0@Ool01000Oomo
ogoo0P001Goo00<007ooOol0_7oo00<007ooOol0<goo00<007ooOol00Woo0009Ool3000>Ool00`00
Ool00002Ool00`00Oomoo`04Ool00`00Oomoo`2mOol00`00Oomoo`0bOol00`00Oomoo`02Ool000Qo
o`03001oogoo011oo`04001oogooOol30004Ool00`00Oomoo`2nOol00`00Oomoo`0aOol00`00Oomo
o`02Ool000Uoo`<001Yoo`800<1oo`03001oogoo02moo`8000Aoo`009Woo00<007ooOol0`7oo00<0
07ooOol0;goo00<007ooOol00Woo0009Ool2000KOol00`00Oomoo`31Ool00`00Oomoo`0^Ool00`00
Oomoo`02Ool000Qoo`800003Ool007oo01Uoo`03001oogoo0<9oo`03001oogoo02eoo`03001oogoo
009oo`0027oo0P0000=oo`00Ool06Goo0P00a7oo00<007ooOol0:goo0P0017oo0009Ool00`00Ool0
000JOol00`00Oomoo`34Ool00`00Oomoo`0[Ool00`00Oomoo`02Ool002Ioo`03001oogoo0<Eoo`03
001oogoo02Yoo`03001oogoo009oo`0027oo00@007ooOol001Yoo`03001oogoo0<Ioo`03001oogoo
02Uoo`03001oogoo009oo`0027oo10006Woo0P00b7oo00<007ooOol09goo0P0017oo0008Ool00`00
Oomoo`0KOol00`00Oomoo`38Ool00`00Oomoo`0WOol00`00Oomoo`02Ool000Qoo`03001oogoo01]o
o`03001oogoo0<Uoo`03001oogoo02Ioo`03001oogoo009oo`002Goo0`006Woo00<007ooOol0bWoo
00<007ooOol09Goo00<007ooOol00Woo000;Ool00`00Oomoo`0HOol2003<Ool00`00Oomoo`0SOol2
0004Ool000Qoo`03001oogoo00moo`8000Aoo`03001oogoo00=oo`03001oogoo0<aoo`03001oogoo
02=oo`03001oogoo009oo`001goo10004Goo00H007ooOol007oo0004Ool00`00Oomoo`3=Ool00`00
Oomoo`0ROol00`00Oomoo`02Ool000Qoo`04001oogoo000?Ool20002Ool00`00Ool00004Ool3003>
Ool00`00Oomoo`0OOol30004Ool000Qoo`04001oogoo000>Ool00`00Ool00002Ool00`00Ool00004
Ool00`00Oomoo`3?Ool00`00Oomoo`0POol00`00Oomoo`02Ool000Qoo`03001oo`0000moo`03001o
o`00009oo`03001oo`0000Aoo`03001oogoo0=1oo`03001oogoo01moo`03001oogoo009oo`006goo
0P000goo00<007ooOol00goo00<007ooOol0dGoo00<007ooOol07Woo00<007ooOol00Woo000VOol2
003BOol00`00Oomoo`0MOol20004Ool002Ioo`03001oogoo0=9oo`03001oogoo01eoo`03001oogoo
009oo`009Woo00<007ooOol0dgoo00<007ooOol077oo00<007ooOol00Woo000VOol00`00Oomoo`3D
Ool00`00Oomoo`0KOol00`00Oomoo`02Ool002Ioo`800=Ioo`03001oogoo01Uoo`8000Aoo`009Woo
00<007ooOol0eWoo00<007ooOol06Goo00<007ooOol00Woo000VOol00`00Oomoo`3GOol00`00Oomo
o`0HOol00`00Oomoo`02Ool002Ioo`03001oogoo0=Moo`03001oogoo01Qoo`03001oogoo009oo`00
9Woo0P00fGoo00<007ooOol05Woo0P0017oo000VOol00`00Oomoo`3IOol00`00Oomoo`0FOol00`00
Oomoo`02Ool002Ioo`03001oogoo0=Yoo`03001oogoo01Eoo`03001oogoo009oo`009Woo00<007oo
Ool0fgoo00<007ooOol057oo00<007ooOol00Woo000VOol2003LOol00`00Oomoo`0COol20004Ool0
02Ioo`03001oogoo0=aoo`03001oogoo01=oo`03001oogoo009oo`006Woo0P0017oo00<007ooOol0
0goo00<007ooOol0gGoo00<007ooOol04Woo00<007ooOol00Woo000LOol01P00Oomoo`00Ool000Ao
o`03001oogoo0=ioo`03001oogoo015oo`03001oogoo009oo`006goo0P0017oo00<007ooOol00Woo
0`00gWoo00<007ooOol03goo0`0017oo000JOol00`00Ool00002Ool20005Ool00`00Oomoo`3OOol0
0`00Oomoo`0@Ool00`00Oomoo`02Ool001Yoo`03001oo`00009oo`03001oogoo00Aoo`03001oogoo
0>1oo`03001oogoo00moo`03001oogoo009oo`006goo0P000Woo0`0017oo00<007ooOol0hGoo00<0
07ooOol03Woo00<007ooOol00Woo000VOol2003ROol00`00Oomoo`0=Ool20004Ool002Ioo`03001o
ogoo0>9oo`03001oogoo00eoo`03001oogoo009oo`009Woo00<007ooOol0hgoo00<007ooOol037oo
00<007ooOol00Woo000VOol2003TOol00`00Oomoo`0;Ool20004Ool002Ioo`03001oogoo0>Aoo`03
001oogoo00]oo`03001oogoo009oo`009Woo00<007ooOol0iGoo00<007ooOol02Woo00<007ooOol0
0Woo000VOol00`00Oomoo`3UOol00`00Oomoo`0:Ool00`00Oomoo`02Ool002Ioo`800>Moo`03001o
ogoo00Qoo`8000Aoo`009Woo00<007ooOol0igoo00<007ooOol027oo00<007ooOol00Woo000VOol0
0`00Oomoo`3XOol00`00Oomoo`07Ool00`00Oomoo`02Ool002Ioo`03001oogoo0>Qoo`03001oogoo
00Moo`03001oogoo009oo`009Woo0P00jWoo00<007ooOol01Goo0P0017oo000VOol00`00Oomoo`3Z
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool001Aoo`D0009oo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo0>]oo`03001oogoo00Aoo`03001oogoo009oo`005Woo00L007ooOomoo`00Ool00002
Ool00`00Ool00004Ool00`00Oomoo`3[Ool00`00Oomoo`04Ool00`00Oomoo`02Ool001Ioo`07001o
ogooOol007oo00000Woo00<007oo000017oo0`00k7oo00@007ooOomoo`<000Aoo`005Woo00L007oo
Oomoo`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`3bOol00`00Oomoo`02Ool001Ioo`07001o
ogooOol007oo00000Woo00<007oo000017oo00<007ooOol00goo00<007ooOol097oo00<007ooOol0
97oo00<007ooOol08goo00<007ooOol097oo00<007ooOol097oo00<007ooOol097oo00<007ooOol0
0goo00<007ooOol00Woo000EOol20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool002IoooH000Aoo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.69966, 55.2578, 0.128574, 
  0.25947}}]
}, Open  ]],

Cell["We can combine these three graphs. ", "MathCaption",
  CellTags->"0.31"],

Cell[CellGroupData[{

Cell["Show[graph1, graph2, graph3];", "Input",
  CellLabel->"In[26]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 -0.477527 0.00786544 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -3 -9 ]
[.18254 -0.0125 3 0 ]
[.34127 -0.0125 -6 -9 ]
[.34127 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -41 -21.5625 ]
[.5 -0.0125 41 -9 ]
[-0.0125 .07305 -12 -4.5 ]
[-0.0125 .07305 0 4.5 ]
[-0.0125 .15171 -12 -4.5 ]
[-0.0125 .15171 0 4.5 ]
[-0.0125 .23036 -12 -4.5 ]
[-0.0125 .23036 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .38767 -18 -4.5 ]
[-0.0125 .38767 0 4.5 ]
[-0.0125 .46633 -18 -4.5 ]
[-0.0125 .46633 0 4.5 ]
[-0.0125 .54498 -18 -4.5 ]
[-0.0125 .54498 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -38 ]
[-0.01875 .30902 -18 38 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(10)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(20)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(25)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(30)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -102 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
93.000000 12.812500 moveto
(in) show
111.000000 12.812500 moveto
(years) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .07305 m
.00625 .07305 L
s
[(70)] -0.0125 .07305 1 0 Mshowa
0 .15171 m
.00625 .15171 L
s
[(80)] -0.0125 .15171 1 0 Mshowa
0 .23036 m
.00625 .23036 L
s
[(90)] -0.0125 .23036 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(100)] -0.0125 .30902 1 0 Mshowa
0 .38767 m
.00625 .38767 L
s
[(110)] -0.0125 .38767 1 0 Mshowa
0 .46633 m
.00625 .46633 L
s
[(120)] -0.0125 .46633 1 0 Mshowa
0 .54498 m
.00625 .54498 L
s
[(130)] -0.0125 .54498 1 0 Mshowa
.125 Mabswid
0 .08878 m
.00375 .08878 L
s
0 .10452 m
.00375 .10452 L
s
0 .12025 m
.00375 .12025 L
s
0 .13598 m
.00375 .13598 L
s
0 .16744 m
.00375 .16744 L
s
0 .18317 m
.00375 .18317 L
s
0 .1989 m
.00375 .1989 L
s
0 .21463 m
.00375 .21463 L
s
0 .24609 m
.00375 .24609 L
s
0 .26182 m
.00375 .26182 L
s
0 .27756 m
.00375 .27756 L
s
0 .29329 m
.00375 .29329 L
s
0 .32475 m
.00375 .32475 L
s
0 .34048 m
.00375 .34048 L
s
0 .35621 m
.00375 .35621 L
s
0 .37194 m
.00375 .37194 L
s
0 .4034 m
.00375 .4034 L
s
0 .41913 m
.00375 .41913 L
s
0 .43486 m
.00375 .43486 L
s
0 .45059 m
.00375 .45059 L
s
0 .48206 m
.00375 .48206 L
s
0 .49779 m
.00375 .49779 L
s
0 .51352 m
.00375 .51352 L
s
0 .52925 m
.00375 .52925 L
s
0 .05732 m
.00375 .05732 L
s
0 .04159 m
.00375 .04159 L
s
0 .02586 m
.00375 .02586 L
s
0 .01013 m
.00375 .01013 L
s
0 .56071 m
.00375 .56071 L
s
0 .57644 m
.00375 .57644 L
s
0 .59217 m
.00375 .59217 L
s
0 .6079 m
.00375 .6079 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -123.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
99 10.2813 translate
90 rotate
-99 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bond) show
93.000000 12.812500 moveto
(payment) show
135.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07305 m
1 .07305 L
s
.99375 .15171 m
1 .15171 L
s
.99375 .23036 m
1 .23036 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .38767 m
1 .38767 L
s
.99375 .46633 m
1 .46633 L
s
.99375 .54498 m
1 .54498 L
s
.125 Mabswid
.99625 .08878 m
1 .08878 L
s
.99625 .10452 m
1 .10452 L
s
.99625 .12025 m
1 .12025 L
s
.99625 .13598 m
1 .13598 L
s
.99625 .16744 m
1 .16744 L
s
.99625 .18317 m
1 .18317 L
s
.99625 .1989 m
1 .1989 L
s
.99625 .21463 m
1 .21463 L
s
.99625 .24609 m
1 .24609 L
s
.99625 .26182 m
1 .26182 L
s
.99625 .27756 m
1 .27756 L
s
.99625 .29329 m
1 .29329 L
s
.99625 .32475 m
1 .32475 L
s
.99625 .34048 m
1 .34048 L
s
.99625 .35621 m
1 .35621 L
s
.99625 .37194 m
1 .37194 L
s
.99625 .4034 m
1 .4034 L
s
.99625 .41913 m
1 .41913 L
s
.99625 .43486 m
1 .43486 L
s
.99625 .45059 m
1 .45059 L
s
.99625 .48206 m
1 .48206 L
s
.99625 .49779 m
1 .49779 L
s
.99625 .51352 m
1 .51352 L
s
.99625 .52925 m
1 .52925 L
s
.99625 .05732 m
1 .05732 L
s
.99625 .04159 m
1 .04159 L
s
.99625 .02586 m
1 .02586 L
s
.99625 .01013 m
1 .01013 L
s
.99625 .56071 m
1 .56071 L
s
.99625 .57644 m
1 .57644 L
s
.99625 .59217 m
1 .59217 L
s
.99625 .6079 m
1 .6079 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .60332 m
.05556 .60027 L
.0873 .59701 L
.11905 .59351 L
.15079 .58976 L
.18254 .58575 L
.21429 .58145 L
.24603 .57685 L
.27778 .57191 L
.30952 .56663 L
.34127 .56097 L
.37302 .5549 L
.40476 .54841 L
.43651 .54145 L
.46825 .53399 L
.5 .52601 L
.53175 .51746 L
.56349 .50829 L
.59524 .49848 L
.62698 .48796 L
.65873 .4767 L
.69048 .46463 L
.72222 .45171 L
.75397 .43786 L
.78571 .42303 L
.81746 .40714 L
.84921 .39012 L
.88095 .37188 L
.9127 .35235 L
.94444 .33143 L
.97619 .30902 L
s
.02381 .30902 m
.05556 .30902 L
.0873 .30902 L
.11905 .30902 L
.15079 .30902 L
.18254 .30902 L
.21429 .30902 L
.24603 .30902 L
.27778 .30902 L
.30952 .30902 L
.34127 .30902 L
.37302 .30902 L
.40476 .30902 L
.43651 .30902 L
.46825 .30902 L
.5 .30902 L
.53175 .30902 L
.56349 .30902 L
.59524 .30902 L
.62698 .30902 L
.65873 .30902 L
.69048 .30902 L
.72222 .30902 L
.75397 .30902 L
.78571 .30902 L
.81746 .30902 L
.84921 .30902 L
.88095 .30902 L
.9127 .30902 L
.94444 .30902 L
.97619 .30902 L
s
.02381 .01472 m
.05556 .01776 L
.0873 .02103 L
.11905 .02452 L
.15079 .02827 L
.18254 .03228 L
.21429 .03658 L
.24603 .04119 L
.27778 .04612 L
.30952 .05141 L
.34127 .05707 L
.37302 .06313 L
.40476 .06963 L
.43651 .07659 L
.46825 .08404 L
.5 .09202 L
.53175 .10058 L
.56349 .10974 L
.59524 .11956 L
.62698 .13007 L
.65873 .14134 L
.69048 .1534 L
.72222 .16633 L
.75397 .18017 L
.78571 .19501 L
.81746 .2109 L
.84921 .22792 L
.88095 .24615 L
.9127 .26568 L
.94444 .2866 L
.97619 .30902 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[26]:=",
  ImageSize->{295.563, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40O003h00Oogoo:7oo003oOolX
Ool00?moobQoo`00[Woo0P00Mgoo002_Ool00`00Oomoo`1eOol007ioo`<0009oo`<00006Ool007oo
001oo`000Woo0P0037oo0`0000=oo`0000000Woo00<007ooOol027oo00<007ooOol00Woo0P000Woo
100000Aoo`000000009oo`8006=oo`00Ogoo00<007ooOol00Woo00X007ooOol007oo001oo`00Ool0
00moo`05001oogooOol00002Ool00`00Oomoo`07Ool00`00Ool00002Ool00`00Oomoo`02Ool30003
Ool00`00Oomoo`03Ool00`00Oomoo`1POol007moo`03001oogoo009oo`09001oogoo001oo`00Ool0
07oo00<000eoo`05001oogooOol00002Ool00`00Oomoo`07Ool00`00Ool00002Ool30004Ool01@00
Oomoogoo000017oo00<007ooOol0HGoo001oOol01000Oomoogoo0P000Woo0P0000Aoo`00Oomoo`<0
00aoo`80009oo`@000Uoo`800004Ool00000Ool30003Ool20002Ool40002Ool2001ROol007eoo`05
001oo`00Ool0002UOol007eoo`D0009oo`03001oogoo01Ioo`03001oogoo08Moo`00ogoo:7oo003o
OolXOol002]oo`03001oogoo02Eoo`03001oogoo025oo`D0009oo`03001oogoo01ioo`D0009oo`03
001oogoo021oo`<000=oo`03001oogoo01moo`<000=oo`03001oogoo01moo`8000Aoo`03001oogoo
00Eoo`00:Woo00<007oo00009Goo00<007oo000097oo00L007ooOomoo`00Ool0000QOol01`00Oomo
ogoo001oo`00025oo`03001oogoo009oo`03001oo`00021oo`03001oogoo009oo`03001oo`00029o
o`06001oogoo001oo`001Woo000ZOol00`00Ool0000WOol00`00Oomoo`0ROol01`00Oomoogoo001o
o`00025oo`03001oogoo00=oo`03001oogoo021oo`07001oogooOol007oo00008Goo00<007ooOol0
0goo00<007ooOol07goo00L007ooOomoo`00Ool00006Ool002Yoo`03001oo`0002Eoo`8002Eoo`07
001oogooOol007oo00008Goo00@007ooOomoo`8002=oo`07001oogooOol007oo00008Goo00@007oo
Oomoo`8002=oo`06001oogoo001oo`001Woo000ZOol00`00Ool0000UOol00`00Oomoo`0TOol01`00
Oomoogoo001oo`00025oo`05001oogooOol0000SOol00`00Ool00002Ool00`00Ool0000POol00`00
Ool00002Ool00`00Oomoo`0POol00`00Ool00002Ool00`00Ool00006Ool002]oo`03001oogoo02Ao
o`<002=oo`8000Aoo`03001oogoo01moo`8000=oo`<0029oo`03001oogoo009oo`03001oogoo021o
o`04001oogooOol3000QOol00`00Oomoo`02Ool00`00Oomoo`05Ool00?moobQoo`00ogoo:7oo003o
OolXOol00?moobQoo`00ogoo:7oo003oOolXOol002Eoool000=oo`009Goo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol00goo00<007ooOol00Goo000UOol2003kOol20003Ool002Eoo`03001oogoo00Aoo`@00?=o
o`03001oogoo005oo`009Goo00<007ooOol027oo2000jgoo00<007ooOol00Goo000UOol00`00Oomo
o`0@Ool8003SOol00`00Oomoo`01Ool002Eoo`8001Uoo`P00=Yoo`8000=oo`009Goo00<007ooOol0
87oo2000dgoo00<007ooOol00Goo000UOol00`00Oomoo`0XOol8003;Ool00`00Oomoo`01Ool002Eo
o`03001oogoo031oo`P00<=oo`03001oogoo005oo`009Goo0P00>Goo2000^Woo0P000goo000UOol0
0`00Oomoo`10Ool6002eOol00`00Oomoo`01Ool002Eoo`03001oogoo04Ioo`@00;5oo`03001oogoo
005oo`009Goo00<007ooOol0BWoo1P00Zgoo00<007ooOol00Goo000UOol2001AOol6002TOol20003
Ool002Eoo`03001oogoo05Ioo`@00:5oo`03001oogoo005oo`006Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol0FWoo1P00Vgoo00<007ooOol00Goo000JOol01`00Oomoogoo001oo`0000Ao
o`03001oogoo061oo`H009Eoo`03001oogoo005oo`006Woo00L007ooOomoo`00Ool00004Ool3001V
Ool4002@Ool20003Ool001]oo`06001oogoo001oo`0017oo00<007ooOol0JWoo1000SGoo00<007oo
Ool00Goo000IOol00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`1^Ool40029Ool00`00Oomo
o`01Ool001Uoo`<000=oo`03001oogoo00=oo`03001oogoo079oo`@008Eoo`03001oogoo005oo`00
9Goo0P00Mgoo1000P7oo0P000goo000UOol00`00Oomoo`1jOol4001mOol00`00Oomoo`01Ool002Eo
o`03001oogoo07ioo`@007Uoo`03001oogoo005oo`009Goo00<007ooOol0PWoo1000MGoo00<007oo
Ool00Goo000UOol20027Ool4001`Ool20003Ool002Eoo`03001oogoo08Yoo`@006eoo`03001oogoo
005oo`009Goo00<007ooOol0SWoo0`00JWoo00<007ooOol00Goo000UOol00`00Oomoo`2AOol3001W
Ool00`00Oomoo`01Ool002Eoo`8009Eoo`<006=oo`8000=oo`009Goo00<007ooOol0Ugoo0P00HWoo
00<007ooOol00Goo000UOol00`00Oomoo`2IOol3001OOol00`00Oomoo`01Ool002Eoo`03001oogoo
09aoo`<005aoo`03001oogoo005oo`009Goo0P00X7oo1000Egoo0P000goo000UOol00`00Oomoo`2S
Ool3001EOol00`00Oomoo`01Ool001Yoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0:Io
o`8005=oo`03001oogoo005oo`006Goo00<007oo00000Woo00<007oo000017oo00<007ooOol0Z7oo
0P00DGoo00<007ooOol00Goo000IOol00`00Ool00002Ool00`00Ool00004Ool3002ZOol2001>Ool2
0003Ool001Yoo`07001oogooOol007oo000017oo00<007ooOol0[7oo0`00C7oo00<007ooOol00Goo
000IOol00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`2_Ool2001:Ool00`00Oomoo`01Ool0
01Yoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0;5oo`<004Moo`03001oogoo005oo`00
9Goo0P00]Goo0`00@goo0P000goo0005Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`2g
Ool20012Ool00`00Oomoo`01Ool000Eoo`H001Yoo`03001oogoo0;Uoo`<003moo`03001oogoo005o
o`001Goo00<007oo00000Woo00<007ooOol067oo00<007ooOol0_7oo0P00?Goo00<007ooOol00Goo
0005Ool00`00Ool00002Ool00`00Oomoo`0HOol2002oOol2000jOol20003Ool000Ioo`04001oo`00
000KOol00`00Oomoo`30Ool2000iOol00`00Oomoo`01Ool002Eoo`03001oogoo0<9oo`8003Moo`03
001oogoo005oo`009Goo00<007ooOol0a7oo0P00=Goo00<007ooOol00Goo0008Ool2000KOol20037
Ool2000bOol20003Ool000Moo`04001oogoo000JOol00`00Oomoo`38Ool2000aOol00`00Oomoo`01
Ool000Moo`04001oogoo000JOol00`00Oomoo`3:Ool2000_Ool00`00Oomoo`01Ool000Qoo`8001]o
o`03001oogoo0<aoo`8002eoo`03001oogoo005oo`009Goo0P00cgoo0P00:Woo0P000goo0007Ool0
1000Oomoo`006Woo00<007ooOol0d7oo0P00:Goo00<007ooOol00Goo0007Ool4000>Ool20004Ool0
0`00Oomoo`03Ool00`00Oomoo`3BOol2000WOol00`00Oomoo`01Ool000Moo`03001oogoo015oo`06
001oogoo001oo`0017oo00<007ooOol0e7oo0P009Goo00<007ooOol00Goo0007Ool00`00Oomoo`0@
Ool20002Ool00`00Ool00004Ool3003FOol2000ROol20003Ool000Qoo`<000ioo`03001oo`00009o
o`03001oo`0000Aoo`03001oogoo0=Qoo`03001oogoo021oo`03001oogoo005oo`002Woo00<007oo
Ool037oo00<007oo00000Woo00<007oo000017oo00<007ooOol0fGoo0P0087oo00<007ooOol00Goo
000JOol20003Ool00`00Oomoo`03Ool00`00Oomoo`3KOol2000NOol00`00Oomoo`01Ool000Qoo`80
01]oo`800=ioo`03001oogoo01Yoo`8000=oo`001goo00@007ooOol001Yoo`03001oogoo0=ioo`80
01]oo`03001oogoo005oo`001Goo00<007oo00000Woo00<007ooOol067oo00<007ooOol0h7oo00<0
07ooOol067oo00<007ooOol00Goo0005Ool6000JOol00`00Oomoo`3QOol2000HOol00`00Oomoo`01
Ool000Yoo`03001oogoo01Qoo`800>Aoo`8001Eoo`8000=oo`009Goo00<007ooOol0iGoo00<007oo
Ool04goo00<007ooOol00Goo000UOol00`00Oomoo`3VOol2000COol00`00Oomoo`01Ool002Eoo`03
001oogoo0>Qoo`03001oogoo011oo`03001oogoo005oo`009Goo0P00jWoo0P003goo0P000goo000U
Ool00`00Oomoo`3[Ool2000>Ool00`00Oomoo`01Ool002Eoo`03001oogoo0>eoo`03001oogoo00]o
o`03001oogoo005oo`001goo00<007ooOol00Woo00<007ooOol05Woo00<007ooOol0kWoo00<007oo
Ool02Woo00<007ooOol00Goo0007Ool6000HOol2003`Ool20009Ool20003Ool000Moo`06001oogoo
001oo`0067oo00<007ooOol0lGoo00<007ooOol01goo00<007ooOol00Goo0007Ool01000Oomoo`00
27oo1@000Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0lWoo00<007ooOol01Woo00<0
07ooOol00Goo0008Ool2000;Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Aoo`03001oogoo
0?=oo`8000Ioo`03001oogoo005oo`005Goo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool3
0004Ooob0004Ool20003Ool001Eoo`07001oogooOol007oo00000Woo00<007oo000017oo00<007oo
Ool0m7oo00<007ooOol017oo00<007ooOol00Goo0009Ool2000:Ool01`00Oomoogoo001oo`00009o
o`03001oo`0000Aoo`03001oogoo0?9oo`8000Moo`03001oogoo005oo`001goo00@007oo000000Uo
o`8000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo0?5oo`03001oogoo00Moo`03001o
ogoo005oo`001goo00@007oo000001Yoo`800?5oo`03001oogoo00Moo`8000=oo`001goo10006Woo
00<007ooOol0kWoo0P002goo00<007ooOol00Goo000:Ool00`00Oomoo`0HOol00`00Oomoo`3]Ool0
0`00Oomoo`0;Ool00`00Oomoo`01Ool000Moo`03001oogoo01]oo`03001oogoo0>]oo`8000ioo`03
001oogoo005oo`001goo0P000goo00<007ooOol05Woo0P00jgoo00<007ooOol03Goo0P000goo0007
Ool01000Ool007oo0P0067oo00<007ooOol0j7oo0P004Goo00<007ooOol00Goo000:Ool00`00Oomo
o`0HOol00`00Oomoo`3VOol2000COol00`00Oomoo`01Ool000Moo`<001]oo`03001oogoo0>Eoo`03
001oogoo01=oo`03001oogoo005oo`001goo00<007ooOol06goo0P00i7oo0P005Goo0P000goo0007
Ool01000Oomoo`006Woo00<007ooOol0hWoo00<007ooOol05Woo00<007ooOol00Goo0007Ool4000J
Ool00`00Oomoo`3POol2000IOol00`00Oomoo`01Ool000Moo`03001oogoo01]oo`03001oogoo0=io
o`8001]oo`03001oogoo005oo`0027oo0`006Woo0P00gWoo00<007ooOol06Woo0P000goo0007Ool0
0`00Oomoo`0KOol00`00Oomoo`3KOol2000NOol00`00Oomoo`01Ool000Qoo`<000Qoo`X0009oo`03
001oogoo00=oo`03001oogoo0=Yoo`03001oogoo01ioo`03001oogoo005oo`005Goo00<007ooOol0
0Woo00L007ooOomoo`00Ool00004Ool00`00Oomoo`3HOol2000QOol00`00Oomoo`01Ool000Qoo`80
00]oo`03001oogoo009oo`07001oogooOol007oo000017oo0`00eWoo0P008Woo0P000goo0007Ool2
00000goo001oo`09Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo0=Eoo`03
001oogoo02=oo`03001oogoo005oo`001goo0P0000=oo`00Ool02Goo00<007ooOol00Woo00L007oo
Oomoo`00Ool00004Ool00`00Oomoo`3COol2000VOol00`00Oomoo`01Ool000Qoo`03001oo`0000Uo
o`8000=oo`8000Aoo`03001oogoo00=oo`03001oogoo0=5oo`8002Qoo`03001oogoo005oo`009Goo
0P00d7oo0P00:Goo0P000goo0007Ool01000Oomoo`006Woo00<007ooOol0cGoo0P00;7oo00<007oo
Ool00Goo0007Ool4000JOol00`00Oomoo`3;Ool2000^Ool00`00Oomoo`01Ool000Moo`03001oogoo
01]oo`03001oogoo0<Uoo`80031oo`03001oogoo005oo`001goo00<007ooOol06goo0P00b7oo0P00
<Goo0P000goo0008Ool3000JOol00`00Oomoo`35Ool2000dOol00`00Oomoo`01Ool000Yoo`03001o
ogoo01Qoo`03001oogoo0<=oo`8003Ioo`03001oogoo005oo`001goo00<007ooOol06goo00<007oo
Ool0`Goo0P00>7oo00<007ooOol00Goo0006Ool4000KOol20030Ool2000iOol20003Ool000Moo`04
001oogoo000JOol00`00Oomoo`2lOol3000lOol00`00Oomoo`01Ool000Moo`04001oogoo000JOol0
0`00Oomoo`2jOol2000oOol00`00Oomoo`01Ool000Moo`03001oo`0001]oo`03001oogoo0;Moo`<0
045oo`03001oogoo005oo`009Goo0P00]Woo0P00@goo0P000goo000UOol00`00Oomoo`2cOol20016
Ool00`00Oomoo`01Ool001=oo`D00004Ool000000003Ool00`00Oomoo`03Ool00`00Oomoo`2aOol2
0018Ool00`00Oomoo`01Ool001Eoo`05001oogooOol00004Ool00`00Ool00004Ool00`00Oomoo`2_
Ool2001:Ool00`00Oomoo`01Ool001Eoo`03001oogoo009oo`07001oogooOol007oo000017oo0`00
[7oo0`00Bgoo0P000goo000EOol00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo
0:Yoo`8004moo`03001oogoo005oo`005Goo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool0
0`00Oomoo`2WOol3001AOol00`00Oomoo`01Ool001Aoo`8000Aoo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo0:Aoo`<005Aoo`03001oogoo005oo`009Goo0P00XGoo1000EWoo0P000goo000U
Ool00`00Oomoo`2LOol4001KOol00`00Oomoo`01Ool002Eoo`03001oogoo09Yoo`8005moo`03001o
ogoo005oo`009Goo00<007ooOol0Ugoo0`00HGoo00<007ooOol00Goo000UOol2002EOol3001SOol2
0003Ool002Eoo`03001oogoo095oo`<006Moo`03001oogoo005oo`009Goo00<007ooOol0SWoo0`00
JWoo00<007ooOol00Goo000UOol00`00Oomoo`2;Ool3001]Ool00`00Oomoo`01Ool002Eoo`8008Qo
o`@006moo`8000=oo`009Goo00<007ooOol0Pgoo1000M7oo00<007ooOol00Goo000UOol00`00Oomo
o`1oOol4001hOol00`00Oomoo`01Ool002Eoo`03001oogoo07]oo`@007aoo`03001oogoo005oo`00
9Goo0P00N7oo1000Ogoo0P000goo000UOol00`00Oomoo`1cOol40024Ool00`00Oomoo`01Ool001=o
o`D00003Ool0000000Aoo`03001oogoo00=oo`03001oogoo06moo`@008Qoo`03001oogoo005oo`00
5Goo00<007ooOol00goo00H007ooOol007oo0004Ool00`00Oomoo`1[Ool4002<Ool00`00Oomoo`01
Ool001Eoo`03001oogoo009oo`07001oogooOol007oo000017oo0`00Igoo1000Sgoo0P000goo000E
Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000Aoo`03001oogoo065oo`H009Aoo`03001oogoo005o
o`005Goo00L007ooOomoo`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`1KOol6002JOol00`00
Oomoo`01Ool001Aoo`8000Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo05Moo`@00:1o
o`03001oogoo005oo`009Goo0P00DWoo1P00Xgoo0P000goo000UOol00`00Oomoo`1;Ool6002ZOol0
0`00Oomoo`01Ool002Eoo`03001oogoo04Moo`@00;1oo`03001oogoo005oo`009Goo00<007ooOol0
@Goo1P00]7oo00<007ooOol00Goo000UOol2000jOol8002iOol20003Ool002Eoo`03001oogoo035o
o`P00<9oo`03001oogoo005oo`009Goo00<007ooOol0:Goo2000bWoo00<007ooOol00Goo000UOol0
0`00Oomoo`0QOol8003BOol00`00Oomoo`01Ool002Eoo`8001Yoo`P00=Uoo`8000=oo`009Goo00<0
07ooOol04Goo2000hWoo00<007ooOol00Goo000UOol00`00Oomoo`09Ool8003ZOol00`00Oomoo`01
Ool002Eoo`03001oogoo00Aoo`D00?9oo`03001oogoo005oo`009Goo0P00ngoo0P000goo000UOol0
0`00Oomoo`04Ool00`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`0VOol0
0`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`03Ool00`00Oomoo`01Ool002Eoool000=oo`00
\
\>"],
  ImageRangeCache->{{{0, 294.563}, {181.625, 0}} -> {-5.45968, 48.3231, 
  0.124088, 0.500838}}]
}, Open  ]],

Cell["Here is a second settlement date. ", "MathCaption",
  CellTags->"0.32"],

Cell["settlement2 = {12, 15, 1993};", "Input",
  CellLabel->"In[27]:="],

Cell["\<\
Here is the accrued interest for the bonds. It is the same for all \
three because their coupon rates and their next coupon payment days are \
identical. \
\>", "MathCaption",
  CellTags->"0.33"],

Cell[CellGroupData[{

Cell["AccruedInterest[bond3, settlement2]", "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(\(4550\ USDollar\)\/181\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["AccruedInterest[bond10, settlement2]", "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(\(4550\ USDollar\)\/181\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["AccruedInterest[bond30, settlement2]", "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(\(4550\ USDollar\)\/181\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["\<\
This 7.5% U.S. Treasury bond pays 100 units at maturity (February \
15, 1994). Here is the accrued interest on January 2, 1990. \
\>", 
  "MathCaption",
  CellTags->"0.34"],

Cell[CellGroupData[{

Cell["\<\
AccruedInterest[Bond[{.075 , {2, 15, 1994}, 100, 2}], {1, 2, 1990}]\
\>", "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(2.8532608695652172`\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell[TextData[{
  "Here are the values of ",
  StyleBox["bond3", "MB"],
  ", ",
  StyleBox["bond10", "MB"],
  ", and ",
  StyleBox["bond30", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.35"],

Cell[CellGroupData[{

Cell["Value[bond3, settlement1, .12]", "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(950.826756739945722`\ USDollar\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Value[bond10, settlement1, .12]", "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(885.300787814346179`\ USDollar\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Value[bond30, settlement1, .12]", "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(838.385722947618283`\ USDollar\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell[TextData[{
  "A synonym for ",
  StyleBox["Value", "MB"],
  " is ",
  StyleBox["FullPayment", "MB"],
  ". Here is the full bond payment of a 10% U.S. Treasury bond that matures \
on February 15, 1994. The settlement day is January 20, 1990 and the required \
yield is 6%. "
}], "MathCaption",
  CellTags->"0.36"],

Cell[CellGroupData[{

Cell["\<\
FullPayment[Bond[{.10, {2, 15, 1994}, 100, 2}],
   {1, 20, 1990}, .06]\
\>", "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(118.543219103107478`\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[TextData[{
  "Here are the full payments of ",
  StyleBox["bond3", "MB"],
  ", ",
  StyleBox["bond10", "MB"],
  ", and ",
  StyleBox["bond30", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.37"],

Cell[CellGroupData[{

Cell["FullPayment[bond3, settlement2, .12]", "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(979.093647539653488`\ USDollar\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["FullPayment[bond10, settlement2, .12]", "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(911.619673475330394`\ USDollar\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["FullPayment[bond30, settlement2, .12]", "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \(863.309882381086701`\ USDollar\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["YieldToMaturity",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["bond",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["price",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["settlement",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(return\ the\ yield\ to\ maturity\ of\ the\ bond\ given\ its\ 
                price\ and\ the\ settlement\ date\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True],

Cell["Additional bond function. ", "Caption"],

Cell[TextData[{
  "The yield to maturity (or internal rate of return) is the yield that would \
be earned if the bond were purchased at the current market price and held \
until maturity. It is a solution for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula"],
  " of the equation "
}], "Text",
  CellTags->"0.39"],

Cell[BoxData[
    FormBox[
      StyleBox[\(Payment[b o n d, s e t t l e m e n t, x] = price\),
        FontSlant->"Italic"], TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
  "Here is the bond payment for ",
  StyleBox["bond3", "MB"],
  " assuming a 12.5% interest rate. "
}], "MathCaption",
  CellTags->"0.40"],

Cell[CellGroupData[{

Cell["Payment[bond3, settlement1, .125]", "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(939.013303286673206`\ USDollar\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell["\<\
Now we compute the yield to maturity using this payment as the \
price. We get 0.125, as expected. \
\>", "MathCaption",
  CellTags->"0.41"],

Cell[CellGroupData[{

Cell["YieldToMaturity[bond3, %, settlement1]", "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \(0.124999999996539368`\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[TextData[{
  "Here is the payment for ",
  StyleBox["bond10", "MB"],
  " assuming a 6.75% interest rate. "
}], "MathCaption",
  CellTags->"0.42"],

Cell[CellGroupData[{

Cell["Payment[bond10, settlement2, .0675]", "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(1229.20660795305791`\ USDollar\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell["\<\
Taking the price of the bond to be this payment, we get 0.0675, \
again as expected. \
\>", "MathCaption",
  CellTags->"0.43"],

Cell[CellGroupData[{

Cell["YieldToMaturity[bond10, %, settlement2]", "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(0.0674999558710252145`\)], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell[TextData[{
  "Bond prices are often expressed in thirty\[Hyphen]seconds, and coupons in \
eighths. For instance, you could find a bond with a price of 101:13 in ",
  StyleBox["The Wall Street Journal", "TI"],
  ". This means ",
  Cell[BoxData[
      \(TraditionalForm\`101  13\/32\)], "InlineFormula"],
  ". "
}], "Text",
  CellTags->"0.44"],

Cell[TextData[{
  "This calculates the yield to maturity of a ",
  Cell[BoxData[
      \(TraditionalForm\`10  3\/8\)], "InlineFormula"],
  "% bond that pays semiannually and matures on September 15, 1995. The \
redemption value is 100 units, and its price is ",
  Cell[BoxData[
      \(TraditionalForm\`101  13\/32\)], "InlineFormula"],
  ". "
}], "MathCaption",
  CellTags->"0.45"],

Cell[CellGroupData[{

Cell["\<\
YieldToMaturity[Bond[{(10 + 3/8) Percent, {9, 15, 1995},
   100, 2}], 101 + 13/32 , {12, 15, 1993}]\
\>", "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(0.0946456549163634441`\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Duration",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["bond",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["settlement",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["ytm",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(return\ the\ Macaulay\ duration\ of\ the\ bond\ given\ the\ 
                settlement\ date\ and\ yeild\ to\ maturity\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Convexity",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["bond",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["settlement",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["ytm",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(return\ the\ convexity\ of\ the\ bond\ given\ the\ settlement
                \ date\ and\ yield\ to\ maturity\ ytm\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True],

Cell["Sensitivity measures functions. ", "Caption"],

Cell["\<\
The Macaulay duration is the weighted average maturity of a bond's cash \
flows. The present values of the cash flows are the weights. It is the time \
to maturity of an equivalent zero\[Hyphen]coupon bond. The Macaulay duration \
is also a measure of the sensitivity of a bond's price to changes in interest \
rates. Furthermore, the duration varies with the interest rates. The \
convexity is a measure of the sensitivity of the duration to interest rates \
changes. It is the slope of the price\[Hyphen]yield curve of a bond. \
\>", "Text",
  CellTags->"0.47"],

Cell["\<\
A 14% Treasury bond matures on September 15, 1996. The yield to \
maturity of the bond is 15%. We calculate the Macaulay duration of the bond \
on July 15, 1993 in half\[Hyphen]years. \
\>", "MathCaption",
  CellTags->"0.48"],

Cell[CellGroupData[{

Cell["\<\
Duration[Bond[{.14, {9, 15, 1996}, 1000, 2}],
   {9, 15, 1993}, .15]\
\>", "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(5.08809076572306206`\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell["\<\
The result is in periods. If we want it in years, we have to divide \
by the bond's frequency. \
\>", "MathCaption",
  CellTags->"0.49"],

Cell[CellGroupData[{

Cell["%/2", "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(2.54404538286153103`\)], "Output",
  CellLabel->"Out[45]="]
}, Open  ]],

Cell[TextData[{
  "We compute the durations of ",
  StyleBox["bond3", "MB"],
  ", ",
  StyleBox["bond10", "MB"],
  ", and ",
  StyleBox["bond30", "MB"],
  " on December 15, 1993 assuming a 12% yield to maturity. "
}], "MathCaption",
  CellTags->"0.50"],

Cell[CellGroupData[{

Cell["Duration[bond3, settlement2, .12]", "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(4.80692936372690748`\)], "Output",
  CellLabel->"Out[46]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Duration[bond10, settlement2, .12]", "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(12.115675264418273`\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Duration[bond30, settlement2, .12]", "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(16.8866930238760648`\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell[TextData[{
  "We define ",
  StyleBox["bd[x, c]", "MB"],
  " to be the duration in years of an ",
  StyleBox["x", "MB"],
  "\[Hyphen]year bond with the coupon rate ",
  StyleBox["c", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.51"],

Cell["\<\
bd[x_Integer?Positive, c_] := Duration[Bond[{c,
   {9, 15, 1993 + x}, 100, 2}], {9, 15, 1993}, .07] / 2;\
\>", "Input",
  CellLabel->"In[49]:="],

Cell["\<\
Here is the relationship between the duration and the coupon rate \
for a 30\[Hyphen]year bond. The duration is more sensitive to coupon changes \
for lower coupon rates than for higher ones. \
\>", "MathCaption",
  CellTags->"0.52"],

Cell[CellGroupData[{

Cell["\<\
Plot[bd[30, c], {c, 0, .20},
   FrameLabel -> {\"Coupon rate\", \"Bond duration\"}];\
\>", "Input",
  CellLabel->"In[50]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.76191 -0.344613 0.0315977 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -12 -9 ]
[.2619 -0.0125 12 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -35 -21.5625 ]
[.5 -0.0125 35 -9 ]
[-0.0125 .05036 -24 -4.5 ]
[-0.0125 .05036 0 4.5 ]
[-0.0125 .12935 -12 -4.5 ]
[-0.0125 .12935 0 4.5 ]
[-0.0125 .20835 -24 -4.5 ]
[-0.0125 .20835 0 4.5 ]
[-0.0125 .28734 -12 -4.5 ]
[-0.0125 .28734 0 4.5 ]
[-0.0125 .36634 -24 -4.5 ]
[-0.0125 .36634 0 4.5 ]
[-0.0125 .44533 -12 -4.5 ]
[-0.0125 .44533 0 4.5 ]
[-0.0125 .52433 -24 -4.5 ]
[-0.0125 .52433 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -41 ]
[-0.01875 .30902 -24 41 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -96 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Coupon) show
105.000000 12.812500 moveto
(rate) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .05036 m
.00625 .05036 L
s
[(12.5)] -0.0125 .05036 1 0 Mshowa
0 .12935 m
.00625 .12935 L
s
[(15)] -0.0125 .12935 1 0 Mshowa
0 .20835 m
.00625 .20835 L
s
[(17.5)] -0.0125 .20835 1 0 Mshowa
0 .28734 m
.00625 .28734 L
s
[(20)] -0.0125 .28734 1 0 Mshowa
0 .36634 m
.00625 .36634 L
s
[(22.5)] -0.0125 .36634 1 0 Mshowa
0 .44533 m
.00625 .44533 L
s
[(25)] -0.0125 .44533 1 0 Mshowa
0 .52433 m
.00625 .52433 L
s
[(27.5)] -0.0125 .52433 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(30)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .06616 m
.00375 .06616 L
s
0 .08196 m
.00375 .08196 L
s
0 .09776 m
.00375 .09776 L
s
0 .11355 m
.00375 .11355 L
s
0 .14515 m
.00375 .14515 L
s
0 .16095 m
.00375 .16095 L
s
0 .17675 m
.00375 .17675 L
s
0 .19255 m
.00375 .19255 L
s
0 .22415 m
.00375 .22415 L
s
0 .23995 m
.00375 .23995 L
s
0 .25574 m
.00375 .25574 L
s
0 .27154 m
.00375 .27154 L
s
0 .30314 m
.00375 .30314 L
s
0 .31894 m
.00375 .31894 L
s
0 .33474 m
.00375 .33474 L
s
0 .35054 m
.00375 .35054 L
s
0 .38214 m
.00375 .38214 L
s
0 .39793 m
.00375 .39793 L
s
0 .41373 m
.00375 .41373 L
s
0 .42953 m
.00375 .42953 L
s
0 .46113 m
.00375 .46113 L
s
0 .47693 m
.00375 .47693 L
s
0 .49273 m
.00375 .49273 L
s
0 .50853 m
.00375 .50853 L
s
0 .54012 m
.00375 .54012 L
s
0 .55592 m
.00375 .55592 L
s
0 .57172 m
.00375 .57172 L
s
0 .58752 m
.00375 .58752 L
s
0 .03456 m
.00375 .03456 L
s
0 .01876 m
.00375 .01876 L
s
0 .00296 m
.00375 .00296 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -132.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
102 10.2813 translate
90 rotate
-102 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bond) show
93.000000 12.812500 moveto
(duration) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05036 m
1 .05036 L
s
.99375 .12935 m
1 .12935 L
s
.99375 .20835 m
1 .20835 L
s
.99375 .28734 m
1 .28734 L
s
.99375 .36634 m
1 .36634 L
s
.99375 .44533 m
1 .44533 L
s
.99375 .52433 m
1 .52433 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .06616 m
1 .06616 L
s
.99625 .08196 m
1 .08196 L
s
.99625 .09776 m
1 .09776 L
s
.99625 .11355 m
1 .11355 L
s
.99625 .14515 m
1 .14515 L
s
.99625 .16095 m
1 .16095 L
s
.99625 .17675 m
1 .17675 L
s
.99625 .19255 m
1 .19255 L
s
.99625 .22415 m
1 .22415 L
s
.99625 .23995 m
1 .23995 L
s
.99625 .25574 m
1 .25574 L
s
.99625 .27154 m
1 .27154 L
s
.99625 .30314 m
1 .30314 L
s
.99625 .31894 m
1 .31894 L
s
.99625 .33474 m
1 .33474 L
s
.99625 .35054 m
1 .35054 L
s
.99625 .38214 m
1 .38214 L
s
.99625 .39793 m
1 .39793 L
s
.99625 .41373 m
1 .41373 L
s
.99625 .42953 m
1 .42953 L
s
.99625 .46113 m
1 .46113 L
s
.99625 .47693 m
1 .47693 L
s
.99625 .49273 m
1 .49273 L
s
.99625 .50853 m
1 .50853 L
s
.99625 .54012 m
1 .54012 L
s
.99625 .55592 m
1 .55592 L
s
.99625 .57172 m
1 .57172 L
s
.99625 .58752 m
1 .58752 L
s
.99625 .03456 m
1 .03456 L
s
.99625 .01876 m
1 .01876 L
s
.99625 .00296 m
1 .00296 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .60332 m
.03279 .50666 L
.04262 .43038 L
.05288 .37139 L
.06244 .32894 L
.0828 .26373 L
.09421 .23697 L
.10458 .21672 L
.12373 .18679 L
.14451 .16197 L
.16396 .1437 L
.18538 .12749 L
.22473 .10497 L
.26501 .08825 L
.30379 .07603 L
.34501 .06586 L
.38472 .05799 L
.42291 .05174 L
.46356 .04617 L
.50269 .04161 L
.54427 .03745 L
.58434 .03399 L
.62289 .03106 L
.66389 .0283 L
.70338 .02594 L
.74135 .0239 L
.78177 .02194 L
.82068 .02023 L
.86204 .01857 L
.90189 .01712 L
.94022 .01583 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[50]:=",
  ImageSize->{295.563, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40O003h00Oogoo:7oo003oOolX
Ool00?moobQoo`00U7oo0`00T7oo002EOol00`00Oomoo`2?Ool008Moo`8000=oo`8000=oo`<00004
Ool000000003Ool200000goo00000002Ool00`00Oomoo`0;Ool30002Ool40002Ool20003Ool2001U
Ool008Ioo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<007oo00000Woo
00<007oo00000Woo00<007ooOol037oo00@007ooOomoo`<0009oo`06001oogoo001oo`00Igoo0026
Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oo`00009oo`03001o
o`00009oo`03001oogoo00aoo`03001oogoo00=oo`04001oogoo0004Ool3001UOol008Ioo`03001o
ogoo00=oo`800004Ool00000Ool60003Ool200000goo00000002000>Ool40002Ool200000goo0000
00020002Ool3001UOol008Ioo`03001oo`00035oo`03001oogoo06Yoo`00QWoo0`00WWoo003oOolX
Ool00?moobQoo`00ogoo:7oo000^Ool00`00Oomoo`0aOol00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool00`00Oomoo`05000/Ool00`00Oomoo`02
Ool00`00Oomoo`050002Ool00`00Oomoo`0]Ool00`00Oomoo`02Ool01000Oomoogoo0`000goo000]
Ool00`00Ool0000aOol00`00Ool00007Ool00`00Ool00002Ool00`00Ool0000/Ool00`00Ool00008
Ool00`00Oomoo`0[Ool00`00Ool00008Ool01`00Oomoogoo001oo`0002eoo`03001oo`0000Moo`03
001oogoo00=oo`00;Goo00<007oo0000<Goo00<007oo00001goo00<007oo000017oo00<007ooOol0
:Woo00<007oo000027oo00<007ooOol0:goo00<007oo000027oo00<007ooOol00goo00<007ooOol0
:goo00<007oo000027oo00<007ooOol00Woo000]Ool00`00Ool0000aOol00`00Ool00007Ool00`00
Ool00002Ool2000]Ool00`00Ool00008Ool00`00Oomoo`0[Ool00`00Ool00008Ool01000Oomoogoo
0P00;Woo00<007oo000027oo00<007ooOol00Woo000]Ool00`00Ool0000aOol00`00Ool00007Ool0
0`00Ool00002Ool00`00Oomoo`0/Ool00`00Ool00008Ool00`00Oomoo`0[Ool00`00Ool00008Ool0
1@00Oomoogoo0000;goo00<007oo00001goo00<007oo00000goo000^Ool00`00Oomoo`0aOol00`00
Oomoo`07Ool01000Oomoogoo0`00;Goo00<007ooOol01Woo0P00;Woo00<007ooOol01Woo0P000goo
0`00;Woo00<007ooOol01goo00<007ooOol00Woo003oOolXOol00?moobQoo`00ogoo:7oo003oOolX
Ool00?moobQoo`00:Goon`000goo000YOol20004Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`02Ool20003Ool002Uoo`03001o
ogoo00=oo`03001oogoo03Qoo`03001oogoo03Uoo`03001oogoo03Qoo`03001oogoo03Uoo`03001o
ogoo00=oo`03001oogoo005oo`00:Goo00<007ooOol0mgoo00<007ooOol00Goo000YOol00`00Oomo
o`3TOol>0005Ool00`00Oomoo`01Ool002Uoo`800<Mooah0019oo`8000=oo`00:Goo00<007ooOol0
/Woo5000<Goo00<007ooOol00Goo000YOol00`00Oomoo`2OOolC0015Ool00`00Oomoo`01Ool002Uo
o`03001oogoo09Eoo`X005Qoo`03001oogoo005oo`00:Goo0P00S7oo2P00HGoo0P000goo000YOol0
0`00Oomoo`21Ool:001/Ool00`00Oomoo`01Ool0019oo`D00004Ool000000003Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`1gOol:001fOol00`00Oomoo`01Ool001Aoo`05001oogooOol0
0009Ool00`00Ool00004Ool00`00Oomoo`1]Ool:0020Ool00`00Oomoo`01Ool001Aoo`03001oogoo
009oo`03001oogoo00Qoo`03001oogoo009oo`8006Ioo`P008Qoo`<000=oo`0057oo00<007ooOol0
0Woo00<007ooOol01Woo0P001Goo00<007ooOol0H7oo1@00TWoo00<007ooOol00Goo000DOol01`00
Oomoogoo001oo`0000Moo`03001oogoo00Aoo`03001oogoo05]oo`D009Moo`03001oogoo005oo`00
4goo0P0017oo00<007ooOol01Woo0`0017oo00<007ooOol0EWoo1@00W7oo00<007ooOol00Goo000Y
Ool2001BOol5002POol20003Ool002Uoo`03001oogoo04aoo`D00:Ioo`03001oogoo005oo`00:Goo
00<007ooOol0B7oo1000Zgoo00<007ooOol00Goo000YOol00`00Oomoo`15Ool3002_Ool00`00Oomo
o`01Ool002Uoo`80049oo`@00;5oo`8000=oo`00:Goo00<007ooOol0?goo0P00]Woo00<007ooOol0
0Goo000YOol00`00Oomoo`0mOol2002hOol00`00Oomoo`01Ool002Uoo`03001oogoo03]oo`800;Yo
o`03001oogoo005oo`00:Goo0P00>Woo0P00^goo0P000goo000YOol00`00Oomoo`0gOol2002nOol0
0`00Oomoo`01Ool002Uoo`03001oogoo03Eoo`800<1oo`03001oogoo005oo`00:Goo00<007ooOol0
<goo0P00`Woo00<007ooOol00Goo000YOol2000bOol20033Ool20003Ool002Uoo`03001oogoo02mo
o`800<Ioo`03001oogoo005oo`0077oo1@000Woo00<007ooOol00goo00<007ooOol0;Goo0P00b7oo
00<007ooOol00Goo000NOol01`00Oomoogoo001oo`0000Aoo`03001oogoo02]oo`800<Yoo`03001o
ogoo005oo`007Woo00<007ooOol00goo00<007ooOol00Woo0P00:goo00<007ooOol0b7oo0`000goo
000NOol01000Oomoogoo0P001Goo00<007ooOol0:7oo0P00cGoo00<007ooOol00Goo000NOol01@00
Oomoogoo00001Woo00<007ooOol09goo00<007ooOol0cGoo00<007ooOol00Goo000MOol20003Ool3
0004Ool00`00Oomoo`0VOol00`00Oomoo`3>Ool00`00Oomoo`01Ool002Uoo`8002Ioo`03001oogoo
0<ioo`8000=oo`00:Goo00<007ooOol097oo00<007ooOol0d7oo00<007ooOol00Goo000YOol00`00
Oomoo`0SOol00`00Oomoo`3AOol00`00Oomoo`01Ool0009oo`03001oogoo009oo`03001oogoo01mo
o`03001oogoo029oo`03001oogoo0=9oo`03001oogoo005oo`000Woo1P008Goo0P008Woo00<007oo
Ool0dWoo0P000goo0002Ool00`00Ool00002Ool00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomo
o`3DOol00`00Oomoo`01Ool0009oo`03001oo`00009oo`03001oogoo01moo`03001oogoo01moo`03
001oogoo0=Eoo`03001oogoo005oo`000goo00@007oo0000029oo`03001oogoo01ioo`03001oogoo
0=Ioo`03001oogoo005oo`00:Goo0P007goo00<007ooOol0eGoo0P000goo000YOol00`00Oomoo`0M
Ool00`00Oomoo`3GOol00`00Oomoo`01Ool000Eoo`80029oo`03001oogoo01aoo`03001oogoo0=Qo
o`03001oogoo005oo`0017oo00@007ooOol0025oo`8001aoo`03001oogoo0=Qoo`8000=oo`0017oo
00@007ooOol0025oo`03001oogoo01]oo`03001oogoo0=Uoo`03001oogoo005oo`001Goo0P002goo
1@000Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol06Woo00<007oo
Ool0fWoo00<007ooOol00Goo000DOol00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Ool00004Ool0
0`00Oomoo`0IOol00`00Oomoo`3KOol00`00Oomoo`01Ool000Aoo`04001oogoo000<Ool00`00Oomo
o`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2000JOol00`00Oomoo`3IOol30003Ool000Aoo`@0
00aoo`03001oogoo00=oo`03001oogoo00Eoo`8000Eoo`03001oogoo01Qoo`03001oogoo0=aoo`03
001oogoo005oo`0017oo00<007ooOol03Goo00L007ooOomoo`00Ool00007Ool00`00Oomoo`04Ool0
0`00Oomoo`0HOol00`00Oomoo`3LOol00`00Oomoo`01Ool000Aoo`03001oogoo00aoo`8000=oo`<0
00Moo`<000Aoo`03001oogoo01Moo`03001oogoo0=eoo`03001oogoo005oo`001Goo0`008Goo0P00
5goo00<007ooOol0gGoo0P000goo0007Ool00`00Oomoo`0OOol00`00Oomoo`0FOol00`00Oomoo`3N
Ool00`00Oomoo`01Ool002Uoo`03001oogoo01Eoo`03001oogoo0=moo`03001oogoo005oo`001Goo
0P008Woo00<007ooOol05Goo00<007ooOol0ggoo00<007ooOol00Goo0004Ool01000Oomoo`008Goo
0P005Goo00<007ooOol0ggoo0P000goo0002Ool00`00Ool00002Ool00`00Oomoo`0OOol00`00Oomo
o`0COol00`00Oomoo`3QOol00`00Oomoo`01Ool0009oo`H0025oo`03001oogoo01=oo`03001oogoo
0>5oo`03001oogoo005oo`001goo00<007ooOol07goo00<007ooOol04Woo00<007ooOol0hWoo00<0
07ooOol00Goo000YOol2000COol00`00Oomoo`3QOol20003Ool002Uoo`03001oogoo015oo`03001o
ogoo0>=oo`03001oogoo005oo`00:Goo00<007ooOol04Goo00<007ooOol0hgoo00<007ooOol00Goo
000YOol00`00Oomoo`0AOol00`00Oomoo`3SOol00`00Oomoo`01Ool002Uoo`80015oo`03001oogoo
0>=oo`8000=oo`00:Goo00<007ooOol047oo00<007ooOol0i7oo00<007ooOol00Goo000MOol30003
Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool00`00Oomoo`3TOol00`00Oomoo`01Ool000Eoo`8001Io
o`03001oogoo009oo`03001oo`0000Aoo`03001oogoo011oo`03001oogoo0>Aoo`03001oogoo005o
o`0017oo00@007ooOol001Ioo`07001oogooOol007oo000017oo0P0047oo00<007ooOol0hgoo0`00
0goo0002Ool00`00Ool00002Ool00`00Oomoo`0DOol01`00Oomoogoo001oo`0000Aoo`03001oogoo
00moo`03001oogoo0>Eoo`03001oogoo005oo`000Woo1P005Goo00<007oo00000Woo00<007oo0000
17oo00<007ooOol03goo00<007ooOol0iGoo00<007ooOol00Goo0007Ool00`00Oomoo`0DOol00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`3VOol00`00Oomoo`01Ool000Ao
o`03001oogoo029oo`8000moo`03001oogoo0>Eoo`8000=oo`0017oo0`008Woo00<007ooOol03Woo
00<007ooOol0iWoo00<007ooOol00Goo0007Ool00`00Oomoo`0OOol00`00Oomoo`0=Ool00`00Oomo
o`3WOol00`00Oomoo`01Ool000Aoo`03001oo`00029oo`03001oogoo00eoo`03001oogoo0>Moo`03
001oogoo005oo`0017oo10008Goo0P003Woo00<007ooOol0iWoo0P000goo0007Ool00`00Oomoo`0O
Ool00`00Oomoo`0=Ool00`00Oomoo`3WOol00`00Oomoo`01Ool002Uoo`03001oogoo00aoo`03001o
ogoo0>Qoo`03001oogoo005oo`0017oo00@007ooOol0025oo`03001oogoo00aoo`03001oogoo0>Qo
o`03001oogoo005oo`0017oo10008Goo0P003Goo00<007ooOol0igoo0P000goo0004Ool01000Oomo
o`008Goo00<007ooOol037oo00<007ooOol0j7oo00<007ooOol00Goo0004Ool01000Oomoo`008Goo
00<007ooOol02goo00<007ooOol0jGoo00<007ooOol00Goo000YOol00`00Oomoo`0;Ool00`00Oomo
o`3YOol00`00Oomoo`01Ool002Uoo`8000aoo`03001oogoo0>Qoo`8000=oo`001Woo0P008Goo00<0
07ooOol02goo00<007ooOol0jGoo00<007ooOol00Goo0004Ool01000Ool000002goo0`000Woo0`00
0goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol0jGoo00<007ooOol0
0Goo0004Ool01000Ool000002goo00<007ooOol00Woo00<007ooOol01goo00<007oo000017oo00<0
07ooOol02Woo00<007ooOol0jWoo00<007ooOol00Goo0004Ool4000<Ool00`00Oomoo`02Ool00`00
Oomoo`08Ool00`00Oomoo`02Ool2000;Ool00`00Oomoo`3XOol30003Ool000Moo`03001oogoo00Yo
o`03001oogoo009oo`03001oogoo00Ioo`8000Eoo`03001oogoo00Yoo`03001oogoo0>Yoo`03001o
ogoo005oo`0017oo00<007ooOol037oo00<007oo00000Woo00<007oo00001goo00<007ooOol017oo
00<007ooOol02Woo00<007ooOol0jWoo00<007ooOol00Goo0003Ool4000=Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool30004Ool00`00Oomoo`0:Ool00`00Oomoo`3ZOol00`00Oomoo`01Ool000Aoo`04
001oogoo000QOol2000:Ool00`00Oomoo`3ZOol20003Ool000Aoo`04001oogoo000QOol00`00Oomo
o`09Ool00`00Oomoo`3[Ool00`00Oomoo`01Ool000Aoo`03001oo`00029oo`03001oogoo00Uoo`03
001oogoo0>]oo`03001oogoo005oo`00:Goo00<007ooOol02Goo00<007ooOol0jgoo00<007ooOol0
0Goo000YOol2000:Ool00`00Oomoo`3ZOol20003Ool002Uoo`03001oogoo00Qoo`03001oogoo0>ao
o`03001oogoo005oo`0017oo00@007ooOol0025oo`03001oogoo00Qoo`03001oogoo0>aoo`03001o
ogoo005oo`000Woo00<007oo00000`008Goo00<007ooOol027oo00<007ooOol0k7oo00<007ooOol0
0Goo0007Ool00`00Oomoo`0OOol20009Ool00`00Oomoo`3[Ool20003Ool002Uoo`03001oogoo00Qo
o`03001oogoo0>aoo`03001oogoo005oo`00:Goo00<007ooOol01goo00<007ooOol0kGoo00<007oo
Ool00Goo0005Ool2000ROol00`00Oomoo`07Ool00`00Oomoo`3]Ool00`00Oomoo`01Ool000Aoo`04
001oogoo000QOol20008Ool00`00Oomoo`3/Ool20003Ool000Aoo`04001oogoo000QOol00`00Oomo
o`07Ool00`00Oomoo`3]Ool00`00Oomoo`01Ool000Eoo`8001Ioo`<000=oo`03001oogoo00=oo`03
001oogoo00Moo`03001oogoo0>eoo`03001oogoo005oo`007Goo00<007ooOol00Woo00<007oo0000
17oo00<007ooOol01goo00<007ooOol0kGoo00<007ooOol00Goo0004Ool01000Oomoo`005Woo00<0
07ooOol00goo00<007ooOol00Woo0P0027oo00<007ooOol0jgoo0`000goo0004Ool4000FOol01000
Oomoogoo0P001Goo00<007ooOol01Woo00<007ooOol0kWoo00<007ooOol00Goo0004Ool00`00Oomo
o`0FOol00`00Ool00002Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`3^Ool00`00Oomo
o`01Ool000Aoo`03001oogoo01Moo`04001oogooOol30004Ool00`00Oomoo`06Ool00`00Oomoo`3^
Ool00`00Oomoo`01Ool000Eoo`<0025oo`8000Moo`03001oogoo0>eoo`8000=oo`001goo00<007oo
Ool07goo00<007ooOol01Woo00<007ooOol0kWoo00<007ooOol00Goo000YOol00`00Oomoo`06Ool0
0`00Oomoo`3^Ool00`00Oomoo`01Ool002Uoo`03001oogoo00Ioo`03001oogoo0>ioo`03001oogoo
005oo`00:Goo0P001goo00<007ooOol0kGoo0P000goo000YOol00`00Oomoo`06Ool00`00Oomoo`3^
Ool00`00Oomoo`01Ool002Uoo`03001oogoo00Ioo`03001oogoo0>ioo`03001oogoo005oo`00:Goo
00<007ooOol01Goo00<007ooOol0kgoo00<007ooOol00Goo000YOol20006Ool00`00Oomoo`3^Ool2
0003Ool002Uoo`03001oogoo00Eoo`03001oogoo0>moo`03001oogoo005oo`00:Goo00<007ooOol0
1Goo00<007ooOol0kgoo00<007ooOol00Goo000YOol00`00Oomoo`05Ool00`00Oomoo`3_Ool00`00
Oomoo`01Ool002Uoo`8000Ioo`03001oogoo0>ioo`8000=oo`00:Goo00<007ooOol01Goo00<007oo
Ool0kgoo00<007ooOol00Goo000COol30003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`05Ool00`00Oomoo`3_Ool00`00Oomoo`01Ool001=oo`03001oogoo00=oo`03
001oogoo00Ioo`03001oo`0000Aoo`03001oogoo00Eoo`03001oogoo0>moo`03001oogoo005oo`00
57oo00<007ooOol00Woo00<007ooOol027oo00<007ooOol00Woo0P001Woo00<007ooOol0kGoo0`00
0goo000DOol00`00Oomoo`03Ool00`00Oomoo`05Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`3`
Ool00`00Oomoo`01Ool001=oo`03001oo`00009oo`03001oo`0000Moo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo0?1oo`03001oogoo005oo`0057oo00@007ooOomoo`<000Moo`<000Aoo`80
00Eoo`03001oogoo0>moo`8000=oo`00:Goo00<007ooOol017oo00<007ooOol0l7oo00<007ooOol0
0Goo000YOol00`00Oomoo`04Ool00`00Oomoo`3`Ool00`00Oomoo`01Ool002Uoo`03001oogoo00Ao
o`03001oogoo0?1oo`03001oogoo005oo`00:Goo0P001Goo00<007ooOol0kgoo0P000goo000YOol0
0`00Oomoo`04Ool00`00Oomoo`3`Ool00`00Oomoo`01Ool002Uoo`03001oogoo00Aoo`03001oogoo
0?1oo`03001oogoo005oo`00:Goo00<007ooOol017oo00<007ooOol0l7oo00<007ooOol00Goo000Y
Ool20005Ool00`00Oomoo`3_Ool20003Ool002Uoo`03001oogoo00Aoo`03001oogoo0?1oo`03001o
ogoo005oo`00:Goo00<007ooOol00goo00<007ooOol0lGoo00<007ooOol00Goo000YOol00`00Oomo
o`03Ool00`00Oomoo`3aOol00`00Oomoo`01Ool002Uoo`8000Aoo`03001oogoo0?1oo`8000=oo`00
:Goo00<007ooOol00goo00<007ooOol0lGoo00<007ooOol00Goo000MOol20004Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`3aOol00`00Oomoo`01Ool001moo`06001oogoo001oo`0017oo
00<007ooOol00goo00<007ooOol0lGoo00<007ooOol00Goo000NOol01`00Oomoogoo001oo`0000Ao
o`8000Aoo`03001oogoo0>moo`<000=oo`007goo00H007ooOol007oo0004Ool00`00Oomoo`3gOol0
0`00Oomoo`01Ool001eoo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo00=oo`03001oogoo
03Qoo`03001oogoo03Uoo`03001oogoo03Qoo`03001oogoo03Uoo`03001oogoo00=oo`03001oogoo
005oo`007Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol00goo00<0
07ooOol00Goo000YOook0003Ool00?moobQoo`00\
\>"],
  ImageRangeCache->{{{0, 294.563}, {181.625, 0}} -> {-0.0396186, 7.69255, 
  0.000839113, 0.126458}}]
}, Open  ]],

Cell["\<\
This shows the relationship between the various maturity issues. \
The duration is more sensitive to coupon changes for long terms to maturity \
than for short ones. \
\>", "MathCaption",
  CellTags->"0.53"],

Cell[CellGroupData[{

Cell["\<\
Plot[{bd[3, c], bd[10, c], bd[30, c]}, {c, 0, .20},
   FrameLabel -> {\"Coupon rate\", \"Bond duration\"}];\
\>", "Input",
  CellLabel->"In[51]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.76191 -0.0384546 0.0213925 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -12 -9 ]
[.2619 -0.0125 12 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.7381 -0.0125 -12 -9 ]
[.7381 -0.0125 12 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -35 -21.5625 ]
[.5 -0.0125 35 -9 ]
[-0.0125 .06851 -6 -4.5 ]
[-0.0125 .06851 0 4.5 ]
[-0.0125 .17547 -12 -4.5 ]
[-0.0125 .17547 0 4.5 ]
[-0.0125 .28243 -12 -4.5 ]
[-0.0125 .28243 0 4.5 ]
[-0.0125 .38939 -12 -4.5 ]
[-0.0125 .38939 0 4.5 ]
[-0.0125 .49636 -12 -4.5 ]
[-0.0125 .49636 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24.5625 -41 ]
[-0.01875 .30902 -12 41 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.05)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(0.15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(0.2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -96 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Coupon) show
105.000000 12.812500 moveto
(rate) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .06851 m
.00625 .06851 L
s
[(5)] -0.0125 .06851 1 0 Mshowa
0 .17547 m
.00625 .17547 L
s
[(10)] -0.0125 .17547 1 0 Mshowa
0 .28243 m
.00625 .28243 L
s
[(15)] -0.0125 .28243 1 0 Mshowa
0 .38939 m
.00625 .38939 L
s
[(20)] -0.0125 .38939 1 0 Mshowa
0 .49636 m
.00625 .49636 L
s
[(25)] -0.0125 .49636 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(30)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .0899 m
.00375 .0899 L
s
0 .11129 m
.00375 .11129 L
s
0 .13269 m
.00375 .13269 L
s
0 .15408 m
.00375 .15408 L
s
0 .19686 m
.00375 .19686 L
s
0 .21825 m
.00375 .21825 L
s
0 .23965 m
.00375 .23965 L
s
0 .26104 m
.00375 .26104 L
s
0 .30382 m
.00375 .30382 L
s
0 .32522 m
.00375 .32522 L
s
0 .34661 m
.00375 .34661 L
s
0 .368 m
.00375 .368 L
s
0 .41079 m
.00375 .41079 L
s
0 .43218 m
.00375 .43218 L
s
0 .45357 m
.00375 .45357 L
s
0 .47496 m
.00375 .47496 L
s
0 .51775 m
.00375 .51775 L
s
0 .53914 m
.00375 .53914 L
s
0 .56053 m
.00375 .56053 L
s
0 .58193 m
.00375 .58193 L
s
0 .04712 m
.00375 .04712 L
s
0 .02572 m
.00375 .02572 L
s
0 .00433 m
.00375 .00433 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -120.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
102 10.2813 translate
90 rotate
-102 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bond) show
93.000000 12.812500 moveto
(duration) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06851 m
1 .06851 L
s
.99375 .17547 m
1 .17547 L
s
.99375 .28243 m
1 .28243 L
s
.99375 .38939 m
1 .38939 L
s
.99375 .49636 m
1 .49636 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .0899 m
1 .0899 L
s
.99625 .11129 m
1 .11129 L
s
.99625 .13269 m
1 .13269 L
s
.99625 .15408 m
1 .15408 L
s
.99625 .19686 m
1 .19686 L
s
.99625 .21825 m
1 .21825 L
s
.99625 .23965 m
1 .23965 L
s
.99625 .26104 m
1 .26104 L
s
.99625 .30382 m
1 .30382 L
s
.99625 .32522 m
1 .32522 L
s
.99625 .34661 m
1 .34661 L
s
.99625 .368 m
1 .368 L
s
.99625 .41079 m
1 .41079 L
s
.99625 .43218 m
1 .43218 L
s
.99625 .45357 m
1 .45357 L
s
.99625 .47496 m
1 .47496 L
s
.99625 .51775 m
1 .51775 L
s
.99625 .53914 m
1 .53914 L
s
.99625 .56053 m
1 .56053 L
s
.99625 .58193 m
1 .58193 L
s
.99625 .04712 m
1 .04712 L
s
.99625 .02572 m
1 .02572 L
s
.99625 .00433 m
1 .00433 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .02572 m
.06244 .025 L
.10458 .02426 L
.14415 .0236 L
.18221 .02299 L
.22272 .02238 L
.26171 .02181 L
.30316 .02124 L
.34309 .02072 L
.3815 .02023 L
.42237 .01974 L
.46172 .01929 L
.49955 .01887 L
.53984 .01844 L
.57861 .01804 L
.61984 .01764 L
.65954 .01726 L
.69774 .01691 L
.73838 .01656 L
.77751 .01623 L
.81909 .01589 L
.85916 .01557 L
.89771 .01528 L
.93871 .01498 L
.97619 .01472 L
s
.02381 .17547 m
.06244 .16376 L
.10458 .15347 L
.14415 .14552 L
.18221 .13908 L
.22272 .13323 L
.26171 .12838 L
.30316 .12389 L
.34309 .12011 L
.3815 .11688 L
.42237 .11381 L
.46172 .11117 L
.49955 .10887 L
.53984 .10664 L
.57861 .10468 L
.61984 .10279 L
.65954 .10111 L
.69774 .09962 L
.73838 .09815 L
.77751 .09685 L
.81909 .09556 L
.85916 .0944 L
.89771 .09336 L
.93871 .09232 L
.97619 .09143 L
s
.02381 .60332 m
.03279 .53788 L
.04262 .48624 L
.05288 .4463 L
.06244 .41756 L
.0828 .37341 L
.09421 .35529 L
.10458 .34158 L
.12373 .32132 L
.14451 .30452 L
.16396 .29215 L
.18538 .28117 L
.22473 .26592 L
.26501 .25461 L
.30379 .24633 L
.34501 .23944 L
.38472 .23412 L
.42291 .22989 L
.46356 .22611 L
.50269 .22303 L
.54427 .22021 L
.58434 .21787 L
.62289 .21588 L
.66389 .21402 L
.70338 .21242 L
.74135 .21104 L
.78177 .20971 L
.82068 .20855 L
.86204 .20743 L
.90189 .20645 L
.94022 .20558 L
.97619 .20482 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[51]:=",
  ImageSize->{295.563, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40O003h00Oogoo:7oo003oOolX
Ool00?moobQoo`00SWoo0`00UWoo002?Ool00`00Oomoo`2EOol0085oo`8000=oo`8000=oo`<00004
Ool000000003Ool200000goo00000002Ool00`00Oomoo`0;Ool30002Ool40002Ool20003Ool2001[
Ool0081oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<007oo00000Woo
00<007oo00000Woo00<007ooOol037oo00@007ooOomoo`<0009oo`06001oogoo001oo`00KGoo0020
Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oo`00009oo`03001o
o`00009oo`03001oogoo00aoo`03001oogoo00=oo`04001oogoo0004Ool3001[Ool0081oo`03001o
ogoo00=oo`800004Ool00000Ool60003Ool200000goo00000002000>Ool40002Ool200000goo0000
00020002Ool3001[Ool0081oo`03001oo`00035oo`03001oogoo071oo`00P7oo0`00Y7oo003oOolX
Ool00?moobQoo`009goo00<007ooOol0<Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol01@00;Goo00<007ooOol00Woo00<007oo
Ool01@000Woo00<007ooOol0;Goo00<007ooOol00Woo00@007ooOomoo`<000Qoo`009Woo00<007oo
0000<Woo00<007oo00001goo00<007oo00000Woo00<007oo0000;7oo00<007oo000027oo00<007oo
Ool0;7oo00<007oo000027oo00L007ooOomoo`00Ool0000]Ool00`00Ool00007Ool00`00Oomoo`08
Ool002Ioo`03001oo`00039oo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo02Yoo`03001o
o`0000Qoo`03001oogoo02aoo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo02]oo`03001o
o`0000Qoo`03001oogoo00Moo`009Woo00<007oo0000<Woo00<007oo00001goo00<007oo00000Woo
0P00;Goo00<007oo000027oo00<007ooOol0;7oo00<007oo000027oo00@007ooOomoo`8002ioo`03
001oo`0000Qoo`03001oogoo00Moo`009Woo00<007oo0000<Woo00<007oo00001goo00<007oo0000
0Woo00<007ooOol0;7oo00<007oo000027oo00<007ooOol0;7oo00<007oo000027oo00D007ooOomo
o`0002moo`03001oo`0000Moo`03001oo`0000Qoo`009goo00<007ooOol0<Woo00<007ooOol01goo
00@007ooOomoo`<002eoo`03001oogoo00Ioo`8002moo`03001oogoo00Ioo`8000=oo`<002ioo`03
001oogoo00Moo`03001oogoo00Moo`00ogoo:7oo003oOolXOol00?moobQoo`00ogoo:7oo003oOolX
Ool00?moobQoo`008Wooo@0027oo000ROol20004Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`02Ool20008Ool0029oo`03001o
ogoo0?Uoo`03001oogoo00Ioo`008Woo00<007ooOol0fgoo6@001Goo00<007ooOol01Woo000ROol0
0`00Oomoo`1]Oom^000NOol00`00Oomoo`06Ool0029oo`03001oogoo02MoodH008aoo`03001oogoo
00Ioo`008Woo0P0017oo9000dGoo0P0027oo000ROol00`00Oomoo`3iOol00`00Oomoo`06Ool0029o
o`03001oogoo0?Uoo`03001oogoo00Ioo`008Woo00<007ooOol0nGoo00<007ooOol01Woo000ROol0
0`00Oomoo`3iOol00`00Oomoo`06Ool0029oo`800?Uoo`8000Qoo`008Woo00<007ooOol0nGoo00<0
07ooOol01Woo000ROol00`00Oomoo`3iOol00`00Oomoo`06Ool0029oo`03001oogoo0?Uoo`03001o
ogoo00Ioo`006goo00<007ooOol017oo00<007ooOol0nGoo00<007ooOol01Woo000JOol00`00Ool0
0005Ool00`00Oomoo`3iOol00`00Oomoo`06Ool001aoo`03001oogoo00=oo`800?Uoo`8000Qoo`00
6Woo0P001Woo00<007ooOol0nGoo00<007ooOol01Woo000JOol00`00Oomoo`05Ool00`00Oomoo`3i
Ool00`00Oomoo`06Ool001Yoo`<000Eoo`03001oogoo0?Uoo`03001oogoo00Ioo`008Woo00<007oo
Ool0nGoo00<007ooOol01Woo000ROol2003iOol20008Ool0029oo`03001oogoo0=9oob8000Eoo`03
001oogoo00Ioo`008Woo00<007ooOol0/goo7`009goo00<007ooOol01Woo000ROol00`00Oomoo`2O
OolD0016Ool00`00Oomoo`06Ool0029oo`03001oogoo08]ooa@005Yoo`03001oogoo00Ioo`008Woo
00<007ooOol0Mgoo5000KWoo00<007ooOol01Woo000ROol2001TOolD0021Ool20008Ool0029oo`03
001oogoo05Uoo`X009Ioo`03001oogoo00Ioo`008Woo00<007ooOol0Cgoo2P00X7oo00<007ooOol0
1Woo000ROol00`00Oomoo`15Ool:002ZOol00`00Oomoo`06Ool0029oo`03001oogoo03]oo`X00;Ao
o`03001oogoo00Ioo`008Woo0P00=7oo2000_Goo0P0027oo000ROol00`00Oomoo`0^Ool50036Ool0
0`00Oomoo`06Ool0029oo`03001oogoo02Moo`L00<]oo`03001oogoo00Ioo`008Woo00<007ooOol0
7goo2000dWoo00<007ooOol01Woo000ROol00`00Oomoo`0JOol5003JOol00`00Oomoo`06Ool0029o
o`03001oogoo01Ioo`@00=moo`03001oogoo00Ioo`008Woo0P004goo1000hWoo0P0027oo0007Ool0
0`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`0>Ool4003WOol00`00Oomoo`06Ool000Moo`H0
01Eoo`03001oogoo00]oo`<00>]oo`03001oogoo00Ioo`001goo00<007oo00000Woo00<007ooOol0
1Goo1@000Woo00<007ooOol017oo00<007ooOol027oo0`00kWoo00<007ooOol01Woo0007Ool00`00
Ool00002Ool00`00Oomoo`07Ool01`00Oomoogoo001oo`0000Eoo`03001oogoo00Eoo`<00?5oo`03
001oogoo00Ioo`0027oo00@007oo000000Yoo`07001oogooOol007oo00001Goo0P0017oo0P00lgoo
0P0027oo000FOol01`00Oomoogoo001oo`0000Eoo`03001oogoo0?Uoo`03001oogoo00Ioo`005Woo
00L007ooOomoo`00Ool00005Ool00`00Oomoo`3iOol00`00Oomoo`06Ool000Yoo`8000Uoo`8000Ao
o`03001oogoo00Aoo`03001oogoo0?Uoo`03001oogoo00Ioo`002Goo00@007ooOol001Eoo`03001o
ogoo0?Uoo`03001oogoo00Ioo`002Goo00@007ooOol001Eoo`800?Uoo`8000Qoo`002Woo0P005Woo
00<007ooOol0nGoo00<007ooOol01Woo000ROol00`00Oomoo`3_Ool50005Ool00`00Oomoo`06Ool0
00Uoo`04001oogoo000EOol00`00Oomoo`38OolW000:Ool00`00Oomoo`06Ool000Uoo`@001Eoo`03
001oogoo0:Yooah0035oo`03001oogoo00Ioo`002Goo00<007ooOol05Woo00<007ooOol0UWoo5000
Cgoo00<007ooOol01Woo0009Ool00`00Oomoo`0FOol20023OolD001ROol20008Ool000Yoo`<001Eo
o`03001oogoo07Qoo`X007Moo`03001oogoo00Ioo`0037oo00<007ooOol04goo00<007ooOol0KGoo
2`00PGoo00<007ooOol01Woo000ROol00`00Oomoo`1SOol:002<Ool00`00Oomoo`06Ool000Yoo`80
01Ioo`03001oogoo05Yoo`T009Ioo`03001oogoo00Ioo`002Goo00@007ooOol001Eoo`8005=oo`P0
09ioo`8000Qoo`001goo00<007oo00000Woo00<007ooOol04goo00<007ooOol0C7oo1P00Ygoo00<0
07ooOol01Woo0007Ool6000EOol00`00Oomoo`17Ool5002]Ool00`00Oomoo`06Ool000aoo`03001o
ogoo01=oo`03001oogoo04=oo`@00;9oo`03001oogoo00Ioo`008Woo00<007ooOol0?goo1000]Woo
00<007ooOol01Woo000ROol00`00Oomoo`0kOol4002jOol00`00Oomoo`06Ool0029oo`8003Qoo`@0
0;eoo`8000Qoo`008Woo00<007ooOol0=7oo0`00`Woo00<007ooOol01Woo000ROol00`00Oomoo`0b
Ool20035Ool00`00Oomoo`06Ool001Aoo`D0009oo`03001oogoo00Aoo`03001oogoo02moo`<00<Mo
o`03001oogoo00Ioo`005Woo00L007ooOomoo`00Ool00005Ool00`00Oomoo`0]Ool2003:Ool00`00
Oomoo`06Ool000Yoo`8000Yoo`03001oogoo00=oo`03001oogoo00=oo`8002]oo`<00<]oo`8000Qo
o`002Goo00@007ooOol000Uoo`04001oogooOol20006Ool00`00Oomoo`0XOol2003?Ool00`00Oomo
o`06Ool000Moo`03001oo`00009oo`03001oogoo00Moo`05001oogooOol00007Ool00`00Oomoo`0V
Ool2003AOol00`00Oomoo`06Ool000Moo`H000Qoo`8000=oo`<000Eoo`03001oogoo02Eoo`03001o
ogoo0=5oo`03001oogoo00Ioo`0037oo00<007ooOol04goo00<007ooOol08goo0P00e7oo00<007oo
Ool01Woo0009Ool00`00Oomoo`0FOol2000SOol00`00Oomoo`3COol20008Ool000Uoo`<001Ioo`03
001oogoo025oo`03001oogoo0=Eoo`03001oogoo00Ioo`0037oo00<007ooOol04goo00<007ooOol0
87oo00<007ooOol0eWoo00<007ooOol01Woo0009Ool00`00Ool0000FOol00`00Oomoo`0NOol2003I
Ool00`00Oomoo`06Ool000Uoo`@001Eoo`03001oogoo01eoo`03001oogoo0=Uoo`03001oogoo00Io
o`0037oo00<007ooOol04goo00<007ooOol077oo00<007ooOol0fWoo00<007ooOol01Woo000ROol2
000LOol00`00Oomoo`3JOol20008Ool000Uoo`04001oogoo000EOol00`00Oomoo`0JOol00`00Oomo
o`3LOol00`00Oomoo`06Ool000Uoo`@001Eoo`03001oogoo01Uoo`03001oogoo0=eoo`03001oogoo
00Ioo`002Goo00@007ooOol001Eoo`03001oogoo01Qoo`03001oogoo0=ioo`03001oogoo00Ioo`00
2Goo00@007ooOol001Eoo`03001oogoo01Moo`03001oogoo0=moo`03001oogoo00Ioo`008Woo0P00
5goo00<007ooOol0ggoo0P0027oo000ROol00`00Oomoo`0EOol00`00Oomoo`3QOol00`00Oomoo`06
Ool000]oo`8001Eoo`03001oogoo01Aoo`03001oogoo0>9oo`03001oogoo00Ioo`002Goo00@007oo
000001Eoo`03001oogoo01Aoo`03001oogoo0>9oo`03001oogoo00Ioo`002Goo00@007oo000001Eo
o`03001oogoo01=oo`03001oogoo0>=oo`03001oogoo00Ioo`002Goo10005Goo00<007ooOol04goo
00<007ooOol0hgoo00<007ooOol01Woo000<Ool00`00Oomoo`0COol2000COol00`00Oomoo`3SOol2
0008Ool000Uoo`03001oogoo01Ioo`03001oogoo019oo`03001oogoo0>Aoo`03001oogoo00Ioo`00
27oo10005Woo00<007ooOol04Goo00<007ooOol0iGoo00<007ooOol01Woo0009Ool01000Oomoo`00
27oo0`000goo00<007ooOol017oo00<007ooOol04Goo00<007ooOol0iGoo00<007ooOol01Woo0009
Ool01000Oomoo`0027oo00<007ooOol00Woo00<007oo00001Goo00<007ooOol047oo00<007ooOol0
iWoo00<007ooOol01Woo0009Ool00`00Ool0000:Ool01`00Oomoogoo001oo`0000Eoo`80015oo`03
001oogoo0>Eoo`8000Qoo`005Woo00L007ooOomoo`00Ool00005Ool00`00Oomoo`0?Ool00`00Oomo
o`3WOol00`00Oomoo`06Ool001Eoo`03001oo`00009oo`03001oo`0000Eoo`03001oogoo00moo`03
001oogoo0>Moo`03001oogoo00Ioo`005Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
3Woo00<007ooOol0j7oo00<007ooOol01Woo0009Ool01000Oomoo`005Goo00<007ooOol03Woo00<0
07ooOol0j7oo00<007ooOol01Woo0007Ool00`00Ool00003000EOol2000>Ool00`00Oomoo`3XOol2
0008Ool000aoo`03001oogoo01=oo`03001oogoo00eoo`03001oogoo0>Uoo`03001oogoo00Ioo`00
8Woo00<007ooOol037oo00<007ooOol0jWoo00<007ooOol01Woo000ROol00`00Oomoo`0<Ool00`00
Oomoo`3ZOol00`00Oomoo`06Ool000Yoo`8001Ioo`03001oogoo00]oo`03001oogoo0>]oo`03001o
ogoo00Ioo`002Goo00@007ooOol001Eoo`03001oogoo00]oo`03001oogoo0>]oo`03001oogoo00Io
o`002Goo00@007ooOol001Eoo`8000aoo`03001oogoo0>Yoo`8000Qoo`002Woo0P005Woo00<007oo
Ool02goo00<007ooOol0jgoo00<007ooOol01Woo000ROol00`00Oomoo`0:Ool00`00Oomoo`3/Ool0
0`00Oomoo`06Ool000Uoo`04001oogoo000EOol00`00Oomoo`0:Ool00`00Oomoo`3/Ool00`00Oomo
o`06Ool000Uoo`@001Eoo`03001oogoo00Yoo`03001oogoo0>aoo`03001oogoo00Ioo`002Goo00<0
07ooOol05Woo0P002Woo00<007ooOol0k7oo0P0027oo0009Ool00`00Oomoo`0FOol00`00Oomoo`09
Ool00`00Oomoo`3]Ool00`00Oomoo`06Ool000Yoo`<001Eoo`03001oogoo00Uoo`03001oogoo0>eo
o`03001oogoo00Ioo`0037oo00<007ooOol04goo00<007ooOol027oo00<007ooOol0kWoo00<007oo
Ool01Woo000ROol00`00Oomoo`08Ool00`00Oomoo`3^Ool00`00Oomoo`06Ool0029oo`03001oogoo
00Qoo`03001oogoo0>ioo`03001oogoo00Ioo`008Woo0P002Goo00<007ooOol0kGoo0P0027oo000R
Ool00`00Oomoo`07Ool00`00Oomoo`3_Ool00`00Oomoo`06Ool0029oo`03001oogoo00Moo`03001o
ogoo0>moo`03001oogoo00Ioo`005Goo0`000goo00<007ooOol017oo00<007ooOol01goo00<007oo
Ool0kgoo00<007ooOol01Woo000EOol00`00Oomoo`02Ool00`00Ool00005Ool00`00Oomoo`07Ool0
0`00Oomoo`3_Ool00`00Oomoo`06Ool001Ioo`03001oogoo00=oo`03001oogoo00=oo`8000Qoo`03
001oogoo0>ioo`8000Qoo`005Woo00@007ooOomoo`8000Ioo`03001oogoo00Ioo`03001oogoo0?1o
o`03001oogoo00Ioo`005Goo00<007oo00000Woo00<007ooOol01Goo00<007ooOol01Woo00<007oo
Ool0l7oo00<007ooOol01Woo000FOol01000Oomoogoo0`001Goo00<007ooOol01Woo00<007ooOol0
l7oo00<007ooOol01Woo000ROol00`00Oomoo`06Ool00`00Oomoo`3`Ool00`00Oomoo`06Ool0029o
o`8000Moo`03001oogoo0>moo`8000Qoo`008Woo00<007ooOol01Woo00<007ooOol0l7oo00<007oo
Ool01Woo000ROol00`00Oomoo`05Ool00`00Oomoo`3aOol00`00Oomoo`06Ool0029oo`03001oogoo
00Eoo`03001oogoo0?5oo`03001oogoo00Ioo`008Woo00<007ooOol01Goo00<007ooOol0lGoo00<0
07ooOol01Woo000ROol00`00Oomoo`05Ool00`00Oomoo`3aOol00`00Oomoo`06Ool0029oo`8000Io
o`03001oogoo0?1oo`8000Qoo`008Woo00<007ooOol01Goo00<007ooOol0lGoo00<007ooOol01Woo
000ROol00`00Oomoo`05Ool00`00Oomoo`3aOol00`00Oomoo`06Ool0029oo`03001oogoo00Eoo`03
001oogoo0?5oo`03001oogoo00Ioo`008Woo00<007ooOol017oo00<007ooOol0lWoo00<007ooOol0
1Woo000ROol20005Ool00`00Oomoo`3aOol20008Ool0029oo`03001oogoo00Aoo`03001oogoo0?9o
o`03001oogoo00Ioo`008Woo00<007ooOol017oo00<007ooOol0lWoo00<007ooOol01Woo000ROol0
0`00Oomoo`04Ool00`00Oomoo`3bOol00`00Oomoo`06Ool0029oo`03001oogoo00Aoo`03001oogoo
0?9oo`03001oogoo00Ioo`008Woo00<007ooOol017oo00<007ooOol0lWoo00<007ooOol01Woo000R
Ool20005Ool00`00Oomoo`3aOol20008Ool0029oo`03001oogoo00=oo`03001oogoo0?=oo`03001o
ogoo00Ioo`008Woo00<007ooOol00goo00<007ooOol0lgoo00<007ooOol01Woo000EOol20004Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`3cOol00`00Oomoo`06Ool001Moo`06001oogoo
001oo`001Goo00<007ooOol00goo00<007ooOol0lgoo00<007ooOol01Woo000FOol01`00Oomoogoo
001oo`0000Eoo`8000Aoo`03001oogoo0?9oo`8000Qoo`005goo00H007ooOol007oo0005Ool00`00
Oomoo`3iOol00`00Oomoo`06Ool001Eoo`03001oo`00009oo`03001oo`0000Eoo`03001oogoo00=o
o`03001oogoo03Uoo`03001oogoo03Uoo`03001oogoo03Uoo`03001oogoo03Uoo`03001oogoo00=o
o`03001oogoo00Ioo`005Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool00goo00<007ooOol01Woo000ROoom0008Ool00001\
\>"],
  ImageRangeCache->{{{0, 294.563}, {181.625, 0}} -> {-0.0333766, -2.77705, 
  0.000831327, 0.185051}}]
}, Open  ]],

Cell["\<\
Here we compute the convexity (in periods) for a 5\[Hyphen]year, \
14% coupon bond selling to yield 10%. \
\>", "MathCaption",
  CellTags->"0.54"],

Cell[CellGroupData[{

Cell["\<\
Convexity[Bond[{.14, {9, 15, 1998}, 1000, 2}],
   settlement1, .10]\
\>", "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \(84.5799556628364967`\)], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell[TextData[{
  "The result returned by ",
  StyleBox["Convexity", "MB"],
  " is in periods squared. So if we want to have the result in years squared \
we have to divide by the bond's frequency squared. This is the previous \
result in years squared. "
}], "MathCaption",
  CellTags->"0.55"],

Cell[CellGroupData[{

Cell["% / 2^2", "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \(21.1449889157091241`\)], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell["\<\
Here we compute the convexity (in periods squared) for a \
10\[Hyphen]year, 8% coupon bond selling to yield 10%. \
\>", "MathCaption",
  CellTags->"0.56"],

Cell[CellGroupData[{

Cell["\<\
Convexity[Bond[{.8, {9, 15, 2003}, 1000, 2}], settlement1, .10]\
\>", "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(150.665339650568919`\)], "Output",
  CellLabel->"Out[54]="]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["CouponPaymentDate",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["bond",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["n",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            StyleBox[
              FormBox[
                StyleBox[
                  RowBox[{
                    StyleBox["give",
                      SingleLetterItalics->False], " ", 
                    StyleBox["the",
                      SingleLetterItalics->False], " ", 
                    StyleBox["date",
                      SingleLetterItalics->False], " ", 
                    StyleBox["of",
                      SingleLetterItalics->False], " ", 
                    StyleBox["the",
                      SingleLetterItalics->False], " ", 
                    FormBox[\(n\^th\),
                      "TraditionalForm"], " ", 
                    StyleBox["coupon",
                      SingleLetterItalics->False], " ", 
                    StyleBox["payment",
                      SingleLetterItalics->False], " ", 
                    StyleBox["for",
                      SingleLetterItalics->False], " ", 
                    StyleBox["the",
                      SingleLetterItalics->False], " ", 
                    StyleBox["bond",
                      SingleLetterItalics->False], " ", 
                    StyleBox["counted",
                      SingleLetterItalics->False], " ", 
                    StyleBox["backward",
                      SingleLetterItalics->False], " ", 
                    StyleBox["from",
                      SingleLetterItalics->False], " ", 
                    StyleBox["maturity",
                      SingleLetterItalics->False]}],
                  "TraditionalForm"],
                "TextForm"],
              "Text"]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["NumberOfCouponPayments",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["bond",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["settlement",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(give\ the\ number\ of\ remaining\ coupon\ payments\ of\ the\ 
                bond\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["CashFlowsDates",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["bond",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["settlement",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(return\ the\ list\ of\ future\ coupon\ payment\ dates\ of\ the
                \ bond\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True],

Cell["Auxiliary functions. ", "Caption"],

Cell["We define a third settlement date. ", "MathCaption",
  CellTags->"0.58"],

Cell["settlement3 = {8, 29, 1993};", "Input",
  CellLabel->"In[55]:="],

Cell["\<\
Here is the date of the third coupon payment counted backward from \
maturity. \
\>", "MathCaption",
  CellTags->"0.59"],

Cell[CellGroupData[{

Cell["CouponPaymentDate[bond10, 3]", "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \({9, 15, 2002}\)], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell[TextData[{
  "This is the number of coupon payments between August 29, 1993 and the \
maturity of ",
  StyleBox["bond10", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.60"],

Cell[CellGroupData[{

Cell["n = NumberOfCouponPayments[bond3, settlement3]", "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(7\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell[TextData[{
  "We can find the dates of all the coupon payments of ",
  StyleBox["bond3", "MB"],
  " after the settlement date. "
}], "MathCaption",
  CellTags->"0.61"],

Cell["tab = Table[CouponPaymentDate[bond3, k],  {k, 1, n}];", "Input",
  CellLabel->"In[58]:="],

Cell["Here we display them in a table. ", "MathCaption",
  CellTags->"0.62"],

Cell[CellGroupData[{

Cell["\<\
TableForm[tab,
   TableHeadings -> {Range[7], {\"M\", \" D\", \"   Y\\n\"}}]\
\>", "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"M\"\>", "\<\" D\"\>", \("   Y\n"\)},
          {"1", "9", "15", "1996"},
          {"2", "3", "15", "1996"},
          {"3", "9", "15", "1995"},
          {"4", "3", "15", "1995"},
          {"5", "9", "15", "1994"},
          {"6", "3", "15", "1994"},
          {"7", "9", "15", "1993"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableHeadings -> {{1, 2, 3, 4, 5, 6, 7}, {"M", " D", 
        "   Y\n"}}]&)]], "Output",
  CellLabel->"Out[59]//TableForm="]
}, Open  ]],

Cell["\<\
We can generate the dates of the cash flows for a given bond and \
settlement directly. \
\>", "MathCaption",
  CellTags->"0.63"],

Cell[CellGroupData[{

Cell["CashFlowsDates[bond3, {9, 30, 1993}] // ColumnForm", "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\({3, 15, 1994}\)},
          {\({9, 15, 1994}\)},
          {\({3, 15, 1995}\)},
          {\({9, 15, 1995}\)},
          {\({3, 15, 1996}\)},
          {\({9, 15, 1996}\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {{3, 15, 1994}, {9, 15, 1994}, {3, 15, 1995}, {9, 15, 
        1995}, {3, 15, 1996}, {9, 15, 1996}}],
      Editable->False]], "Output",
  CellLabel->"Out[60]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowSize->{500, 350},
WindowMargins->{{-1, Automatic}, {Automatic, 0}},
DefaultNewCellStyle->"TraditionalForm",
StyleDefinitions -> "ApplicationManual.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "0.1"->{
    Cell[1739, 51, 43, 1, 72, "Section",
      CellTags->"0.1"]},
  "0.2"->{
    Cell[1785, 54, 204, 5, 52, "Text",
      CellTags->"0.2"]},
  "0.3"->{
    Cell[1992, 61, 119, 5, 32, "MathCaption",
      CellTags->"0.3"]},
  "0.4"->{
    Cell[2175, 71, 85, 1, 31, "MathCaption",
      CellTags->"0.4"]},
  "0.6"->{
    Cell[3685, 127, 143, 4, 48, "MathCaption",
      CellTags->"0.6"]},
  "0.7"->{
    Cell[4028, 143, 225, 6, 49, "MathCaption",
      CellTags->"0.7"]},
  "0.8"->{
    Cell[4513, 164, 217, 6, 49, "MathCaption",
      CellTags->"0.8"]},
  "0.9"->{
    Cell[4991, 185, 217, 6, 49, "MathCaption",
      CellTags->"0.9"]},
  "0.11"->{
    Cell[8942, 321, 96, 1, 31, "MathCaption",
      CellTags->"0.11"]},
  "0.12"->{
    Cell[9113, 327, 215, 6, 49, "MathCaption",
      CellTags->"0.12"]},
  "0.13"->{
    Cell[9533, 345, 162, 5, 48, "MathCaption",
      CellTags->"0.13"]},
  "0.14"->{
    Cell[9902, 362, 97, 1, 31, "MathCaption",
      CellTags->"0.14"]},
  "0.15"->{
    Cell[10340, 377, 89, 1, 31, "MathCaption",
      CellTags->"0.15"]},
  "0.16"->{
    Cell[10607, 390, 208, 5, 65, "MathCaption",
      CellTags->"0.16"]},
  "0.17"->{
    Cell[11071, 410, 263, 8, 49, "MathCaption",
      CellTags->"0.17"]},
  "0.18"->{
    Cell[11463, 426, 121, 4, 31, "MathCaption",
      CellTags->"0.18"]},
  "0.19"->{
    Cell[11683, 435, 151, 4, 48, "MathCaption",
      CellTags->"0.19"]},
  "0.20"->{
    Cell[34108, 1201, 210, 5, 48, "MathCaption",
      CellTags->"0.20"]},
  "0.21"->{
    Cell[56874, 1965, 321, 9, 67, "MathCaption",
      CellTags->"0.21"]},
  "0.22"->{
    Cell[121431, 3465, 160, 4, 48, "MathCaption",
      CellTags->"0.22"]},
  "0.23"->{
    Cell[121715, 3476, 222, 9, 50, "MathCaption",
      CellTags->"0.23"]},
  "0.24"->{
    Cell[146494, 4319, 165, 4, 52, "Text",
      CellTags->"0.24"]},
  "0.25"->{
    Cell[146662, 4325, 260, 8, 50, "MathCaption",
      CellTags->"0.25"]},
  "0.26"->{
    Cell[147136, 4345, 155, 4, 48, "MathCaption",
      CellTags->"0.26"]},
  "0.27"->{
    Cell[147418, 4356, 66, 1, 31, "MathCaption",
      CellTags->"0.27"]},
  "0.28"->{
    Cell[147579, 4362, 166, 5, 49, "MathCaption",
      CellTags->"0.28"]},
  "0.29"->{
    Cell[170238, 5211, 167, 5, 49, "MathCaption",
      CellTags->"0.29"]},
  "0.30"->{
    Cell[189648, 5919, 166, 5, 49, "MathCaption",
      CellTags->"0.30"]},
  "0.31"->{
    Cell[212289, 6768, 78, 1, 31, "MathCaption",
      CellTags->"0.31"]},
  "0.32"->{
    Cell[234842, 7661, 77, 1, 31, "MathCaption",
      CellTags->"0.32"]},
  "0.33"->{
    Cell[234996, 7667, 205, 5, 48, "MathCaption",
      CellTags->"0.33"]},
  "0.34"->{
    Cell[235803, 7704, 182, 5, 48, "MathCaption",
      CellTags->"0.34"]},
  "0.35"->{
    Cell[236223, 7723, 193, 9, 32, "MathCaption",
      CellTags->"0.35"]},
  "0.36"->{
    Cell[237024, 7764, 317, 9, 66, "MathCaption",
      CellTags->"0.36"]},
  "0.37"->{
    Cell[237583, 7788, 200, 9, 32, "MathCaption",
      CellTags->"0.37"]},
  "0.39"->{
    Cell[239433, 7866, 330, 8, 71, "Text",
      CellTags->"0.39"]},
  "0.40"->{
    Cell[239931, 7881, 154, 5, 32, "MathCaption",
      CellTags->"0.40"]},
  "0.41"->{
    Cell[240292, 7898, 150, 4, 48, "MathCaption",
      CellTags->"0.41"]},
  "0.42"->{
    Cell[240645, 7914, 150, 5, 32, "MathCaption",
      CellTags->"0.42"]},
  "0.43"->{
    Cell[241004, 7931, 136, 4, 48, "MathCaption",
      CellTags->"0.43"]},
  "0.44"->{
    Cell[241345, 7947, 346, 9, 77, "Text",
      CellTags->"0.44"]},
  "0.45"->{
    Cell[241694, 7958, 382, 10, 73, "MathCaption",
      CellTags->"0.45"]},
  "0.47"->{
    Cell[244353, 8055, 573, 9, 128, "Text",
      CellTags->"0.47"]},
  "0.48"->{
    Cell[244929, 8066, 235, 5, 65, "MathCaption",
      CellTags->"0.48"]},
  "0.49"->{
    Cell[245404, 8086, 146, 4, 48, "MathCaption",
      CellTags->"0.49"]},
  "0.50"->{
    Cell[245717, 8102, 252, 9, 49, "MathCaption",
      CellTags->"0.50"]},
  "0.51"->{
    Cell[246555, 8143, 240, 9, 50, "MathCaption",
      CellTags->"0.51"]},
  "0.52"->{
    Cell[246955, 8160, 243, 5, 65, "MathCaption",
      CellTags->"0.52"]},
  "0.53"->{
    Cell[269235, 8946, 217, 5, 65, "MathCaption",
      CellTags->"0.53"]},
  "0.54"->{
    Cell[290333, 9703, 156, 4, 48, "MathCaption",
      CellTags->"0.54"]},
  "0.55"->{
    Cell[290728, 9722, 294, 7, 66, "MathCaption",
      CellTags->"0.55"]},
  "0.56"->{
    Cell[291193, 9741, 164, 4, 48, "MathCaption",
      CellTags->"0.56"]},
  "0.58"->{
    Cell[295538, 9886, 78, 1, 31, "MathCaption",
      CellTags->"0.58"]},
  "0.59"->{
    Cell[295692, 9892, 130, 4, 48, "MathCaption",
      CellTags->"0.59"]},
  "0.60"->{
    Cell[296007, 9908, 179, 6, 49, "MathCaption",
      CellTags->"0.60"]},
  "0.61"->{
    Cell[296377, 9926, 172, 5, 49, "MathCaption",
      CellTags->"0.61"]},
  "0.62"->{
    Cell[296650, 9936, 76, 1, 31, "MathCaption",
      CellTags->"0.62"]},
  "0.63"->{
    Cell[297523, 9967, 139, 4, 48, "MathCaption",
      CellTags->"0.63"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"0.1", 299027, 10015},
  {"0.2", 299104, 10018},
  {"0.3", 299179, 10021},
  {"0.4", 299261, 10024},
  {"0.6", 299342, 10027},
  {"0.7", 299425, 10030},
  {"0.8", 299508, 10033},
  {"0.9", 299591, 10036},
  {"0.11", 299675, 10039},
  {"0.12", 299759, 10042},
  {"0.13", 299844, 10045},
  {"0.14", 299929, 10048},
  {"0.15", 300013, 10051},
  {"0.16", 300098, 10054},
  {"0.17", 300184, 10057},
  {"0.18", 300270, 10060},
  {"0.19", 300356, 10063},
  {"0.20", 300442, 10066},
  {"0.21", 300529, 10069},
  {"0.22", 300616, 10072},
  {"0.23", 300704, 10075},
  {"0.24", 300792, 10078},
  {"0.25", 300873, 10081},
  {"0.26", 300961, 10084},
  {"0.27", 301049, 10087},
  {"0.28", 301136, 10090},
  {"0.29", 301224, 10093},
  {"0.30", 301312, 10096},
  {"0.31", 301400, 10099},
  {"0.32", 301487, 10102},
  {"0.33", 301574, 10105},
  {"0.34", 301662, 10108},
  {"0.35", 301750, 10111},
  {"0.36", 301838, 10114},
  {"0.37", 301926, 10117},
  {"0.39", 302014, 10120},
  {"0.40", 302095, 10123},
  {"0.41", 302183, 10126},
  {"0.42", 302271, 10129},
  {"0.43", 302359, 10132},
  {"0.44", 302447, 10135},
  {"0.45", 302528, 10138},
  {"0.47", 302617, 10141},
  {"0.48", 302699, 10144},
  {"0.49", 302787, 10147},
  {"0.50", 302875, 10150},
  {"0.51", 302963, 10153},
  {"0.52", 303051, 10156},
  {"0.53", 303139, 10159},
  {"0.54", 303227, 10162},
  {"0.55", 303315, 10165},
  {"0.56", 303403, 10168},
  {"0.58", 303491, 10171},
  {"0.59", 303578, 10174},
  {"0.60", 303666, 10177},
  {"0.61", 303754, 10180},
  {"0.62", 303842, 10183},
  {"0.63", 303929, 10186}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 43, 1, 72, "Section",
  CellTags->"0.1"],
Cell[1785, 54, 204, 5, 52, "Text",
  CellTags->"0.2"],
Cell[1992, 61, 119, 5, 32, "MathCaption",
  CellTags->"0.3"],
Cell[2114, 68, 58, 1, 30, "Input"],
Cell[2175, 71, 85, 1, 31, "MathCaption",
  CellTags->"0.4"],

Cell[CellGroupData[{
Cell[2285, 76, 57, 1, 30, "Input"],
Cell[2345, 79, 203, 6, 93, "Print"]
}, Open  ]],
Cell[2563, 88, 857, 27, 41, "TopSpanBox"],
Cell[3423, 117, 224, 6, 26, "BottomBox"],
Cell[3650, 125, 32, 0, 16, "Caption"],
Cell[3685, 127, 143, 4, 48, "MathCaption",
  CellTags->"0.6"],

Cell[CellGroupData[{
Cell[3853, 135, 46, 1, 30, "Input"],
Cell[3902, 138, 111, 2, 44, "Print"]
}, Open  ]],
Cell[4028, 143, 225, 6, 49, "MathCaption",
  CellTags->"0.7"],

Cell[CellGroupData[{
Cell[4278, 153, 112, 4, 48, "Input"],
Cell[4393, 159, 105, 2, 42, "Output"]
}, Open  ]],
Cell[4513, 164, 217, 6, 49, "MathCaption",
  CellTags->"0.8"],

Cell[CellGroupData[{
Cell[4755, 174, 113, 4, 48, "Input"],
Cell[4871, 180, 105, 2, 42, "Output"]
}, Open  ]],
Cell[4991, 185, 217, 6, 49, "MathCaption",
  CellTags->"0.9"],

Cell[CellGroupData[{
Cell[5233, 195, 112, 4, 48, "Input"],
Cell[5348, 201, 105, 2, 42, "Output"]
}, Open  ]],
Cell[5468, 206, 630, 22, 41, "TopSpanBox"],
Cell[6101, 230, 344, 9, 42, "MiddleBox"],
Cell[6448, 241, 1099, 29, 34, "MiddleSpanBox"],
Cell[7550, 272, 316, 9, 42, "MiddleBox"],
Cell[7869, 283, 631, 22, 33, "MiddleSpanBox"],
Cell[8503, 307, 392, 10, 58, "BottomBox"],
Cell[8898, 319, 41, 0, 16, "Caption"],
Cell[8942, 321, 96, 1, 31, "MathCaption",
  CellTags->"0.11"],
Cell[9041, 324, 69, 1, 30, "Input"],
Cell[9113, 327, 215, 6, 49, "MathCaption",
  CellTags->"0.12"],

Cell[CellGroupData[{
Cell[9353, 337, 74, 1, 30, "Input"],
Cell[9430, 340, 88, 2, 29, "Output"]
}, Open  ]],
Cell[9533, 345, 162, 5, 48, "MathCaption",
  CellTags->"0.13"],

Cell[CellGroupData[{
Cell[9720, 354, 76, 1, 30, "Input"],
Cell[9799, 357, 88, 2, 29, "Output"]
}, Open  ]],
Cell[9902, 362, 97, 1, 31, "MathCaption",
  CellTags->"0.14"],

Cell[CellGroupData[{
Cell[10024, 367, 84, 1, 30, "Input"],
Cell[10111, 370, 214, 4, 86, "Output"]
}, Open  ]],
Cell[10340, 377, 89, 1, 31, "MathCaption",
  CellTags->"0.15"],

Cell[CellGroupData[{
Cell[10454, 382, 46, 1, 30, "Input"],
Cell[10503, 385, 89, 2, 29, "Output"]
}, Open  ]],
Cell[10607, 390, 208, 5, 65, "MathCaption",
  CellTags->"0.16"],

Cell[CellGroupData[{
Cell[10840, 399, 124, 4, 48, "Input"],
Cell[10967, 405, 89, 2, 29, "Output"]
}, Open  ]],
Cell[11071, 410, 263, 8, 49, "MathCaption",
  CellTags->"0.17"],
Cell[11337, 420, 123, 4, 48, "Input"],
Cell[11463, 426, 121, 4, 31, "MathCaption",
  CellTags->"0.18"],
Cell[11587, 432, 93, 1, 30, "Input"],
Cell[11683, 435, 151, 4, 48, "MathCaption",
  CellTags->"0.19"],

Cell[CellGroupData[{
Cell[11859, 443, 93, 1, 30, "Input"],
Cell[11955, 446, 22138, 752, 191, 8410, 577, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[34108, 1201, 210, 5, 48, "MathCaption",
  CellTags->"0.20"],

Cell[CellGroupData[{
Cell[34343, 1210, 127, 4, 48, "Input"],
Cell[34473, 1216, 22386, 746, 191, 8484, 569, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[56874, 1965, 321, 9, 67, "MathCaption",
  CellTags->"0.21"],

Cell[CellGroupData[{
Cell[57220, 1978, 179, 5, 66, "Input"],
Cell[57402, 1985, 64014, 1477, 218, 26533, 1009, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[121431, 3465, 160, 4, 48, "MathCaption",
  CellTags->"0.22"],
Cell[121594, 3471, 118, 3, 48, "Input"],
Cell[121715, 3476, 222, 9, 50, "MathCaption",
  CellTags->"0.23"],

Cell[CellGroupData[{
Cell[121962, 3489, 138, 4, 48, "Input"],
Cell[122103, 3495, 24376, 821, 191, 9215, 629, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[146494, 4319, 165, 4, 52, "Text",
  CellTags->"0.24"],
Cell[146662, 4325, 260, 8, 50, "MathCaption",
  CellTags->"0.25"],

Cell[CellGroupData[{
Cell[146947, 4337, 80, 1, 30, "Input"],
Cell[147030, 4340, 91, 2, 29, "Output"]
}, Open  ]],
Cell[147136, 4345, 155, 4, 48, "MathCaption",
  CellTags->"0.26"],
Cell[147294, 4351, 121, 3, 48, "Input"],
Cell[147418, 4356, 66, 1, 31, "MathCaption",
  CellTags->"0.27"],
Cell[147487, 4359, 89, 1, 30, "Input"],
Cell[147579, 4362, 166, 5, 49, "MathCaption",
  CellTags->"0.28"],

Cell[CellGroupData[{
Cell[147770, 4371, 128, 4, 48, "Input"],
Cell[147901, 4377, 22322, 831, 186, 9434, 667, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[170238, 5211, 167, 5, 49, "MathCaption",
  CellTags->"0.29"],

Cell[CellGroupData[{
Cell[170430, 5220, 127, 4, 48, "Input"],
Cell[170560, 5226, 19073, 690, 186, 8149, 550, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[189648, 5919, 166, 5, 49, "MathCaption",
  CellTags->"0.30"],

Cell[CellGroupData[{
Cell[189839, 5928, 127, 4, 48, "Input"],
Cell[189969, 5934, 22305, 831, 186, 9430, 667, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[212289, 6768, 78, 1, 31, "MathCaption",
  CellTags->"0.31"],

Cell[CellGroupData[{
Cell[212392, 6773, 71, 1, 30, "Input"],
Cell[212466, 6776, 22361, 882, 191, 10339, 728, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[234842, 7661, 77, 1, 31, "MathCaption",
  CellTags->"0.32"],
Cell[234922, 7664, 71, 1, 30, "Input"],
Cell[234996, 7667, 205, 5, 48, "MathCaption",
  CellTags->"0.33"],

Cell[CellGroupData[{
Cell[235226, 7676, 77, 1, 30, "Input"],
Cell[235306, 7679, 82, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[235425, 7686, 78, 1, 30, "Input"],
Cell[235506, 7689, 82, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[235625, 7696, 78, 1, 30, "Input"],
Cell[235706, 7699, 82, 2, 42, "Output"]
}, Open  ]],
Cell[235803, 7704, 182, 5, 48, "MathCaption",
  CellTags->"0.34"],

Cell[CellGroupData[{
Cell[236010, 7713, 117, 3, 48, "Input"],
Cell[236130, 7718, 78, 2, 29, "Output"]
}, Open  ]],
Cell[236223, 7723, 193, 9, 32, "MathCaption",
  CellTags->"0.35"],

Cell[CellGroupData[{
Cell[236441, 7736, 72, 1, 30, "Input"],
Cell[236516, 7739, 89, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[236642, 7746, 73, 1, 30, "Input"],
Cell[236718, 7749, 89, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[236844, 7756, 73, 1, 30, "Input"],
Cell[236920, 7759, 89, 2, 29, "Output"]
}, Open  ]],
Cell[237024, 7764, 317, 9, 66, "MathCaption",
  CellTags->"0.36"],

Cell[CellGroupData[{
Cell[237366, 7777, 120, 4, 48, "Input"],
Cell[237489, 7783, 79, 2, 29, "Output"]
}, Open  ]],
Cell[237583, 7788, 200, 9, 32, "MathCaption",
  CellTags->"0.37"],

Cell[CellGroupData[{
Cell[237808, 7801, 78, 1, 30, "Input"],
Cell[237889, 7804, 89, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[238015, 7811, 79, 1, 30, "Input"],
Cell[238097, 7814, 89, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[238223, 7821, 79, 1, 30, "Input"],
Cell[238305, 7824, 89, 2, 29, "Output"]
}, Open  ]],
Cell[238409, 7829, 640, 22, 41, "TopSpanBox"],
Cell[239052, 7853, 330, 9, 42, "BottomBox"],
Cell[239385, 7864, 45, 0, 16, "Caption"],
Cell[239433, 7866, 330, 8, 71, "Text",
  CellTags->"0.39"],
Cell[239766, 7876, 162, 3, 31, "DisplayFormula"],
Cell[239931, 7881, 154, 5, 32, "MathCaption",
  CellTags->"0.40"],

Cell[CellGroupData[{
Cell[240110, 7890, 75, 1, 30, "Input"],
Cell[240188, 7893, 89, 2, 29, "Output"]
}, Open  ]],
Cell[240292, 7898, 150, 4, 48, "MathCaption",
  CellTags->"0.41"],

Cell[CellGroupData[{
Cell[240467, 7906, 80, 1, 30, "Input"],
Cell[240550, 7909, 80, 2, 29, "Output"]
}, Open  ]],
Cell[240645, 7914, 150, 5, 32, "MathCaption",
  CellTags->"0.42"],

Cell[CellGroupData[{
Cell[240820, 7923, 77, 1, 30, "Input"],
Cell[240900, 7926, 89, 2, 29, "Output"]
}, Open  ]],
Cell[241004, 7931, 136, 4, 48, "MathCaption",
  CellTags->"0.43"],

Cell[CellGroupData[{
Cell[241165, 7939, 81, 1, 30, "Input"],
Cell[241249, 7942, 81, 2, 29, "Output"]
}, Open  ]],
Cell[241345, 7947, 346, 9, 77, "Text",
  CellTags->"0.44"],
Cell[241694, 7958, 382, 10, 73, "MathCaption",
  CellTags->"0.45"],

Cell[CellGroupData[{
Cell[242101, 7972, 149, 4, 48, "Input"],
Cell[242253, 7978, 81, 2, 29, "Output"]
}, Open  ]],
Cell[242349, 7983, 631, 22, 41, "TopSpanBox"],
Cell[242983, 8007, 338, 9, 42, "MiddleBox"],
Cell[243324, 8018, 635, 22, 33, "MiddleSpanBox"],
Cell[243962, 8042, 334, 9, 42, "BottomBox"],
Cell[244299, 8053, 51, 0, 16, "Caption"],
Cell[244353, 8055, 573, 9, 128, "Text",
  CellTags->"0.47"],
Cell[244929, 8066, 235, 5, 65, "MathCaption",
  CellTags->"0.48"],

Cell[CellGroupData[{
Cell[245189, 8075, 118, 4, 48, "Input"],
Cell[245310, 8081, 79, 2, 29, "Output"]
}, Open  ]],
Cell[245404, 8086, 146, 4, 48, "MathCaption",
  CellTags->"0.49"],

Cell[CellGroupData[{
Cell[245575, 8094, 45, 1, 30, "Input"],
Cell[245623, 8097, 79, 2, 29, "Output"]
}, Open  ]],
Cell[245717, 8102, 252, 9, 49, "MathCaption",
  CellTags->"0.50"],

Cell[CellGroupData[{
Cell[245994, 8115, 75, 1, 30, "Input"],
Cell[246072, 8118, 79, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[246188, 8125, 76, 1, 30, "Input"],
Cell[246267, 8128, 78, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[246382, 8135, 76, 1, 30, "Input"],
Cell[246461, 8138, 79, 2, 29, "Output"]
}, Open  ]],
Cell[246555, 8143, 240, 9, 50, "MathCaption",
  CellTags->"0.51"],
Cell[246798, 8154, 154, 4, 48, "Input"],
Cell[246955, 8160, 243, 5, 65, "MathCaption",
  CellTags->"0.52"],

Cell[CellGroupData[{
Cell[247223, 8169, 134, 4, 48, "Input"],
Cell[247360, 8175, 21860, 768, 191, 8659, 600, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[269235, 8946, 217, 5, 65, "MathCaption",
  CellTags->"0.53"],

Cell[CellGroupData[{
Cell[269477, 8955, 157, 4, 48, "Input"],
Cell[269637, 8961, 20681, 739, 191, 8690, 586, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[290333, 9703, 156, 4, 48, "MathCaption",
  CellTags->"0.54"],

Cell[CellGroupData[{
Cell[290514, 9711, 117, 4, 48, "Input"],
Cell[290634, 9717, 79, 2, 29, "Output"]
}, Open  ]],
Cell[290728, 9722, 294, 7, 66, "MathCaption",
  CellTags->"0.55"],

Cell[CellGroupData[{
Cell[291047, 9733, 49, 1, 30, "Input"],
Cell[291099, 9736, 79, 2, 29, "Output"]
}, Open  ]],
Cell[291193, 9741, 164, 4, 48, "MathCaption",
  CellTags->"0.56"],

Cell[CellGroupData[{
Cell[291382, 9749, 113, 3, 48, "Input"],
Cell[291498, 9754, 79, 2, 29, "Output"]
}, Open  ]],
Cell[291592, 9759, 512, 18, 41, "TopSpanBox"],
Cell[292107, 9779, 1718, 41, 42, "MiddleBox"],
Cell[293828, 9822, 529, 18, 33, "MiddleSpanBox"],
Cell[294360, 9842, 301, 9, 42, "MiddleBox"],
Cell[294664, 9853, 521, 18, 33, "MiddleSpanBox"],
Cell[295188, 9873, 304, 9, 42, "BottomBox"],
Cell[295495, 9884, 40, 0, 16, "Caption"],
Cell[295538, 9886, 78, 1, 31, "MathCaption",
  CellTags->"0.58"],
Cell[295619, 9889, 70, 1, 30, "Input"],
Cell[295692, 9892, 130, 4, 48, "MathCaption",
  CellTags->"0.59"],

Cell[CellGroupData[{
Cell[295847, 9900, 70, 1, 30, "Input"],
Cell[295920, 9903, 72, 2, 29, "Output"]
}, Open  ]],
Cell[296007, 9908, 179, 6, 49, "MathCaption",
  CellTags->"0.60"],

Cell[CellGroupData[{
Cell[296211, 9918, 88, 1, 30, "Input"],
Cell[296302, 9921, 60, 2, 29, "Output"]
}, Open  ]],
Cell[296377, 9926, 172, 5, 49, "MathCaption",
  CellTags->"0.61"],
Cell[296552, 9933, 95, 1, 30, "Input"],
Cell[296650, 9936, 76, 1, 31, "MathCaption",
  CellTags->"0.62"],

Cell[CellGroupData[{
Cell[296751, 9941, 126, 4, 48, "Input"],
Cell[296880, 9947, 628, 17, 174, "Output"]
}, Open  ]],
Cell[297523, 9967, 139, 4, 48, "MathCaption",
  CellTags->"0.63"],

Cell[CellGroupData[{
Cell[297687, 9975, 92, 1, 30, "Input"],
Cell[297782, 9978, 500, 14, 108, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

