(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    892855,      25010]*)
(*NotebookOutlinePosition[    899881,      25259]*)
(*  CellTagsIndexPosition[    898358,      25199]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Options", "Section",
  CellTags->"0.1"],

Cell[TextData[{
  "This ",
  StyleBox["Finance`Options`", "MB"],
  " subpackage contains tools to compute options using the \
Black\[Hyphen]Scholes model. "
}], "Text",
  CellTags->"0.2"],

Cell[TextData[{
  "This loads the ",
  StyleBox["Options", "MB"],
  " subpackage. "
}], "MathCaption",
  CellTags->"0.3"],

Cell["<< Finance`Options`", "Input",
  CellLabel->"In[1]:="],

Cell["Here are the basic option functions. ", "MathCaption",
  CellTags->"0.4"],

Cell[CellGroupData[{

Cell["?Finance`Options`*", "Input",
  CellLabel->"In[2]:="],

Cell["\<\
Delta                Norm
Elasticity           Option
HistoricalVolatility Rho
ImpliedVolatility    Theta
Lambda\
\>", "Print",
  CellLabel->"From In[2]:="]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["Option",
                        "MR",
                        FontWeight->"Plain"], 
                      StyleBox["[",
                        "MR",
                        FontWeight->"Plain"], 
                      RowBox[{
                        StyleBox["{",
                          "MR",
                          FontWeight->"Plain"], 
                        
                        StyleBox[\(type, \ asset, \ exerciseprice, \ 
                          maturity\),
                          FontWeight->"Plain"], 
                        StyleBox["}",
                          "MR",
                          FontWeight->"Plain"]}], 
                      StyleBox["]",
                        "MR",
                        FontWeight->"Plain"]}],
                    "TraditionalForm"],
                  FontFamily->"Times",
                  FontWeight->"Plain",
                  FontSlant->"Italic"],
                "StandardForm"],
              "Input"], 
            StyleBox[
              FormBox[" ",
                "StandardForm"],
              "Input"]}
          }], TopSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[" ",
                "StandardForm"],
              "Input"], 
            StyleBox[\(an\ object\ representing\ an\ option\),
              "Text"]}
          }], BottomBox]]],

Cell["An option object. ", "Caption"],

Cell[TextData[{
  "This is a put option for an asset named ",
  StyleBox["XYZ", "MB"],
  " that expires on December 20, 1992 with an exercise (or striking) price of \
40. "
}], "MathCaption",
  CellTags->"0.6"],

Cell[CellGroupData[{

Cell["xyzft = Option[{\"Put\", XYZ, 40, {12, 20, 1992}}]", "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(Option[{"Put", XYZ, 40, {12, 20, 1992}}]\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell["\<\
However, we have to remember that an option is a derivative \
security and we need to specify the price and volatility of the underlying \
asset. \
\>", "MathCaption",
  CellTags->"0.7"],

Cell["\<\
(Price[XYZ] ^= 40;
Volatility[XYZ] ^= 3/10;)\
\>", "Input",
  CellLabel->"In[4]:="],

Cell["We also have to define the riskless interest rate. ", "MathCaption",
  CellTags->"0.8"],

Cell[CellGroupData[{

Cell["r = 12/100", "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(3\/25\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["We define the settlement date to be August 20, 1992. ", "MathCaption",
  CellTags->"0.9"],

Cell[CellGroupData[{

Cell["settlement = {8, 20, 1992}", "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \({8, 20, 1992}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
  "This is a call option for an asset named ",
  StyleBox["ABC", "MB"],
  ". The striking price is 40 and the expiration date is December 19, 1992. "
}], "MathCaption",
  CellTags->"0.10"],

Cell[CellGroupData[{

Cell["abcft = Option[{\"Call\", ABC, 40, {12, 19, 1992}}]", "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(Option[{"Call", ABC, 40, {12, 19, 1992}}]\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell["\<\
This time we specify the volatility but not the price of the \
underlying asset. \
\>", "MathCaption",
  CellTags->"0.11"],

Cell[CellGroupData[{

Cell["Volatility[ABC] = 3/10", "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(3\/10\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Value",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(option, \ settlement, \ riskfreerate\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], " "}
          }], TopSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[\(return\ the\ Black\ Scholes\ value\ of\ an\ option\ \
given\ the\ settlement\ date\ and\ the\ riskless\ interest\ rate\),
              "TraditionalForm"]}
          }], BottomBox]]],

Cell["A basic function. ", "Caption"],

Cell[TextData[{
  "We compute the value of ",
  StyleBox["xyzft", "MB"],
  " given the riskless interest rate ",
  StyleBox["r", "MB"],
  " = 12%. ",
  StyleBox["Mathematica", "TI"],
  " gives us an exact result. "
}], "MathCaption",
  CellTags->"0.13"],

Cell[CellGroupData[{

Cell["val1 = Value[xyzft, settlement, r]", "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(\(-20\)\ \((1 + 
            Erf[\(\(-\(2\/\(5\ \@3\)\)\) - \@3\/20\)\/\@2])\) + \(20\ \((1 + \
Erf[\(\(-\(2\/\(5\ \@3\)\)\) + \@3\/20\)\/\@2])\)\)\/E\^\(1/25\)\)], "Output",\

  CellLabel->"Out[9]="]
}, Open  ]],

Cell["Here is a numerical approximation. ", "MathCaption",
  CellTags->"0.14"],

Cell[CellGroupData[{

Cell["N[%]", "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(1.99383024232412076`\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["\<\
Another way to get an approximation is to write one of the \
arguments with a decimal point. \
\>", "MathCaption",
  CellTags->"0.15"],

Cell[CellGroupData[{

Cell["Value[xyzft, settlement, .12]", "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(1.99383024232412076`\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[TextData[{
  "We define an option's value as a function of two variables, the price of \
the underlying asset ",
  StyleBox["x", "MB"],
  " and the time to maturity ",
  StyleBox["t", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.16"],

Cell["\<\
optionvalue[x_, t_] = Value[abcft,
   ToCalendar[ToJulian[settlement] + Floor[t]], r] /.
   Price[ABC] -> x;\
\>", "Input",
  CellLabel->"In[12]:="],

Cell["\<\
This illustrates how the graph of the option value changes as the \
time to maturity varies. \
\>", "MathCaption",
  CellTags->"0.17"],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Table[optionvalue[x, t],
   {t, 0, 120, 10}]], {x, 25, 45},
   PlotLabel ->
      \"    Call Option Value\\nfor Different Maturities\",
   FrameLabel -> {\"Stock Price\", \"\"}];\
\>", "Input",
  CellLabel->"In[13]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.16667 0.0476191 0.0147151 0.0810974 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -35 -24 ]
[.5 -0.0125 35 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09581 -6 -4.5 ]
[-0.0125 .09581 0 4.5 ]
[-0.0125 .17691 -6 -4.5 ]
[-0.0125 .17691 0 4.5 ]
[-0.0125 .25801 -6 -4.5 ]
[-0.0125 .25801 0 4.5 ]
[-0.0125 .3391 -6 -4.5 ]
[-0.0125 .3391 0 4.5 ]
[-0.0125 .4202 -6 -4.5 ]
[-0.0125 .4202 0 4.5 ]
[-0.0125 .5013 -6 -4.5 ]
[-0.0125 .5013 0 4.5 ]
[-0.0125 .5824 -6 -4.5 ]
[-0.0125 .5824 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74 0 ]
[.5 .63053 74 31 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(25)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(30)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(35)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(40)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(45)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -96 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09581 m
.00625 .09581 L
s
[(1)] -0.0125 .09581 1 0 Mshowa
0 .17691 m
.00625 .17691 L
s
[(2)] -0.0125 .17691 1 0 Mshowa
0 .25801 m
.00625 .25801 L
s
[(3)] -0.0125 .25801 1 0 Mshowa
0 .3391 m
.00625 .3391 L
s
[(4)] -0.0125 .3391 1 0 Mshowa
0 .4202 m
.00625 .4202 L
s
[(5)] -0.0125 .4202 1 0 Mshowa
0 .5013 m
.00625 .5013 L
s
[(6)] -0.0125 .5013 1 0 Mshowa
0 .5824 m
.00625 .5824 L
s
[(7)] -0.0125 .5824 1 0 Mshowa
.125 Mabswid
0 .03093 m
.00375 .03093 L
s
0 .04715 m
.00375 .04715 L
s
0 .06337 m
.00375 .06337 L
s
0 .07959 m
.00375 .07959 L
s
0 .11203 m
.00375 .11203 L
s
0 .12825 m
.00375 .12825 L
s
0 .14447 m
.00375 .14447 L
s
0 .16069 m
.00375 .16069 L
s
0 .19313 m
.00375 .19313 L
s
0 .20935 m
.00375 .20935 L
s
0 .22557 m
.00375 .22557 L
s
0 .24179 m
.00375 .24179 L
s
0 .27423 m
.00375 .27423 L
s
0 .29045 m
.00375 .29045 L
s
0 .30667 m
.00375 .30667 L
s
0 .32289 m
.00375 .32289 L
s
0 .35532 m
.00375 .35532 L
s
0 .37154 m
.00375 .37154 L
s
0 .38776 m
.00375 .38776 L
s
0 .40398 m
.00375 .40398 L
s
0 .43642 m
.00375 .43642 L
s
0 .45264 m
.00375 .45264 L
s
0 .46886 m
.00375 .46886 L
s
0 .48508 m
.00375 .48508 L
s
0 .51752 m
.00375 .51752 L
s
0 .53374 m
.00375 .53374 L
s
0 .54996 m
.00375 .54996 L
s
0 .56618 m
.00375 .56618 L
s
0 .59862 m
.00375 .59862 L
s
0 .61484 m
.00375 .61484 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09581 m
1 .09581 L
s
.99375 .17691 m
1 .17691 L
s
.99375 .25801 m
1 .25801 L
s
.99375 .3391 m
1 .3391 L
s
.99375 .4202 m
1 .4202 L
s
.99375 .5013 m
1 .5013 L
s
.99375 .5824 m
1 .5824 L
s
.125 Mabswid
.99625 .03093 m
1 .03093 L
s
.99625 .04715 m
1 .04715 L
s
.99625 .06337 m
1 .06337 L
s
.99625 .07959 m
1 .07959 L
s
.99625 .11203 m
1 .11203 L
s
.99625 .12825 m
1 .12825 L
s
.99625 .14447 m
1 .14447 L
s
.99625 .16069 m
1 .16069 L
s
.99625 .19313 m
1 .19313 L
s
.99625 .20935 m
1 .20935 L
s
.99625 .22557 m
1 .22557 L
s
.99625 .24179 m
1 .24179 L
s
.99625 .27423 m
1 .27423 L
s
.99625 .29045 m
1 .29045 L
s
.99625 .30667 m
1 .30667 L
s
.99625 .32289 m
1 .32289 L
s
.99625 .35532 m
1 .35532 L
s
.99625 .37154 m
1 .37154 L
s
.99625 .38776 m
1 .38776 L
s
.99625 .40398 m
1 .40398 L
s
.99625 .43642 m
1 .43642 L
s
.99625 .45264 m
1 .45264 L
s
.99625 .46886 m
1 .46886 L
s
.99625 .48508 m
1 .48508 L
s
.99625 .51752 m
1 .51752 L
s
.99625 .53374 m
1 .53374 L
s
.99625 .54996 m
1 .54996 L
s
.99625 .56618 m
1 .56618 L
s
.99625 .59862 m
1 .59862 L
s
.99625 .61484 m
1 .61484 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Call) show
117.000000 15.000000 moveto
(Option) show
159.000000 15.000000 moveto
(Value) show
63.000000 31.000000 moveto
(for) show
87.000000 31.000000 moveto
(Different) show
147.000000 31.000000 moveto
(Maturities) show
207.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.02381 .0156 m
.04262 .01589 L
.06244 .01628 L
.08255 .01679 L
.10458 .01749 L
.12579 .01836 L
.14509 .01933 L
.18408 .02194 L
.20323 .0236 L
.22401 .02574 L
.26488 .03114 L
.30423 .03811 L
.34206 .04675 L
.38235 .05836 L
.42112 .07216 L
.46235 .08996 L
.50206 .11035 L
.54025 .13313 L
.58089 .16089 L
.62002 .19106 L
.66161 .22682 L
.70167 .26478 L
.74022 .30443 L
.78123 .34979 L
.82071 .39639 L
.85869 .44369 L
.89911 .4965 L
.93802 .54949 L
.97619 .60332 L
s
.02381 .01528 m
.04262 .01548 L
.06244 .01576 L
.08255 .01613 L
.10458 .01665 L
.12415 .01725 L
.14509 .01806 L
.16496 .01901 L
.18653 .02029 L
.22646 .02348 L
.2463 .02554 L
.26733 .02812 L
.30517 .03398 L
.34545 .04223 L
.38422 .05244 L
.42545 .06611 L
.46516 .08233 L
.50335 .10099 L
.544 .12434 L
.58313 .15035 L
.62471 .18184 L
.66477 .21591 L
.70333 .2521 L
.74433 .2941 L
.78382 .33779 L
.82179 .38261 L
.86221 .43312 L
.90112 .48421 L
.94248 .54091 L
.97619 .58875 L
s
.02381 .01505 m
.04262 .01518 L
.06244 .01536 L
.08255 .01562 L
.10458 .01599 L
.12415 .01642 L
.14509 .01701 L
.16639 .01779 L
.18653 .01872 L
.22495 .02112 L
.24479 .02277 L
.26581 .02487 L
.30365 .02975 L
.34394 .0368 L
.38271 .04576 L
.42393 .05801 L
.46364 .07282 L
.50184 .09014 L
.54248 .11213 L
.58161 .13692 L
.62319 .16727 L
.66326 .20043 L
.70181 .23589 L
.74281 .27732 L
.7823 .32063 L
.82027 .36525 L
.8607 .41568 L
.8996 .46683 L
.94097 .52369 L
.97619 .57392 L
s
.02381 .01489 m
.04262 .01497 L
.06244 .01508 L
.08255 .01524 L
.10458 .01549 L
.12415 .01578 L
.14509 .01619 L
.16639 .01674 L
.18653 .01742 L
.22495 .01924 L
.24479 .02051 L
.26581 .02218 L
.30365 .02615 L
.34394 .03208 L
.38271 .03981 L
.42393 .05067 L
.46364 .06409 L
.50184 .08009 L
.54248 .10073 L
.58161 .12434 L
.62319 .15359 L
.66326 .18587 L
.70181 .22069 L
.74281 .26164 L
.7823 .3047 L
.82027 .34923 L
.8607 .39973 L
.8996 .45107 L
.94097 .50824 L
.97619 .5588 L
s
.02381 .0148 m
.03279 .01481 L
.04262 .01484 L
.06244 .0149 L
.07298 .01494 L
.08426 .015 L
.10458 .01514 L
.12589 .01533 L
.14603 .01559 L
.166 .01593 L
.18444 .01635 L
.20316 .01688 L
.22379 .01764 L
.2432 .01854 L
.26408 .01976 L
.28379 .0212 L
.3053 .02313 L
.34501 .02791 L
.38566 .03482 L
.42479 .04384 L
.46637 .05648 L
.50643 .07205 L
.54499 .09053 L
.58599 .11423 L
.62548 .14118 L
.66345 .17098 L
.70387 .20686 L
.74278 .24533 L
.78414 .29024 L
.82399 .33715 L
.86232 .38535 L
.9031 .43961 L
.94237 .49441 L
.97619 .54338 L
s
.02381 .01475 m
.03279 .01475 L
.04262 .01476 L
.06244 .01479 L
.07298 .01482 L
.08426 .01484 L
.10458 .01491 L
.1148 .01496 L
.12589 .01502 L
.14603 .01517 L
.16586 .01537 L
.18689 .01566 L
.20643 .01603 L
.22473 .01648 L
.24497 .01713 L
.2635 .01789 L
.28248 .01887 L
.30321 .02022 L
.32452 .02196 L
.34385 .02391 L
.38298 .02916 L
.42305 .03675 L
.4616 .04664 L
.5026 .06046 L
.54209 .07744 L
.58006 .09749 L
.62049 .12312 L
.6594 .15209 L
.70076 .18753 L
.7406 .2261 L
.77893 .26712 L
.81971 .31468 L
.85898 .36395 L
.89673 .4142 L
.93693 .47042 L
.97562 .52682 L
.97619 .52766 L
s
.02381 .01472 m
.03279 .01473 L
.04262 .01473 L
.05288 .01474 L
.06244 .01474 L
.0731 .01475 L
.0828 .01476 L
.094 .01477 L
.10458 .01479 L
.11428 .01481 L
.12455 .01483 L
.14299 .01489 L
.1524 .01493 L
.16253 .01499 L
.18083 .01511 L
.20196 .01531 L
.22205 .01558 L
.24186 .01595 L
.26025 .0164 L
.28077 .01706 L
.29938 .01785 L
.31862 .01888 L
.33944 .02031 L
.35899 .02199 L
.38045 .0243 L
.41993 .03006 L
.43944 .03377 L
.46036 .03849 L
.50172 .0504 L
.54156 .06559 L
.57989 .08409 L
.62068 .10832 L
.65994 .13631 L
.69769 .16759 L
.7379 .20555 L
.77658 .2464 L
.81772 .29418 L
.85735 .34403 L
.89546 .3951 L
.93602 .45239 L
.97506 .50995 L
.97619 .51164 L
s
.02381 .01472 m
.03279 .01472 L
.04262 .01472 L
.05288 .01472 L
.06244 .01472 L
.0731 .01472 L
.0828 .01473 L
.094 .01473 L
.10458 .01474 L
.11428 .01474 L
.12455 .01475 L
.13333 .01476 L
.14299 .01477 L
.1624 .01481 L
.17331 .01483 L
.18328 .01487 L
.20227 .01495 L
.21301 .01501 L
.22299 .01508 L
.24351 .01527 L
.26212 .01552 L
.28137 .01587 L
.30219 .01639 L
.32212 .01707 L
.34319 .01803 L
.36283 .0192 L
.38116 .02059 L
.42007 .02474 L
.44131 .02786 L
.46143 .03147 L
.49976 .04047 L
.54054 .05366 L
.57981 .07049 L
.61756 .09094 L
.65776 .11767 L
.69645 .14838 L
.73759 .18636 L
.77721 .22792 L
.81532 .27218 L
.85588 .32345 L
.89493 .37635 L
.93643 .4358 L
.97619 .49536 L
s
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03793 .01472 L
.04262 .01472 L
.0522 .01472 L
.05746 .01472 L
.06244 .01472 L
.07295 .01472 L
.08265 .01472 L
.09329 .01472 L
.09866 .01472 L
.10458 .01472 L
.11472 .01472 L
.12399 .01472 L
.13469 .01472 L
.14487 .01473 L
.15445 .01473 L
.16467 .01474 L
.17432 .01474 L
.18306 .01475 L
.19308 .01476 L
.20231 .01477 L
.21243 .01479 L
.22313 .01482 L
.2326 .01485 L
.24276 .01488 L
.2611 .01498 L
.27127 .01505 L
.28234 .01514 L
.2919 .01524 L
.30246 .01537 L
.32223 .0157 L
.33307 .01594 L
.34324 .0162 L
.36342 .01688 L
.38193 .01771 L
.40085 .01883 L
.42155 .02043 L
.44116 .0224 L
.46211 .02509 L
.48203 .02829 L
.50361 .03261 L
.54359 .04335 L
.58451 .05875 L
.62392 .0785 L
.6618 .10251 L
.70214 .13375 L
.74097 .16936 L
.78224 .21295 L
Mistroke
.822 .26006 L
.86025 .30959 L
.90095 .36616 L
.94013 .42374 L
.97619 .4789 L
Mfstroke
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.04262 .01472 L
.04795 .01472 L
.053 .01472 L
.05753 .01472 L
.06244 .01472 L
.06751 .01472 L
.07308 .01472 L
.0789 .01472 L
.08435 .01472 L
.0941 .01472 L
.09957 .01472 L
.10458 .01472 L
.10934 .01472 L
.11442 .01472 L
.12357 .01472 L
.12916 .01472 L
.13443 .01472 L
.13913 .01472 L
.14429 .01472 L
.15405 .01472 L
.15939 .01472 L
.16437 .01472 L
.17328 .01472 L
.18284 .01472 L
.19301 .01472 L
.19876 .01472 L
.20408 .01472 L
.21384 .01473 L
.2242 .01473 L
.23357 .01474 L
.24367 .01474 L
.25321 .01475 L
.26195 .01476 L
.27175 .01478 L
.28087 .0148 L
.29088 .01483 L
.30158 .01487 L
.31182 .01491 L
.32292 .01498 L
.33341 .01506 L
.34307 .01515 L
.36184 .01539 L
.3725 .01558 L
.38248 .01579 L
.40276 .01636 L
.4213 .0171 L
Mistroke
.44032 .01813 L
.46106 .01967 L
.48077 .02162 L
.50176 .02436 L
.52321 .028 L
.54339 .03236 L
.582 .04371 L
.60197 .05138 L
.62305 .06098 L
.66108 .08254 L
.70155 .11192 L
.74051 .14659 L
.78193 .1901 L
.82182 .23793 L
.8602 .2887 L
.90104 .34694 L
.94036 .40628 L
.97619 .46247 L
Mfstroke
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.0402 .01472 L
.04262 .01472 L
.0475 .01472 L
.05026 .01472 L
.05281 .01472 L
.05749 .01472 L
.06244 .01472 L
.06743 .01472 L
.07023 .01472 L
.0728 .01472 L
.07777 .01472 L
.0825 .01472 L
.08797 .01472 L
.09305 .01472 L
.09863 .01472 L
.10175 .01472 L
.10458 .01472 L
.10945 .01472 L
.1146 .01472 L
.119 .01472 L
.12383 .01472 L
.12902 .01472 L
.13459 .01472 L
.13985 .01472 L
.14465 .01472 L
.14945 .01472 L
.15456 .01472 L
.15892 .01472 L
.16373 .01472 L
.16888 .01472 L
.17444 .01472 L
.17968 .01472 L
.18449 .01472 L
.18923 .01472 L
.19429 .01472 L
.20342 .01472 L
.20899 .01472 L
.21426 .01472 L
.21895 .01472 L
.22412 .01472 L
.23384 .01472 L
.23915 .01472 L
.24413 .01472 L
.25303 .01472 L
.25802 .01472 L
.26258 .01472 L
Mistroke
.26736 .01472 L
.27245 .01472 L
.28161 .01472 L
.28721 .01472 L
.29249 .01472 L
.30234 .01473 L
.31213 .01473 L
.32246 .01474 L
.33128 .01475 L
.34095 .01476 L
.35118 .01478 L
.36049 .0148 L
.37125 .01484 L
.38142 .01488 L
.3911 .01494 L
.40137 .01501 L
.41014 .0151 L
.4198 .01521 L
.43919 .01554 L
.45008 .0158 L
.46006 .0161 L
.47902 .01687 L
.48976 .01745 L
.49974 .0181 L
.52023 .01986 L
.53883 .02206 L
.55806 .02508 L
.57887 .0294 L
.59878 .03476 L
.61984 .04193 L
.65778 .05941 L
.69817 .08534 L
.73705 .11794 L
.77837 .16071 L
.81819 .20906 L
.85649 .26113 L
.89724 .32121 L
.93647 .38239 L
.97419 .44332 L
.97619 .4466 L
Mfstroke
.02381 .01472 m
.03279 .01472 L
.04262 .01472 L
.04758 .01472 L
.05288 .01472 L
.05546 .01472 L
.05672 .01472 L
.05789 .01472 L
.05895 .01472 L
.06007 .01472 L
.0612 .01472 L
.06244 .01472 L
.06314 .01472 L
.06379 .01472 L
.06525 .01472 L
.06654 .01472 L
.06726 .01472 L
.06792 .01472 L
.06916 .01472 L
.06981 .01472 L
.0705 .01472 L
.07176 .01472 L
.07293 .01472 L
.07361 .01472 L
.07427 .01472 L
.07502 .01472 L
.07571 .01472 L
.07695 .01472 L
.07765 .01472 L
.0783 .01472 L
.079 .01472 L
.07966 .01472 L
.08038 .01472 L
.08116 .01472 L
.08193 .01472 L
.08275 .01472 L
.08344 .01472 L
.0842 .01472 L
.08486 .01472 L
.08558 .01472 L
.08687 .01472 L
.08814 .01472 L
.0893 .01472 L
.09057 .01472 L
.09128 .01472 L
.09195 .01472 L
.09266 .01472 L
.0933 .01472 L
.09405 .01472 L
.09476 .01472 L
Mistroke
.09594 .01472 L
.0972 .01472 L
.09838 .01472 L
.09946 .01472 L
.10073 .01472 L
.10144 .01472 L
.1021 .01472 L
.1033 .01472 L
.10458 .01472 L
.1058 .01472 L
.1065 .01472 L
.10714 .01472 L
.10831 .01472 L
.10955 .01472 L
.11067 .01472 L
.11171 .01472 L
.11285 .01472 L
.11408 .01472 L
.11533 .01472 L
.11602 .01472 L
.11665 .01472 L
.11788 .01472 L
.11904 .01472 L
.12024 .01472 L
.12153 .01472 L
.12222 .01472 L
.12295 .01472 L
.12426 .01472 L
.1254 .01472 L
.12662 .01472 L
.12777 .01472 L
.12882 .01472 L
.13005 .01472 L
.13075 .01472 L
.13139 .01472 L
.13265 .01472 L
.13383 .01472 L
.13481 .01472 L
.13585 .01472 L
.13808 .01472 L
.14044 .01472 L
.1426 .01472 L
.14508 .01472 L
.14733 .01472 L
.14993 .01472 L
.15239 .01472 L
.15451 .01472 L
.15676 .01472 L
.15923 .01472 L
.1615 .01472 L
Mistroke
.16396 .01472 L
.16659 .01472 L
.16908 .01472 L
.17135 .01472 L
.17401 .01472 L
.17691 .01472 L
.17965 .01472 L
.1822 .01472 L
.18484 .01472 L
.18728 .01472 L
.18995 .01472 L
.19277 .01472 L
.19523 .01472 L
.19752 .01472 L
.2002 .01472 L
.20273 .01472 L
.20499 .01472 L
.20743 .01472 L
.21172 .01472 L
.21414 .01472 L
.21672 .01472 L
.22135 .01472 L
.22373 .01472 L
.22624 .01472 L
.23073 .01472 L
.23323 .01472 L
.23555 .01472 L
.23827 .01472 L
.24083 .01472 L
.24547 .01472 L
.24967 .01472 L
.25421 .01472 L
.25676 .01472 L
.25912 .01472 L
.2638 .01472 L
.26642 .01472 L
.26882 .01472 L
.27348 .01472 L
.27789 .01472 L
.28302 .01472 L
.28777 .01472 L
.29299 .01472 L
.2959 .01472 L
.29854 .01472 L
.30344 .01472 L
.3086 .01472 L
.31301 .01472 L
.31784 .01472 L
.32305 .01472 L
.32863 .01472 L
Mistroke
.33389 .01472 L
.33868 .01472 L
.34351 .01472 L
.34863 .01472 L
.353 .01472 L
.35782 .01472 L
.36298 .01472 L
.36854 .01472 L
.37379 .01472 L
.37859 .01472 L
.38336 .01472 L
.38843 .01472 L
.39323 .01472 L
.39757 .01472 L
.40269 .01472 L
.40824 .01472 L
.41347 .01472 L
.41829 .01473 L
.42299 .01473 L
.42802 .01473 L
.43711 .01474 L
.44265 .01475 L
.44791 .01476 L
.4526 .01476 L
.45777 .01478 L
.46741 .01481 L
.4727 .01483 L
.47767 .01485 L
.48653 .01491 L
.49608 .01499 L
.50565 .0151 L
.51612 .01527 L
.52704 .01552 L
.53721 .01582 L
.54773 .01624 L
.55766 .01676 L
.56658 .01734 L
.57624 .01814 L
.59611 .0204 L
.60613 .02194 L
.61715 .02401 L
.63659 .0288 L
.65748 .03588 L
.67864 .04548 L
.69874 .05716 L
.73698 .08687 L
.77766 .12932 L
.81683 .17944 L
.85845 .2402 L
.89856 .30351 L
Mistroke
.93715 .36697 L
.97619 .43247 L
Mfstroke
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.34309 .01472 L
.3815 .01472 L
.42237 .01472 L
.46172 .01472 L
.48147 .01472 L
.49012 .01472 L
.49468 .01472 L
.49955 .01472 L
.50095 .01472 L
.50226 .01472 L
.50344 .01472 L
.50471 .01472 L
.50592 .01472 L
.50721 .01472 L
.50841 .01472 L
.5095 .01472 L
.51063 .01472 L
.51183 .01472 L
.51295 .01472 L
.51401 .01472 L
.51524 .01472 L
.51638 .01472 L
.51762 .01472 L
.51832 .01472 L
.51896 .01472 L
.52017 .01472 L
.52144 .01472 L
.52256 .01472 L
.52377 .01472 L
.52447 .01472 L
.5251 .01472 L
.52583 .01472 L
.52652 .01472 L
.52775 .01472 L
.52845 .01472 L
.52908 .01472 L
.53039 .01472 L
.5311 .01472 L
.53178 .01472 L
.5331 .01472 L
.53431 .01472 L
.53497 .01472 L
Mistroke
.53567 .01472 L
.53694 .01472 L
.53833 .01472 L
.53911 .01472 L
.53984 .01472 L
.54109 .01472 L
.54175 .01472 L
.54245 .01472 L
.5432 .01472 L
.5439 .01472 L
.54521 .01472 L
.54644 .01472 L
.54758 .01472 L
.54883 .01472 L
.55015 .01472 L
.55147 .01472 L
.55289 .01472 L
.55422 .01472 L
.55545 .01472 L
.55681 .01472 L
.5583 .01472 L
.55905 .01472 L
.55985 .01472 L
.56129 .01472 L
.56265 .01472 L
.56391 .01472 L
.56528 .01472 L
.56674 .01472 L
.568 .01472 L
.56918 .01472 L
.57048 .01472 L
.57187 .01472 L
.57311 .01472 L
.57445 .01472 L
.57572 .01472 L
.57689 .01472 L
.57795 .01472 L
.57911 .01472 L
.58033 .01472 L
.58147 .01472 L
.58265 .01472 L
.5839 .01472 L
.58508 .01472 L
.58616 .01472 L
.58742 .01472 L
.5888 .01472 L
.59009 .01472 L
.59129 .01472 L
.59368 .01472 L
.59504 .01472 L
Mistroke
.59631 .01472 L
.59765 .01472 L
.59887 .01472 L
.60029 .01472 L
.60163 .01472 L
.60385 .01472 L
.60509 .01472 L
.60622 .01472 L
.60727 .01472 L
.60841 .01472 L
.61048 .01472 L
.61164 .01472 L
.61292 .01472 L
.61417 .01472 L
.61551 .01472 L
.61676 .01472 L
.6179 .01472 L
.62013 .01472 L
.62242 .01472 L
.62372 .01472 L
.62494 .01472 L
.6274 .01472 L
.62878 .01472 L
.63005 .01472 L
.63219 .01472 L
.63452 .01472 L
.63696 .01472 L
.63923 .01472 L
.64194 .01472 L
.64449 .01472 L
.64679 .01473 L
.64927 .01473 L
.65198 .01474 L
.65485 .01475 L
.6573 .01476 L
.65999 .01478 L
.66249 .0148 L
.66521 .01483 L
.66778 .01486 L
.67017 .0149 L
.67467 .01501 L
.67718 .01508 L
.67946 .01517 L
.68463 .01544 L
.68755 .01565 L
.69023 .01588 L
.69516 .01643 L
.70035 .01723 L
.70533 .01828 L
.70987 .0195 L
Mistroke
.7151 .0213 L
.72005 .02345 L
.72884 .02845 L
.7384 .03581 L
.75823 .05747 L
.77925 .08782 L
.81707 .15036 L
.85735 .21888 L
.89611 .28488 L
.93732 .35507 L
.97619 .42127 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40n007h00Ooooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool007;oo`<000?oo`8000?oo`8000;oo`<00004ool00000
ool2000;ool30003ool30002ool30002ool30003ool2001cool007;oo`03003oo`0000;oo`06003o
oooo003oo`000_oo00<00?oo00001?oo00<00?oo00003Ooo00<00?ooool00ooo00<00?ooool00_oo
00D00?ooooooo`0000Coo`03003ooooo07?oo`00M?oo00@00?ooool000Coo`06003ooooo003oo`00
1?oo0`003Ooo0`000ooo00<00?ooool00_oo00D00?ooooooo`0000Coo`<007?oo`00Looo00<00?oo
ool010000ooo0P000_oo0`000_oo00@00?oo000000coo`05003ooooo003oo`0400000ooo00000003
ool30002ool3001cool007;oo`03003oo`0000;oo`03003ooooo00coo`03003ooooo00goo`04003o
oooo0026ool007;oo`<0013oo`8000koo`@000Soo`03003ooooo07coo`00oooo8Ooo003ooolQool0
0?ooob7oo`00oooo8Ooo003ooolQool003Coo`<000?oo`03003ooooo02Coo`8000Coo`03003ooooo
02Coo`8000Coo`03003ooooo02Koo`<000;oo`03003ooooo02Goo`<000;oo`03003ooooo02koo`00
=?oo00<00?ooool00_oo00<00?oo00009ooo00H00?ooool00?oo000Wool01P00ooooo`00ool002So
o`06003ooooo003oo`009ooo00H00?ooool00?oo000_ool003Goo`03003ooooo00?oo`03003ooooo
02Coo`07003oooooool00?oo00009_oo00<00?ooool00ooo00<00?ooool09?oo100000Coo`00ool0
02Goo`@000?oo`03003ooooo02goo`00=Ooo00@00?ooooooo`8002Soo`06003ooooo003oo`009ooo
00<00?ooool00P009ooo00<00?oo00000_oo00<00?oo00009Ooo00<00?oo00000_oo0P00<?oo000d
ool00`00ool00002ool00`00ooooo`0Uool00`00ool00002ool00`00ool0000Uool00`00ool00002
ool00`00ooooo`0Wool20002ool00`00ool0000Vool20002ool00`00ooooo`0_ool003Goo`04003o
ooooool3000Vool00`00ooooo`02ool00`00ooooo`0Uool01000oooooooo0`00:?oo00D00?oooooo
o`0002Soo`03003ooooo00<002ooo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo000doonn
000^ool002koo`03003ooooo00?oo`05003oooooool00008ool00`00ooooo`06ool00`00ooooo`06
ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06
ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`06
ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`06
ool00`00ooooo`06ool00`00ooooo`06ool01@00oooooooo0000;_oo000]ool00`00ool00004ool0
0`00ooooo`2jool00`00ooooo`0/ool002goo`03003oo`0000Coo`8000;ooh8003Koo`8002koo`00
;Ooo00<00?oo00001?oo00<00?ooool05_ooA0000ooo20001ooo20003ooo0`00=?oo00<00?ooool0
;?oo000]ool00`00ool00004ool00`00ooooo`0UoolE00000ooo000000030002oolP0003ool3000<
ool2000@ool2000bool00`00ooooo`0/ool002koo`03003ooooo00?oo`03003ooooo02_ooaT000?o
o`l000Coo`@000Coo`@000;oo`@000[oo`80013oo`03003ooooo02ooo`03003ooooo02coo`00=?oo
00<00?ooool0<ooo3@000_oo200000?oo`0000000P000ooo20001?oo10001?oo10000_oo10002?oo
0P003ooo00<00?ooool0;_oo00<00?ooool0;?oo000dool00`00ooooo`0hool<0003ool200000ooo
000000070003ool70005ool40004ool20004ool40006ool2000>ool00`00ooooo`0]ool00`00oooo
o`0/ool003Coo`03003ooooo03coo`<00003ool0000000D000;oo`<000?oo`8000;oo`<000Coo`L0
00Goo`8000Coo`8000Koo`8000Koo`8000goo`03003ooooo02coo`03003ooooo02coo`00=?oo00<0
0?ooool0?ooo100000?oo`0000001@0000Coo`00000000;oo`<000;oo`@000Coo`800003ool00000
008000?oo`8000Coo`<000Goo`8000Koo`8000_oo`03003ooooo02coo`03003ooooo02coo`00=?oo
00<00?ooool0@ooo400000Coo`00000000?oo`<000?oo`8000?oo`8000?oo`8000Goo`<000Coo`80
00Koo`8000[oo`03003ooooo02_oo`03003ooooo02coo`00=?oo00<00?ooool0Aooo0P000_oo0`00
00?oo`0000000_oo1P001?oo0P000ooo0P000ooo0`000_oo0P001_oo0P001?oo0P001_oo0P002Ooo
00<00?ooool0:_oo00<00?ooool0;?oo000dool00`00ooooo`19ool20003ool200001?oo00000000
0ooo1@000ooo0P000ooo0P001?oo0P000_oo0P001_oo00<00?ooool00ooo00<00?ooool01Ooo00<0
0?ooool01_oo00<00?ooool0:_oo00<00?ooool0;?oo000dool00`00ooooo`1;ool30002ool20002
ool30002ool200001?oo000000000_oo0P000ooo0P001?oo0P000_oo0P001Ooo00<00?ooool00ooo
0P001_oo00<00?ooool01_oo00<00?ooool0:Ooo00<00?ooool0;?oo000dool00`00ooooo`1>ool2
0002ool20003ool20002ool20002ool20002ool20003ool20004ool20002ool20004ool20005ool2
0005ool20007ool00`00ooooo`0Xool00`00ooooo`0/ool002coo`D000?oo`03003ooooo053oo`<0
0004ool000000002ool20002ool20002ool20002ool20003ool20004ool20002ool20004ool00`00
ooooo`04ool00`00ooooo`04ool00`00ooooo`04ool00`00ooooo`0Xool00`00ooooo`0/ool002ko
o`03003ooooo00?oo`03003ooooo05?oo`8000;oo`8000;oo`8000;oo`8000;oo`8000;oo`<000;o
o`8000Coo`04003oooooool20003ool20005ool00`00ooooo`04ool00`00ooooo`04ool00`00oooo
o`0Wool00`00ooooo`0/ool002koo`03003ooooo00?oo`8005Koo`8000;oo`8000;oo`8000;oo`80
00;oo`8000?oo`8000;oo`8000?oo`8000?oo`8000?oo`03003ooooo00?oo`03003ooooo00Coo`03
003ooooo00Coo`03003ooooo02Goo`8002koo`00;_oo00<00?ooool00ooo00<00?ooool0Eooo0P00
0_oo0P000_oo0P000_oo0P000_oo00<00?ooool00_oo0P000_oo0P000ooo00<00?ooool00_oo00@0
0?ooooooo`8000Coo`8000Goo`03003ooooo00?oo`03003ooooo02Koo`03003ooooo02coo`00;_oo
00<00?ooool00ooo00<00?ooool0FOoo0P000_oo0P000_oo0P000_oo0P0000?oo`0000001?oo00D0
0?ooooooo`0000?oo`03003ooooo00;oo`03003ooooo00;oo`8000Coo`03003ooooo00?oo`03003o
oooo00?oo`03003ooooo02Goo`03003ooooo02coo`00;Ooo0P001Ooo00<00?ooool0Fooo0P000_oo
00@00?ooooooo`8000;oo`03003ooooo008000?oo`05003oooooool00003ool20003ool20004ool0
0`00ooooo`02ool00`00ooooo`03ool00`00ooooo`03ool00`00ooooo`0Tool00`00ooooo`0/ool0
03Coo`03003ooooo05goo`800003ool0000000?oo`800003ool00?oo00;oo`04003oooooool20002
ool20003ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`03ool00`00
ooooo`03ool00`00ooooo`0Sool00`00ooooo`0/ool003Coo`03003ooooo05ooo`800003ool00000
00?oo`04003oo`000002ool20003ool01@00oooooooo00000ooo00<00?ooool00_oo00<00?ooool0
0_oo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool08ooo00<00?ooool0
;?oo000dool00`00ooooo`1Qool200000ooo003oo`02ool01000ooooo`000ooo00D00?ooooooo`00
00?oo`04003oooooool20003ool20003ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`02
ool00`00ooooo`0Rool00`00ooooo`0/ool003Coo`03003ooooo06?oo`04003oo`000002ool20000
0ooo00000002ool01000oooooooo0P000_oo0P000ooo00<00?ooool00_oo00D00?ooooooo`0000Co
o`03003ooooo00?oo`03003ooooo00;oo`03003ooooo027oo`03003ooooo02coo`00=?oo00<00?oo
ool0I?oo0P0000?oo`0000000_oo00@00?ooool000;oo`8000?oo`05003oooooool00003ool00`00
ooooo`02ool01@00oooooooo00001?oo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool08?oo
00<00?ooool0;?oo000dool00`00ooooo`1Vool00`00ooooo`0200001?oo003ooooo0P000_oo00D0
0?ooooooo`0000?oo`04003oooooool20003ool01@00oooooooo00001?oo00<00?ooool00_oo00<0
0?ooool00_oo00<00?ooool08?oo00<00?ooool0;?oo000dool00`00ooooo`1Wool20002ool01000
ool000000_oo0P0000?oo`0000000_oo0P000_oo00<00?ooool00_oo00D00?ooooooo`0000?oo`03
003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo01ooo`03003ooooo02coo`00
=?oo00<00?ooool0JOoo0P0000Goo`00ooooo`0000?oo`04003ooooo0003ool00`00ooooo`020003
ool01@00oooooooo00000ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?oo
ool07_oo00<00?ooool0;?oo000dool00`00ooooo`1[ool01P00ool00000ool000?oo`04003ooooo
0003ool01@00oooooooo00000ooo00D00?ooooooo`0000?oo`03003ooooo00;oo`03003ooooo00;o
o`05003oooooool0000Pool00`00ooooo`0/ool002goo`<000Coo`03003ooooo06coo`05003ooooo
003oo`020002ool00`00ooooo`020002ool20002ool01@00oooooooo00000ooo00D00?ooooooo`00
00Coo`03003ooooo00;oo`05003oooooool0000Oool00`00ooooo`0/ool002goo`03003ooooo00Co
o`03003ooooo06goo`04003ooooo0002ool00`00ooooo`020002ool01@00oooooooo00000_oo00D0
0?ooooooo`0000?oo`05003oooooool00004ool01@00oooooooo00000ooo00<00?ooool07Ooo00<0
0?ooool0;?oo000^ool00`00ooooo`03ool2001_ool200001Ooo00000?oo00000ooo00@00?ooool0
00?oo`04003ooooo0003ool01@00oooooooo00000ooo00D00?ooooooo`0000Coo`05003oooooool0
000Mool2000^ool002koo`03003ooooo00?oo`03003ooooo073oo`06003ooooo003oo`000ooo00@0
0?ooool000?oo`800003ool00?oo00;oo`05003oooooool00003ool01@00oooooooo00001?oo00@0
0?ooool001koo`03003ooooo02coo`00;Ooo00<00?oo00001?oo00<00?ooool0LOoo00D00?ooool0
0?oo008000;oo`04003ooooo0004ool00`00ool00003ool01@00oooooooo00000ooo00D00?oooooo
o`0000Coo`04003ooooo000Mool00`00ooooo`0/ool002koo`03003ooooo00?oo`03003ooooo07;o
o`04003ooooo0002ool01000ooooo`000_oo0P000ooo00@00?oo000000;oo`05003oooooool00003
ool01@00oooooooo00000ooo00@00?ooool001goo`03003ooooo02coo`00=?oo00<00?ooool0Looo
00@00?ooool000;oo`04003ooooo0003ool01@00oooooooo00000_oo00@00?ooool000?oo`05003o
ooooool00003ool01@00oooooooo00000_oo00<00?ooool06_oo00<00?ooool0;?oo000dool00`00
ooooo`1dool00`00ooooo`0200001Ooo003ooooo00000ooo00D00?ooooooo`0000;oo`04003ooooo
0003ool01@00oooooooo00000_oo00<00?ooool00_oo00<00?oo00007?oo00<00?ooool0;?oo000d
ool00`00ooooo`1eool01`00oooooooo003oo`0000;oo`8000;oo`05003oooooool00002ool01000
ooooo`000ooo00@00?ooool000?oo`05003oooooool00002ool00`00ooooo`0Iool00`00ooooo`0/
ool003Coo`03003ooooo07Koo`8000;oo`03003oo`0000?oo`04003ooooo0002ool01@00oooooooo
00000_oo00D00?ooooooo`0000;oo`05003oooooool00003ool00`00ool0000Kool00`00ooooo`0/
ool003Coo`03003ooooo07Soo`06003ooooo003oo`000ooo00@00?ooool000;oo`05003oooooool0
0002ool01@00oooooooo00000_oo00D00?ooooooo`0000;oo`04003ooooo000Jool00`00ooooo`0/
ool003Coo`03003ooooo07Woo`05003ooooo003oo`020002ool01000ooooo`000_oo00D00?oooooo
o`0000;oo`05003oooooool00002ool01@00oooooooo00000_oo00@00?ooool001Woo`03003ooooo
02coo`00=?oo00<00?ooool0N_oo00@00?ooool000;oo`04003ooooo0002ool01000ooooo`000ooo
00@00?ooool000?oo`03003oo`0000?oo`07003oooooool00?oo00006Ooo00<00?ooool0;?oo000d
ool00`00ooooo`1kool01000ooooo`000_oo00@00?ooool000;oo`04003ooooo0002ool01@00oooo
oooo00000ooo00<00?oo00000ooo00@00?ooool000;oo`03003ooooo01Koo`03003ooooo02coo`00
=?oo00<00?ooool0O?oo00@00?ooool000;oo`04003ooooo0002ool01000ooooo`000_oo00D00?oo
ooooo`0000;oo`04003ooooo0003ool01P00ooooo`00ool001Soo`03003ooooo02coo`00=?oo00<0
0?ooool0OOoo00@00?ooool000;oo`04003ooooo0002ool01000ooooo`000_oo00@00?ooool000?o
o`04003ooooo0003ool01P00ooooo`00ool001Ooo`03003ooooo02coo`00;Ooo0P001Ooo00<00?oo
ool0O_oo0P0000Ooo`00ooooo`00ool00003ool01000ooooo`000_oo00@00?ooool000?oo`04003o
oooo0002ool01000ooooo`000_oo00<00?ooool05?oo00<00?ooool0;?oo000_ool00`00ooooo`02
ool00`00ooooo`20ool00`00ool00002ool00`00ool00003ool00`00ool00003ool01000ooooo`00
0ooo00<00?oo00000ooo00H00?ooool00?oo000Fool00`00ooooo`0/ool002koo`03003ooooo00?o
o`8008;oo`03003oo`0000;oo`03003oo`0000?oo`03003oo`0000?oo`04003ooooo0003ool00`00
ool00003ool01P00ooooo`00ool001Coo`8002koo`00;ooo00<00?ooool00_oo00<00?ooool0P_oo
00D00?oo003oo`0000;oo`07003oooooool00?oo00000ooo00<00?oo00001?oo00<00?oo00000ooo
00<00?oo00000_oo00<00?ooool04_oo00<00?ooool0;?oo000]ool00`00ool00004ool00`00oooo
o`23ool01@00ool00?oo00000_oo00@00?ooool000;oo`07003oooooool00?oo00000ooo00@00?oo
ool000;oo`06003ooooo003oo`005?oo00<00?ooool0;?oo000^ool00`00ooooo`03ool00`00oooo
o`24ool01@00ool00?oo00000_oo00@00?ooool000;oo`04003ooooo0002ool01@00oooooooo0000
0_oo00@00?ooool000;oo`03003oo`0001?oo`03003ooooo02coo`00=?oo00<00?ooool0QOoo00D0
0?oo003oo`0000;oo`04003ooooo0002ool01000ooooo`000_oo00L00?ooooooo`00ool00003ool0
1@00ool00?oo00004ooo00<00?ooool0;?oo000dool00`00ooooo`26ool01@00ool00?oo00000_oo
00@00?ooool000;oo`04003ooooo0002ool01`00oooooooo003oo`0000;oo`06003ooooo003oo`00
4_oo00<00?ooool0;?oo000dool00`00ooooo`26ool01P00ooooo`00ool000;oo`04003ooooo0002
ool01000ooooo`000_oo00@00?ooool000;oo`04003ooooo0002ool00`00ool0000Aool00`00oooo
o`0/ool003Coo`03003ooooo08Ooo`06003ooooo003oo`000_oo00H00?ooool00?oo0003ool01000
ooooo`000_oo00@00?ooool000;oo`05003oo`00ool0000Aool00`00ooooo`0/ool003Coo`03003o
oooo08Soo`06003ooooo003oo`000_oo00H00?ooool00?oo0003ool00`00ool00003ool00`00ool0
0002ool01P00ooooo`00ool0013oo`03003ooooo02coo`00=?oo00<00?ooool0ROoo00H00?ooool0
0?oo0002ool01P00ooooo`00ool000?oo`03003oo`0000;oo`04003ooooo0002ool00`00ooooo`02
000@ool00`00ooooo`0/ool003Coo`03003ooooo08[oo`06003ooooo003oo`000_oo00H00?ooool0
0?oo0002ool01000ooooo`000_oo00@00?ooool000;oo`05003oo`00ool0000?ool00`00ooooo`0/
ool003Coo`03003ooooo08_oo`06003ooooo003oo`000_oo00<00?oo00000_oo00@00?ooool000;o
o`06003ooooo003oo`000_oo00<00?ooool00P003ooo00<00?ooool0;?oo000dool00`00ooooo`2<
ool00`00ool00002ool01P00ooooo`00ool000;oo`04003ooooo0002ool00`00ool00002ool02000
ooooo`00ool00?oo000>ool00`00ooooo`0/ool002koo`<000?oo`03003ooooo08goo`03003oo`00
00;oo`06003ooooo003oo`000_oo00@00?ooool000;oo`05003oo`00ool00003ool01000ool00000
3_oo00<00?ooool0;?oo000_ool00`00ooooo`02ool00`00ooooo`2>ool00`00ool00002ool00`00
ool00002ool01P00ooooo`00ool000;oo`06003ooooo003oo`000_oo00D00?oo003oo`0000goo`03
003ooooo02coo`00;Ooo10000ooo0P00T?oo00<00?oo00000_oo00<00?oo00000_oo00H00?ooool0
0?oo0002ool01P00ooooo`00ool000;oo`04003oo`00000<ool2000^ool002goo`03003oo`0000Co
o`03003ooooo093oo`03003oo`0000;oo`03003oo`0000;oo`03003oo`0000;oo`08003ooooo003o
o`00ool000?oo`800003ool00?oo00_oo`03003ooooo02coo`00;_oo0P001?oo00<00?ooool0TOoo
00D00?oo003oo`0000;oo`06003ooooo003oo`000_oo00P00?ooool00?oo003oo`000_oo00@00?oo
000000coo`03003ooooo02coo`00;ooo00<00?ooool00_oo00<00?ooool0T_oo00D00?oo003oo`00
00;oo`03003oo`0000;oo`03003oo`0000;oo`06003ooooo003oo`000_oo0P0000?oo`00ool02_oo
00<00?ooool0;?oo000dool00`00ooooo`2Cool01@00ool00?oo00000_oo00<00?oo00000_oo00<0
0?oo00000_oo00D00?oo003oo`0000;oo`05003oo`00ool0000:ool00`00ooooo`0/ool003Coo`03
003ooooo09?oo`03003oo`0000;oo`03003oo`0000;oo`06003ooooo003oo`000_oo00D00?oo003o
o`0000;oo`800003ool00?oo00Woo`03003ooooo02coo`00=?oo00<00?ooool0U?oo00<00?oo0000
0_oo00<00?oo00000_oo00P00?ooool00?oo003oo`000_oo00<00?oo00000_oo0P0000?oo`00ool0
2?oo00<00?ooool0;?oo000dool00`00ooooo`2Eool00`00ool00002ool01@00ool00?oo00000ooo
0P000_oo00<00?oo00000_oo00@00?oo003oo`8000Woo`03003ooooo02coo`00=?oo00<00?ooool0
U_oo00D00?oo003oo`0000;oo`03003oo`0000;oo`03003oo`0000;oo`05003oo`00ool00002ool2
00000ooo003oo`07ool00`00ooooo`0/ool003Coo`03003ooooo09Koo`06003ooooo003oo`000_oo
00<00?oo00000_oo00D00?oo003oo`0000;oo`03003oo`0000;oo`800003ool00?oo00Koo`03003o
oooo02coo`00=?oo00<00?ooool0Uooo00P00?ooool00?oo003oo`000_oo00<00?ooool00P000_oo
00T00?ooool00?oo003oo`00ool00P001ooo00<00?ooool0;?oo000dool00`00ooooo`2Hool00`00
ool00002ool00`00ool00002ool00`00ooooo`020002ool00`00ool00002ool01P00ool00000ool0
00Koo`03003ooooo02coo`00=?oo00<00?ooool0VOoo00<00?oo00000_oo00D00?oo003oo`0000;o
o`05003oo`00ool00002ool02@00ool00?oo003oo`00ool00005ool00`00ooooo`0/ool003Coo`03
003ooooo09[oo`05003oo`00ool00002ool00`00ool00002ool20002ool02@00ooooo`00ool00?oo
003oo`020005ool00`00ooooo`0/ool002koo`03003ooooo00?oo`03003ooooo09[oo`06003ooooo
003oo`000_oo00<00?oo00000_oo0P000_oo00L00?ooool00?oo003oo`0200000ooo003oo`03ool0
0`00ooooo`0/ool002goo`03003oo`0000Coo`03003ooooo09_oo`08003ooooo003oo`00ool000;o
o`03003ooooo0080000:ool00?ooool00?oo003oo`00ool20004ool00`00ooooo`0/ool002ooo`03
003ooooo00;oo`8009goo`03003oo`0000;oo`03003oo`0000;oo`07003oo`00ool00?oo00000_oo
00H00?oo003oo`00ool20002ool2000^ool002goo`8000Goo`03003ooooo09goo`03003oo`0000;o
o`05003oo`00ool00002ool20002ool01@00ooooo`00ool00P0000?oo`00ool00ooo00<00?ooool0
;?oo000]ool00`00ooooo`04ool00`00ooooo`2Mool01P00ooooo`00ool000;oo`03003oo`0000;o
o`80000;ool00?ooool00?oo003oo`00ool00003ool00`00ooooo`0/ool002goo`<000Coo`03003o
oooo09koo`08003ooooo003oo`00ool000;oo`07003oo`00ool00?oo00000_oo00@00?oo000000Go
o`03003ooooo02coo`00=?oo00<00?ooool0Wooo00P00?ooool00?oo003oo`000_oo00L00?oo003o
o`00ool00002ool200000ooo003oo`03ool00`00ooooo`0/ool003Coo`03003ooooo0:3oo`03003o
o`0000;oo`0;003oo`00ool00?oo003oo`00ool00002ool01@00ool00?oo00000ooo00<00?ooool0
;?oo000dool00`00ooooo`2Qool01@00ool00?oo00000_oo00T00?oo003oo`00ool00?oo00000_oo
00<00?oo00001?oo00<00?ooool0;?oo000dool00`00ooooo`2Qool02000ooooo`00ool00?oo0002
ool02`00ool00?oo003oo`00ool00?oo00001?oo00<00?ooool0;?oo000dool00`00ooooo`2Rool0
3P00ooooo`00ool00?oo003oo`00ool00?oo0002ool01@00ool00?oo00000ooo00<00?ooool0;?oo
000dool00`00ooooo`2Sool04000ooooo`00ool00?oo003oo`00ool00?oo003oo`000_oo00<00?oo
ool00_oo00<00?ooool0;?oo000dool00`00ooooo`2Tool01@00ool00?oo00000_oo0P000_oo00L0
0?oo003oo`00ool00004ool00`00ooooo`0/ool003Coo`03003ooooo0:Goo`0;003oo`00ool00?oo
003oo`00ool00002ool01@00ool00?oo00000ooo00<00?ooool0;?oo000dool00`00ooooo`2Uool0
3P00ooooo`00ool00?oo003oo`00ool00?oo0002ool00`00ooooo`02ool00`00ooooo`0/ool002go
o`8000Goo`03003ooooo0:Koo`07003ooooo003oo`00ool00P000_oo00D00?oo003oo`0000Coo`03
003ooooo02coo`00;Ooo00<00?oo00001?oo00<00?ooool0Yooo00D00?oo003oo`0000;oo`8000;o
o`05003oo`00ool00003ool00`00ooooo`0/ool002goo`03003oo`0000Coo`800:Woo`0;003oo`00
ool00?oo003oo`00ool00002ool01000oooooooo0P00;_oo000]ool20005ool00`00ooooo`2Yool0
3@00ool00?oo003oo`00ool00?oo003oo`0000Coo`03003ooooo02coo`00;Ooo00<00?ooool01?oo
00<00?ooool0ZOoo00<00?oo00000_oo00@00?oo000000;oo`03003oo`0000?oo`03003ooooo02co
o`00;_oo0P001?oo00<00?ooool0Z_oo00T00?oo003oo`00ool00?oo00000_oo00<00?ooool00_oo
00<00?ooool0;?oo000dool00`00ooooo`2[ool20002ool01`00ool00?oo003oo`0000Coo`03003o
oooo02coo`00=?oo00<00?ooool0[?oo0P000_oo00L00?oo003oo`00ool00003ool00`00ooooo`0/
ool003Coo`03003ooooo0:goo`800004ool00?ooool20005ool00`00ooooo`0/ool003Coo`03003o
oooo0:goo`8000;oo`05003oo`00ool00004ool00`00ooooo`0/ool003Coo`03003ooooo0:koo`80
00;oo`05003oo`00ool00003ool00`00ooooo`0/ool003Coo`03003ooooo0:ooo`8000;oo`03003o
o`0000Coo`03003ooooo02coo`00=?oo00<00?ooool0/?oo0P0000Coo`00ool000Coo`03003ooooo
02coo`00=?oo00<00?ooool0/?oo0P000_oo00<00?oo00000ooo00<00?ooool0;?oo000dool00`00
ooooo`2aool20002ool00`00ooooo`02ool00`00ooooo`0/ool002koo`03003ooooo00?oo`03003o
oooo0;;oo`800003ool00?oo00?oo`03003ooooo02coo`00;_oo00<00?ooool00ooo00<00?ooool0
/ooo0P0000?oo`00ool00_oo00<00?ooool0;?oo000^ool00`00ooooo`03ool2002dool20004ool2
000^ool002ooo`03003ooooo00;oo`03003ooooo0;Coo`8000Coo`03003ooooo02coo`00;Ooo00<0
0?oo00001?oo00<00?ooool0]Ooo0P000ooo00<00?ooool0;?oo000]ool30004ool00`00ooooo`2e
ool00`00ooooo`02ool00`00ooooo`0/ool003Coo`03003ooooo0;Koo`05003oooooool0000^ool0
03Coo`03003ooooo0;[oo`03003ooooo02coo`00=?oo00D00?ooooooo`0000Soo`03003ooooo00Ko
o`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ko
o`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Oo
o`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ko
o`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Koo`05003oooooool0000^ool003Cookh0
02koo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00Booo0`00
0ooo0P000_oo0`002_oo10000_oo0`000_oo0`000_oo0`000ooo0P000_oo0`000ooo0P0000?oo`00
00000_oo00<00?ooool00P004?oo0P0000Coo`00003oo`@000;oo`8000?oo`<00004ool000000002
ool30003ool20002ool30003ool20002ool2001Bool004coo`05003oooooool00002ool01000oooo
o`003?oo00@00?ooool000;oo`03003ooooo00;oo`03003ooooo00;oo`05003oooooool00005ool0
1@00oooooooo00001?oo00H00?ooool00?oo0002ool00`00ooooo`0=ool01P00oooooooo003oo`<0
00;oo`06003ooooo003oo`000_oo00@00?ooool000Coo`05003oooooool00002ool01000ooooo`00
0ooo00<00?ooool01?oo00<00?ooool0Cooo001<ool01@00oooooooo00000_oo00@00?ooool000co
o`04003ooooo0002ool00`00ooooo`02ool00`00ooooo`02ool01000oooooooo0`000ooo00@00?oo
ooooo`<000;oo`06003ooooo003oo`004_oo00D00?oo003oo`0000?oo`04003ooooo0004ool01000
ooooo`000_oo00<00?ooool00_oo00D00?ooooooo`0000Goo`04003oooooool30003ool00`00oooo
o`1@ool004_oo`<000?oo`8000;oo`@000[oo`05003ooooo003oo`020003ool30002ool30002ool3
0002ool400001Ooo00000000ool0100000?oo`0000000P004?oo0P0000?oo`0000000_oo0P0000?o
o`0000000P0000Coo`00003oo`800003ool0000000800003ool0000000;oo`@000;oo`8000?oo`<0
00?oo`80057oo`00C?oo00<00?ooool05?oo00@00?ooool000Ooo`03003ooooo00;oo`03003ooooo
01Goo`03003ooooo013oo`800003ool0000000Koo`03003ooooo017oo`03003ooooo063oo`00COoo
00<00?ooool04_oo10000ooo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool09ooo0P0000?o
o`0000005_oo00<00?ooool01ooo00<00?ooool0F_oo003ooolQool00?ooob7oo`00oooo8Ooo003o
oolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00QOoo0`00V?oo0026ool00`00oooo
o`2Gool006Coo`8000;oo`@00004ool000000002ool3000=ool20002ool30003ool20002ool30003
ool200000ooo00000002ool00`00ooooo`0<ool20002ool400001?oo000000000ooo0`000_oo0P00
G_oo001Sool00`00ooooo`02ool30003ool00`00ooooo`02ool00`00ooooo`0;ool01P00ooooo`00
ool000;oo`03003oo`0000;oo`04003ooooo0003ool01P00ooooo`00ool000;oo`03003ooooo00_o
o`03003oo`0000;oo`<000?oo`05003oooooool00002ool00`00ool0001Pool006?oo`03003ooooo
00Coo`05003oooooool00004ool00`00ooooo`0;ool01P00ooooo`00ool000;oo`03003oo`0000Go
o`05003oooooool00002ool00`00ool00002ool00`00ooooo`0;ool00`00ool00004ool01@00oooo
oooo00000ooo00D00?ooool00?oo00<005koo`00Hooo00<00?ooool00ooo0P000ooo00<00?ooool0
0_oo00<00?ooool02ooo00<00?ooool01@0000?oo`0000000P000_oo0P001?oo0P0000?oo`000000
0P003_oo00@00?ooool000;oo`8000?oo`03003ooooo00800004ool00000ool3001Nool006?oo`03
003oo`0000Soo`03003ooooo00;oo`03003ooooo00_oo`04003ooooo0006ool00`00ooooo`0Lool0
1@00oooooooo00001ooo00<00?ooool0Iooo001Sool30007ool20003ool2000>ool2000=ool00`00
ooooo`0Fool200000ooo00000006ool2001Yool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7o
o`00oooo8Ooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {18.7271, -1.89626, 0.110743, \
0.0650266}}]
}, Open  ]],

Cell["Here is the equivalent three\[Hyphen]dimensional graph. ", "MathCaption",
  CellTags->"0.18"],

Cell[CellGroupData[{

Cell["\<\
Plot3D[optionvalue[x, t], {x, 25, 55}, {t, 0, 120},
   AxesLabel->{\"Stock Price\", \"Time\", \"Option  \\nValue \"}];\
\>", \
"Input",
  CellLabel->"In[14]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -11.1734 -9 ]
[.3345 .12542 .8266 0 ]
[.56094 .0364 -10.3394 -9 ]
[.56094 .0364 1.66057 0 ]
[.29165 .07573 -65.1782 -15 ]
[.29165 .07573 4.82182 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.77009 .10107 0 -6.15794 ]
[.77009 .10107 12 2.84206 ]
[.83293 .1973 0 -6.06544 ]
[.83293 .1973 12 2.93456 ]
[.89031 .28516 0 -5.98272 ]
[.89031 .28516 12 3.01728 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 18 3.0917 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 28 4.94788 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01393 .32896 -6 -2.79632 ]
[.01393 .32896 0 6.20368 ]
[.00331 .39551 -12 -2.85284 ]
[.00331 .39551 0 6.14716 ]
[-0.00777 .46494 -12 -2.91207 ]
[-0.00777 .46494 0 6.08793 ]
[-0.05457 .39542 -52 -9.75946 ]
[-0.05457 .39542 0 21.2405 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75778 .10561 m
.75162 .10787 L
s
[(25)] .77009 .10107 -1 .36843 Mshowa
.82054 .20161 m
.81434 .20377 L
s
[(50)] .83293 .1973 -1 .34788 Mshowa
.87784 .28927 m
.87161 .29132 L
s
[(75)] .89031 .28516 -1 .32949 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(100)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.70309 .02196 m
.69942 .02338 L
s
.71716 .04348 m
.71349 .04489 L
s
.73096 .06459 m
.72728 .06598 L
s
.7445 .0853 m
.74081 .08667 L
s
.7708 .12553 m
.7671 .12688 L
s
.78358 .14509 m
.77988 .14642 L
s
.79613 .16428 m
.79242 .1656 L
s
.80845 .18312 m
.80473 .18442 L
s
.83241 .21978 m
.82869 .22106 L
s
.84407 .23761 m
.84035 .23888 L
s
.85553 .25514 m
.8518 .25639 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.89939 .32223 m
.89565 .32344 L
s
.9099 .3383 m
.90615 .3395 L
s
.92022 .35409 m
.91647 .35528 L
s
.94036 .3849 m
.9366 .38606 L
s
.95018 .39992 m
.94642 .40107 L
s
.95984 .4147 m
.95608 .41584 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.0262 .32431 m
.03233 .32199 L
s
[(5)] .01393 .32896 1 -0.3786 Mshowa
.01563 .391 m
.02179 .38874 L
s
[(10)] .00331 .39551 1 -0.36603 Mshowa
.0046 .46058 m
.01079 .45839 L
s
[(15)] -0.00777 .46494 1 -0.35287 Mshowa
.125 Mabswid
.03434 .27292 m
.03801 .2715 L
s
.03233 .28561 m
.036 .28419 L
s
.0303 .2984 m
.03398 .29699 L
s
.02826 .3113 m
.03194 .3099 L
s
.02412 .33743 m
.0278 .33604 L
s
.02202 .35065 m
.02571 .34927 L
s
.01991 .36399 m
.0236 .36262 L
s
.01778 .37744 m
.02147 .37607 L
s
.01346 .40468 m
.01716 .40333 L
s
.01128 .41847 m
.01498 .41714 L
s
.00907 .43239 m
.01278 .43106 L
s
.00685 .44642 m
.01056 .4451 L
s
.00234 .47485 m
.00606 .47355 L
s
6e-05 .48926 m
.00378 .48796 L
s
gsave
-0.05457 .39542 -113 -13.7595 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Option) show
63.000000 31.000000 moveto
(Value) show
99.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.38313 .58323 .40512 .60371 .44189 .59268 .42021 .57192 Metetra
.664 .741 .908 r
.42021 .57192 .44189 .59268 .47916 .5815 .45781 .56045 Metetra
.664 .741 .908 r
.45781 .56045 .47916 .5815 .51695 .57017 .49594 .54882 Metetra
.664 .741 .908 r
.49594 .54882 .51695 .57017 .55526 .55867 .5346 .53702 Metetra
.663 .741 .908 r
.5346 .53702 .55526 .55867 .59412 .54701 .57382 .52516 Metetra
.647 .737 .915 r
.57382 .52516 .59412 .54701 .63352 .53522 .61365 .51467 Metetra
.562 .722 .948 r
.61365 .51467 .63352 .53522 .67368 .52753 .65435 .51081 Metetra
.33 .656 .971 r
.65435 .51081 .67368 .52753 .71549 .53691 .69638 .51702 Metetra
.258 .579 .943 r
.69638 .51702 .71549 .53691 .75875 .55064 .73989 .52918 Metetra
.257 .561 .934 r
.73989 .52918 .75875 .55064 .80334 .56483 .78481 .54309 Metetra
.257 .56 .933 r
.78481 .54309 .80334 .56483 .84932 .57947 .83117 .55759 Metetra
.257 .56 .933 r
.83117 .55759 .84932 .57947 .89675 .59456 .87901 .57255 Metetra
.257 .56 .933 r
.87901 .57255 .89675 .59456 .94571 .61014 .92842 .58801 Metetra
.257 .56 .933 r
.92842 .58801 .94571 .61014 .99627 .62623 .97946 .60398 Metetra
.664 .741 .908 r
.36056 .56222 .38313 .58323 .42021 .57192 .39797 .55062 Metetra
.664 .741 .908 r
.39797 .55062 .42021 .57192 .45781 .56045 .4359 .53885 Metetra
.664 .741 .908 r
.4359 .53885 .45781 .56045 .49594 .54882 .47438 .52691 Metetra
.663 .741 .908 r
.47438 .52691 .49594 .54882 .5346 .53702 .5134 .51487 Metetra
.657 .74 .911 r
.5134 .51487 .5346 .53702 .57382 .52516 .55299 .50329 Metetra
.626 .735 .926 r
.55299 .50329 .57382 .52516 .61365 .51467 .59324 .49446 Metetra
.533 .719 .959 r
.59324 .49446 .61365 .51467 .65435 .51081 .63438 .49198 Metetra
.376 .663 .97 r
.63438 .49198 .65435 .51081 .69638 .51702 .67674 .49718 Metetra
.277 .597 .95 r
.67674 .49718 .69638 .51702 .73989 .52918 .72052 .50782 Metetra
.256 .568 .938 r
.72052 .50782 .73989 .52918 .78481 .54309 .76576 .52101 Metetra
.254 .561 .934 r
.76576 .52101 .78481 .54309 .83117 .55759 .81249 .53524 Metetra
.254 .56 .934 r
.81249 .53524 .83117 .55759 .87901 .57255 .86075 .55005 Metetra
.254 .559 .934 r
.86075 .55005 .87901 .57255 .92842 .58801 .91061 .56537 Metetra
.254 .559 .934 r
.91061 .56537 .92842 .58801 .97946 .60398 .96216 .58121 Metetra
.664 .741 .908 r
.33741 .54067 .36056 .56222 .39797 .55062 .37515 .52876 Metetra
.664 .741 .908 r
.37515 .52876 .39797 .55062 .4359 .53885 .41342 .51668 Metetra
.663 .741 .908 r
.41342 .51668 .4359 .53885 .47438 .52691 .45224 .50444 Metetra
.661 .741 .909 r
.45224 .50444 .47438 .52691 .5134 .51487 .49162 .49225 Metetra
.649 .739 .915 r
.49162 .49225 .5134 .51487 .55299 .50329 .53159 .4811 Metetra
.61 .733 .933 r
.53159 .4811 .55299 .50329 .59324 .49446 .57223 .4733 Metetra
.522 .711 .958 r
.57223 .4733 .59324 .49446 .63438 .49198 .61377 .47142 Metetra
.399 .661 .965 r
.61377 .47142 .63438 .49198 .67674 .49718 .65648 .47611 Metetra
.306 .607 .952 r
.65648 .47611 .67674 .49718 .72052 .50782 .70058 .48578 Metetra
.268 .575 .94 r
.70058 .48578 .72052 .50782 .76576 .52101 .74615 .49826 Metetra
.258 .564 .935 r
.74615 .49826 .76576 .52101 .81249 .53524 .79324 .51211 Metetra
.257 .56 .934 r
.79324 .51211 .81249 .53524 .86075 .55005 .84192 .5267 Metetra
.257 .56 .933 r
.84192 .5267 .86075 .55005 .91061 .56537 .89223 .54185 Metetra
.257 .559 .933 r
.89223 .54185 .91061 .56537 .96216 .58121 .94428 .55753 Metetra
.664 .741 .908 r
.31365 .51855 .33741 .54067 .37515 .52876 .35172 .50632 Metetra
.663 .741 .908 r
.35172 .50632 .37515 .52876 .41342 .51668 .39033 .49392 Metetra
.663 .741 .908 r
.39033 .49392 .41342 .51668 .45224 .50444 .4295 .48142 Metetra
.658 .74 .911 r
.4295 .48142 .45224 .50444 .49162 .49225 .46925 .46924 Metetra
.64 .738 .92 r
.46925 .46924 .49162 .49225 .53159 .4811 .50959 .45862 Metetra
.595 .73 .939 r
.50959 .45862 .53159 .4811 .57223 .4733 .55062 .45168 Metetra
.51 .708 .96 r
.55062 .45168 .57223 .4733 .61377 .47142 .59255 .45022 Metetra
.402 .663 .965 r
.59255 .45022 .61377 .47142 .65648 .47611 .63562 .45453 Metetra
.317 .614 .955 r
.63562 .45453 .65648 .47611 .70058 .48578 .68005 .4634 Metetra
.274 .582 .943 r
.68005 .4634 .70058 .48578 .74615 .49826 .72596 .47516 Metetra
.259 .567 .937 r
.72596 .47516 .74615 .49826 .79324 .51211 .77343 .48853 Metetra
.255 .562 .935 r
.77343 .48853 .79324 .51211 .84192 .5267 .82252 .50283 Metetra
.254 .56 .934 r
.82252 .50283 .84192 .5267 .89223 .54185 .8733 .51777 Metetra
.254 .56 .934 r
.8733 .51777 .89223 .54185 .94428 .55753 .92585 .53328 Metetra
.664 .741 .908 r
.28926 .49583 .31365 .51855 .35172 .50632 .32766 .48327 Metetra
.663 .741 .908 r
.32766 .48327 .35172 .50632 .39033 .49392 .36661 .47056 Metetra
.662 .741 .909 r
.36661 .47056 .39033 .49392 .4295 .48142 .40614 .45782 Metetra
.654 .74 .913 r
.40614 .45782 .4295 .48142 .46925 .46924 .44625 .44567 Metetra
.632 .736 .923 r
.44625 .44567 .46925 .46924 .50959 .45862 .48696 .43546 Metetra
.584 .726 .941 r
.48696 .43546 .50959 .45862 .55062 .45168 .52837 .42904 Metetra
.505 .701 .958 r
.52837 .42904 .55062 .45168 .59255 .45022 .57067 .42777 Metetra
.411 .661 .962 r
.57067 .42777 .59255 .45022 .63562 .45453 .6141 .43177 Metetra
.333 .618 .954 r
.6141 .43177 .63562 .45453 .68005 .4634 .65888 .44004 Metetra
.287 .587 .944 r
.65888 .44004 .68005 .4634 .72596 .47516 .70514 .4512 Metetra
.266 .571 .938 r
.70514 .4512 .72596 .47516 .77343 .48853 .75299 .4641 Metetra
.259 .563 .935 r
.75299 .4641 .77343 .48853 .82252 .50283 .80249 .47806 Metetra
.257 .561 .934 r
.80249 .47806 .82252 .50283 .8733 .51777 .85373 .49275 Metetra
.257 .56 .933 r
.85373 .49275 .8733 .51777 .92585 .53328 .90679 .50805 Metetra
.663 .741 .908 r
.2642 .4725 .28926 .49583 .32766 .48327 .30294 .45961 Metetra
.663 .741 .908 r
.30294 .45961 .32766 .48327 .36661 .47056 .34225 .44658 Metetra
.66 .741 .91 r
.34225 .44658 .36661 .47056 .40614 .45782 .38213 .43367 Metetra
.649 .739 .915 r
.38213 .43367 .40614 .45782 .44625 .44567 .4226 .42163 Metetra
.623 .735 .927 r
.4226 .42163 .44625 .44567 .48696 .43546 .46367 .41184 Metetra
.573 .724 .945 r
.46367 .41184 .48696 .43546 .52837 .42904 .50545 .40587 Metetra
.497 .699 .96 r
.50545 .40587 .52837 .42904 .57067 .42777 .54813 .40476 Metetra
.41 .662 .963 r
.54813 .40476 .57067 .42777 .6141 .43177 .59193 .40848 Metetra
.337 .622 .956 r
.59193 .40848 .6141 .43177 .65888 .44004 .63706 .4162 Metetra
.291 .592 .946 r
.63706 .4162 .65888 .44004 .70514 .4512 .68369 .42676 Metetra
.268 .574 .94 r
.68369 .42676 .70514 .4512 .75299 .4641 .73192 .43916 Metetra
.259 .566 .936 r
.73192 .43916 .75299 .4641 .80249 .47806 .78184 .45273 Metetra
.255 .562 .935 r
.78184 .45273 .80249 .47806 .85373 .49275 .83355 .46713 Metetra
.254 .56 .934 r
.83355 .46713 .85373 .49275 .90679 .50805 .88712 .48217 Metetra
.663 .741 .908 r
.23846 .44853 .2642 .4725 .30294 .45961 .27753 .43529 Metetra
.662 .741 .909 r
.27753 .43529 .30294 .45961 .34225 .44658 .31719 .42196 Metetra
.658 .74 .911 r
.31719 .42196 .34225 .44658 .38213 .43367 .35744 .40891 Metetra
.644 .738 .917 r
.35744 .40891 .38213 .43367 .4226 .42163 .39826 .397 Metetra
.615 .733 .93 r
.39826 .397 .4226 .42163 .46367 .41184 .43969 .38755 Metetra
.564 .721 .947 r
.43969 .38755 .46367 .41184 .50545 .40587 .48184 .38191 Metetra
.492 .696 .959 r
.48184 .38191 .50545 .40587 .54813 .40476 .52489 .38086 Metetra
.412 .661 .962 r
.52489 .38086 .54813 .40476 .59193 .40848 .56905 .38432 Metetra
.343 .624 .956 r
.56905 .38432 .59193 .40848 .63706 .4162 .61455 .39155 Metetra
.298 .596 .948 r
.61455 .39155 .63706 .4162 .68369 .42676 .66155 .40155 Metetra
.273 .578 .941 r
.66155 .40155 .68369 .42676 .73192 .43916 .71017 .41345 Metetra
.261 .568 .937 r
.71017 .41345 .73192 .43916 .78184 .45273 .76052 .42661 Metetra
.257 .563 .935 r
.76052 .42661 .78184 .45273 .83355 .46713 .8127 .44067 Metetra
.255 .561 .934 r
.8127 .44067 .83355 .46713 .88712 .48217 .86679 .45544 Metetra
.663 .741 .908 r
.212 .4239 .23846 .44853 .27753 .43529 .25142 .4103 Metetra
.661 .741 .909 r
.25142 .4103 .27753 .43529 .31719 .42196 .29143 .39668 Metetra
.655 .74 .912 r
.29143 .39668 .31719 .42196 .35744 .40891 .33203 .38348 Metetra
.64 .737 .919 r
.33203 .38348 .35744 .40891 .39826 .397 .37321 .37162 Metetra
.609 .731 .932 r
.37321 .37162 .39826 .397 .43969 .38755 .415 .36237 Metetra
.558 .717 .947 r
.415 .36237 .43969 .38755 .48184 .38191 .45751 .3569 Metetra
.489 .692 .958 r
.45751 .3569 .48184 .38191 .52489 .38086 .50092 .35582 Metetra
.415 .659 .96 r
.50092 .35582 .52489 .38086 .56905 .38432 .54545 .359 Metetra
.351 .625 .955 r
.54545 .359 .56905 .38432 .61455 .39155 .59131 .36578 Metetra
.307 .598 .947 r
.59131 .36578 .61455 .39155 .66155 .40155 .63868 .37528 Metetra
.28 .58 .941 r
.63868 .37528 .66155 .40155 .71017 .41345 .6877 .3867 Metetra
.267 .569 .937 r
.6877 .3867 .71017 .41345 .76052 .42661 .73848 .39945 Metetra
.261 .564 .935 r
.73848 .39945 .76052 .42661 .8127 .44067 .79113 .41315 Metetra
.258 .561 .934 r
.79113 .41315 .8127 .44067 .86679 .45544 .84575 .4276 Metetra
.663 .741 .908 r
.18479 .39857 .212 .4239 .25142 .4103 .22456 .38461 Metetra
.66 .741 .91 r
.22456 .38461 .25142 .4103 .29143 .39668 .26492 .37072 Metetra
.653 .74 .913 r
.26492 .37072 .29143 .39668 .33203 .38348 .30588 .35741 Metetra
.635 .737 .922 r
.30588 .35741 .33203 .38348 .37321 .37162 .34741 .34565 Metetra
.601 .73 .935 r
.34741 .34565 .37321 .37162 .415 .36237 .38955 .33661 Metetra
.55 .715 .949 r
.38955 .33661 .415 .36237 .45751 .3569 .43242 .33129 Metetra
.483 .691 .959 r
.43242 .33129 .45751 .3569 .50092 .35582 .47619 .33016 Metetra
.413 .659 .961 r
.47619 .33016 .50092 .35582 .54545 .359 .52109 .33306 Metetra
.352 .627 .956 r
.52109 .33306 .54545 .359 .59131 .36578 .56732 .3394 Metetra
.308 .601 .949 r
.56732 .3394 .59131 .36578 .63868 .37528 .61507 .34839 Metetra
.282 .583 .943 r
.61507 .34839 .63868 .37528 .6877 .3867 .66449 .35931 Metetra
.267 .572 .939 r
.66449 .35931 .6877 .3867 .73848 .39945 .71571 .3716 Metetra
.26 .565 .936 r
.71571 .3716 .73848 .39945 .79113 .41315 .76884 .38491 Metetra
.257 .562 .935 r
.76884 .38491 .79113 .41315 .84575 .4276 .82399 .399 Metetra
.662 .741 .908 r
.1568 .37252 .18479 .39857 .22456 .38461 .19692 .3582 Metetra
.659 .741 .91 r
.19692 .3582 .22456 .38461 .26492 .37072 .23764 .34402 Metetra
.65 .739 .915 r
.23764 .34402 .26492 .37072 .30588 .35741 .27895 .33057 Metetra
.63 .735 .923 r
.27895 .33057 .30588 .35741 .34741 .34565 .32083 .31882 Metetra
.596 .727 .936 r
.32083 .31882 .34741 .34565 .38955 .33661 .36333 .30986 Metetra
.545 .711 .949 r
.36333 .30986 .38955 .33661 .43242 .33129 .40655 .30457 Metetra
.481 .687 .958 r
.40655 .30457 .43242 .33129 .47619 .33016 .45068 .30332 Metetra
.415 .657 .959 r
.45068 .30332 .47619 .33016 .52109 .33306 .49593 .30593 Metetra
.358 .627 .955 r
.49593 .30593 .52109 .33306 .56732 .3394 .54253 .31183 Metetra
.315 .602 .948 r
.54253 .31183 .56732 .3394 .61507 .34839 .59066 .32033 Metetra
.288 .584 .943 r
.59066 .32033 .61507 .34839 .66449 .35931 .64049 .33077 Metetra
.272 .573 .939 r
.64049 .33077 .66449 .35931 .71571 .3716 .69214 .3426 Metetra
.264 .566 .936 r
.69214 .3426 .71571 .3716 .76884 .38491 .74575 .35549 Metetra
.26 .563 .935 r
.74575 .35549 .76884 .38491 .82399 .399 .80143 .3692 Metetra
.662 .741 .909 r
.12799 .34572 .1568 .37252 .19692 .3582 .16846 .33104 Metetra
.657 .74 .911 r
.16846 .33104 .19692 .3582 .23764 .34402 .20954 .31659 Metetra
.647 .739 .916 r
.20954 .31659 .23764 .34402 .27895 .33057 .2512 .30303 Metetra
.625 .734 .926 r
.2512 .30303 .27895 .33057 .32083 .31882 .29343 .29132 Metetra
.589 .726 .938 r
.29343 .29132 .32083 .31882 .36333 .30986 .33627 .28245 Metetra
.538 .71 .951 r
.33627 .28245 .36333 .30986 .40655 .30457 .37984 .27718 Metetra
.476 .687 .959 r
.37984 .27718 .40655 .30457 .45068 .30332 .42433 .27579 Metetra
.413 .658 .96 r
.42433 .27579 .45068 .30332 .49593 .30593 .46995 .27809 Metetra
.358 .629 .956 r
.46995 .27809 .49593 .30593 .54253 .31183 .51691 .28356 Metetra
.316 .604 .95 r
.51691 .28356 .54253 .31183 .59066 .32033 .56543 .29155 Metetra
.289 .587 .944 r
.56543 .29155 .59066 .32033 .64049 .33077 .61566 .30147 Metetra
.272 .575 .94 r
.61566 .30147 .64049 .33077 .69214 .3426 .66776 .31281 Metetra
.263 .568 .937 r
.66776 .31281 .69214 .3426 .74575 .35549 .72186 .32524 Metetra
.259 .564 .935 r
.72186 .32524 .74575 .35549 .80143 .3692 .77808 .33853 Metetra
.661 .741 .909 r
.09834 .31813 .12799 .34572 .16846 .33104 .13916 .30308 Metetra
.656 .74 .912 r
.13916 .30308 .16846 .33104 .20954 .31659 .18059 .28835 Metetra
.644 .738 .917 r
.18059 .28835 .20954 .31659 .2512 .30303 .2226 .27463 Metetra
.621 .733 .927 r
.2226 .27463 .2512 .30303 .29343 .29132 .26518 .26286 Metetra
.584 .723 .939 r
.26518 .26286 .29343 .29132 .33627 .28245 .30836 .25398 Metetra
.534 .707 .95 r
.30836 .25398 .33627 .28245 .37984 .27718 .35228 .24863 Metetra
.475 .683 .958 r
.35228 .24863 .37984 .27718 .42433 .27579 .39712 .24704 Metetra
.414 .656 .958 r
.39712 .24704 .42433 .27579 .46995 .27809 .44309 .24899 Metetra
.362 .628 .955 r
.44309 .24899 .46995 .27809 .51691 .28356 .49042 .25402 Metetra
.322 .605 .949 r
.49042 .25402 .51691 .28356 .56543 .29155 .53932 .26151 Metetra
.294 .587 .944 r
.53932 .26151 .56543 .29155 .61566 .30147 .58996 .27091 Metetra
.277 .576 .94 r
.58996 .27091 .61566 .30147 .66776 .31281 .6425 .28175 Metetra
.267 .569 .937 r
.6425 .28175 .66776 .31281 .72186 .32524 .69709 .2937 Metetra
.262 .564 .935 r
.69709 .2937 .72186 .32524 .77808 .33853 .75385 .30654 Metetra
.66 .741 .909 r
.06779 .28973 .09834 .31813 .13916 .30308 .10897 .2743 Metetra
.654 .74 .913 r
.10897 .2743 .13916 .30308 .18059 .28835 .15075 .2593 Metetra
.64 .737 .919 r
.15075 .2593 .18059 .28835 .2226 .27463 .1931 .24545 Metetra
.616 .732 .929 r
.1931 .24545 .2226 .27463 .26518 .26286 .23602 .23365 Metetra
.578 .722 .941 r
.23602 .23365 .26518 .26286 .30836 .25398 .27954 .22475 Metetra
.528 .706 .952 r
.27954 .22475 .30836 .25398 .35228 .24863 .3238 .21932 Metetra
.47 .683 .959 r
.3238 .21932 .35228 .24863 .39712 .24704 .36899 .21751 Metetra
.412 .656 .959 r
.36899 .21751 .39712 .24704 .44309 .24899 .41531 .21911 Metetra
.361 .629 .956 r
.41531 .21911 .44309 .24899 .49042 .25402 .46301 .22367 Metetra
.322 .607 .95 r
.46301 .22367 .49042 .25402 .53932 .26151 .5123 .23064 Metetra
.295 .59 .945 r
.5123 .23064 .53932 .26151 .58996 .27091 .56335 .23949 Metetra
.277 .578 .941 r
.56335 .23949 .58996 .27091 .6425 .28175 .61634 .24979 Metetra
.267 .57 .938 r
.61634 .24979 .6425 .28175 .69709 .2937 .67141 .26122 Metetra
.261 .566 .936 r
.67141 .26122 .69709 .2937 .75385 .30654 .72872 .27355 Metetra
.66 .741 .91 r
.03632 .26047 .06779 .28973 .10897 .2743 .07785 .24465 Metetra
.652 .739 .913 r
.07785 .24465 .10897 .2743 .15075 .2593 .11998 .22935 Metetra
.637 .736 .92 r
.11998 .22935 .15075 .2593 .1931 .24545 .16268 .21531 Metetra
.612 .73 .93 r
.16268 .21531 .1931 .24545 .23602 .23365 .20593 .20339 Metetra
.574 .72 .942 r
.20593 .20339 .23602 .23365 .27954 .22475 .24979 .19438 Metetra
.525 .703 .952 r
.24979 .19438 .27954 .22475 .3238 .21932 .29439 .18877 Metetra
.469 .68 .957 r
.29439 .18877 .3238 .21932 .36899 .21751 .33991 .18667 Metetra
.413 .654 .958 r
.33991 .18667 .36899 .21751 .41531 .21911 .38659 .18788 Metetra
.364 .629 .955 r
.38659 .18788 .41531 .21911 .46301 .22367 .43465 .19196 Metetra
.326 .607 .949 r
.43465 .19196 .46301 .22367 .5123 .23064 .48431 .19839 Metetra
.299 .59 .945 r
.48431 .19839 .5123 .23064 .56335 .23949 .53576 .20668 Metetra
.281 .578 .941 r
.53576 .20668 .56335 .23949 .61634 .24979 .5892 .21642 Metetra
.27 .571 .938 r
.5892 .21642 .61634 .24979 .67141 .26122 .64476 .2273 Metetra
.264 .566 .936 r
.64476 .2273 .67141 .26122 .72872 .27355 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[14]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jA000`40n007h00Ooooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00
oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00
oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003Fool00`00ooooo`17ool00=Goo`03003oo`00
04Soo`00eOoo00<00?oo0000B?oo003Eool00`00ool00018ool00=Goo`03003oo`0004Soo`00/?oo
00<00?ooool00_oo00<00?ooool07_oo00<00?ooool0Aooo002_ool00`00ool00002ool00`00ool0
000Iool3001=ool00;7oo`06003ooooo003oo`006?oo0P0000?oo`000000C?oo002_ool20003ool0
0`00ool0000Eool30003ool2001<ool00:ooo`03003ooooo00;oo`03003oo`0001;oo`<000Koo`03
003oo`0004_oo`00[ooo0`000ooo00<00?ooool03ooo0P002Ooo00@00?ooool004[oo`00a?oo0`00
2ooo00@00?oo000004[oo`00?ooo0`000ooo0P000ooo0P000_oo0`0000Coo`00003oo`8000_oo`<0
00?oo`<000;oo`<000;oo`<000?oo`8004Soo`8000koo`05003oooooool00019ool003ooo`03003o
o`0000;oo`06003ooooo003oo`000_oo00<00?oo00001?oo00<00?oo00003Ooo00<00?ooool00ooo
00<00?ooool00_oo00D00?ooooooo`0000Coo`03003ooooo04Goo`<0013oo`03003ooooo00;oo`03
003ooooo04Koo`00@Ooo00@00?ooool000Coo`06003ooooo003oo`001?oo0`003Ooo0`000ooo00<0
0?ooool00_oo00D00?ooooooo`0000Coo`<004?oo`8001?oo`03003ooooo00;oo`03003ooooo04Ko
o`00@?oo00<00?ooool010000ooo0P000_oo0`000_oo00@00?oo000000coo`05003ooooo003oo`04
00000ooo00000003ool30002ool30010ool3000Fool01000oooooooo0P00Aooo000oool00`00ool0
0002ool00`00ooooo`0<ool00`00ooooo`0=ool01000ooooo`00D?oo0`006Ooo00<00?ooool00_oo
00<00?ooool0AOoo000oool3000@ool2000>ool40008ool00`00ooooo`14ool20002ool00`00oooo
o`0Gool00`00ooooo`03ool00`00ooooo`14ool00;;oo`<001koo`03003ooooo00Coo`03003ooooo
04?oo`00[_oo00@00?oo0000027oo`03003ooooo00Coo`8004Coo`00[Ooo0`008ooo00<00?ooool0
1?oo0P00A?oo002[ool2000Vool00`00ooooo`06ool00`00ooooo`11ool00:Soo`<002Soo`03003o
oooo00Koo`03003ooooo047oo`00Y?oo1000:ooo00<00?ooool01ooo00<00?ooool01?oo0`000ooo
00<00?ooool0<ooo001oool30002ool00`00ooooo`0Lool3000]ool00`00ooooo`07ool20005ool0
0`00ooooo`02ool00`00ool0000dool0083oo`06003ooooo003oo`006_oo0`00<?oo00<00?ooool0
2?oo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool0<_oo001nool400001?oo003oo`006?oo
0P00<ooo00<00?ooool02Ooo00<00?ooool00ooo00@00?ooooooo`8003Goo`00O_oo00<00?oo0000
0_oo00<00?oo00005Ooo0`00=Ooo00<00?ooool02_oo00L00?ooooooo`00ool00002ool00`00oooo
o`0dool007ooo`8000;oo`03003oo`0001?oo`<003Ooo`03003ooooo00[oo`03003ooooo00;oo`04
003oooooool3000dool0083oo`05003oooooool0000Aool3000jool00`00ooooo`09ool00`00ool0
000nool009?oo`<003goo`03003ooooo00coo`03003ooooo03_oo`00TOoo0P00@?oo00<00?ooool0
3?oo00<00?ooool0>ooo002>ool30013ool00`00ooooo`0<ool00`00ooooo`0jool008coo`8004Ko
o`03003ooooo00_oo`03003oo`0003_oo`00R?oo1000B?oo00<00?ooool03Ooo00<00?ooool0>Ooo
0027ool3001:ool00`00ooooo`0>ool00`00ooooo`0hool008Coo`<004goo`03003ooooo00koo`80
03Woo`00POoo0`00D?oo00<00?ooool03_oo0P00>Ooo001oool2001Cool00`00ooooo`0@ool00`00
ooooo`0fool007coo`<00003ool00?oo05;oo`03003ooooo013oo`03003ooooo03Koo`00N_oo0P00
F?oo00<00?ooool04Ooo00<00?ooool0=Ooo001fool4001Jool00`00ooooo`0Aool2000fool0057o
o`8000Coo`03003ooooo01_oo`<005coo`03003ooooo01;oo`03003ooooo03Coo`00Dooo00H00?oo
ool00?oo000Iool3001Oool00`00ooooo`0Cool00`00ooooo`05ool00`00ooooo`02ool00`00oooo
o`0Vool005;oo`07003oooooool00?oo00005_oo0`00H_oo00<00?ooool05?oo00<00?ooool00ooo
00<00?oo00000_oo00<00?oo00009ooo001Cool01P00ooooo`00ool001Coo`8001Coo`T004Soo`03
003ooooo01?oo`8000Ooo`06003ooooo003oo`009ooo001Aool00`00ool00002ool00`00ool0000A
ool300000ooo003oo`0:ool900002GEMMGieGGEnMEd006DMKCiU7@0C000eool00`00ooooo`0Eool0
0`00ooooo`02ool20003ool00`00ool0000=ool30002ool300001_oo003oo`00ool000;oo`8000So
o`00D_oo00<00?ooool00_oo00<00?ooool03_oo0P002?oo200002F5WHFmQIf5_XFM001eGGEnMEee
OWEMMGieGGEnMEd006DMICiU7VDnIAeU?VDNICh005cnG=eLoUCMG?iLgEcnE=eLoUcM001<g@05000`
ool00`00ooooo`0Fool01@00oooooooo00001?oo00<00?oo00003_oo00<00?ooool00_oo00X00?oo
ool00?oo003oo`00ool000[oo`00I?oo10001_oo100003:E_HfMUKh008FnOEf5_WeMQKimGHFnOEf5
_WeM001eGGEnMEeeOWEMMGieGGEnMEd006DMKCiU7FDnIAe]?VDMICh005dnE=eM?UCMGCiDgEdnE=eM
?UCM001<WECnC9eDoTbM1@00:ooo00<00?ooool05_oo0P000_oo0`000ooo00<00?ooool03Ooo00<0
0?ooool00_oo00T00?ooool00?oo003oo`00ool00`002?oo001Sool30003ool50000>hfMSKf=WHfm
SIf=_HfMSKd008FnQIf5_HFMQKj5WHFmQIf5_XFM001eGGEnMEeeOWEMMGieGGEnMEd006DMICiU7VDn
IAeU?VDNICh005cnG=eLoUCMG?iLgEcnE=eLoUcM001<gDcmC=eDoDcMC?e<g@00?9d01P009Ooo00<0
0?ooool05Ooo0`006?oo00@00?ooooooo`8000;oo`800004ool00?ooool30008ool0063oo`<000;o
o`@0000>UIbMoIFL002=WIFnSIfE_HfMUKj=WIFmSIfE_P80000fOEf5_WeMQKimGHFnOEf5_WeM001e
GGEnMEeeOWEMMGieGGEnMEd006DMKCiU7FDnIAe]?VDMICh005dnE=eM?UCMGCiDgEdnE=eM?P00E?i<
WECnC9eDoTbME?i<W@00A9e<_TBMC;e4WDbn1@008Ooo00<00?ooool05ooo00<00?ooool04ooo00D0
0?oo003oo`0001Koo`00GOoo0`0000?oo`0000000P0004nMoIFMWOfEWIgmUIfMoIFM002=WHfmSIf=
_HfMSKf=WHfmSIf=_HfM0025WHFmQIf5_XFMQKf5WHFnQId007EMMGieGGEnMEeeOWEMMGieG@00IAeU
?VDNICiU7FDnIAiU?P00G?iLgEcnE=eLoUcMG?iDgEcn001DoDcMC?e<gECmC=e<oDcM000lWDbm?9e<
_CbMC;dlWDbm0014_@06000Kool00`00ooooo`0Gool00`00ooooo`0Cool50002ool00`00ooooo`0A
ool005_oo`80000Sool00000002Mo:Gm002MoIFLWOfEW9gmUIbMoIFLWOfEW000SIfE_XfMUKf=WIFn
SIfE_HfMUKj=W@00OEf5_WeMQKimG@0M00007ECMGCiDgEdn001DoTbME?i<WECnC9eDoP00C;e4WDbn
A9e<_DBMC;i4WDbm0014_DAMA;dlGDBmA5d01@005_oo00<00?ooool06?oo00<00?ooool0;Ooo001H
ool600006igLYOfMg9glWMbUo@00WOfEWIgmUIfMoIFMWOfEWIgmUId008fMSKf=WHfmSIf=_HfMSKf=
W@0700007HFMQKf5WHFnQId007ENMGieGGEnMEieOWEMMGieGP00IAeU?VDNICiU7FDnIAiU?P00G?iD
gEcnE=d0200001Y<oDcME?e<gDcm001<_CbMC;dlWDbm?9e<_CbMC;d004Bm?9e4_CbMA;dlWDBm?9d0
03aM1P004?oo00<00?ooool05ooo0P00;ooo001Fool500006IglYOfMo:GmWObUoIglYOfMo:Gm002M
oIFLWOfEW9gmUIbMoIFLWOfEW000SIfE_XfM00D0000/SIfE_HfM001mWHFnQIf5_WfMQKj5WHFnOId0
07EMMGieGGEnMEeeOWEMMGieG@00IAe]?VDMICiU7FdnIAeU?P00GCiDgEdnE=eM?UCMGCiDgEdn001D
oPD0000KE?h004bmA9e<_TBMC;e4WDbnA9d003aMA;e4GDBm?5e4_DAMA;dlG@00?5e4_CaMA;dlGDBm
00L000Woo`03003ooooo01Woo`03003ooooo02coo`00Dooo1@0001RUg:Gl002Mo9gLYOfMg9glWMbU
oIgLWObMg000UIfMoIFMWOfEWIgmUIfMoIFMWOd40000=XfMUKf=WHfmSIfE_HfMSKf=W@00QIf5_HFM
QKj5WHFmQIf5_XFM001eGWEnMEeeOWENMGieGGEnMEh006DMICiU7VDnIAeU?VDNICh005cnE=eLoUCM
G?iDgEcnE=d004cMC?i<gDcmC=e<oPD0000MC;dlWDbm?9e<_CbM000lWDBm?9e4_CbMA;dlWDBm?9d0
03aMA;ddGDBm?5e4_CAMA;dlG@00=5dlG@060003ool00`00ooooo`0Jool00`00ooooo`0[ool0057o
o`80000Jool00000YObMo:GmWObUo000YOfMo:GmWObUoIglYOfMo:GmWO`009FLWOfEW9gmUIbMo@<0
000oWOfEW000SIfE_HfMUKf=WIFmSIfE_HfMUKf=W@00OIf5_XFMQKimWHFnQIf5_WfM001eGGEnMEee
OWEMMGieGGEnMEd006DMKCiU7FDnIAe]?VDM001DgEdnE=eM?UCMGCiDgEdnE=d004bME?i<WECnC9eD
oTbME?h004bm00H0000MA9d003aMA;e4GDBm?5e4_DAMA;d004Bm?5e4_CaMA;dlGDBm?5e4_CaM000l
G4Am?5e4OCaLA7dlG@04000Lool2000/ool004koo`<0000Iool00000YMbUo:GLYObUg:GlYMbUo000
WObMg:GmWMbMo9gLYOfMg9glWM`009FMWOd00`0004RMoIgMWOfEg9gmWMd008fMSKf=WIFmSIf=_HfM
UKf=WHfm0025_XFMQKf5WHFnQIf5_HFMQKj5W@00MEieOWEMMGieGWEnMEeeOWEN001U7FDnIAiU?VDM
ICiU7P00E=eLoUCMG?iDgEcnE=eLoUCM001<gDcnC=e<oDcMC?i<gDcm001<_CbMA;dlWDbm?9d50000
6cbMA;dlWDBm?9e4_@00A;dlGDBm=5e4_CaMA;ddGDBm?5d003AM?5ddGDAM=5dlGCAMA5ddG@02000L
ool00`00ooooo`0Zool004_oo`<0000Iool00000002UoIglYObMo:GmWObUo9glYOfMo000WObUoIgl
YOfMo:GmWObUoIglYOd00`0001jMoIFLWOfEW9gmUIbMoIFLWOfEW000SIfE_HfMUKf=WIFmSIfE_HfM
UKd008FnOIf5_XFMQKimWHFnQIdA00008FDMKCiU7@00E=eM?UCMGCiDgEdnE=eM?UCM001<WECnC9eD
oTbME?i<WECn001<_DBMC;i4WDbmA9e<_TBM000lG@06000054Bm0014_CaMA;dlGDBm?5e4_CaMA;d0
04Am?5a4OCaMA7dlG4Am?5d3000Mool00`00ooooo`0Yool004Woo`80000Iool00000002Uo:GL002U
g:GlYMbUo:GLYObUg:GlYMbUo:GL002Mg9glWMbUoIgLWO`00`0001fMo9gL002Eg9gmWMfMoIGLWOfM
gIgmUMbMoIgM002=WHfmSIfE_HfMSKf=WIFmSIf=_@00QKj5WHFm00@0000AQIf5_XFM001eGWEnMEee
OWENMGieGGEnMEh006DMICiU7P0900007UCMG?iDgEcn001<oDcMC?i<gDcmC=e<oTcMC?d004bm?9e4
_CbMC;dlWDBm?9d003bMA;dlWDBm?9e4_@D0000<A;ddGDBm?5e4_CAMA;d004AM=5dlGCAM0`0000@d
GDAM000001coo`03003ooooo02Woo`00Aooo1@001ZGl00l009glYOfMo:GlWObUoIglYObMo:GmWO`0
09glYOd00`0001^UoIglYOfMo:GmWO`009FLWOfEW9gmUIbMoIFLWOfEW9gmUI`008fMUKf=WIFmSIfE
_HfMUKd01@0001j5_XFMQKj5WHFnQIf5_XFM001eGGEnMEemOWEMMGieGGenMEd006DMKCiU7FDnIAe]
?VDM001DgEcnE=d;000064bME?i<WECn001<_DBMC;i4WDbmA9e<_TBM000lGDBm?5e4_CaMA;dlGDBm
0014_@H00003?5e4_@0000<00008?5e4OCaLA7dlG@00?5`001_oo`8002[oo`00Aooo0P0001FUo:GL
YObUg:GlYMbUo:GLYObUg000YMbUo:GLYObUg:GlYMbUo:GLYO`00`0001ZMo9gLYOfMg9glWMbUoIgL
WObMg000UMbMoIgMWOfEg9gmWMfMoIGLWOfMg@00SIf=_HfM100002jE_HfMUKd008FnQIf5_HFMQKj5
WHFmQIf5_XFM001eGWEnMEeeOWENMGieGGEnMEh006DMICiU7VDnIAeU?VDN001DgEcnE=eLoUCMG?iD
gEcn001<oDbMC?e<W@P0000FA;dlWDbm?9e4_CbM000lWDBm?9e4_CbMA;dlWDBm0014GCAMA5ddGDAM
=5d500001cAM?5ddGDAM=5dlGCAM008001goo`03003ooooo02Ooo`00@Ooo00<00?ooool00ooo0P00
2jGl00L009glYOfMo:GlWObUo@0300006:GmYO`009glYOfMo:GmWObUoIglYOfMo:GmWO`009FLWOfE
W9gmUIbMoIFLWOfEW0D0000jSIfEoHfMUOf=WIGmSIfEo@00QKj5WHFnQIf5_XFMQKj5WHFn001mOWEM
MGieGGenMEeeOWEMOGh006DnIAe]?VDMICiU7FdnIAd005CMG?iDgEcnE=eLoUCMG?h005CnC9eDoTbM
E?i<WECnC9eDoP00C;d600003TBM000lGDBm?5e4_CaMA;dlGDBm0014_CaMA;d2000013aMA;dlGDBm
1@0000A4OCaLA7dlG@8001coo`03003ooooo00Goo`03003ooooo00;oo`03003ooooo01[oo`00@?oo
00<00?oo00001?oo01400?oo002Ug:GlYMbUo:GLYObUg:GlYMbUo:GL002Ug:Gl00<0000FYObUg:Gl
YMbUo:GL002Mg9glWMbUoIgLWObMg:GmWMbMo9gL002Eg9gmWMd50000AIgLWOfMg@00SIfE_IFMUKf=
WIFmUIfE_HfMUKd008FnQIf5_HFMQKj5WHFmQIf5_P00MGieGWEnMEeeOWENMGieGGEn001U?VDMICiU
7VDnIAeU?VDN001DgEcnE=eLoUCMG?iDgEcn001<oDbMC?e<WDcmC9e<oDbM000lWDbm?9e4_CbMC;dl
W@0400001TBm?9e4_CbMA;dlW@@0000;A5ddGDAM=5e4GCAM000dGCaM=5dlG@0400000cAM003oo`0L
ool00`00ooooo`04ool01`00oooooooo003oo`0001_oo`00@?oo00<00?oo00000ooo00@00?oooooo
o`8000VUo0<00005YOfUo:GlWObUo@02YO`00iglYOfUo00200002JGmWObUoIglYOfMo:GmWObUo@04
000099FLWOfEW9gmUIbMoIFLWOfEW000SIfEoHfMUOf=WIGmSIfEoHfMUOd008FnQIf5_XFMQKj5WHFn
QIf5_P00OGieGGEnMEemOPT0000PICiU7FdnIAd005CMG?iDgEcnE=eLoUCMG?h005CnC9eDoTbME?i<
WECnC9d004BMC;e4WDbnA9e<_DBMC;i4W@T0000A?5e4_CaMA;dlGDBm?5e4_CaM000lGDAm?5a4OCaM
A7dlG003000Lool20005ool00`00ooooo`03ool00`00ooooo`0Iool0043oo`03003oo`0000?oo`03
003ooooo00?oo`07002Uo:GLYObUg:GlYM`00P0001JUo:GL002Ug:GlYMbUo:GLYObUg:GlYMbUo:GL
YO`009glWMbUoIgLWObMg080000OYObMg000WMbMoIgMWOfMg9gmWMfMoIgLWOfMg@00SIfE_IFMUKf=
WIFmUIfE_HfMUKd008FnQIf5_HFMQKh02@0000UeOWENMGieGGEn001U?VDMICh02P0001QDgEcnE=eL
oP00C?e<WDcmC9e<oDbMC?e<W@00?9e<_CbMA;dlWDbm?9e4_@00A;d800004SAMA5ddGDAM=5e4GCAM
A5ddG@00=5dlGCAM?5ddGCaM=5dlG@8001coo`03003ooooo00Coo`03003ooooo008001coo`00@?oo
00<00?oo00000ooo0P001Ooo00<00:GlYO`00`001JGl00<009glYOd00ZGl00JMo:GmYObUo9glYOd2
YO`00`00YOfMo00300006YglYOfMo:GmWO`009FLWOfEW9gmUIbMoIFLWOfEW9gmUI`008fMUOf=WIGm
SIfEoHfMUOd7000078FnQIf=_XFMQKh007enMEeeOWEMOGieGGEnMEemOP00ICiU7FdnIAeU?VDMKCiU
7@00E=eM?UCM200000eDoTbME?i<WECnC9d004BMC;e4WDbnA9e<_@0300001dBm?5e4_CaMA;dlGDBm
00@0000A?5e4_CaMA;dlGDBm?5d003aMA7dlG4Am?5e4OCaLA7d0000Mool01`00oooooooo003oo`00
00;oo`03003ooooo01_oo`00@Ooo00<00?ooool00_oo00<00?ooool01Ooo0P0000VUg:GlYMbUo:GL
YObUg:GlYM`00P0000ZUo:GLYObUg:GlYMbUo:GLYObUg0<00009WMbUo9gLYObMg:GlWMbUo9gL0080
000>WOfMgIgmWMbMoIgMWOfMg9gmWMd008fMUKfEW@@0000[UKfEWIFm0025_XFMQKf5WHFnQIf5_HFM
QKh007EnMEieOWEMMGieGWEnMEeeOP00ICiU7FDnIAiU?VDMICiU7P00E=eDoUCMG?iDgECnE=eLoP00
C?d01@0000E<o@00A;dlWDbm00<0000>C;dlWDBm0014_CbMA;dlWDBm?9e4_CbM000dG@H0000<A5d0
03aM=5dlGCAM?5ddGCaM=5dlG@007Ooo00<00?ooool00`000_oo0`006ooo0016ool00`00ooooo`06
ool00`00YObUo009YO`01`00YOfUo:GlWObUoJGl00<000:Uo00E002UoIglYOfMo:GmWObUoIglYOfM
o:Gm002MoIFLWOfEW9gmUIbMoIFL00D0000BSIfEoHfMUOf=WIGmSIfEo@00QKj5WHfnQIf5_XFMSKj5
WHFn0P00021eGGEnMEemOWEMMGieGGen001U?VDMKCiU7FDnIAe]?VDM001DgEdnE=eM?UCMGCiDgEdn
001<oTbMC?i<WDcn1@0001M<_DBMC;i4WDbmA9e<_P00A;dlGDBm?5e4_CaMA;dlG@00?5a4_CaMA;dl
G4Bm00@00007?5e4OCaLA7dlGDAm?5`00P006ooo0P009Ooo0016ool00`00ooooo`07ool03`00YObU
g:GlYMbUo:GLYObUg:GlYMbUo000YObUg00300005ZGLYObUg:GlYMbUo000YObMg:GlWMbUo9gLYObM
g:GlWMbUo000WOfMgIgm100003RMg9gmWMd009FMUKfEWIFmUIfE_IFMUKfEWIFm0025_XFMQKf5WHFn
QIf5_HFMQKj5W@00MEieOWEMMGieGWEnMEeeOP00ICiU7FDnIAiU?VDMICiU7P00E=eDoUCMG?iDgECn
E=eLoP00C?e<WDcn0`0000=<oP00A;d01P0001@lW@00?9e4_CbMA;dlWDBm?9e4_CbM000dGDAM=5e4
GCAMA5ddGDAM1@0000@lGCAM?5ddG@8001coo`03003ooooo02;oo`00AOoo00<00?ooool02Ooo00<0
0:GlYO`02:Gl0`000ZGl00JMo:GmYObUo9glYOd2YO`02`00YOfMo:GmWObUoIglYOfMo:GmWO`01000
01ZMoIFLWOfMW9gmUIbMoIfL002=WIGmSIfEoHfMUOf=WIGmSIfEo@00QKj5WHfnQIf5_XFM4P0000eU
?VDMKCiU7@00E=eM?UCMGCiDgEdnE=eM?P03000034cnC9e<oTbMC?h004bnA9e4_DBMC;i4W@D0000D
?5e4_CaMA;dlGDBm0014_CaLA;dlGDBm?5a4_CaMA;d004Am?5e4O@@00003?5`00?oo01_oo`03003o
oooo02;oo`00AOoo00<00?ooool02_oo00L00:GlYMbUo:GLYObUg00300005JGLYO`00:GlYMbUo:GL
YObUg:GlYMbUo:GLYO`00:GlWMbUo9gLYObMg00300005ZGLYO`009gmWMfMoIgLWOfMgIgmWMbMoIgM
002EWIFmUIfE_IFMUKfEWIFm200001:5WHFmQIf=_HFM001eGWenMEeeOWENOGieGGEn001U?VDMICh:
00005eCM000005cn001<oDbMC?i<WDcmC9e<oP00A;dlWDBm?9e4_CbMA;dlW@00?9d01P000194_@00
A5ddGDAM=5e4GCAMA5ddGDAM000lGCAMA5ddGCaM=5d3000Kool2000Sool004Goo`8000coo`03002U
o:Gl00<000>Uo005[ObUo:Gl002Uo@02YO`01YglYOfUo:GlWObUo@:Uo003002UoIgl00<0000EWObU
oIglYOfMo:Gm002MoIfLWOfEW9gmWIbMoIFLWOfMW000SIfEoHfM00@0000RUOfEW9Gm002=_XFMSKj5
WHfnQIf=_XFMSKj5W@00MEemOWEMOGieGGenMEemOP00KCiU7FdnIAe]?VDMKCiU7@00E=d:00005Dcn
C9e<oTbMC?h004bnA9e4_DBMC;i4WDBmA9d003aMA;dlGDBm?5e4_@04000043aLA;dlGDBm?5a4_CaM
000lG4Am?5e4OCaLA7dlGDAm0P007?oo00<00?ooool08?oo0015ool00`00ooooo`0<ool200005JGL
YObUg:GlYMbUo:GLYObUg:Gl002Uo:GLYObUg:GlYMbUo:GLYObUg00300005:GLYObMg:GlYMbUo9gL
YObUg:Gl002MoIgMWOfMg9gmWMfMoIgLWOd400008iFMUOfEWIGmUIfEoIFMUOd008fmQIf5_HFMSKf5
WHFmQIf=_HFM001eGWenMEeeOWENOGieGGEn001U?VDMICiU7VDnIAd00`0000YDgECnE=eLoUCME?iD
gEcn001<o@D0000CC?h004Bm?9e4_CbMA;dlWDBm?9d003bMA;ddWDBm?9e4_CBMA;d01@0000e4GCAM
A5ddG@00=5dlGCAMA5ddGCaM=5e4G@02000Kool00`00ooooo`0Pool004Goo`8000koo`03002]o:Gl
00:Uo005[ObUo:GlYOb]o002YO`01`00YOfUo:GlWObUoJGl00<000:Uo00B002UoIglYOfMo:GmWObU
oIglYOfMo000UIbMoIfLWOfEW9gm0`0002BUoIgl002EW9GmUIfEoIFLUOfEWIGmUIbEo@00SKj5WHfn
QIf=_XFMSKj5WHfn001mOWEMOGieGGenMEemOWEM001U7FdnIAd300004VDMKCiU7@00E=eLoUCMG?iD
gEcnE=eLoP00C?i<WDcnC9e<oPD0000CA;e4WDbnA9e4_@00A;dlGDBm?5e4_CaMA;dlGDBm0014_CaL
A;d0100000XlG@00?5a4OCaMA7dlG4Am?5e4O@8001_oo`03003ooooo01ooo`00AOoo00<00?ooool0
3_oo00l00:GlYMbUo:GLYObUg:GlYMbUo:GLYO`00:GlYM`00`0001BUg:GlYMbUo:GLYO`00:GlYMbU
o9gLYObUg:GlWMbUo:GL002Mg9gm0`0002BMoIgLWOfMg9gmWM`009FMUOfEWIGmUIfEoIFMUOfEWIGm
002=_HFMQKf5WHfmQIf5_HFMSKd007EnMEimOWEMMGieGWenMEd300006VDMICiU7VDnIAeU?VDN001D
gECnE=eLoUCME?iDgEcn001<oDbMC?e<WDcmC9e<o@00A;d500004TBm0014_CbMA;ddWDBm?9e4_CBM
A;d004AM=5dlGCAMA5ddG@@00006?5ddGDAM=5dlGCAM0P007?oo00<00?ooool07_oo000oool00`00
ooooo`02ool00`00ooooo`0@ool00`00[ObUo002YO`01ZglYObUo:Gl[ObUo0<000>Uo005YOfUo:Gl
YObUo@02YO`02P00YOfMo:GmWObUoIglYOfMo:Gm0`0001^UoIglWOfMo:GmWObMoIglYOfMo000UIbE
oIFMUOfEW9GmUIfEoIFLUOd008fnQIf=_XFMSKh06P0001ADgEcnE=eLoUCM001<WDcnC9e<oTbMC?i<
WDcn001<_TBMA;e4WDbn1@000114_CaMA;dlGDBm?5d003aMA;dlG4Bm?5e4_CaLA;dlG@D00003?5a4
OCaM008001_oo`03003ooooo01koo`00?_oo00<00?oo00000ooo0P004_oo00L00:GlYMbUo:GLYObU
g00300005JGLYO`00:GlYMbUo:GLYObUg:GlYMbUo:GLYO`00:GlYMbUo9gLYObUg00200005jGlYM`0
09gLWOfMg9gmWMbMoIgLWOfMg9gmWM`009FMUOfEWIGmUIfEoIFMUOd01`0000F=_HFMSKf5WHfm00@0
000AMEeeOWENOGieG@00IAiU?VDNICiU7VDnIAiU?VDN001Dg@05000055CM001<WDcmC9e<oDbMC?e<
WDcm0014_CbMA;dlWDBm?9e4_@00A;d600003cBM000dGDAM=5dlGCAMA5ddGCaM=5d003AM?5ddG@06
000Kool00`00ooooo`0Mool0043oo`05003oooooool0000Dool00`00[ObUo0030003YO`01JglYObU
o000YOd00jGl00FUoJGlYObUo:Gm00:Uo003002UoIgl00<0000EWObUoIglYOfMo000WObUoIglWOfM
o:GmWObMoIglYOfMo000UIbEoIFM00@0000:UOfEW9gm002=_XFMSKj5WHfnQId4000067enMEemOWEM
OGieGGenMEd006DMICiU7FdnIAeU?VDMKCiU7@00E=eLoUCMG?iDg@D0000EC9e<oTbMC?i<W@00A9e<
_TBMA;e4WDbnA9e4_@00A;dlGDBm?5e4_CaM00@0000?A;dlG4Bm?5e4_CaLA;dlG@00?5a4OCaMA7dl
G4Am00<001[oo`8001koo`00?_oo0P001?oo00<00?ooool04ooo0P0001FUg:GlYMbUo:GLYObUg:Gl
YMbUo000YObUg:GlYMbUo:GLYObUg:GlYM`00`0001BUg:GlYMbUo:GLYObUg:GlYM`009gLWOfMg9gm
WMbMoIgLWOfMg9gm100000^EWIGmUIfEoIFMUOfEWIGm002=_HFM00<0000=QIf=_HFMSKd007EnMEim
OWEMMGieGWenMEd00P00019U?VDNICiU7VDnIAiU?VDN001DgECnE=eDoUCME?iDg@00C9d500004dbM
000lWDBm?9e4_CbMA;dlWDBm0014_CaMA;ddGDBm?5e4_CAM00D0000?=5e4GCAM?5d003aM=5dlGCAM
?5ddGCaM000lG@0001[oo`03003ooooo01coo`00?_oo00<00?ooool00ooo0P005Ooo00<00:glYO`0
0ZGl00F]o:GlYObUo:gl00:Uo003002UoJGl00:Uo003YOfUo000008000:Uo00B002UoIglYOfMo:Gm
WObUoIglYOfMo000WObUoIglWOfMo:Gm0`0000fUoIgl002EW9gmUIfEoIFLWOfEWIGmUIbMo@020000
:HFMSKj5WHfnQIf=_XFM001eGGenMEemOWEMOGieGGenMEemOP00ICiU7FdnIAeU?VDMKCh005cnE=eL
oUCMG?iDgEcnE=d004BMC?i4WDcnA9d01@0001=4WDBmA9e<_TBM000lGDBm?5e4_CaMA;dlGDBm0014
OCaMA7dlG004000034Bm0014OCaLA7dlGDAm?5a4O@00A7d001[oo`03003ooooo00?oo`D000;oo`03
003ooooo00;oo`03003ooooo00Woo`00?_oo0`000ooo00<00?ooool05Ooo00l00:GlYMbUo:GLYObU
g:GlYMbUo:GLYO`00:GlYM`00`0001BUg:GlYMbUo:GLYO`00:GlYMbUo:GLYObUg:GlYMbUo:GL002M
g9gm0`0000fMoIgLWOfMg9gmWM`009FMUOfEWIGmUIfEo@04000048FMSKf5WHfmQIf=_HFMSKf5W@00
MEeeOWENOGieGGEn2@0001IU?VDNICh005CnE=eDoUCME?iDgECnE=d004bMC;e<WDbmC9e<_DbM000l
W@D0000B?9d003AMA;dlGDBm=5e4_CaMA;d003aM=5e4GCAM?5ddGDAM100000TdGCaM=5dlGCAM?5d0
03aM00006Ooo0P001_oo00L00?ooooooo`00ool00002ool00`00ool0000:ool004?oo`03003ooooo
01Ooo`03002]o:Gl00:Uo006[ObUo:GlYOb]o:Gl0`002ZGl00T00:GmWObUoIglYOfMo:GmWO`01000
00fUoIglYOfMo:GmWObUoIglYOfMo000UIbMo@0300002YgmUIfEoIFL0025WHfnQIf=_XFM2P0000Um
_WEMOKieGGfn001]?VDMKCh02@00019LoUCMG?iDg@00A9e<oTBMC?i4WDcnA9d004BMA;i4WDBmA9d4
00004DBm?5e4_CaMA;dlGDBm0014OCaMA7dlG4Am?5e4OCaLA7d01@0000E4OCaL000lG@0001[oo`03
003ooooo00Coo`07003oooooool00?oo00000_oo00<00?oo00002_oo0013ool2000Iool01`00YObU
g:GlYMbUo:GL00<0000BYMbUo000YObUg:GlYMbUo:GLYObUg:GlYMbUo000YObUg:Gl100000jUg:Gl
YM`009gLWOfMg9gmWMbMoIgLWOfMg9gm0`0000JEoIFMUOfEWIGmUId7000078fMSKf=WHfmSId007EM
OGimGWenMEemOWeNOGieGGen001U?VDMICiU7VDnIAeU?P00E?iDgECn200000e<WDbmC9e<_DbM000l
WDBm?9e4_CbMA;dlW@0500004SAMA;dlGDBm000lGCAMA5ddGCaM=5e4GCAM?5d003aM=5dlG@@00003
=5d00?oo01Woo`03003ooooo00?oo`07003oooooool00?oo00000_oo00<00?oo00002_oo0013ool0
0`00ooooo`0Iool00`00[ObUo0030003YO`01:glYObUo0002ZGl100000>Uo9glYOd00ZGl00ZMo:Gm
YO`009glYOfMo:GmWObUo@<00005YOd009GmUIbMo@040000:iFLWOfEW000QIf=_XFMSKj5WHfnQIf=
_XFM001eGGfnMEem_WEMOKieGGfnMEem_P00KCiU7FdnIAe]?VDMKCh005CnE=eLoUCME?iDgEcnE=d0
04BM00D0000=A9d004BMA;i4WDBmA9e4_TBM000lGDBm?5d01@00014lG4Am?5e4OCaLA7dlGDAm?5a4
O@00A7dlG4Am?5e4OCaL00<001[oo`03003ooooo00;oo`07003oooooool00?oo00000_oo00<00?oo
00002_oo0004ool20002ool400001?oo000000000ooo0`000_oo0P00:Ooo00<00?ooool06_oo0P00
00ZUg:GlYMbUo:GLYObUg:GlYMbUo0800006YMbUo:GLYObUg:Gl0P0000fUg:Gl002Uo:GLYObUg:Gl
YMbUo:GLYObUg002000029gm00000000WOfMg9gmWM`400004YGmUMfMoIGMUOfEgIgmUMd008fMSKf=
WHfmSIf=_HfMSKf=W@80000POGimGWenMEemOWeNOGieG@00IAiU?VDMICiU7VDnIAeU?P00E?iDgECn
E=eDoUCME?iDg@00C9e<_DbMC;e<W@@0000=A;dlWDBm?9e4_CbM000dGDBm=5e4_CAMA;d01000018d
GDAM=5dlGCAMA5ddG@00=5dlGCAM?5ddGCaM=5d003AM000Hool20003ool20004ool00`00ooooo`02
ool00`00ooooo`09ool000?oo`03003oo`0000;oo`<000?oo`05003oooooool00002ool00`00ool0
000[ool2000Lool00`00[ObUo002YO`01JglYObUo:Gl[O`00jGl00<00:GlYO`00`001JGl00H00:Gm
YObUo9glYOd2YO`00iglYOd0000200000jGmWObUo@0400003IglYOd009gmUIbMoIFLWOfEW9gmUIbM
oIFL0080000/SKj5WHfnQIf=_XFMSKj5WHfn001m_WEMOKieGGfnMEem_WEM001U7FdnIAe]?VDMKCiU
7Fdn001DoUCMG?iDgECnE=eLoUCM0014WDcnA9e<oTBMC?i4W@@0000>A;e4WDBn0014_CaMA;dlGDBm
?5e4_CaM000lG0H0000<A7dlG000?5e4OCaLA7dlGDAm0014O@006_oo00<00?ooool05ooo0003ool0
0`00ool00004ool01@00oooooooo00000ooo00D00?ooool00?oo00<002Woo`03003ooooo01coo`0<
002Uo:GLYObUg:GlYMbUo:GLYObUg:Gl0`0000nUo:GLYObUg:GlYMbUo:GLYO`00:GlYMbUo:GLYO`0
0`0000>Uo:GL00000`0001VUoIgLWObMg:GmWMbMo000WOfEgIGmUMfMoIGMUOfEgIgmUMfEo@00SKf=
WHfmSIf=_@0I00004ECnE=eDoUCME?h004bmC9e<_DbMC;e<WDbmC9d003bMA;d01@0000m4_CAMA;dd
GDBm=5e4_CAM000dGCaM=5dlGCAM?5d01@0000PlGCAM?5ddGCaM000lG@006_oo00<00?ooool05_oo
0003ool01000ooooo`000_oo0P000ooo00<00?ooool00P0000Coo`00003oo`<002Woo`8001koo`80
00>Uo003[ObUo:Gl00<000:Uo003002Uo:Gl00RUo003002UoJGl00800003YOfUo000008000:Uo00:
002UoIglYOfMo:GmWObUoIglYOd2000029FLWOfEW9gmUIbMoIFLWOd700006HfnSIf=_XfMSKh007fn
MEem_WEMOKieGGfnMEd006DMIGiU7FenIAeUOVDMKGh005Cn00D0000@G?h004cnA9e<oTBMC?i4WDcn
A9d003bMA;e4WDBm?9d300004CaMA;dlGDBm?5e4_CaM000lG4Am?5e4OCaLA7dlGDAm?5`01@0000Dl
GDAm0014O@0001Soo`8001Soo`000_oo00D00?ooooooo`0000Ooo`03003ooooo037oo`80027oo`03
002Ug:Gl00<0000@YObUg:GlYMbUo:GL002Ug:GlYMbUo:GLYObUg:GlYM`300006JGL00000000YMbU
o:GLYObUg:Gl002Mo9gLYOfMg9glWMbUoIgLWObMg000UMfEoIGM00@0000UWOfEgIgm002=_HfMSKf=
WHfmSIf=_HfMSKd007fnOEim_WEMOKimGWfnMEd006DNICiU7VDnIAiU?VDNICh005CnE=eDoUCME?h0
1@0000e<_DbMC;e<WDbm0014_CbMA;dlWDBm?9e4_@0500004TBm=5e4_@00?5ddGCaM=5dlGCAM?5dd
GCaM000lGCAM?5ddG@D001[oo`03003ooooo01Goo`000_oo0P0000?oo`0000001_oo0P009ooo1@00
0_oo00<00?ooool00_oo00<00?ooool08Ooo0P000ZGl00F]o:GlYObUo:gl00>Uo003002Uo:Gl00>U
o0<00004YO`000000002YO`01YglYOfUo:GlWObUo@:Uo00:002UoIglYOfMo:GmWObUoIglYOd40000
;YFLWOfEW9gmUIbMoIFLWOd008fnSIf=_XfMSKj=WHfnSIf=_P00OKieGGfnMEem_WEMOKieG@00IAeU
OVDMKGiU7FEnIAe]OP00E?i<gECnE=eDoTcME?h004bn1@0000e<oP00A;dlWDBmA9e4_CbMA;d004Bm
?5a4_@05000044Am?5a4OCaMA7dlG4Am?5e4O@00A7dlGCam?5a4OCaM0`006Ooo00<00?ooool05Ooo
000hool01`00oooooooo003oo`0000?oo`8002?oo`0>002Ug:GlYMbUo:GLYObUg:GlYMbUo:GL002U
g0<0000HYMbUo000002Ug:Gl002Uo:GLYObUg:GlYMbUo:GLYObUg000WMbMo9gLYOfMg9gl0`0003NU
o9gL002EgIgmWMfMoIGMWOfMgIgmUMfMo@00SKf=WHfmSIf=_HfMSKf=WHfm001m_WeNOKieGGfnOEim
_WEM001U7VDnIAiU?VDNICiU7VDn001DoUCME?iDgECnE=eDoP00C;dlWDbm?9e<_@0400003CbMA;dl
WDBm?9e4_@00A5ddGDAM=5e4GCAM00@0000A?5ddGCaM=5dlGCAM?5d003aM=5dlGCAM?5ddG@00=5d0
000Hool2000Fool003Soo`07003oooooool00?oo00000ooo00<00?ooool08ooo00D00:GlYObUo:gl
00>Uo003[ObUo000008000:Uo0<000:Uo005[ObUo:Gl002Uo@02YO`02YglYOfUo:GlWObUoJGl002M
o:Gm0`0001NUoIglYOfMo:GmWO`009FLWOfEW9gmUIbMoIFLWOfEW9gm002=_XfMSKj=WHfn01T0000=
E?iDgECnC=eDoP00C;i4WDbnA9e<_TBMC;h0100000i4WDBm?9d003aMA;dlG4Bm?5e4_CaLA;d004Am
1P0000TlG@00?5a4OCaM?7dlG4Am?5d00P006_oo00<00?ooool04ooo000hool01`00oooooooo003o
o`0000?oo`03003ooooo02Coo`06002Ug:GlYMbUo:GL0`0000>Ug:Gl00000P0000VUo:GLYObUg:Gl
YMbUo:GLYO`00P0000RUg:GlYMbUo:GLYObUg:Gl0`0001>Uo9gLYObMg:GlWMbUo9gLYObMg000UMfM
oIgMWOfEgIgmWMfMo@0700006HfmSIf=_HfMSKd007fnOEim_WeMOKimGWfnOEd006DNICiU7VDnIAiU
?VDNICh005Cn00D0000<E?h004bm?9e<_CbMC;dlWDbm0014_CBM1@0000ldGDAM=5e4GCAMA5ddGDAM
000lGCAM?5ddGCaM=5d0100000PlGCAM?5ddGCaM000lG@006Ooo00<00?ooool04ooo000hool01`00
oooooooo003oo`0000?oo`03003ooooo02Goo`03002Uo000008000:Uo0<000:Uo005002Uo:GlYOb]
o003YO`01JglYObUo:Gl00000ZGl00>Mo00000000P0001:UoJGl002Mo:GmWObUoIglYOfMo:GmWObU
oIgl002EW9gmUI`400009IgmUObMo@00UOf=WIGnSIfEoHfMUOj=WIGm001m_WeMOKieGGfnOEem_WEM
001U7FEnIAeUOVDMIGiU7FEn001DoTcME?i<gECn00D0000;C;i4WDbnA9e<_P00A;dlGDBm?5e4_@04
00003caLA;dlGDBm?5a4_@00A7dlG4Am?5e4OCaLA7dlG@0400001Sam?5a4O@00?7d001Soo`8001Co
o`00=ooo0P001?oo00@00?ooooooo`8002Koo`<00003YMbUo0000080000AYObUg:GlYMbUo:GL002U
g:GlYMbUo:GLYObUg:GlYMbUo00400004ZGLYObUg:GlYMbUo:GL002Mg:GlWMbUo9gLYObMg:GlWMbU
o0@0000^WMfMoIgLWOfMgIgmWMbMo@00SKf=WHfmSIf=_HfMSKf=W@00OEem_WeNOKimGGfnOEim_P00
ICiU7VDnIAiU?VDNICiU7VDn001DoUCME?iDgECnE=eDoP00A;d500002Tbm0014_CBMA;dlWDBm=9d0
03AM1P0000e4G@00?5ddGCaM=5dlGCAM?5ddG@00=5dlG@03000013aM000lG@006Ooo00<00?ooool0
4Ooo0011ool00`00ooooo`0Rool30003ool20002YO`01JglYObUo:Gl[O`00jGl00D00:GlYObUo:gl
00:Uo0<000:Uo005002Uo:GlYObUo@03YO`02JGmYO`009glYOfMo:GmWObUo@030000=jGmWO`009Gl
WOfMo9gmUObMoIglWOfEo9gm002EoHfMUOj=WIGmSIfEoXfM001eGGfnOEem_WEMOKimGGfn001UOVDM
IGiU7FEnIAeUOVDMIGh005CnC=eDoTcME?i<gECn001<_TBMC;i4WDbn00@0000<?5e4_CaMA;dlG@00
?5e4_CaLA;dlGDBm100000`lG4Am?5e4OCaLA7dlG@00?5a4OCaMA7d4000Iool00`00ooooo`0Aool0
047oo`80027oo`8000Ooo`0?002Ug:GlYMbUo:GLYObUg:GlYMbUo:GL002Ug:Gl00<0000CYObUg:Gl
YMbUo:GL002Ug:GlYMbUo:GLYObUg:GlYM`009gLYO`00`0001NUo:GLYObUg:GlYM`009gLWOfMgIgm
WMbMoIgMWOfMg9gm002=_HfMSKf=WHfm01T0000=E?iDgECnE=d003bMA;dlWDBm?9e4_CbMA;d01000
00`lWDBm=9d003AM?5ddGCaM=5dlGCAM?5d500002SaM=5dlG@00?5ddGCaM=5dlGCAM0`006?oo0P00
4_oo0011ool00`00ooooo`0Mool3000:ool01@00YObUo:Gl[O`00jGl00>]o:GlYO`00`000ZGl00F]
o:GlYObUo:gl00>Uo005002Uo:GlYObUo@03YO`05jGm00000000YOfMo:GmWObUoIglYOfMo:GmWO`0
09GlWOfMo9gmUObMoIglWOd01`0001VEoHfMUOf=W@00OEf5_WeMOKimGHFnOEem_P00KGiU7FEnIAe]
OVDMIGiU7Fen001DoP0400003DcM0014WDbnA9e<_TBMC;i4W@00?5e4_CaM00D0000<?5e4_CaLA;dl
GDBm?5`003aM?7dlG4Am1@0000U4OCaLA7dlGDAm?5`003aM00005?oo0`0000?oo`00ool04Ooo0007
ool3000gool00`00ooooo`0Jool3000>ool200001ZGlYMbUo:GLYObUg080000DYObUg000YMbUo:GL
YObUg:GlYMbUo:GLYO`00:GlYMbUo:GLYObUg080000BYObUg000YMbUo:GLYObUg:GlYMbUo:GLYObU
g000WMbMoIgM100001FMoIgLWOd009FmSIfE_IFMUKf=WIFmUId007fMOKimWWfnOIem_WfNOKh00P00
00eU7VDnIAiU?VDNICiU7VDn001DoTcME?iDg@0400003DBm?9e4_CbMA;dlW@00=5e4_CAMA;ddGDBm
00<0000>?5ddGCaM=5dlGCAM000dGCaM=5dlGCAM?5ddG@<00008=5dlGCAM?5ddG@00=5d000ooo`@0
00Coo`03003ooooo013oo`002?oo00<00?ooool0=_oo00<00?ooool05ooo0`004ooo00<00:GlYO`0
0`0000>Uo:glYO`00ZGl00D00:GlYObUo:gl00>Uo006[ObUo:Gl002UoJGl0`001JGl00/009glYOfM
o:GmWObUoIglYOfMo:Gm00@0000[WObMoIglYOfMo9gmWObUo@00UOf=WIGmSIfEoHfMUOf=W@00OEf5
_WeMOKimGHFnOEem_WeM001U7FEnIAe]OVDMIGiU7@00C=eDoTcME?i<gECnC=d0100000a<_TBMC;i4
W@00?5e4_CaMA;dlGDBm?5d400003DBm?5e4_CaL000lGCam?5a4OCaM?7dlG4Am00D00004A7d004Am
000<ool30008ool00`00ooooo`0@ool000Coo`8000;oo`<000?oo`8000;oo`<000?oo`800003ool0
000000;oo`03003ooooo01koo`8001Koo`<001Ooo`800009YMbUo:GLYObUg:GlYMbUo:GL00800008
YObUg:GlYMbUo:GLYObUg0<0000@YMbUo:GLYObUg:GlYMbUo:GL002Ug:GlYMbUo:GLYO`300007:Gl
YM`009gLWOfMg9gmWMbMoIgLWOfMg9gm002E_HfMUKfEWIFmSIfE_IFM001mWGfnOIim_WfM2@0000iU
7VDnIAh005CME?i<gECnE=eDoTcM000lWDBm1@0000]4_CAMA;ddGDBm=5e4_CAM000dGCaM00D0000=
?5ddGCaM=5dlGCAM?5ddG@00=5dlGCAM?5d01@002?oo0`003?oo00<00?ooool03ooo0003ool01P00
ooooo`00ool000;oo`03003oo`0000;oo`04003ooooo0003ool01P00ooooo`00ool000;oo`03003o
oooo01koo`03003ooooo01;oo`<001_oo`04002Uo:Gl[O`3YO`01ZglYObUo:Gl[O`000:Uo003[O`0
0000008000:Uo003002Uo:Gl00RUo003002Mo:Gm00<0000GYOfUo:GlWObUoJGl002Mo:GmWObMoIgl
YOfMo9gmWObUo@00UOf=WIGmSIfEo@0800002GfMQKimWHFnOId005dNIGiM7@0700002dcME?i<gECn
C=d004BMA;e4WDbnA9d0100000a4_CaMA;dlGDBm0014OCaMA7dlG4Am?5d300003SaM?7dlG4Am?5dl
OCaL000lGCam?5a4OCaM?7d30003ool4000?ool00`00ooooo`0?ool000?oo`06003ooooo003oo`00
0_oo00<00?oo00001Ooo00D00?ooooooo`0000;oo`03003oo`0000;oo`03003ooooo01koo`80013o
o`<001ooo`0;002Uo:GLYObUg:GlYMbUo:GLYObUg00400004JGlYMbUo:GLYObUg:Gl002Uo:GLYObU
g:GlYMbUo:GLYO`00`0001>Uo:GLYObUg:GlYMbUo:GLYObUg000WMbMoIgLWOfMg9gmWMbMo@070000
69GmUIfEoIFM001mWGfnOIim_WfMOKimWWfnOId006DNICiU7VDnIAiU?VDN001<g@D0000:C=d003bM
A;dlWDBm?9e4_@00A;d500002DBm000lGCAM?5ddGCaM=5dlG@0500003CaM=5dlGCAM000dGCaM=5dl
GCAM?5d003aM00<001?oo`03003ooooo00ooo`000ooo00<00?ooool01@0000?oo`0000000P000_oo
0P001?oo0P0000?oo`0000000P008Ooo00<00?ooool03?oo0`008ooo00@00:GlYOb]o0>Uo0<00003
YOb]o00000:Uo005[ObUo:GlYOb]o002YO`00`00YObUo004YO`200001JglYO`009glYOd00ZGl00^M
o:GmYObUo9glYOfUo000WObUoIgl00@0000<YOfMo:Gm002EoIFMUOfEWIGmUIfEoIFM0P0001J5_WfM
QKimWHFnOIf5_WfM001M7VEnGAeUOUdNIGiM7@00C=e<oTcME?i<g@@0000;A;e4WDbnA9e4_@00A;dl
GDBm?5e4_@0400002SaMA7dlG4Am?5e4O@00A7dlGCam1@0000Y4OCaM?7dlG4Am?5d003aLA7d001Co
o`03003ooooo00ooo`000ooo00@00?ooool000Koo`03003ooooo02?oo`D000;oo`03003ooooo00?o
o`03003ooooo00Woo`<002Ooo`03002Uo:GL00<0000CYMbUo:GLYObUg:Gl002Uo:GLYObUg:GlYMbU
o:GLYO`00:GlYM`00`00012Ug:GlYMbUo:GL002Ug:GlYMbUo:GLYObUg:GlYMbUo0@0000[WMbUoIgL
WObMg:GmWMbMo000UOfEWIGmUIfEoIFMUOfEWIGm001m_WfNOKimWGfnOIim_WfM001U7VDnIAiU?VDN
ICiU7P00C=e<oTcMC?i<gDcnC=d0100000]4_CbMA;d004Bm=5e4_CAMA;ddGDBm00D0000:?5ddGCaM
000lGCAM?5ddGCaM=5d300002CAM?5ddGCaM=5d003AM?5d0000Cool00`00ooooo`0?ool000Coo`80
00goo`03003ooooo01ooo`07003oooooool00?oo00001?oo00<00?ooool01ooo0P00:ooo0P0000>U
o:glYO`00ZGl00J]o:GlYObUo:gl0002YO`01ZglYObUo:Gl[ObUo0<000>Uo009[ObUo:GlYOb]o:Gl
002Mo:Gm00:Uo003WObUo@000080000EYOfUo000WObUoIglYOfMo:GmWObUoIgl002EWIGmUIfEoIFM
UOfEWIGm0100000>GAiUOUdM001<gDcnC=eDoTcMC?i<g@00?9e4_@D0000;A;dlGDBm?5e4_CaMA;d0
04Am?5e4O@0500001dAm?5dlOCaLA7dlGCam00D00005A7dlG@00?5`0000Cool00`00ooooo`0?ool0
03Goo`03003ooooo00?oo`04003oooooool20006ool3000^ool04000YObUg:GlYMbUo:GLYObUg:Gl
YMbUo000YObUg:Gl1000012Ug:Gl002Uo:GLYObUg:GlYMbUo:GLYObUg000YMbUo0<0000DYObUg:Gl
YMbUo:GL002Mg9glWMbUoIgLWObMg:GmWM`009FMUOfEW@@0000@WOfEgIgm0025_XFNQKimWHFnQIj5
_WfM001U7VDnIAh700002dcMC?i<gDcn0014_CbMA;dlWDBm?9d00`0000ddGDBm=5e4_CAMA;d003aM
=5dlGCAM?5ddG@0300002SAM?5ddGCaM=5dlG@00?5ddGCaM100000<dG@00ool04Ooo00<00?ooool0
3ooo000eool01000oooooooo0P001?oo00<00?ooool00_oo0`00<_oo00@00:GlYOb]o0>Uo004[ObU
o:GlYO`400001JglYObUo:Gl[O`00ZGl00<00:glYO`00ZGl00F]o:GlYObUo:gl00<00005YOfUo:Gl
YObUo@03YO`02jGmYO`009glYOfMo:GmWObUoIglYOd0100001^EW9gmUIbMoIFLWOfEW9gm0025_WfM
QKimWHFnOIf5_WfM001M7VEnGAeUOUdNIGiM7@00A9d0100000U<oP00A;hlWDBm?9e4_SbMA;d01000
00`lGDBm?5d003aLA7dlGDAm?5a4OCaMA7d500002DAm?5dlO@00A7dlGCam?5a4O@04000Bool00`00
ooooo`0>ool003Goo`05003oooooool00005ool5000fool200001ZGLYObUg:GlYMbUo080000CYMbU
o000YObUg:GlYMbUo:GLYObUg:Gl002Uo:GLYObUg:GlYM`00P0001:Uo:GL002Ug:GlYMbUo:GLYObU
g:GlYMbUo:GL002Mg9glWM`400008jGlYM`009GMWOfEgIgmUMfMoIGMWOfEg@00OIf5_XFNQKimWHFn
QIj5_WfM001U7VDnIAiU?VDNICiU7P00C=e<oTcMC?d0100000TlWDBm?9e4_CbMA;d003aM=5d01@00
00`dGCaM=5dlGCAM?5ddG@00=5dlGCAM?5d500002CaM=5dlGCAM?5d003aM=5d0000Aool00`00oooo
o`0>ool003Coo`8000?oo`<000?oo`8003_oo`03002Uo:gl00<00006[ObUo:GlYOb]o0000ZGl00F]
o:GlYObUo:gl00:Uo003002]o:Gl00<000>Uo005[ObUo000YObUo@03YO`01JGmYObUo:GlYOd01000
01NMo:GmWObUoIglYOfMo000UIbMoIFLWOfEW9gmUIbMoIFL001mWHFnOIf5_WfM00T0000:GAiUOUdM
0014WDcnA9e<oTBMC?h400002SbMA;hlW@00?5a4_CaMA;dlG4Bm0`0000i4OCaMA7dlG4Am?5d003aL
A7dlGCam?5a4OCaM0`0000LlGCam?5a4O@00?7d0000Aool00`00ooooo`0>ool0043oo`03003ooooo
03[oo`80000BYObUg:GlYMbUo:GLYObUg:Gl002Uo:GLYObUg:GlYMbUo:GL0`00012Ug:GlYMbUo:GL
YObUg:GlYM`00:GLYObUg:GlYMbUo0<0000EYObUg000YMbUo:GLYObUg:GlYMbUo:GL002EgIgmUMfM
oIGMWOfEgIgm00H00009QIf5_XFNQKj5W@00GAiM?UdN00H00008C?i<gDcmC=e<oP00A;ddW@D00007
=5dlGCAM?5ddGCaM=5d0100000dlGCAM?5ddG@00=5dlGCAM?5ddGCaM=5dlG@0400001CAM000dGCaM
00004?oo00<00?ooool03_oo0011ool2000kool00`00YOb]o003YO`01ZglYObUo:Gl[O`000:Uo003
[O`00000008000:Uo003002]o:Gl00:Uo009[ObUo:GlYOb]o:Gl002Uo:Gm00<0000D[ObUo:GlYOb]
o:Gl002Mo:GmWObUoIglYOfMo:GmWO`009FLWOfEW0@0000DWOfMo000QIf5_XFMQKj5WHFnQIf5_XFM
001M7UenGAiMOUdNGGiM7P@00009C?i4W@00?5e4_CaMA;dlGDBm00<00009A;dlGDBm?5a4_CaM000l
G4Am00D0000<?7dlG4Am?5dlOCaLA7dlG@00?5a4OCaL0`0000<lGCam00003ooo00<00?ooool03_oo
0013ool00`00ooooo`0iool02P00YMbUo:GLYObUg:GlYMbUo:GL100000NUo:GLYObUg:GlYMbUo002
00002:GLYObUg:GlYMbUo:GLYO`300004ZGlYMbUo:GLYObUg:GlYMbUo000YObUg:GlYMbUo:GLYObU
g0D00007WMbMoIgMWOfMg9gmWMd00P0001>5_XFNQKj5WHFnQIj5_XFM001M7UdnGAiM?UdNGCiM7P00
?9e4_P0400001cBMA;ddWDBm=9e4_CBM00@0000:?5ddGCaM000lGCAM?5ddGCaM=5d3000033AM?5dd
GCaM=5dlGCAM000dGCaM=5dlG@@000ooo`03003ooooo00koo`00A?oo00<00?ooool0>Ooo00<00:Gl
[O`00jGl00J]o000002Uo:gl0002YO`01JglYObUo:Gl[O`00jGl00@00:GlYObUo0@00005[ObUo000
YOb]o003YO`02JglYObUo:Gl[O`00:GmWObUo@040003YO`04@00WObMoIglWOfMo9gmWObMoIglWOd0
08FnQIf5_XFMQKh01P0000YM7UenGAiMOP00A;hlWDBn?9e4_P@00008?5e4_CaMA;dlG@00?5a4O@D0
0007?7dlG4Am?5dlOCaLA7d01@0000XlOCaLA7dlG@00?5a4OCaL?7dlG0<000koo`03003ooooo00ko
o`00AOoo00<00?ooool0>Ooo00<00:GLYO`00`0000nUo:GLYObUg:Gl002Uo:GLYObUg:GlYMbUo:GL
YO`01000016Ug:GlYMbUo:GLYObUg000YMbUo:GLYObUg:GlYMbUo:GL00@0000AYObUg:GlYMbUo:GL
YObUg000WMfMoIgLWOfMgIgmWMbMo@0700001XfmSIf=_HfM001=7P@0000:GCh004Bm?9e4_SbMA;dl
W@00=5d500001cBM000dGCaM=5dlGCAM00<0000:=5dlGCAM?5ddGCaM000lGCAM?5d500002CaM=5dl
GCAM?5d003aM=5d0000>ool00`00ooooo`0=ool004Koo`8003[oo`800005[ObUo:GlYOb]o003YO`0
1Jgl002Uo:Gl[O`00jGl0P000ZGl00D00:GlYObUo:gl00>Uo005[ObUo000YOb]o003YO`01Zgl0000
0:Gl[O`000:Uo005YOfUo:GlYObUo@03YO`01000WObMoIgl1000016UoIglYOd008fnSIf=_XFMSKj=
WHfnQId004dNECi=7UDn00D0000:A;hlWDBn?9d003aMA;dlGCbm?5d400001DAm?5e4OCaLA7d01000
00/lGCam?5`003aM?7dlG4Am?5dlOCaL00<00008?5a4OCaL?7d004Am?5`000goo`03003ooooo00go
o`00B?oo00<00?ooool0>?oo00h00:GLYObUg:GlYMbUo:GLYObUg:Gl002Uo:GL0`0001:Ug:GlYMbU
o:GL002Ug:GlYMbUo:GLYObUg:GlYM`00:GLYO`300003jGlYMbUo:GLYO`00:GlYMbUo:GLYObUg:Gl
YMbUo00400006YgLYObUg:GlWMbUo:GLYO`008fmSIf=_HfMSKf=WHfmSId004dNECi=7UDnCAiE?P00
?;d400002CbM000dGCaM=5dlGCAM?5ddG@0400001SaM=5dlG@00?5ddG@D00008=5dlGCAM?5ddGCaM
=5dlG@D00004?5d003aM000=ool00`00ooooo`0=ool004Woo`03003ooooo03Soo`03002Uo:gl00>U
o004[ObUo:GlYO`300000jGl[ObUo002YO`01JglYObUo:Gl00000jGl00F]o:GlYObUo:gl00<00005
[ObUo:GlYOb]o003YO`01Jgl002Uo:GlYOd00jGl0P000ZGl014009glYOfMo:GmWObUoIglYOfMo:Gm
002=_XfMSKj5WHfn00H00009CAiE?TdNECh004Bn?9e4_CbM00@00009A;dlGCbm?5e4_CaM000lG4Am
00D00005?7dlG4Am?5dlO@0300002cam?5a4OCaM?7dlG4Am000lOCaLA7d01@003?oo00<00?ooool0
3Ooo001:ool00`00ooooo`0hool01`00YMbUo:GLYObUg:Gl0080000AYMbUo000YObUg:GlYMbUo:GL
YObUg:GlYM`00:GLYObUg00400004:GlYM`00:GLYObUg:GlYMbUo:GLYObUg:Gl002Uo:GL0`0000nU
g:GlYMbUo:GL002Ug:GlWMbUo:GLYObMg:GlYM`01P001_oo100000QE?P00?;ddWCbm=9dl_CBM1000
00XlGCAM?5d003aM=5dlGCAM?5ddG@<00005=5dlGCAM?5ddG@0500002cAM?5ddG@00=5dlGCAM?5dd
G@00=5d00P002ooo00<00?ooool03Ooo001;ool2000iool00`00YOb]o00300001ZglYObUo:Gl[O`0
00:Uo005[ObUo:GlYOb]o002YO`400000jGl[ObUo002YO`01JglYO`00000[O`00jGl00B]o:GlYObU
o0<00003YOb]o:Gl00:Uo00:[ObUo:Gl002UoIglYOfMo:GmWO`3000@ool4000023bMA;dlWDBn?9d0
03aLA7d500001cam?5a4OCaM?7dlG4Am00<00008A7dlGCam?5`003aL?7dlG0D00009?5dlOCaLA7dl
G@00?5a4O@0000[oo`03003ooooo00goo`00COoo00<00?ooool0=ooo0P00012Uo:GLYObUg:GlYMbU
o:GLYO`00:GlYMbUo:GLYObUg080000AYObUg000YMbUo:GLYObUg:GlYMbUo:GLYO`00:GlYMbUo004
00003jGLYO`00:GlYMbUo:GLYObUg:GlYMbUo000YObUg003000Gool300002CBM?;d003aM=5dlGCAM
?5ddG@03000023AM?5ddGCaM=5dlG@00?5d300002CaM000lGCAM?5ddGCaM=5dlG@03000023aM=5dl
GCAM000dGCaM000:ool00`00ooooo`0<ool004koo`03003ooooo03Ooo`03002Uo:gl00>Uo006[ObU
o:GlYOb]o0000ZGl0`0000>Uo:glYO`00ZGl00D00:GlYObUo:gl00>Uo003[ObUo00000<000:Uo006
[ObUo:GlYOb]o0000ZGl00J]o:GlYObUo:glYO`3000Mool400001cam?5a4OCaM?7dlG4Am00@00008
?5dlOCaL000lGCam?5a4O@<00008A7dlG3am?5a4OCaL?7dlG0H00003?7dlG00000[oo`03003ooooo
00coo`00Cooo00<00?ooool0=ooo0P0000RUo:GLYObUg:GlYMbUo:GL0`0000nUg:GlYMbUo:GLYObU
g:Gl002Uo:GLYObUg:GlYM`00`00012Ug:Gl002Uo:GLYObUg:GlYMbUo:GLYO`00:GlYMbUo0@002?o
o`<00009=5dlGCAM?5ddGCaM000lGCAM00D00005=5dlGCAM?5ddG@0300002cAM?5ddGCaM=5dlGCAM
000dGCaM=5d01@002Ooo00<00?ooool03?oo001@ool2000iool01000[ObUo:Gl100000>Uo:gl0000
0ZGl00F]o:GlYObUo:gl00:Uo003002]o:Gl00<000>Uo005[ObUo:Gl002]o003YO`01:glYObUo:Gl
1000:_oo0`0000XlGCam?5`003aL?7dlG4Am?5`lO@<00005?7dlG4Am?5dlO@0500002dAm?5`lO@00
A7dlG3am?5a4O@00?7d00P002?oo00<00?ooool03?oo001Bool00`00ooooo`0gool300004:GlYMbU
o:GLYObUg:Gl002Uo:GLYObUg:GlYMbUo:GL0`00012Ug:GlYMbUo:GLYObUg:GlYM`00:GLYObUg:Gl
YMbUo080037oo`D00007=5dlGCAM?5ddGCaM=5d0100000LlGCAM?5d003aM=5dlG@0500002CaM=5dl
GCAM?5d003aM=5d00007ool00`00ooooo`0<ool005?oo`03003ooooo03Ooo`03002]o:Gl00:Uo006
[ObUo:GlYOb]o0000ZGl00>]o00000000P000ZGl00<00:glYO`00ZGl00V]o:GlYObUo:glYO`00:Gl
[O`00`00=ooo0`0000TlOCaLA7dlG3am?5`003aL?7d01@0000I4OCaM?7dlG4Am?5d3000023aL?7dl
G000?5`lOCaL0006ool00`00ooooo`0<ool005Coo`03003ooooo03Ooo`09002Uo:GLYObUg:GlYMbU
o:GL00@00007YObUg:GlYMbUo:GLYO`00P0000RUg:GlYMbUo:GLYObUg:Gl0`00?Ooo0`0000XlGCAM
?5d003aM=5dlGCAM?5ddG@<00006=5dlGCAM?5ddGCaM1P0000<dGCaM00001_oo00<00?ooool03?oo
001Eool2000hool00`00[ObUo002YO`01Zgl00000:Gl[O`000:Uo005[ObUo:GlYOb]o003YO`01000
YObUo:Gl1000@ooo1@0000M4OCaL?7dlG4Am?5`lO@04000023aLA7dlGCam0014OCaM?7d50006ool0
0`00ooooo`0;ool005Ooo`03003ooooo03Koo`03002Uo:GL0080000?YObUg:GlYMbUo000YObUg:Gl
YMbUo:GLYObUg:Gl00@004_oo`<00009=5dlGCAM?5ddGCaM000lGCAM0080000:?5ddG@00=5dlGCAM
?5d003aM=5d20005ool00`00ooooo`0;ool005Soo`03003ooooo03Koo`8000>Uo006[ObUo:GlYOb]
o0000ZGl00B]o:GlYObUo08005;oo`<00008?5a4OCaL000lG4Am?5`lO@@00009?5a4OCaM?7d004Am
?5dlO@0000Coo`03003ooooo00_oo`00FOoo00<00?ooool0=_oo00d00:GlYMbUo:GLYObUg:GlYMbU
o000YObUg003001Gool500001SAM?5ddGCaM=5dlG@<00007?5ddGCaM000lGCAM00001?oo00<00?oo
ool02ooo001Jool2000gool00`00[ObUo002YO`01:glYObUo:Gl0`00G_oo0`0000I4OCaL?7dlG4Am
?5`400001Cam0014OCaM00000ooo00<00?ooool02ooo001Lool00`00ooooo`0eool01000YObUg:Gl
1000I?oo0`0000LlGCAM?5ddG@00=5dlG@050003ool00`00ooooo`0;ool005goo`03003ooooo03Go
o`<006_oo`D00006?7dlG4Am?5`003aL0P000_oo00<00?ooool02ooo001Nool00`00ooooo`0dool0
0`00ooooo`1_ool300001cAM?5ddG@00=5dlG@0000;oo`03003ooooo00[oo`00Gooo0P00=?oo00<0
0?ooool0L_oo100000HlOCaLA7d00?oo000<ool0067oo`03003ooooo037oo`03003ooooo07Goo`80
0005?5ddG@00ool0000<ool006;oo`03003ooooo033oo`03003ooooo07Ooo`D000coo`00Hooo00<0
0?ooool0;ooo00<00?ooool0N?oo00@00?oo000000coo`00I?oo0P00;ooo00<00?ooool0N?oo00@0
0?ooool000coo`00I_oo00<00?ooool0;?oo00<00?ooool0NOoo00<00?oo00003?oo001Wool00`00
ooooo`0[ool00`00ooooo`1jool00`00ool0000;ool006Soo`03003ooooo02[oo`03003ooooo07_o
o`8000_oo`00JOoo0P00:_oo00<00?ooool0Nooo0P002ooo001[ool00`00ooooo`0Wool00`00oooo
o`1kool2000;ool006coo`03003ooooo02Koo`03003ooooo07Ooo`@000goo`00KOoo00<00?ooool0
9Ooo00<00?ooool0Looo10004Ooo001^ool2000Uool00`00ooooo`1_ool4000Eool0073oo`03003o
oooo02;oo`03003ooooo06_oo`@001Woo`00LOoo00<00?ooool08Ooo00<00?ooool0Iooo10007Ooo
001bool00`00ooooo`0Pool00`00ooooo`1Sool4000Qool007?oo`80023oo`03003ooooo05ooo`@0
02Goo`00MOoo00<00?ooool07Ooo00<00?ooool0G?oo0`00:Ooo001fool00`00ooooo`0Lool00`00
ooooo`1Hool4000/ool007Ooo`03003ooooo01_oo`03003ooooo05Coo`@0033oo`00N?oo0P006_oo
00<00?ooool0DOoo1000=?oo001jool00`00ooooo`0Gool00`00ooooo`1=ool4000hool007_oo`03
003ooooo01Koo`03003ooooo04Woo`@003coo`00O?oo00<00?ooool05Ooo00<00?ooool0AOoo1000
@?oo001mool2000Eool00`00ooooo`11ool40014ool007ooo`03003ooooo01;oo`03003ooooo03ko
o`<004Soo`00P?oo00<00?ooool04Ooo00<00?ooool0>_oo1000Booo0021ool00`00ooooo`0@ool0
0`00ooooo`0fool4001?ool008;oo`80013oo`03003ooooo03;oo`@005?oo`00Q?oo00<00?ooool0
3Ooo00<00?ooool0;_oo1000Eooo0025ool00`00ooooo`0<ool00`00ooooo`0Zool4001Kool008Ko
o`03003ooooo00_oo`03003ooooo02Koo`@005ooo`00Qooo0P002ooo00<00?ooool08_oo1000Hooo
0029ool00`00ooooo`08ool00`00ooooo`0Nool4001Wool008[oo`03003ooooo00Ooo`03003ooooo
01_oo`<006_oo`00Rooo00<00?ooool01_oo00<00?ooool05ooo1000K_oo002<ool20006ool00`00
ooooo`0Cool4001bool008koo`03003ooooo00?oo`03003ooooo00ooo`@007Koo`00Sooo00<00?oo
ool00_oo00<00?ooool02ooo1000N_oo002@ool01@00oooooooo00002Ooo1000O_oo002Aool20000
0ooo003oo`04ool40022ool009?oo`800003ool00000008008Koo`00U?oo0P00R_oo003ooolQool0
0?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo
8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool0
0?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo
8Ooo003ooolQool00?ooob7oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.28487, -0.0859866, \
0.0044785, 0.0044785}}]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Delta",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(option, \ settlement, \ riskfreerate\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], TopSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox[\(return\ delta\),
                "TraditionalForm"], 
              StyleBox[",",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              RowBox[{
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["sensitivity",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["of",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox[\(option'\),
                  "TraditionalForm"], "s", 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["value",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["to",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["changes",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["in",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["price",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["of",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["underlying",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["asset",
                  "TraditionalForm"]}]}]}
          }], MiddleBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Theta",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(option, \ settlement, \ riskfreerate\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], MiddleSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox[\(return\ theta\),
                "TraditionalForm"], 
              StyleBox[",",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              RowBox[{
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["sensitivity",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["of",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox[\(option'\),
                  "TraditionalForm"], 
                StyleBox["s",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False}], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["value",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["to",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["changes",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["in",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["time",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["until",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["expriation",
                  "TraditionalForm"]}]}]}
          }], MiddleBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Gamma",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(option, \ settlement, \ riskfreerate\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], MiddleSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox[\(return\ gamma\),
                "TraditionalForm"], 
              StyleBox[",",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              RowBox[{
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["sensitivity",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["of",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox[\(option'\),
                  "TraditionalForm"], 
                StyleBox["s",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False}], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["value",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["to",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["changes",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["in",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["underlying",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox[\(asset'\),
                  "TraditionalForm"], 
                StyleBox["s",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["price",
                  "TraditionalForm"]}]}]}
          }], MiddleBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Rho",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(option, \ settlement, \ riskfreerate\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], MiddleSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox[\(return\ rho\),
                "TraditionalForm"], 
              StyleBox[",",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              RowBox[{
                RowBox[{
                  StyleBox["the",
                    "TraditionalForm"], 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox["sensitivity",
                    "TraditionalForm"], 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox["of",
                    "TraditionalForm"], 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox["the",
                    "TraditionalForm"], 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox[\(option'\),
                    "TraditionalForm"], "s", 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox["value",
                    "TraditionalForm"], 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox["to",
                    "TraditionalForm"], 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox["changes",
                    "TraditionalForm"], 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox["in",
                    "TraditionalForm"], 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox["the",
                    "TraditionalForm"], 
                  StyleBox[" ",
                    "TraditionalForm"], 
                  StyleBox["risk",
                    "TraditionalForm"]}], 
                StyleBox["-",
                  "TraditionalForm"], 
                StyleBox[\(free\ rate\ of\ return\),
                  "TraditionalForm"]}]}]}
          }], MiddleBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Lambda",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(option, \ settlement, \ riskfreerate\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], " "}
          }], MiddleSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox[\(return\ lambda\),
                "TraditionalForm"], 
              StyleBox[",",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              RowBox[{
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["sensitivity",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["of",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox[\(option'\),
                  "TraditionalForm"], 
                StyleBox["s",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontTracking->"Plain",
                  FontVariations->{"Underline"->False,
                  "Outline"->False,
                  "Shadow"->False}], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["value",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["to",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["changes",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["in",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["the",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["underlying",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox[\(asset'\),
                  "TraditionalForm"], 
                StyleBox["s",
                  "TraditionalForm"], 
                StyleBox[" ",
                  "TraditionalForm"], 
                StyleBox["volatility",
                  "TraditionalForm"]}]}]}
          }], MiddleBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Elasticity",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(option, \ settlement, \ riskfreerate\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], MiddleSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[\(return\ elasticity\ of\ an\ option\ given\ the\ \
settlement\ date\ and\ riskless\ interest\ rate\),
              "TraditionalForm"]}
          }], BottomBox]]],

Cell["Sensitivity measures functions. ", "Caption"],

Cell[TextData[{
  "Here is the analytical expression for the delta of the put option ",
  StyleBox["xyzft", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.20"],

Cell[CellGroupData[{

Cell["Delta[xyzft, settlement, r]", "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(1\/2\ \((\(-1\) - 
          Erf[\(\(-\(2\/\(5\ \@3\)\)\) - \@3\/20\)\/\@2])\)\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["This is a numerical approximation. ", "MathCaption",
  CellTags->"0.21"],

Cell[CellGroupData[{

Cell["N[%]", "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(\(-0.375415942044558414`\)\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[TextData[{
  "We define the delta of the option ",
  StyleBox["abxft", "MB"],
  " as a function of two variables, ",
  StyleBox["x", "MB"],
  " and ",
  StyleBox["t", "MB"],
  ", the price of the underlying asset and the time to maturity, \
respectively. "
}], "MathCaption",
  CellTags->"0.22"],

Cell["\<\
optiondelta[x_, t_] = Delta[abcft,
   ToCalendar[ToJulian[settlement] + Floor[t]], r] /.
   Price[ABC] -> x;\
\>", "Input",
  CellLabel->"In[17]:="],

Cell["\<\
This illustrates how the graph of the option delta changes as the \
time to maturity varies. \
\>", "MathCaption",
  CellTags->"0.23"],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Table[optiondelta[x, j],
   {j, 0, 120, 10}]], {x, 25, 45},
   PlotLabel ->
      \"    Call Option Delta\\nfor Different Maturities\",
   FrameLabel -> {\"Stock Price\", \"\"}];\
\>", "Input",
  CellLabel->"In[18]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.16667 0.0476191 0.0147151 0.588604 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -35 -24 ]
[.5 -0.0125 35 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -18 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -18 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -18 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74 0 ]
[.5 .63053 74 31 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(25)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(30)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(35)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(40)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(45)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -96 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(0.2)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(0.4)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(0.6)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(0.8)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Call) show
117.000000 15.000000 moveto
(Option) show
159.000000 15.000000 moveto
(Delta) show
63.000000 31.000000 moveto
(for) show
87.000000 31.000000 moveto
(Different) show
147.000000 31.000000 moveto
(Maturities) show
207.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.02381 .01943 m
.04262 .02074 L
.06244 .02242 L
.10458 .02724 L
.14264 .03335 L
.18314 .04205 L
.22214 .05289 L
.26358 .06731 L
.30351 .08416 L
.34193 .10312 L
.38279 .12612 L
.42214 .15074 L
.45998 .17638 L
.50027 .20534 L
.53904 .23432 L
.58026 .26577 L
.61997 .29613 L
.65817 .3249 L
.69881 .35462 L
.73794 .38195 L
.77952 .40931 L
.81959 .43378 L
.85814 .45543 L
.89914 .47635 L
.93863 .49444 L
.97619 .5098 L
s
.02381 .01796 m
.04262 .01895 L
.06244 .02026 L
.08426 .02206 L
.10458 .02413 L
.14264 .02922 L
.18163 .03641 L
.22307 .04663 L
.263 .05934 L
.30142 .07444 L
.34228 .09367 L
.38164 .11521 L
.41947 .13854 L
.45976 .16586 L
.49853 .19411 L
.53975 .22569 L
.57946 .25698 L
.61766 .28733 L
.6583 .31931 L
.69743 .34927 L
.73901 .37972 L
.77908 .40734 L
.81763 .43204 L
.85863 .45613 L
.89812 .47711 L
.93609 .49521 L
.97619 .51217 L
s
.02381 .0168 m
.04262 .01751 L
.06244 .01847 L
.08255 .0197 L
.10458 .02142 L
.12579 .0235 L
.14509 .02582 L
.18408 .03193 L
.22401 .04055 L
.26243 .0515 L
.30329 .06631 L
.34264 .08386 L
.38048 .10381 L
.42077 .12822 L
.45954 .15451 L
.50076 .18499 L
.54047 .2162 L
.57866 .24734 L
.61931 .28098 L
.65844 .31321 L
.70002 .34661 L
.74009 .37742 L
.77864 .40537 L
.81964 .43293 L
.85913 .45717 L
.8971 .47822 L
.93752 .4982 L
.97619 .51501 L
s
.02381 .01593 m
.04262 .0164 L
.06244 .01705 L
.08255 .01792 L
.10458 .01917 L
.12415 .0206 L
.14509 .02251 L
.16496 .02476 L
.18653 .02775 L
.22646 .03509 L
.26733 .04546 L
.30668 .05861 L
.34452 .07446 L
.3848 .09493 L
.42358 .11809 L
.4648 .14615 L
.50451 .17607 L
.5427 .20696 L
.58335 .24137 L
.62248 .27523 L
.66406 .31118 L
.70413 .34503 L
.74268 .37624 L
.78368 .40746 L
.82317 .43522 L
.86114 .45955 L
.90156 .48278 L
.94047 .50252 L
.97619 .51844 L
s
.02381 .01534 m
.04262 .01562 L
.06244 .01602 L
.08255 .01658 L
.10458 .01741 L
.12415 .01839 L
.14509 .01975 L
.16639 .02155 L
.18653 .02369 L
.22495 .02925 L
.24479 .03301 L
.26581 .03778 L
.30365 .0486 L
.34394 .06367 L
.38271 .08194 L
.42393 .1055 L
.46364 .1321 L
.50184 .16091 L
.54248 .19445 L
.58161 .22877 L
.62319 .26649 L
.66326 .30309 L
.70181 .3377 L
.74281 .37307 L
.7823 .4051 L
.82027 .43356 L
.8607 .46103 L
.8996 .48458 L
.94097 .50645 L
.97619 .5226 L
s
.02381 .01498 m
.03279 .01505 L
.04262 .01512 L
.06244 .01534 L
.07298 .01549 L
.08426 .01568 L
.10458 .01614 L
.12589 .0168 L
.14603 .01766 L
.166 .01879 L
.18444 .02014 L
.20316 .02186 L
.22379 .02425 L
.24483 .0273 L
.26408 .03073 L
.30285 .0398 L
.34256 .05259 L
.38075 .06871 L
.4214 .09029 L
.46053 .11544 L
.50211 .14656 L
.54217 .18024 L
.58073 .21529 L
.62173 .25437 L
.66122 .2927 L
.69919 .3292 L
.73961 .36672 L
.77852 .40076 L
.81988 .43404 L
.85973 .46286 L
.89806 .48739 L
.93884 .51001 L
.97619 .5277 L
s
.02381 .0148 m
.03279 .01483 L
.04262 .01486 L
.06244 .01495 L
.07298 .01502 L
.08426 .01511 L
.10458 .01533 L
.1148 .01548 L
.12589 .01568 L
.14603 .01615 L
.16586 .0168 L
.18689 .01775 L
.20643 .01895 L
.22473 .0204 L
.24497 .02246 L
.2635 .02484 L
.28409 .02815 L
.30321 .03194 L
.3414 .04195 L
.38053 .05613 L
.42211 .0762 L
.46218 .10073 L
.50073 .12908 L
.54173 .16387 L
.58122 .20106 L
.61919 .23922 L
.65962 .28114 L
.69852 .32149 L
.73989 .36306 L
.77973 .40074 L
.81806 .43402 L
.85884 .4657 L
.89811 .49232 L
.93586 .51429 L
.97606 .53395 L
.97619 .534 L
s
.02381 .01473 m
.03279 .01474 L
.04262 .01475 L
.05288 .01476 L
.06244 .01478 L
.0731 .0148 L
.0828 .01482 L
.094 .01486 L
.10458 .01491 L
.11428 .01496 L
.12455 .01504 L
.14299 .01521 L
.1524 .01533 L
.16253 .01549 L
.18083 .01587 L
.19093 .01613 L
.20196 .01649 L
.22205 .01733 L
.24173 .01847 L
.2627 .02011 L
.28411 .02237 L
.30428 .02516 L
.32436 .0287 L
.34283 .03275 L
.38232 .04438 L
.42029 .06011 L
.46072 .08244 L
.49962 .10966 L
.54098 .14456 L
.58083 .18324 L
.61916 .22398 L
.65994 .26957 L
.69921 .31398 L
.73696 .35566 L
.77716 .39759 L
.81585 .43447 L
.85699 .46921 L
.89661 .49795 L
.93472 .52121 L
.97528 .54149 L
.97619 .54189 L
s
.02381 .01472 m
.03279 .01472 L
.04262 .01472 L
.04758 .01472 L
.05288 .01472 L
.06244 .01472 L
.06788 .01473 L
.07379 .01473 L
.08451 .01473 L
.09494 .01474 L
.10458 .01475 L
.11425 .01476 L
.12331 .01478 L
.13324 .0148 L
.14393 .01483 L
.15404 .01487 L
.16506 .01493 L
.17548 .015 L
.18515 .01508 L
.19572 .01519 L
.20568 .01532 L
.22428 .01566 L
.23405 .0159 L
.24436 .0162 L
.26284 .01692 L
.28247 .01799 L
.30081 .01937 L
.32116 .02143 L
.33972 .02394 L
.3588 .02726 L
.37956 .0319 L
.39895 .03736 L
.42034 .04484 L
.45961 .06313 L
.49981 .08871 L
.5385 .1202 L
.57964 .16067 L
.61926 .20523 L
.65737 .25156 L
.69793 .30241 L
.73698 .35065 L
.77848 .39898 L
.81846 .44104 L
.85692 .47635 L
.89784 .50795 L
.93725 .53262 L
.97513 .55143 L
.97619 .55189 L
s
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03793 .01472 L
.04262 .01472 L
.0522 .01472 L
.05746 .01472 L
.06244 .01472 L
.06754 .01472 L
.07295 .01472 L
.08265 .01472 L
.08804 .01472 L
.09308 .01472 L
.09858 .01472 L
.10458 .01472 L
.10996 .01472 L
.11496 .01472 L
.12483 .01472 L
.13379 .01472 L
.14335 .01473 L
.15364 .01473 L
.15943 .01473 L
.16476 .01474 L
.17457 .01475 L
.18493 .01476 L
.19441 .01478 L
.20457 .01481 L
.21416 .01484 L
.22291 .01488 L
.23282 .01494 L
.24199 .015 L
.25206 .0151 L
.26275 .01523 L
.27212 .01538 L
.28222 .01558 L
.3005 .01609 L
.31007 .01644 L
.32054 .01692 L
.3316 .01755 L
.34164 .01824 L
.36125 .02002 L
.3822 .02272 L
.40139 .02609 L
.42218 .03097 L
.44206 .03707 L
.4631 .04532 L
.50099 .06564 L
.54133 .09602 L
.58015 .13414 L
.62143 .18331 L
Mistroke
.66119 .23694 L
.69944 .29147 L
.74013 .34928 L
.77932 .40164 L
.82095 .45112 L
.86107 .49128 L
.89967 .52252 L
.94073 .54813 L
.97619 .56468 L
Mfstroke
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.0402 .01472 L
.04262 .01472 L
.0475 .01472 L
.05026 .01472 L
.05281 .01472 L
.05749 .01472 L
.06244 .01472 L
.06743 .01472 L
.0728 .01472 L
.07786 .01472 L
.0825 .01472 L
.08791 .01472 L
.09097 .01472 L
.09382 .01472 L
.09903 .01472 L
.10458 .01472 L
.10994 .01472 L
.11487 .01472 L
.12028 .01472 L
.12599 .01472 L
.13096 .01472 L
.13561 .01472 L
.1407 .01472 L
.14616 .01472 L
.15145 .01472 L
.15634 .01472 L
.1617 .01472 L
.1674 .01472 L
.17233 .01472 L
.17697 .01472 L
.18205 .01472 L
.18752 .01472 L
.19248 .01472 L
.19709 .01472 L
.20258 .01472 L
.20756 .01472 L
.21776 .01472 L
.22337 .01472 L
.22866 .01472 L
.23838 .01473 L
.24329 .01473 L
.24868 .01473 L
.25821 .01474 L
.26713 .01475 L
.27211 .01476 L
.27754 .01477 L
Mistroke
.28742 .0148 L
.29704 .01484 L
.30595 .01488 L
.31655 .01495 L
.32652 .01505 L
.33547 .01516 L
.34514 .01532 L
.35467 .01552 L
.36511 .01581 L
.37602 .01621 L
.38619 .01669 L
.39667 .01732 L
.40658 .01808 L
.42515 .02001 L
.43483 .02134 L
.4451 .02306 L
.46353 .02705 L
.48304 .03286 L
.50134 .04011 L
.52156 .05054 L
.54008 .06262 L
.57975 .09769 L
.61791 .14368 L
.65853 .20426 L
.69762 .26996 L
.73917 .3417 L
.77921 .40673 L
.81773 .46121 L
.8587 .50794 L
.89815 .54162 L
.93609 .5646 L
.95544 .57331 L
.97619 .58078 L
Mfstroke
.02381 .01472 m
.03279 .01472 L
.04262 .01472 L
.04758 .01472 L
.05288 .01472 L
.05546 .01472 L
.05672 .01472 L
.05789 .01472 L
.05895 .01472 L
.06007 .01472 L
.0612 .01472 L
.06244 .01472 L
.06379 .01472 L
.06525 .01472 L
.06592 .01472 L
.06663 .01472 L
.06792 .01472 L
.06857 .01472 L
.06927 .01472 L
.07054 .01472 L
.07178 .01472 L
.07293 .01472 L
.07358 .01472 L
.07428 .01472 L
.07554 .01472 L
.07841 .01472 L
.07915 .01472 L
.07996 .01472 L
.08144 .01472 L
.08212 .01472 L
.08286 .01472 L
.0842 .01472 L
.08539 .01472 L
.08664 .01472 L
.08731 .01472 L
.08804 .01472 L
.08933 .01472 L
.0907 .01472 L
.09216 .01472 L
.09353 .01472 L
.09479 .01472 L
.0972 .01472 L
.09982 .01472 L
.1023 .01472 L
.10458 .01472 L
.10702 .01472 L
.10925 .01472 L
.11183 .01472 L
.11427 .01472 L
.11653 .01472 L
Mistroke
.11861 .01472 L
.1209 .01472 L
.12334 .01472 L
.12603 .01472 L
.12892 .01472 L
.13166 .01472 L
.13417 .01472 L
.13645 .01472 L
.13895 .01472 L
.14155 .01472 L
.14398 .01472 L
.14659 .01472 L
.14901 .01472 L
.15165 .01472 L
.15446 .01472 L
.1569 .01472 L
.15918 .01472 L
.16168 .01472 L
.16438 .01472 L
.16663 .01472 L
.1691 .01472 L
.17168 .01472 L
.17407 .01472 L
.17836 .01472 L
.18076 .01472 L
.18294 .01472 L
.18781 .01472 L
.19026 .01472 L
.19295 .01472 L
.19525 .01472 L
.19772 .01472 L
.20217 .01472 L
.20484 .01472 L
.20775 .01472 L
.2105 .01472 L
.21305 .01472 L
.21786 .01472 L
.22029 .01472 L
.22298 .01472 L
.22788 .01472 L
.23035 .01472 L
.23305 .01472 L
.23537 .01472 L
.23784 .01472 L
.2423 .01472 L
.24499 .01472 L
.24792 .01472 L
.25049 .01472 L
.25322 .01472 L
.25568 .01472 L
Mistroke
.25838 .01472 L
.26315 .01472 L
.26564 .01472 L
.26835 .01472 L
.27329 .01472 L
.27811 .01472 L
.28257 .01472 L
.28788 .01472 L
.29268 .01472 L
.29823 .01472 L
.30346 .01472 L
.30812 .01472 L
.31323 .01472 L
.31857 .01472 L
.32355 .01472 L
.32822 .01472 L
.33247 .01472 L
.33738 .01472 L
.34203 .01472 L
.34662 .01472 L
.35169 .01472 L
.35698 .01472 L
.36195 .01473 L
.36658 .01473 L
.37082 .01473 L
.38038 .01474 L
.38512 .01475 L
.39019 .01476 L
.39931 .01479 L
.4049 .01481 L
.41017 .01483 L
.41486 .01486 L
.42002 .0149 L
.42975 .015 L
.43507 .01507 L
.44005 .01515 L
.44895 .01534 L
.45851 .01563 L
.46865 .01605 L
.4797 .01671 L
.49013 .01757 L
.4998 .01864 L
.51041 .0202 L
.52038 .02213 L
.52934 .02432 L
.53901 .02726 L
.559 .03571 L
.56906 .04142 L
.58008 .04899 L
.59964 .06628 L
Mistroke
.62058 .0909 L
.66201 .15927 L
.70193 .24564 L
.74033 .33664 L
.78118 .42695 L
.80149 .46543 L
.82052 .49652 L
.83991 .52303 L
.85834 .54351 L
.87858 .56115 L
.8971 .57341 L
.9169 .58311 L
.93528 .58959 L
.94585 .59243 L
.9558 .59462 L
.9744 .5977 L
.97619 .59794 L
Mfstroke
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.34309 .01472 L
.3815 .01472 L
.42237 .01472 L
.46172 .01472 L
.48147 .01472 L
.49012 .01472 L
.49468 .01472 L
.49955 .01472 L
.50095 .01472 L
.50226 .01472 L
.50344 .01472 L
.50471 .01472 L
.50592 .01472 L
.50721 .01472 L
.50841 .01472 L
.5095 .01472 L
.51063 .01472 L
.51183 .01472 L
.51295 .01472 L
.51401 .01472 L
.51524 .01472 L
.51638 .01472 L
.51763 .01472 L
.51826 .01472 L
.51896 .01472 L
.52028 .01472 L
.52094 .01472 L
.52166 .01472 L
.52295 .01472 L
.52414 .01472 L
.52487 .01472 L
.52556 .01472 L
.52684 .01472 L
.52756 .01472 L
.52823 .01472 L
.52895 .01472 L
.52973 .01472 L
.53094 .01472 L
.53207 .01472 L
.53341 .01472 L
.53464 .01472 L
.53592 .01472 L
Mistroke
.53664 .01472 L
.53731 .01472 L
.53853 .01472 L
.53984 .01472 L
.54109 .01472 L
.54245 .01472 L
.54314 .01472 L
.54388 .01472 L
.54521 .01472 L
.54654 .01472 L
.5478 .01472 L
.54893 .01472 L
.55015 .01472 L
.55149 .01472 L
.55296 .01472 L
.5537 .01472 L
.5545 .01472 L
.55594 .01472 L
.5573 .01472 L
.55873 .01472 L
.55996 .01472 L
.56129 .01472 L
.56266 .01472 L
.56394 .01472 L
.5651 .01472 L
.56635 .01472 L
.56772 .01472 L
.56916 .01472 L
.5704 .01472 L
.57175 .01472 L
.57302 .01472 L
.57418 .01472 L
.57551 .01472 L
.57678 .01472 L
.57795 .01472 L
.57903 .01472 L
.58021 .01472 L
.58147 .01472 L
.58261 .01472 L
.58385 .01472 L
.58514 .01472 L
.58635 .01472 L
.58852 .01472 L
.58973 .01472 L
.59083 .01472 L
.59332 .01472 L
.59472 .01472 L
.59602 .01472 L
.5984 .01472 L
.5996 .01472 L
Mistroke
.60092 .01472 L
.60214 .01472 L
.6033 .01472 L
.60547 .01472 L
.60668 .01472 L
.60781 .01472 L
.60912 .01472 L
.61036 .01472 L
.6126 .01472 L
.61463 .01472 L
.61682 .01472 L
.61919 .01473 L
.62157 .01473 L
.62411 .01474 L
.62652 .01475 L
.62871 .01477 L
.63128 .01479 L
.63407 .01483 L
.63671 .01487 L
.63915 .01493 L
.64165 .01502 L
.644 .01512 L
.64658 .01526 L
.64936 .01548 L
.65212 .01576 L
.65503 .01615 L
.65751 .01659 L
.66022 .0172 L
.66275 .01793 L
.66551 .01893 L
.66793 .02003 L
.6705 .02145 L
.67536 .02505 L
.67984 .02971 L
.685 .03709 L
.68982 .04644 L
.69511 .05994 L
.7008 .07881 L
.71094 .12509 L
.72199 .19366 L
.74209 .34699 L
.75226 .42196 L
.76182 .48168 L
.76712 .50894 L
.77284 .53344 L
.778 .55131 L
.78281 .56464 L
.78742 .57474 L
.79235 .58307 L
.79782 .58985 L
Mistroke
.8028 .59424 L
.8055 .59606 L
.808 .59745 L
.81068 .59867 L
.81364 .59976 L
.81861 .60108 L
.82133 .6016 L
.82389 .60198 L
.82629 .60227 L
.82884 .60252 L
.83165 .60272 L
.83426 .60287 L
.83692 .60298 L
.83943 .60307 L
.84169 .60312 L
.84412 .60317 L
.84636 .60321 L
.84881 .60324 L
.85138 .60326 L
.85377 .60327 L
.85601 .60329 L
.85805 .60329 L
.86041 .6033 L
.86265 .6033 L
.86501 .60331 L
.86723 .60331 L
.86967 .60331 L
.87092 .60331 L
.87229 .60332 L
.8749 .60332 L
.87632 .60332 L
.87764 .60332 L
.88001 .60332 L
.88134 .60332 L
.88255 .60332 L
.88491 .60332 L
.88709 .60332 L
.88948 .60332 L
.89069 .60332 L
.89202 .60332 L
.89424 .60332 L
.89549 .60332 L
.89664 .60332 L
.89886 .60332 L
.90096 .60332 L
.90221 .60332 L
.90356 .60332 L
.90475 .60332 L
.906 .60332 L
.90714 .60332 L
Mistroke
.90838 .60332 L
.91057 .60332 L
.91191 .60332 L
.91312 .60332 L
.91444 .60332 L
.91586 .60332 L
.91718 .60332 L
.9184 .60332 L
.91955 .60332 L
.9208 .60332 L
.92194 .60332 L
.92299 .60332 L
.92504 .60332 L
.92613 .60332 L
.92732 .60332 L
.92858 .60332 L
.92972 .60332 L
.93086 .60332 L
.9321 .60332 L
.9334 .60332 L
.93463 .60332 L
.93579 .60332 L
.93701 .60332 L
.9392 .60332 L
.94038 .60332 L
.94167 .60332 L
.94289 .60332 L
.94402 .60332 L
.94615 .60332 L
.94723 .60332 L
.94842 .60332 L
.9497 .60332 L
.95087 .60332 L
.95216 .60332 L
.95352 .60332 L
.95471 .60332 L
.95581 .60332 L
.95702 .60332 L
.95832 .60332 L
.95952 .60332 L
.96063 .60332 L
.96184 .60332 L
.96313 .60332 L
.96425 .60332 L
.96529 .60332 L
.96644 .60332 L
.96768 .60332 L
.96877 .60332 L
.96996 .60332 L
.97108 .60332 L
Mistroke
.97212 .60332 L
.97409 .60332 L
.97519 .60332 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[18]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo003ooolX
ool00?ooobSoo`00oooo:?oo003ooolXool007coo`<000?oo`8000?oo`8000;oo`<00004ool00000
ool2000;ool30003ool30002ool30002ool30003ool2001`ool007coo`03003oo`0000;oo`06003o
oooo003oo`000_oo00<00?oo00001?oo00<00?oo00003Ooo00<00?ooool00ooo00<00?ooool00_oo
00D00?ooooooo`0000Coo`03003ooooo073oo`00O_oo00@00?ooool000Coo`06003ooooo003oo`00
1?oo0`003Ooo0`000ooo00<00?ooool00_oo00D00?ooooooo`0000Coo`<0073oo`00OOoo00<00?oo
ool010000ooo0P000_oo0`000_oo00@00?oo000000coo`05003ooooo003oo`0400000ooo00000003
ool30002ool3001`ool007coo`03003oo`0000;oo`03003ooooo00coo`03003ooooo00goo`04003o
oooo0023ool007coo`<0013oo`8000koo`@000Soo`03003ooooo07Woo`00oooo:?oo003ooolXool0
0?ooobSoo`00oooo:?oo003ooolXool003_oo`<000?oo`03003ooooo02Goo`8000Coo`03003ooooo
02Koo`8000Coo`03003ooooo02Ooo`<000;oo`03003ooooo02Ooo`<000;oo`03003ooooo02Soo`00
>ooo00<00?ooool00_oo00<00?oo0000:?oo00H00?ooool00?oo000Yool01P00ooooo`00ool002Wo
o`06003ooooo003oo`00:Ooo00H00?ooool00?oo000Yool003coo`03003ooooo00?oo`03003ooooo
02Goo`07003oooooool00?oo0000:?oo00<00?ooool00ooo00<00?ooool09Ooo100000Coo`00ool0
02Ooo`@000?oo`03003ooooo02Ooo`00??oo00@00?ooooooo`8002Woo`06003ooooo003oo`00:Ooo
00<00?ooool00P00:?oo00<00?oo00000_oo00<00?oo00009ooo00<00?oo00000_oo0P00:_oo000k
ool00`00ool00002ool00`00ooooo`0Vool00`00ool00002ool00`00ool0000Wool00`00ool00002
ool00`00ooooo`0Xool20002ool00`00ool0000Xool20002ool00`00ooooo`0Yool003coo`04003o
ooooool3000Wool00`00ooooo`02ool00`00ooooo`0Wool01000oooooooo0`00:Ooo00D00?oooooo
o`0002[oo`03003ooooo00<002Woo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo000jooo6
000Wool003Coo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00Koo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00;oo`03003ooooo02Goo`00
<ooo00<00?oo00001?oo00<00?ooool00_oo00<00?ooool0:ooo00<00?ooool0;?oo00<00?ooool0
;?oo00<00?ooool0;?oo00<00?ooool00_oo00<00?ooool09Ooo000cool00`00ool00004ool20003
ooml0013ool2000Wool003?oo`03003oo`0000Coo`03003ooooo00;ooe0000Soo`P001coo`<0047o
o`03003ooooo02Goo`00<ooo00<00?oo00001?oo00<00?ooool01ooo>`001?oo20001?oo1@002ooo
10006ooo0P00?ooo00<00?ooool09Ooo000dool00`00ooooo`03ool00`00ooooo`0=oolB00000ooo
0000000E0004ool40003ool40008ool30006ool3000<ool3000Jool00`00ooooo`0lool00`00oooo
o`0Uool003[oo`03003ooooo01Gooa000003ool0000000L000Coo`P000Coo`<000Coo`@000Ooo`80
00Ooo`@000_oo`<001Soo`03003ooooo03_oo`03003ooooo02Goo`00>_oo00<00?ooool06ooo2000
0_oo1P0000?oo`0000001@001?oo20000ooo10001?oo10001Ooo0`002?oo0`002ooo0P005_oo00<0
0?ooool0>ooo00<00?ooool09Ooo000jool2000Pool80004ool400000ooo000000050004ool20002
ool30004ool40004ool30005ool30008ool2000;ool00`00ooooo`0Dool00`00ooooo`0iool2000W
ool003[oo`03003ooooo02?oo`P000Coo`@00004ool00000ool40002ool20003ool40004ool20005
ool20006ool20008ool2000:ool00`00ooooo`0Cool00`00ooooo`0jool00`00ooooo`0Uool003[o
o`03003ooooo02Ooo`P000Coo`800003ool0000000?oo`8000;oo`<000Coo`<000?oo`<000Coo`80
00Koo`8000Soo`03003ooooo00Soo`03003ooooo01?oo`03003ooooo03Woo`03003ooooo02Goo`00
>_oo00<00?ooool0:ooo0P000_oo10000_oo1P000_oo0`000_oo0P001Ooo0P001?oo0P001?oo0P00
1_oo0P001ooo00<00?ooool02?oo0P004ooo00<00?ooool0>Ooo00<00?ooool09Ooo000jool00`00
ooooo`0]ool30003ool20003ool200000ooo00000003ool300001?oo000000001?oo0P001?oo0P00
1?oo00<00?ooool01Ooo0P001_oo00<00?ooool02Ooo00<00?ooool04?oo00<00?ooool0>Ooo00<0
0?ooool09Ooo000jool00`00ooooo`0`ool30002ool20003ool200001?oo000000000ooo0P000_oo
0P001?oo0P001?oo00<00?ooool00_oo0P001ooo00<00?ooool01?oo00<00?ooool02Ooo00<00?oo
ool04?oo00<00?ooool0>?oo00<00?ooool09Ooo000jool2000dool20002ool20003ool20002ool2
0003ool20002ool20004ool20003ool20004ool00`00ooooo`05ool00`00ooooo`04ool00`00oooo
o`09ool00`00ooooo`0?ool00`00ooooo`0gool2000Wool003[oo`03003ooooo03Goo`<00003ool0
000000?oo`8000;oo`8000?oo`8000;oo`8000Coo`8000?oo`8000?oo`8000Koo`8000Goo`03003o
oooo00Soo`03003ooooo00ooo`03003ooooo03Soo`03003ooooo02Goo`00>_oo00<00?ooool0>?oo
0P0000?oo`0000000ooo00@00?ooooooo`8000?oo`8000;oo`8000Coo`03003ooooo00;oo`03003o
oooo00;oo`8000Koo`03003ooooo00?oo`8000Woo`03003ooooo00koo`03003ooooo03Soo`03003o
oooo02Goo`00>_oo00<00?ooool0>_oo0P0000?oo`0000000_oo0P000ooo0P000ooo00@00?oooooo
o`8000?oo`8000?oo`8000Coo`03003ooooo00Coo`03003ooooo00Coo`03003ooooo00Ooo`03003o
oooo00goo`03003ooooo03Soo`03003ooooo02Goo`00>_oo00<00?ooool0??oo0P0000?oo`000000
0_oo0P000ooo0P000_oo0P000ooo0P000ooo0P000ooo00<00?ooool00_oo00<00?ooool01?oo00<0
0?ooool01?oo00<00?ooool01ooo00<00?ooool03Ooo00<00?ooool0=ooo00<00?ooool09Ooo000j
ool00`00ooooo`0nool200000ooo00000002ool20003ool20002ool20003ool00`00ooooo`02ool0
1@00oooooooo00001?oo0P001Ooo00<00?ooool01?oo00<00?ooool01_oo00<00?ooool03Ooo00<0
0?ooool0=ooo00<00?ooool09Ooo000jool20011ool00`00ooooo`020002ool20003ool01@00oooo
oooo00000ooo0P000ooo00@00?ooooooo`8000Coo`03003ooooo00?oo`03003ooooo00Coo`03003o
oooo00Koo`03003ooooo00coo`03003ooooo03Koo`8002Ooo`00>_oo00<00?ooool0@Ooo0P000_oo
0P000_oo0P000_oo00@00?ooooooo`8000?oo`8000;oo`8000?oo`03003ooooo00;oo`03003ooooo
00?oo`03003ooooo00Coo`03003ooooo00Goo`03003ooooo00coo`03003ooooo03Ooo`03003ooooo
02Goo`00>_oo00<00?ooool0@ooo0P000_oo0P000_oo00<00?ooool00P000ooo00<00?ooool00_oo
00D00?ooooooo`0000?oo`03003ooooo00;oo`8000Coo`03003ooooo00Coo`03003ooooo00Goo`03
003ooooo00coo`03003ooooo03Koo`03003ooooo02Goo`00:_oo00<00?ooool00_oo00@00?oooooo
o`<000Coo`03003ooooo04Goo`8000;oo`800003ool0000000;oo`04003oooooool20003ool01@00
oooooooo00000ooo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool01?oo
00<00?ooool03?oo00<00?ooool0=_oo00<00?ooool09Ooo000Yool00`00ool00007ool00`00oooo
o`04ool00`00ooooo`17ool20002ool00`00ooooo`0200000ooo00000003ool20002ool20002ool2
0002ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`05ool00`00oooo
o`0;ool00`00ooooo`0fool00`00ooooo`0Uool002Woo`03003oo`0000Soo`03003ooooo00?oo`80
04[oo`800003ool0000000;oo`04003ooooo0004ool01@00oooooooo00000ooo00<00?ooool00P00
1?oo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool01Ooo00<00?ooool02_oo00<00?ooool0
=Ooo0P009ooo000Yool00`00ool00008ool00`00ooooo`03ool00`00ooooo`1;ool00`00ooooo`02
00001?oo00000?oo0P000ooo00D00?ooooooo`0000?oo`05003oooooool00004ool00`00ooooo`02
ool00`00ooooo`03ool00`00ooooo`04ool00`00ooooo`0:ool00`00ooooo`0fool00`00ooooo`0U
ool002Woo`03003oo`0000Ooo`03003oo`0000Coo`03003ooooo04coo`8000;oo`04003ooooo0002
ool20002ool20002ool20002ool01@00oooooooo00001?oo00<00?ooool00_oo00<00?ooool00ooo
00<00?ooool01?oo00<00?ooool02Ooo00<00?ooool0=_oo00<00?ooool09Ooo000Zool00`00oooo
o`07ool00`00ooooo`03ool00`00ooooo`1>ool200001Ooo00000?oo00000ooo00D00?ooooooo`00
00?oo`04003ooooo0003ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`03ool00`00oooo
o`03ool00`00ooooo`0:ool00`00ooooo`0eool00`00ooooo`0Uool003[oo`03003ooooo053oo`05
003ooooo003oo`020002ool01@00oooooooo00000ooo00<00?ooool00P000_oo00<00?ooool00_oo
00<00?ooool00_oo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool02Ooo00<00?ooool0=Ooo
00<00?ooool09Ooo000jool00`00ooooo`1Aool200001Ooo003ooooo00000_oo0P000_oo0P000_oo
00D00?ooooooo`0000;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo
00?oo`03003ooooo00Woo`03003ooooo03Goo`03003ooooo02Goo`00>_oo0P00E?oo00D00?oo0000
0?oo008000;oo`05003oooooool00002ool01@00oooooooo00000_oo00<00?ooool00_oo00D00?oo
ooooo`0000Goo`03003ooooo00?oo`03003ooooo00Soo`03003ooooo03Coo`8002Ooo`00>_oo00<0
0?ooool0E?oo00@00?ooool000;oo`04003ooooo0003ool00`00ooooo`020002ool00`00ooooo`02
0003ool01@00oooooooo00001Ooo00<00?ooool00_oo00<00?ooool02?oo00<00?ooool0=Ooo00<0
0?ooool09Ooo000jool00`00ooooo`1Eool200001?oo003ooooo0P0000?oo`0000000_oo00D00?oo
ooooo`0000;oo`05003oooooool00003ool01@00oooooooo00001?oo00<00?ooool00ooo00<00?oo
ool01ooo00<00?ooool0=Ooo00<00?ooool09Ooo000jool00`00ooooo`1Gool01000ool000000_oo
00@00?ooool000;oo`05003oooooool00002ool01@00oooooooo00000ooo00D00?ooooooo`0000Co
o`03003ooooo00;oo`03003ooooo00Soo`03003ooooo03Coo`03003ooooo02Goo`00>_oo00<00?oo
ool0F?oo00@00?ooool000;oo`800004ool00?ooool20002ool01000ooooo`000ooo00D00?oooooo
o`0000?oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Ooo`03003ooooo03Coo`03003o
oooo02Goo`00>_oo00<00?ooool0FOoo0P0000?oo`00ool00_oo00@00?oo000000;oo`04003ooooo
0002ool01@00oooooooo00000_oo00<00?ooool00_oo00D00?ooooooo`0000Coo`03003ooooo00Oo
o`03003ooooo03Coo`03003ooooo02Goo`00>_oo0P00G?oo00@00?oo000000;oo`04003ooooo0002
ool01000ooooo`000_oo00D00?ooooooo`0000;oo`05003oooooool00004ool00`00ooooo`02ool0
0`00ooooo`06ool00`00ooooo`0cool2000Wool003[oo`03003ooooo05coo`04003ooooo0002ool0
1000ooooo`000_oo00@00?ooool000;oo`05003oooooool00002ool01@00oooooooo00001?oo00D0
0?ooooooo`0000Soo`03003ooooo03Coo`03003ooooo02Goo`00>_oo00<00?ooool0GOoo0P0000Co
o`00ooooo`800005ool00000ool00002ool01000ooooo`000ooo00@00?ooool000?oo`05003ooooo
ool00004ool00`00ooooo`05ool00`00ooooo`0dool00`00ooooo`0Uool003[oo`03003ooooo05oo
o`04003oo`000002ool01P00ooooo`00ool000;oo`04003ooooo0003ool01000ooooo`000ooo00D0
0?ooooooo`0000?oo`03003ooooo00Goo`03003ooooo03Coo`03003ooooo02Goo`00>_oo00<00?oo
ool0H?oo0P0000Goo`00ooooo`0000;oo`06003oo`00003oo`000_oo00D00?ooooooo`0000;oo`04
003ooooo0004ool01@00oooooooo00001ooo00<00?ooool0<ooo00<00?ooool09Ooo000jool00`00
ooooo`1Rool00`00ool00002ool01000ooooo`000_oo00<00?oo00000_oo00D00?ooooooo`0000;o
o`04003ooooo0003ool01@00oooooooo00001ooo00<00?ooool0<ooo00<00?ooool09Ooo000jool2
001Tool400001Ooo003ooooo00000_oo00<00?oo00000_oo0P000_oo00<00?oo00000ooo00D00?oo
ooooo`0000?oo`03003ooooo00Coo`03003ooooo03;oo`8002Ooo`00>_oo00<00?ooool0IOoo0`00
00Coo`00003oo`800004ool00?oo0003ool01P00ooooo`00ool000?oo`04003ooooo0003ool00`00
ooooo`04ool00`00ooooo`0cool00`00ooooo`0Uool003[oo`03003ooooo06Ooo`8000;oo`08003o
oooo003oo`00ool000?oo`06003ooooo003oo`000_oo00D00?ooooooo`0000?oo`03003ooooo00?o
o`03003ooooo03?oo`03003ooooo02Goo`00>_oo00<00?ooool0J?oo0`0000Soo`00ooooo`00ool0
0?oo0P000_oo00H00?ooool00?oo0002ool01@00oooooooo00000_oo00<00?ooool00ooo00<00?oo
ool0<ooo00<00?ooool09Ooo000Zool00`00ooooo`02ool00`00ooooo`02ool30003ool00`00oooo
o`1Yool01000ool00?oo0P0000Coo`00ool000;oo`04003ooooo0002ool20003ool01000ooooo`00
0ooo00<00?ooool00_oo00<00?ooool0<ooo00<00?ooool09Ooo000Yool00`00ool00009ool00`00
ooooo`02ool00`00ooooo`1Zool00`00ool00002ool01000ool00?oo0P0000Woo`00ooooo`00ool0
0?oo00000_oo00D00?ooooooo`0000;oo`03003ooooo00;oo`03003ooooo03?oo`03003ooooo02Go
o`00:Ooo00<00?oo00001ooo10000ooo0P00K?oo100000Coo`00ool000;oo`03003oo`0000;oo`05
003oo`00ool00002ool01000ooooo`000_oo00<00?ooool00ooo00<00?ooool0<Ooo0P009ooo000Y
ool00`00ool00007ool00`00ool00004ool00`00ooooo`1]ool01`00ool00?oo003oo`0000;oo`03
003oo`0000;oo`05003oo`00ool00002ool01000ooooo`000_oo00<00?ooool00_oo00<00?ooool0
<_oo00<00?ooool09Ooo000Yool00`00ool00008ool20004ool00`00ooooo`1^ool01`00ool00?oo
003oo`0000;oo`05003oo`00ool00002ool00`00ool00002ool00`00ool00002ool00`00ooooo`02
ool00`00ooooo`0bool00`00ooooo`0Uool002[oo`03003ooooo00Soo`03003ooooo00;oo`03003o
oooo06ooo`03003oo`0000@000;oo`05003oo`00ool00002ool20002ool01000ooooo`000_oo00D0
0?ooooooo`0003Coo`03003ooooo02Goo`00>_oo00<00?ooool0L?oo00D00?ooool00?oo008000;o
o`05003oo`00ool00002ool20002ool01P00ooooo`00ool000?oo`03003ooooo03;oo`03003ooooo
02Goo`00>_oo0P00L_oo0P0000?oo`00ool00P000_oo00D00?oo003oo`0000;oo`8000;oo`03003o
o`0000;oo`04003ooooo000cool2000Wool003[oo`03003ooooo07?oo`03003oo`0000<000;oo`05
003oo`00ool00002ool20002ool01@00ool00?oo00000_oo00<00?ooool0<_oo00<00?ooool09Ooo
000jool00`00ooooo`1dool00`00ooooo`0400001_oo00000000ool000;oo`800004ool00?oo0002
ool00`00ool0000dool00`00ooooo`0Uool003[oo`03003ooooo07Goo`800003ool00000008000;o
o`800003ool00?oo008000;oo`05003oo`00ool00002ool00`00ooooo`0aool00`00ooooo`0Uool0
03[oo`03003ooooo07Ooo`03003oo`0000<000;oo`800003ool00?oo008000;oo`800005ool00?oo
ool0000cool00`00ooooo`0Uool003[oo`03003ooooo07Soo`800003ool0000000800006ool00000
ool00?oo0P0000Soo`00ool00?oo003oo`00<ooo00<00?ooool09Ooo000jool2001kool00`00ool0
000300001?oo000000000_oo0P0000Ooo`00003oo`00ool0000bool2000Wool003[oo`03003ooooo
07_oo`H00004ool000000002ool200001?oo00000?oo0P00<ooo00<00?ooool09Ooo000jool00`00
ooooo`1mool500001?oo003oo`000_oo0P0000?oo`00ool00P00<ooo00<00?ooool09Ooo000jool0
0`00ooooo`1oool600001?oo003ooooo100000?oo`00ool0<_oo00<00?ooool09Ooo000jool00`00
ooooo`20ool300001Ooo00000?oo00000_oo00D00?oo003oo`0003?oo`03003ooooo02Goo`00>_oo
00<00?ooool0POoo1P0000Woo`00ooooo`00ool00?oo0000<_oo00<00?ooool09Ooo000jool20024
ool500000ooo003oo`05000aool2000Wool003[oo`03003ooooo08Coo`<00003ool00?oo00H003;o
o`03003ooooo02Goo`00>_oo00<00?ooool0QOoo0`0000?oo`00ool01P00<Ooo00<00?ooool09Ooo
000jool00`00ooooo`27ool200000ooo003oo`05000aool00`00ooooo`0Uool002[oo`03003ooooo
00;oo`04003oooooool20005ool00`00ooooo`28ool:000`ool00`00ooooo`0Uool002Woo`03003o
o`0000Ooo`03003oo`0000Coo`03003ooooo08Woo`<00003ool0000000<0033oo`03003ooooo02Go
o`00:Ooo00<00?oo00001ooo00<00?oo00001?oo0P00Rooo0`0000?oo`0000000`00;_oo0P009ooo
000Yool00`00ool00007ool20005ool00`00ooooo`2<ool8000^ool00`00ooooo`0Uool002Woo`03
003oo`0000Ooo`03003ooooo00Coo`03003ooooo08goo`L002koo`03003ooooo02Goo`00:_oo00<0
0?ooool01ooo0P001?oo00<00?ooool0S_oo1`00;Ooo00<00?ooool09Ooo000jool00`00ooooo`2?
ool7000/ool00`00ooooo`0Uool003[oo`03003ooooo093oo`H002coo`03003ooooo02Goo`00>_oo
0P00TOoo00<00?oo00001000:_oo0P009ooo000jool00`00ooooo`2Aool00`00ooooo`04000Zool0
0`00ooooo`0Uool003[oo`03003ooooo097oo`03003ooooo00;oo`<002Woo`03003ooooo02Goo`00
>_oo00<00?ooool0TOoo00<00?ooool00_oo1000:?oo00<00?ooool09Ooo000jool00`00ooooo`2A
ool00`00ooooo`03ool5000Vool00`00ooooo`0Uool003[oo`8009;oo`03003ooooo00?oo`03003o
o`0000<002Coo`8002Ooo`00>_oo00<00?ooool0TOoo00<00?ooool01?oo00<00?oo000010008ooo
00<00?ooool09Ooo000jool00`00ooooo`2Bool00`00ooooo`03ool01000ool00?oo1@008Ooo00<0
0?ooool09Ooo000jool00`00ooooo`2Bool00`00ooooo`04ool01000ool00?oo1@008?oo00<00?oo
ool09Ooo000jool00`00ooooo`2Bool00`00ooooo`04ool01@00ooooo`00ool01P007_oo00<00?oo
ool09Ooo000jool00`00ooooo`2Bool00`00ooooo`05ool01@00ooooo`00ool01`007?oo00<00?oo
ool09Ooo000jool2002Cool00`00ooooo`05ool01000ooooo`000_oo1`006_oo0P009ooo000jool0
0`00ooooo`2Bool00`00ooooo`06ool01000ooooo`000_oo20006Ooo00<00?ooool09Ooo000jool0
0`00ooooo`2Cool00`00ooooo`05ool01@00oooooooo00000_oo00<00?oo00001P005ooo00<00?oo
ool09Ooo000jool00`00ooooo`2Cool00`00ooooo`06ool01@00oooooooo00000_oo00<00?oo0000
1`005Ooo00<00?ooool09Ooo000Zool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`03ool0
0`00ooooo`2Cool00`00ooooo`06ool00`00ooooo`02ool00`00ool00002ool9000Cool00`00oooo
o`0Uool002Woo`03003oo`0000Ooo`03003oo`0000Coo`03003ooooo09?oo`03003ooooo00Ooo`03
003ooooo00;oo`03003oo`0000;oo`03003oo`0000L0017oo`03003ooooo02Goo`00:Ooo00<00?oo
00001ooo00<00?oo00001?oo0P00U?oo00<00?ooool01ooo00<00?ooool00_oo00@00?ooool000;o
o`<00003ool0000000D000koo`8002Ooo`00:Ooo00<00?oo00002?oo00<00?ooool00ooo00<00?oo
ool0Tooo00<00?ooool02?oo00<00?ooool00_oo00@00?ooool000?oo`<00003ool0000000D000go
o`03003ooooo02Goo`00:Ooo00<00?oo00001ooo00<00?oo00001?oo00<00?ooool0U?oo00<00?oo
ool01ooo00<00?ooool00ooo00@00?ooool000?oo`04003oo`00ool9000:ool00`00ooooo`0Uool0
02[oo`03003ooooo00Ooo`03003ooooo00?oo`03003ooooo09Coo`03003ooooo00Soo`03003ooooo
00?oo`03003ooooo008000;oo`@00003ool0000000L000Soo`03003ooooo02Goo`00>_oo00<00?oo
ool0U?oo00<00?ooool02Ooo00<00?ooool00ooo00D00?ooooooo`0000?oo`06003oo`00ool00?oo
20001_oo00<00?ooool09Ooo000jool00`00ooooo`2Dool00`00ooooo`09ool00`00ooooo`04ool0
1@00oooooooo00000ooo1P0000?oo`0000001P001?oo00<00?ooool09Ooo000jool2002Eool00`00
ooooo`0:ool00`00ooooo`04ool01000oooooooo0P000ooo00<00?oo00000`0000?oo`0000001000
0ooo0P009ooo000jool00`00ooooo`2Eool00`00ooooo`0:ool00`00ooooo`04ool00`00ooooo`02
ool01@00oooooooo00000_oo00D00?oo00000?oo00@000Coo`03003ooooo02Goo`00>_oo00<00?oo
ool0UOoo00<00?ooool02ooo00<00?ooool01?oo0P000ooo0P000_oo0P0000Coo`00003oo`D000Co
o`03003ooooo02Goo`00>_oo00<00?ooool0UOoo00<00?ooool03?oo00<00?ooool01Ooo00<00?oo
ool00_oo00D00?ooooooo`0000;oo`8000;oo`8000Coo`03003ooooo02Goo`00>_oo00<00?ooool0
UOoo00<00?ooool03Ooo00<00?ooool01Ooo00<00?ooool00_oo0P000_oo0P000_oo0P001_oo00<0
0?ooool09Ooo000jool00`00ooooo`2Fool00`00ooooo`0=ool00`00ooooo`05ool00`00ooooo`03
ool20002ool20002ool20004ool00`00ooooo`0Uool003[oo`8009Ooo`03003ooooo00koo`03003o
oooo00Goo`8000Goo`04003oooooool20005ool2000Wool003[oo`03003ooooo09Koo`03003ooooo
00ooo`03003ooooo00Koo`03003ooooo00?oo`8000?oo`8000Coo`03003ooooo02Goo`00>_oo00<0
0?ooool0U_oo00<00?ooool04?oo00<00?ooool01_oo00<00?ooool01?oo0P001ooo00<00?ooool0
9Ooo000jool00`00ooooo`2Gool00`00ooooo`0@ool00`00ooooo`06ool20006ool20005ool00`00
ooooo`0Uool003[oo`03003ooooo09Ooo`03003ooooo017oo`8000Soo`8000Koo`03003ooooo00;o
o`03003ooooo02Goo`00>_oo0P00VOoo00<00?ooool04_oo0P002?oo0`001ooo0P009ooo000jool0
0`00ooooo`2Hool00`00ooooo`0Dool20009ool20006ool00`00ooooo`0Uool003[oo`03003ooooo
09Woo`03003ooooo01Goo`8000Woo`8000Coo`03003ooooo02Goo`00>_oo00<00?ooool0V_oo00<0
0?ooool05_oo0`003?oo00<00?ooool09Ooo000bool50003ool00`00ooooo`2Kool00`00ooooo`0H
ool50007ool00`00ooooo`0Uool003Coo`03003ooooo00?oo`03003ooooo09coo`8001goo`<000Co
o`03003ooooo02Goo`00=?oo00<00?ooool00ooo0P00Wooo80000ooo0P009ooo000dool00`00oooo
o`03ool00`00ooooo`32ool00`00ooooo`0Uool003Coo`03003ooooo00?oo`03003ooooo00;oo`03
003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00;oo`03003ooooo02Goo`00<ooo0P001OooaP009ooo003ooolXool00?ooobSoo`00oooo
:?oo003ooolXool00?ooobSoo`00oooo:?oo001Eool30003ool20002ool3000:ool40002ool30002
ool30002ool30003ool20002ool30003ool200000ooo00000002ool00`00ooooo`02000@ool20000
1?oo00000?oo10000_oo0P000ooo0`0000Coo`00000000;oo`<000?oo`8000;oo`<000?oo`8000;o
o`8004ooo`00E_oo00D00?ooooooo`0000;oo`04003ooooo000<ool01000ooooo`000_oo00<00?oo
ool00_oo00<00?ooool00_oo00D00?ooooooo`0000Goo`05003oooooool00004ool01P00ooooo`00
ool000;oo`03003ooooo00goo`06003oooooool00?oo0`000_oo00H00?ooool00?oo0002ool01000
ooooo`001?oo00D00?ooooooo`0000;oo`04003ooooo0003ool00`00ooooo`04ool00`00ooooo`1<
ool005Koo`05003oooooool00002ool01000ooooo`003?oo00@00?ooool000;oo`03003ooooo00;o
o`03003ooooo00;oo`04003oooooool30003ool01000oooooooo0`000_oo00H00?ooool00?oo000B
ool01@00ool00?oo00000ooo00@00?ooool000Coo`04003ooooo0002ool00`00ooooo`02ool01@00
oooooooo00001Ooo00@00?ooooooo`<000?oo`03003ooooo04goo`00EOoo0`000ooo0P000_oo1000
2_oo00D00?ooool00?oo008000?oo`<000;oo`<000;oo`<000;oo`@00005ool00000003oo`040000
0ooo00000002000@ool200000ooo00000002ool200000ooo0000000200001?oo00000?oo0P0000?o
o`0000000P0000?oo`0000000_oo10000_oo0P000ooo0`000ooo0P00C_oo001Fool00`00ooooo`0D
ool01000ooooo`001ooo00<00?ooool00_oo00<00?ooool05Ooo00<00?ooool04?oo0P0000?oo`00
00001_oo00<00?ooool04Ooo00<00?ooool0GOoo001Gool00`00ooooo`0Bool40003ool00`00oooo
o`03ool00`00ooooo`02ool00`00ooooo`0Wool200000ooo0000000Fool00`00ooooo`07ool00`00
ooooo`1Gool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool00?oo
obSoo`00oooo:?oo002?ool3002Eool0093oo`03003ooooo09Coo`00K_oo0P000_oo100000Coo`00
000000;oo`<000goo`8000;oo`<000?oo`8000;oo`<000?oo`800003ool0000000;oo`03003ooooo
00[oo`@000?oo`8000;oo`<000?oo`8000;oo`@005[oo`00KOoo00<00?ooool00_oo0`000ooo00<0
0?ooool00_oo00<00?ooool02ooo00H00?ooool00?oo0002ool00`00ool00002ool01000ooooo`00
0ooo00H00?ooool00?oo0002ool00`00ooooo`0;ool01P00ooooo`00ool000Goo`05003oooooool0
0002ool00`00ool00002001Kool006goo`03003ooooo00Coo`05003oooooool00004ool00`00oooo
o`0;ool01P00ooooo`00ool000;oo`03003oo`0000Goo`05003oooooool00002ool00`00ool00002
ool00`00ooooo`0;ool01@00ooooo`00ool00`000ooo00D00?ooooooo`0000Koo`03003ooooo05Wo
o`00KOoo00<00?ooool00ooo0P000ooo00<00?ooool00_oo00<00?ooool02ooo00<00?ooool01@00
00?oo`0000000P000_oo0P001?oo0P0000?oo`0000000P003_oo00D00?ooool00?oo00<000?oo`03
003ooooo00@000?oo`8005_oo`00KOoo00<00?oo00002?oo00<00?ooool00_oo00<00?ooool02ooo
00@00?ooool000Koo`03003ooooo01goo`04003ooooo0007ool01@00oooooooo0000H_oo001]ool3
0007ool20003ool2000>ool2000=ool00`00ooooo`0Fool40007ool2001Vool00?ooobSoo`00oooo
:?oo003ooolXool00?ooobSoo`00oooo:?oo0000\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {18.2723, -0.253306, \
0.106644, 0.00862766}}]
}, Open  ]],

Cell["Here is the equivalent three\[Hyphen]dimensional graph. ", "MathCaption",
  CellTags->"0.24"],

Cell[CellGroupData[{

Cell["\<\
Plot3D[optiondelta[x, t], {x, 25, 55}, {t, 0, 120},
   AxesLabel->{\"Stock Price\", \"Time\", \"Option  \\nDelta\"}];\
\>", \
"Input",
  CellLabel->"In[19]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -11.1734 -9 ]
[.3345 .12542 .8266 0 ]
[.56094 .0364 -10.3394 -9 ]
[.56094 .0364 1.66057 0 ]
[.29165 .07573 -65.1782 -15 ]
[.29165 .07573 4.82182 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.77009 .10107 0 -6.15794 ]
[.77009 .10107 12 2.84206 ]
[.83293 .1973 0 -6.06544 ]
[.83293 .1973 12 2.93456 ]
[.89031 .28516 0 -5.98272 ]
[.89031 .28516 12 3.01728 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 18 3.0917 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 28 4.94788 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -24 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -18 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -24 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -52 -9.75946 ]
[-0.05457 .39542 0 21.2405 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75778 .10561 m
.75162 .10787 L
s
[(25)] .77009 .10107 -1 .36843 Mshowa
.82054 .20161 m
.81434 .20377 L
s
[(50)] .83293 .1973 -1 .34788 Mshowa
.87784 .28927 m
.87161 .29132 L
s
[(75)] .89031 .28516 -1 .32949 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(100)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.70309 .02196 m
.69942 .02338 L
s
.71716 .04348 m
.71349 .04489 L
s
.73096 .06459 m
.72728 .06598 L
s
.7445 .0853 m
.74081 .08667 L
s
.7708 .12553 m
.7671 .12688 L
s
.78358 .14509 m
.77988 .14642 L
s
.79613 .16428 m
.79242 .1656 L
s
.80845 .18312 m
.80473 .18442 L
s
.83241 .21978 m
.82869 .22106 L
s
.84407 .23761 m
.84035 .23888 L
s
.85553 .25514 m
.8518 .25639 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.89939 .32223 m
.89565 .32344 L
s
.9099 .3383 m
.90615 .3395 L
s
.92022 .35409 m
.91647 .35528 L
s
.94036 .3849 m
.9366 .38606 L
s
.95018 .39992 m
.94642 .40107 L
s
.95984 .4147 m
.95608 .41584 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.25)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0.5)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(0.75)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
gsave
-0.05457 .39542 -113 -13.7595 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Option) show
63.000000 31.000000 moveto
(Delta) show
93.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.38313 .58323 .40512 .60371 .44189 .59268 .42021 .57192 Metetra
.664 .741 .908 r
.42021 .57192 .44189 .59268 .47916 .5815 .45781 .56045 Metetra
.664 .741 .908 r
.45781 .56045 .47916 .5815 .51695 .57017 .49594 .54882 Metetra
.663 .741 .908 r
.49594 .54882 .51695 .57017 .55526 .55867 .5346 .53708 Metetra
.636 .733 .919 r
.5346 .53708 .55526 .55867 .59412 .54701 .57386 .52782 Metetra
.128 .507 .91 r
.57386 .52782 .59412 .54701 .63357 .53662 .61441 .54342 Metetra
.827 .395 .21 r
.61441 .54342 .63357 .53662 .67811 .62733 .65819 .60966 Metetra
.717 .219 0 r
.65819 .60966 .67811 .62733 .72576 .71779 .70425 .67021 Metetra
.479 .511 .813 r
.70425 .67021 .72576 .71779 .76967 .70812 .74974 .6828 Metetra
.619 .719 .918 r
.74974 .6828 .76967 .70812 .81416 .69643 .79493 .67415 Metetra
.644 .76 .933 r
.79493 .67415 .81416 .69643 .85934 .68456 .84064 .66214 Metetra
.646 .762 .934 r
.84064 .66214 .85934 .68456 .90523 .6725 .88706 .64973 Metetra
.646 .762 .934 r
.88706 .64973 .90523 .6725 .95186 .66025 .93423 .63711 Metetra
.646 .762 .934 r
.93423 .63711 .95186 .66025 .99922 .6478 .98216 .62429 Metetra
.664 .741 .908 r
.36056 .56222 .38313 .58323 .42021 .57192 .39797 .55062 Metetra
.664 .741 .908 r
.39797 .55062 .42021 .57192 .45781 .56045 .4359 .53885 Metetra
.663 .741 .908 r
.4359 .53885 .45781 .56045 .49594 .54882 .47437 .52698 Metetra
.65 .738 .914 r
.47437 .52698 .49594 .54882 .5346 .53708 .51339 .51625 Metetra
.523 .705 .954 r
.51339 .51625 .5346 .53708 .57386 .52782 .55309 .5149 Metetra
0 .201 .615 r
.55309 .5149 .57386 .52782 .61441 .54342 .59417 .5398 Metetra
.776 .273 0 r
.59417 .5398 .61441 .54342 .65819 .60966 .63762 .5901 Metetra
.509 .001 0 r
.63762 .5901 .65819 .60966 .70425 .67021 .68303 .63459 Metetra
.355 .509 .873 r
.68303 .63459 .70425 .67021 .74974 .6828 .72899 .65204 Metetra
.567 .659 .898 r
.72899 .65204 .74974 .6828 .79493 .67415 .775 .64925 Metetra
.629 .736 .924 r
.775 .64925 .79493 .67415 .84064 .66214 .82135 .63872 Metetra
.643 .758 .932 r
.82135 .63872 .84064 .66214 .88706 .64973 .86834 .62624 Metetra
.646 .762 .934 r
.86834 .62624 .88706 .64973 .93423 .63711 .91607 .61328 Metetra
.646 .762 .934 r
.91607 .61328 .93423 .63711 .98216 .62429 .96458 .60007 Metetra
.664 .741 .908 r
.33741 .54067 .36056 .56222 .39797 .55062 .37515 .52876 Metetra
.663 .741 .908 r
.37515 .52876 .39797 .55062 .4359 .53885 .41342 .5167 Metetra
.659 .74 .91 r
.41342 .5167 .4359 .53885 .47437 .52698 .45223 .50491 Metetra
.621 .732 .926 r
.45223 .50491 .47437 .52698 .51339 .51625 .49158 .49647 Metetra
.396 .665 .967 r
.49158 .49647 .51339 .51625 .55309 .5149 .53163 .50074 Metetra
0 .185 .61 r
.53163 .50074 .55309 .5149 .59417 .5398 .57301 .52715 Metetra
.642 .098 0 r
.57301 .52715 .59417 .5398 .63762 .5901 .61641 .56906 Metetra
0 .15 .645 r
.61641 .56906 .63762 .5901 .68303 .63459 .66164 .60546 Metetra
.276 .519 .905 r
.66164 .60546 .68303 .63459 .72899 .65204 .70784 .62264 Metetra
.526 .655 .917 r
.70784 .62264 .72899 .65204 .775 .64925 .75444 .62278 Metetra
.61 .721 .924 r
.75444 .62278 .775 .64925 .82135 .63872 .80144 .61399 Metetra
.637 .75 .93 r
.80144 .61399 .82135 .63872 .86834 .62624 .84903 .60186 Metetra
.644 .76 .933 r
.84903 .60186 .86834 .62624 .91607 .61328 .89735 .58868 Metetra
.646 .762 .934 r
.89735 .58868 .91607 .61328 .96458 .60007 .94646 .57509 Metetra
.663 .741 .908 r
.31365 .51855 .33741 .54067 .37515 .52876 .35172 .50633 Metetra
.662 .741 .909 r
.35172 .50633 .37515 .52876 .41342 .5167 .39032 .49408 Metetra
.649 .738 .915 r
.39032 .49408 .41342 .5167 .45223 .50491 .42946 .48299 Metetra
.577 .724 .943 r
.42946 .48299 .45223 .50491 .49158 .49647 .46911 .47762 Metetra
.267 .613 .957 r
.46911 .47762 .49158 .49647 .53163 .50074 .50946 .48597 Metetra
0 .203 .629 r
.50946 .48597 .53163 .50074 .57301 .52715 .55109 .51186 Metetra
.506 0 0 r
.55109 .51186 .57301 .52715 .61641 .56906 .59455 .54731 Metetra
0 .265 .745 r
.59455 .54731 .61641 .56906 .66164 .60546 .63978 .57758 Metetra
.269 .533 .916 r
.63978 .57758 .66164 .60546 .70784 .62264 .68618 .59336 Metetra
.499 .649 .925 r
.68618 .59336 .70784 .62264 .75444 .62278 .73327 .59506 Metetra
.592 .709 .925 r
.73327 .59506 .75444 .62278 .80144 .61399 .78088 .58786 Metetra
.628 .741 .929 r
.78088 .58786 .80144 .61399 .84903 .60186 .8291 .57639 Metetra
.641 .755 .932 r
.8291 .57639 .84903 .60186 .89735 .58868 .87803 .56319 Metetra
.645 .76 .933 r
.87803 .56319 .89735 .58868 .94646 .57509 .92776 .5493 Metetra
.663 .741 .908 r
.28926 .49583 .31365 .51855 .35172 .50633 .32765 .48331 Metetra
.659 .74 .91 r
.32765 .48331 .35172 .50633 .39032 .49408 .36659 .47103 Metetra
.635 .736 .921 r
.36659 .47103 .39032 .49408 .42946 .48299 .40603 .46092 Metetra
.533 .713 .954 r
.40603 .46092 .42946 .48299 .46911 .47762 .44595 .45805 Metetra
.206 .576 .941 r
.44595 .45805 .46911 .47762 .50946 .48597 .48657 .46856 Metetra
0 .266 .709 r
.48657 .46856 .50946 .48597 .55109 .51186 .52844 .4933 Metetra
0 .17 .633 r
.52844 .4933 .55109 .51186 .59455 .54731 .57203 .52447 Metetra
0 .343 .807 r
.57203 .52447 .59455 .54731 .63978 .57758 .61736 .55071 Metetra
.267 .548 .926 r
.61736 .55071 .63978 .57758 .68618 .59336 .66401 .56501 Metetra
.479 .654 .937 r
.66401 .56501 .68618 .59336 .73327 .59506 .71153 .56719 Metetra
.576 .707 .932 r
.71153 .56719 .73327 .59506 .78088 .58786 .75971 .5609 Metetra
.619 .737 .931 r
.75971 .5609 .78088 .58786 .8291 .57639 .80854 .54994 Metetra
.637 .752 .932 r
.80854 .54994 .8291 .57639 .87803 .56319 .8581 .53678 Metetra
.643 .759 .933 r
.8581 .53678 .87803 .56319 .92776 .5493 .90846 .52263 Metetra
.662 .741 .909 r
.2642 .47251 .28926 .49583 .32765 .48331 .30293 .45974 Metetra
.654 .74 .913 r
.30293 .45974 .32765 .48331 .36659 .47103 .34218 .44767 Metetra
.615 .733 .93 r
.34218 .44767 .36659 .47103 .40603 .46092 .3819 .43894 Metetra
.483 .699 .964 r
.3819 .43894 .40603 .46092 .44595 .45805 .42207 .43844 Metetra
.15 .548 .926 r
.42207 .43844 .44595 .45805 .48657 .46856 .46294 .45035 Metetra
0 .305 .744 r
.46294 .45035 .48657 .46856 .52844 .4933 .50504 .47359 Metetra
0 .257 .716 r
.50504 .47359 .52844 .4933 .57203 .52447 .54882 .50096 Metetra
0 .405 .85 r
.54882 .50096 .57203 .52447 .61736 .55071 .59432 .52365 Metetra
.286 .565 .932 r
.59432 .52365 .61736 .55071 .66401 .56501 .64122 .5363 Metetra
.471 .654 .94 r
.64122 .5363 .66401 .56501 .71153 .56719 .68915 .53852 Metetra
.565 .702 .934 r
.68915 .53852 .71153 .56719 .75971 .5609 .73787 .53287 Metetra
.611 .731 .931 r
.73787 .53287 .75971 .5609 .80854 .54994 .78731 .52239 Metetra
.632 .748 .931 r
.78731 .52239 .80854 .54994 .8581 .53678 .83751 .50934 Metetra
.641 .756 .932 r
.83751 .50934 .8581 .53678 .90846 .52263 .88853 .495 Metetra
.66 .741 .909 r
.23845 .44856 .2642 .47251 .30293 .45974 .27751 .43563 Metetra
.646 .738 .917 r
.27751 .43563 .30293 .45974 .34218 .44767 .31707 .42397 Metetra
.592 .728 .939 r
.31707 .42397 .34218 .44767 .3819 .43894 .35704 .41666 Metetra
.439 .683 .967 r
.35704 .41666 .3819 .43894 .42207 .43844 .39743 .41802 Metetra
.13 .533 .918 r
.39743 .41802 .42207 .43844 .46294 .45035 .43855 .43063 Metetra
0 .351 .789 r
.43855 .43063 .46294 .45035 .50504 .47359 .4809 .45231 Metetra
0 .331 .783 r
.4809 .45231 .50504 .47359 .54882 .50096 .52489 .47659 Metetra
.06 .452 .88 r
.52489 .47659 .54882 .50096 .59432 .52365 .5706 .49638 Metetra
.303 .58 .938 r
.5706 .49638 .59432 .52365 .64122 .5363 .61778 .50748 Metetra
.466 .657 .944 r
.61778 .50748 .64122 .5363 .68915 .53852 .66612 .5094 Metetra
.556 .702 .937 r
.66612 .5094 .68915 .53852 .73787 .53287 .71536 .50404 Metetra
.603 .729 .933 r
.71536 .50404 .73787 .53287 .78731 .52239 .7654 .49387 Metetra
.627 .745 .932 r
.7654 .49387 .78731 .52239 .83751 .50934 .81625 .4809 Metetra
.638 .754 .932 r
.81625 .4809 .83751 .50934 .88853 .495 .86794 .46638 Metetra
.658 .74 .911 r
.21199 .42398 .23845 .44856 .27751 .43563 .25137 .41093 Metetra
.637 .737 .921 r
.25137 .41093 .27751 .43563 .31707 .42397 .29121 .39972 Metetra
.571 .722 .944 r
.29121 .39972 .31707 .42397 .35704 .41666 .33142 .39357 Metetra
.409 .668 .966 r
.33142 .39357 .35704 .41666 .39743 .41802 .37204 .39618 Metetra
.136 .529 .918 r
.37204 .39618 .39743 .41802 .43855 .43063 .41339 .40899 Metetra
0 .392 .828 r
.41339 .40899 .43855 .43063 .4809 .45231 .45598 .42927 Metetra
0 .386 .83 r
.45598 .42927 .4809 .45231 .52489 .47659 .5002 .45118 Metetra
.113 .485 .9 r
.5002 .45118 .52489 .47659 .5706 .49638 .54616 .46876 Metetra
.317 .592 .943 r
.54616 .46876 .5706 .49638 .61778 .50748 .59366 .47852 Metetra
.463 .662 .948 r
.59366 .47852 .61778 .50748 .66612 .5094 .6424 .47998 Metetra
.549 .703 .942 r
.6424 .47998 .66612 .5094 .71536 .50404 .69216 .47462 Metetra
.597 .728 .936 r
.69216 .47462 .71536 .50404 .7654 .49387 .7428 .46453 Metetra
.623 .744 .934 r
.7428 .46453 .7654 .49387 .81625 .4809 .79429 .45151 Metetra
.635 .753 .933 r
.79429 .45151 .81625 .4809 .86794 .46638 .84665 .43677 Metetra
.654 .74 .913 r
.18477 .39874 .21199 .42398 .25137 .41093 .22445 .3857 Metetra
.626 .735 .926 r
.22445 .3857 .25137 .41093 .29121 .39972 .26456 .37514 Metetra
.547 .717 .951 r
.26456 .37514 .29121 .39972 .33142 .39357 .30499 .37021 Metetra
.376 .656 .966 r
.30499 .37021 .33142 .39357 .37204 .39618 .34583 .37389 Metetra
.128 .527 .916 r
.34583 .37389 .37204 .39618 .41339 .40899 .38741 .38665 Metetra
0 .42 .848 r
.38741 .38665 .41339 .40899 .45598 .42927 .43025 .40544 Metetra
0 .427 .859 r
.43025 .40544 .45598 .42927 .5002 .45118 .47473 .42504 Metetra
.157 .514 .915 r
.47473 .42504 .5002 .45118 .54616 .46876 .52096 .44046 Metetra
.335 .604 .946 r
.52096 .44046 .54616 .46876 .59366 .47852 .56879 .44882 Metetra
.465 .665 .949 r
.56879 .44882 .59366 .47852 .6424 .47998 .61795 .44967 Metetra
.546 .702 .942 r
.61795 .44967 .6424 .47998 .69216 .47462 .66821 .44419 Metetra
.592 .726 .937 r
.66821 .44419 .69216 .47462 .7428 .46453 .71944 .43411 Metetra
.619 .741 .934 r
.71944 .43411 .7428 .46453 .79429 .45151 .77158 .42102 Metetra
.633 .751 .933 r
.77158 .42102 .79429 .45151 .84665 .43677 .82464 .40606 Metetra
.65 .739 .915 r
.15676 .37282 .18477 .39874 .22445 .3857 .19675 .35982 Metetra
.615 .732 .93 r
.19675 .35982 .22445 .3857 .26456 .37514 .23711 .34981 Metetra
.528 .71 .955 r
.23711 .34981 .26456 .37514 .30499 .37021 .27776 .3458 Metetra
.358 .644 .963 r
.27776 .3458 .30499 .37021 .34583 .37389 .3188 .35013 Metetra
.144 .53 .92 r
.3188 .35013 .34583 .37389 .38741 .38665 .36061 .36262 Metetra
.023 .449 .871 r
.36061 .36262 .38741 .38665 .43025 .40544 .40369 .3801 Metetra
.056 .461 .883 r
.40369 .3801 .43025 .40544 .47473 .42504 .44844 .39784 Metetra
.194 .536 .925 r
.44844 .39784 .47473 .42504 .52096 .44046 .49496 .41151 Metetra
.348 .614 .949 r
.49496 .41151 .52096 .44046 .56879 .44882 .54313 .41865 Metetra
.466 .669 .951 r
.54313 .41865 .56879 .44882 .61795 .44967 .59272 .41885 Metetra
.542 .704 .945 r
.59272 .41885 .61795 .44967 .66821 .44419 .6435 .41308 Metetra
.588 .726 .939 r
.6435 .41308 .66821 .44419 .71944 .43411 .69533 .40284 Metetra
.615 .741 .936 r
.69533 .40284 .71944 .43411 .77158 .42102 .74812 .38955 Metetra
.63 .75 .934 r
.74812 .38955 .77158 .42102 .82464 .40606 .80187 .3743 Metetra
.644 .738 .918 r
.12793 .34624 .15676 .37282 .19675 .35982 .1682 .33339 Metetra
.601 .73 .935 r
.1682 .33339 .19675 .35982 .23711 .34981 .20879 .32405 Metetra
.505 .704 .959 r
.20879 .32405 .23711 .34981 .27776 .3458 .24963 .32096 Metetra
.336 .635 .962 r
.24963 .32096 .27776 .3458 .3188 .35013 .29086 .32581 Metetra
.146 .533 .921 r
.29086 .32581 .3188 .35013 .36061 .36262 .3329 .33787 Metetra
.054 .471 .885 r
.3329 .33787 .36061 .36262 .40369 .3801 .37625 .35397 Metetra
.097 .489 .899 r
.37625 .35397 .40369 .3801 .44844 .39784 .42128 .36982 Metetra
.225 .555 .933 r
.42128 .36982 .44844 .39784 .49496 .41151 .46811 .38172 Metetra
.363 .623 .952 r
.46811 .38172 .49496 .41151 .54313 .41865 .51665 .38759 Metetra
.47 .671 .952 r
.51665 .38759 .54313 .41865 .59272 .41885 .56667 .38704 Metetra
.541 .704 .945 r
.56667 .38704 .59272 .41885 .6435 .41308 .61797 .38089 Metetra
.585 .725 .939 r
.61797 .38089 .6435 .41308 .69533 .40284 .67039 .37042 Metetra
.612 .739 .936 r
.67039 .37042 .69533 .40284 .74812 .38955 .72384 .35691 Metetra
.628 .748 .934 r
.72384 .35691 .74812 .38955 .80187 .3743 .7783 .34135 Metetra
.638 .737 .92 r
.09823 .31891 .12793 .34624 .1682 .33339 .13878 .30619 Metetra
.589 .726 .939 r
.13878 .30619 .1682 .33339 .20879 .32405 .17959 .29737 Metetra
.488 .696 .96 r
.17959 .29737 .20879 .32405 .24963 .32096 .22062 .29492 Metetra
.327 .627 .96 r
.22062 .29492 .24963 .32096 .29086 .32581 .26205 .30001 Metetra
.165 .538 .925 r
.26205 .30001 .29086 .32581 .3329 .33787 .30431 .31155 Metetra
.094 .491 .899 r
.30431 .31155 .3329 .33787 .37625 .35397 .34791 .32641 Metetra
.138 .511 .912 r
.34791 .32641 .37625 .35397 .42128 .36982 .39322 .34068 Metetra
.252 .57 .939 r
.39322 .34068 .42128 .36982 .46811 .38172 .44037 .35109 Metetra
.374 .63 .953 r
.44037 .35109 .46811 .38172 .51665 .38759 .48928 .35581 Metetra
.472 .675 .953 r
.48928 .35581 .51665 .38759 .56667 .38704 .53976 .35451 Metetra
.539 .705 .947 r
.53976 .35451 .56667 .38704 .61797 .38089 .59158 .34788 Metetra
.583 .726 .941 r
.59158 .34788 .61797 .38089 .67039 .37042 .6446 .33707 Metetra
.609 .739 .937 r
.6446 .33707 .67039 .37042 .72384 .35691 .69872 .32321 Metetra
.626 .748 .935 r
.69872 .32321 .72384 .35691 .7783 .34135 .7539 .30726 Metetra
.631 .736 .923 r
.06762 .29087 .09823 .31891 .13878 .30619 .10842 .27838 Metetra
.576 .724 .943 r
.10842 .27838 .13878 .30619 .17959 .29737 .14943 .27015 Metetra
.469 .69 .963 r
.14943 .27015 .17959 .29737 .22062 .29492 .19063 .26831 Metetra
.313 .622 .959 r
.19063 .26831 .22062 .29492 .26205 .30001 .23225 .27354 Metetra
.171 .544 .927 r
.23225 .27354 .26205 .30001 .30431 .31155 .27474 .28445 Metetra
.119 .508 .909 r
.27474 .28445 .30431 .31155 .34791 .32641 .3186 .298 Metetra
.168 .531 .922 r
.3186 .298 .34791 .32641 .39322 .34068 .36421 .31064 Metetra
.275 .584 .944 r
.36421 .31064 .39322 .34068 .44037 .35109 .4117 .31951 Metetra
.387 .637 .955 r
.4117 .31951 .44037 .35109 .48928 .35581 .461 .32302 Metetra
.476 .678 .953 r
.461 .32302 .48928 .35581 .53976 .35451 .51192 .32089 Metetra
.539 .705 .947 r
.51192 .32089 .53976 .35451 .59158 .34788 .56428 .31371 Metetra
.581 .725 .942 r
.56428 .31371 .59158 .34788 .6446 .33707 .6179 .30248 Metetra
.607 .738 .937 r
.6179 .30248 .6446 .33707 .69872 .32321 .6727 .28825 Metetra
.623 .747 .935 r
.6727 .28825 .69872 .32321 .7539 .30726 .72861 .27187 Metetra
.624 .734 .926 r
.03607 .262 .06762 .29087 .10842 .27838 .07711 .24967 Metetra
.564 .719 .946 r
.07711 .24967 .10842 .27838 .14943 .27015 .11832 .24187 Metetra
.456 .683 .963 r
.11832 .24187 .14943 .27015 .19063 .26831 .15969 .2404 Metetra
.31 .617 .957 r
.15969 .2404 .19063 .26831 .23225 .27354 .20148 .24557 Metetra
.188 .55 .931 r
.20148 .24557 .23225 .27354 .27474 .28445 .24419 .25582 Metetra
.15 .523 .918 r
.24419 .25582 .27474 .28445 .3186 .298 .28831 .26818 Metetra
.199 .546 .929 r
.28831 .26818 .3186 .298 .36421 .31064 .33421 .2794 Metetra
.295 .595 .947 r
.33421 .2794 .36421 .31064 .4117 .31951 .38204 .28691 Metetra
.397 .643 .956 r
.38204 .28691 .4117 .31951 .461 .32302 .43173 .28931 Metetra
.479 .681 .954 r
.43173 .28931 .461 .32302 .51192 .32089 .48312 .28635 Metetra
.539 .707 .949 r
.48312 .28635 .51192 .32089 .56428 .31371 .53602 .27856 Metetra
.579 .725 .943 r
.53602 .27856 .56428 .31371 .6179 .30248 .59026 .26683 Metetra
.605 .738 .939 r
.59026 .26683 .6179 .30248 .6727 .28825 .64574 .25212 Metetra
.622 .747 .936 r
.64574 .25212 .6727 .28825 .72861 .27187 .70239 .23524 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jA000`40n007h00Ooooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00
oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00
oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003Fool00`00ooooo`17ool00=Goo`03003oo`00
04Soo`00eOoo00<00?oo0000B?oo003Eool00`00ool00018ool00=Goo`03003oo`0004Soo`00/?oo
00<00?ooool00_oo00<00?ooool07_oo00<00?ooool0Aooo002_ool00`00ool00002ool00`00ool0
000Iool3001=ool00;7oo`06003ooooo003oo`006?oo0P0000?oo`000000C?oo002_ool20003ool0
0`00ool0000Eool30003ool2001<ool00:ooo`03003ooooo00;oo`03003oo`0001;oo`<000Koo`03
003oo`0004_oo`00[ooo0`000ooo00<00?ooool03ooo0P002Ooo00@00?ooool004[oo`00a?oo0`00
2ooo00@00?oo000004[oo`00?ooo0`000ooo0P000ooo0P000_oo0`0000Coo`00003oo`8000_oo`<0
00?oo`<000;oo`<000;oo`<000?oo`8004Soo`8000koo`05003oooooool00019ool003ooo`03003o
o`0000;oo`06003ooooo003oo`000_oo00<00?oo00001?oo00<00?oo00003Ooo00<00?ooool00ooo
00<00?ooool00_oo00D00?ooooooo`0000Coo`03003ooooo04Goo`<0013oo`03003ooooo00;oo`03
003ooooo04Koo`00@Ooo00@00?ooool000Coo`06003ooooo003oo`001?oo0`003Ooo0`000ooo00<0
0?ooool00_oo00D00?ooooooo`0000Coo`<004?oo`8001?oo`03003ooooo00;oo`03003ooooo04Ko
o`00@?oo00<00?ooool010000ooo0P000_oo0`000_oo00@00?oo000000coo`05003ooooo003oo`04
00000ooo00000003ool30002ool30010ool3000Fool01000oooooooo0P00Aooo000oool00`00ool0
0002ool00`00ooooo`0<ool00`00ooooo`0=ool01000ooooo`00D?oo0`006Ooo00<00?ooool00_oo
00<00?ooool0AOoo000oool3000@ool2000>ool40008ool00`00ooooo`14ool20002ool00`00oooo
o`0Gool00`00ooooo`03ool00`00ooooo`14ool00;;oo`<001koo`03003ooooo00Coo`03003ooooo
04?oo`00[_oo00@00?oo0000027oo`03003ooooo00Coo`8004Coo`00[Ooo0`008ooo00<00?ooool0
1?oo0P00A?oo002[ool2000Vool00`00ooooo`06ool00`00ooooo`11ool00:Soo`<002Soo`03003o
oooo00Koo`03003ooooo047oo`00Y?oo1000:ooo00<00?ooool01ooo00<00?ooool01?oo0`000ooo
00<00?ooool0<ooo001oool30002ool00`00ooooo`0Lool3000]ool00`00ooooo`07ool20005ool0
0`00ooooo`02ool00`00ool0000dool0083oo`06003ooooo003oo`006_oo0`00<?oo00<00?ooool0
2?oo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool0<_oo001nool400001?oo003oo`006?oo
0P00<ooo00<00?ooool02Ooo00<00?ooool00ooo00@00?ooooooo`8003Goo`00O_oo00<00?oo0000
0_oo00<00?oo00005Ooo0`00=Ooo00<00?ooool02_oo00L00?ooooooo`00ool00002ool00`00oooo
o`0dool007ooo`8000;oo`03003oo`0001?oo`<003Ooo`03003ooooo00[oo`03003ooooo00;oo`04
003oooooool3000dool0083oo`05003oooooool0000Aool3000jool00`00ooooo`09ool00`00ool0
000nool009?oo`<003goo`03003ooooo00coo`03003ooooo03_oo`00TOoo0P00@?oo00<00?ooool0
3?oo00<00?ooool0>ooo002>ool30013ool00`00ooooo`0<ool00`00ooooo`0jool008coo`8004Ko
o`03003ooooo00_oo`03003oo`0003_oo`00R?oo1000B?oo00<00?ooool03Ooo00<00?ooool0>Ooo
0027ool3001:ool00`00ooooo`0>ool00`00ooooo`0hool008Coo`<004goo`03003ooooo00koo`80
03Woo`00POoo0`00D?oo00<00?ooool03_oo0P00>Ooo001oool2001Cool00`00ooooo`0@ool00`00
ooooo`0fool007coo`<00003ool00?oo05;oo`03003ooooo013oo`03003ooooo03Koo`00N_oo0P00
F?oo00<00?ooool04Ooo00<00?ooool0=Ooo001fool4001Jool00`00ooooo`0Aool2000fool0057o
o`8000Coo`03003ooooo01_oo`<005coo`03003ooooo01;oo`03003ooooo03Coo`00Dooo00H00?oo
ool00?oo000Iool3001Oool00`00ooooo`0Cool00`00ooooo`05ool00`00ooooo`02ool00`00oooo
o`0Vool005;oo`07003oooooool00?oo00005_oo0`00H_oo00<00?ooool05?oo00<00?ooool00ooo
00<00?oo00000_oo00<00?oo00009ooo001Cool01P00ooooo`00ool001Coo`8006Goo`03003ooooo
01?oo`8000Ooo`06003ooooo003oo`009ooo001Aool00`00ool00002ool00`00ool0000Aool30000
0ooo003oo`1Tool00`00ooooo`0Eool00`00ooooo`02ool20003ool00`00ool0000=ool30002ool3
00001_oo003oo`00ool000;oo`8000Soo`00D_oo00<00?ooool00_oo00<00?ooool03_oo0P00J_oo
00<00?ooool05_oo00D00?ooooooo`0000Coo`03003oo`0000koo`03003ooooo00;oo`0:003ooooo
003oo`00ool00?oo000:ool006Coo`@006coo`03003ooooo01Koo`8000;oo`<000?oo`03003ooooo
00goo`03003ooooo00;oo`09003ooooo003oo`00ool00?oo00<000Soo`00Hooo0`00K_oo00<00?oo
ool05Ooo0`006?oo00@00?ooooooo`8000;oo`800004ool00?ooool30008ool0063oo`<007;oo`03
003ooooo01Ooo`03003ooooo01?oo`05003oo`00ool0000Fool005goo`<007Goo`03003ooooo01Oo
o`03003ooooo01?oo`D000;oo`03003ooooo017oo`00Fooo0P00N?oo00<00?ooool06?oo00<00?oo
ool0;Ooo001Hool30002ool00`00ooooo`1eool00`00ooooo`0Gool2000_ool005Koo`8007goo`03
003ooooo01Woo`03003ooooo02coo`00Dooo0`00Oooo00<00?ooool06_oo00<00?ooool0:ooo001A
ool200000ooo003oo`1mool3000Lool2000/ool004koo`<000Koo`l006Woo`@00004WOfMg@00000L
ool00`00ooooo`0Zool004_oo`<000Goo`@0000?SIf=_P00MGi]GGEnKEeeOVeMMGi]G@00C=e<oTCM
00L005koo`@000:Mo@03UObMoIgm00<001goo`03003ooooo02Woo`00BOoo0P0000?oo`00ool01@00
01Z=_HfMSKf=WHfmSIf=_@00MGiUGWEnIEieOVENMGiUGP00C=e<oTcMC?i<gDcnC=d002aM1000E_oo
100000JMoIgMWOfMgIgmWMd3000019gMWOd000007?oo00<00?ooool0:Ooo0017ool200000ooo0000
000200003IgmUIbMo@00SKj=WHfnSIf=_XfMSKj=WHfn00800007KEeeOVeMMGi]GGEnKEd00P0000]<
oTCMC?i<gDcnA=d002aL;7d/G2am00@004koo`@00005UOfMo@00WOfEo002WOd30002WOd01YGlWOfM
o@00UO`001_oo`8002[oo`00Aooo0`0002>MgIgmWMbMoIgMWOfMg9gm002=_HfMSKf=WHfmSIf=_HfM
SKf=W@00IEieOVENMGiUGWEnIEieOP00C?i<gDcnC=e<oTcM008000D/G@@004Ooo`@00007UOfEgIGm
UMfEoIGMUOd0100000bMgIgmWMfMoIgMWOfMgIgmWMd009gM000Lool00`00ooooo`0Wool0047oo`03
003ooooo00?oo`80000_UIbMoIfLWOfEW9gmWIbMoIFLWOd008fnSIf=_XfMSKj=WHfnSIf=_XfM001]
GGEnKEeeOVeMMGi]GGEn001<oTCMC?i<gDcnA=e<oP00;7d/G2am;5`/O@0093dL70030011ool30000
2YGmWOfEoIgmUOfMoIGmWOfEoIgm0P000Ygm00FEo9gmWOfMoIGl00>Mo@03UObMoIgm008001coo`03
003ooooo00Goo`03003ooooo00;oo`03003ooooo01[oo`00@?oo00<00?oo00000ooo0P0001Goo`00
WMbMoIgMWOfMg9gmWMfMoIgLWOd008fmSIf=_HfMSKf=WHfmSId0400000A<oTcMC?h000D/G@800003
71`T7A`L00@003Woo`@0000:SIfE_@00UOfEgIGmUMfEoIGMUOd3000049GmUMd009gMWOfMgIgmWMfM
oIgMWOfMgIgmWMfMoIgM0P007?oo00<00?ooool01?oo00L00?ooooooo`00ool0000Kool0043oo`03
003oo`0000?oo`0C003oooooool009FLWOfMW9gmUIbMoIfLWOfEW9gm002=_XfMSKh01000012=WIGm
SId007EMMGieGGEnMEeeOWEMMGh004cnC=e<oPL0000;;7d/G2am;5`001`L93dL72@m000dO@05000`
ool400002iGnSIfEoHfMUOj=WIGm002MoIGmWOd00`0000NMoIGmWOfEoIgmUOd00002WOd01IGlWOfM
oIgmUO`00Ygm100000>Mo@00ool06_oo0P001Ooo00<00?ooool00ooo00<00?ooool06Ooo0010ool0
0`00ool00003ool20003ool02@00WMbMoIgMWOfMg9gmWMfMo@0500006hfmSIfE_HfMSKf=WIFmSId0
07ENMGieGWEnMEieOWENMGh004cnC=e<oTcNC?i<gDcn000/G@0400002BaM000L72@M71`T7000;5d/
G003;5d5000Sool800002hfMUKf=WIFmSIfE_HfMUKf=WIFmSId01000012EoIGMUOfEgIGmUMfEoIGM
UOfEg@00WMfMoIgMWOfMg@<00004WMfMoIgMWOd2000Lool00`00ooooo`04ool00`00ooooo`02000L
ool0043oo`03003oo`0000?oo`03003ooooo00?oo`04002EW9gmWI`400005igmWObUo@00UOf=WIGn
SIfEoHfMUOj=WIGmSId007EMMGieGGEnMEeeOWEMMGh00P0000]<gDcnC=e<oTcMC?h002am91`/OB@L
00@0000393dL72@m00800008;1`dOB`L=7d/73Am001<_PD001?oo`/0000AQKj5WHfnQIf5_XFM002=
WIGmSIfEoXfMUOf=WIGnSIfEo@0400003IGmWOfEoIgmUOfMoIGmWOfEoIgmUOfMo@0000:Mo@<000:M
o@06UObMoIgmWOfEo9gm0P007?oo00L00?ooooooo`00ool00002ool00`00ooooo`0Kool0047oo`03
003ooooo00;oo`8000Goo`<0000TWMbMoIgLWOfMg9gmWMbMo@00UKf=WHfmSIfE_HfMSKf=WIFmSId0
07ENMGieGWEnMEieOWENMGieGP00C=e<oTcNC?i<gDcn0P0000DLG2AM75d/GAaL00@0000491`L7000
;5`3;5d022aL;5d004bm?9e4_CbMC;dC00006GEnMEeeOWEMMGieG@00QIf5_HFMQKf5WHFmQIf5_HFM
QKf5W@00SIfE_HfMUKf=WIFm00<0000@UKf=WIFmSId009GMUOfEgIGmUMfEoIGMUOfEgIGmUMd30000
39gMWOfMgIgmWMfMoIgMWOfMgIgmWMfMo@8001coo`03003ooooo00<000;oo`<001_oo`00A_oo00<0
0?ooool01Ooo00/009glYOfMo9gmWObUoIglWOfMo:Gm0080000?SIfEoXfMUOf=WIGnSIfEoHfM001e
GGEnMEeeOWEM00T0000<C=e<oTcM000T72am91`/OB@L000Cg1`l100003@/73Am;1`dOB`L=7d004bn
A9e<_TBMC;i4WDbn001U?UdMICiM7FDnGAeU?UdMICiM7@00MEemOWEMOGieGGenMEemOWEMOGieG@00
QIf5_XFMSKj5WHFnQIf=_XFMQKj5W@00SIfEo@<0000?UOf=WIGnSIfEoHfMUOj=W@00UOfMoIGmWOfE
oIgm00@00003UOfMo@0000>Mo@05UObMoIgmWOfEo003WOd00iGl0000000Kool2000Uool004Koo`03
003ooooo00Koo`0E002Mg9gmWMbMoIgLWOfMg9gmWMbMoIgL002=WHfmSIfE_HfMSKf=WIFm00H00009
MEim_WEMOKieGP00C=e<oTcN00H0000995dLGBaM75`001?L71`Cg1`L00<000</G@0/;5`/G@00C;dl
WDBm?9e<_CbMA;d006DnGAeU?VDMICiM7FDnIAeU?UdM001eGGEnMEeeOWEMMGieGGEnMEeeOP00QKf5
WHFmQIf5_HFMQKf5WHFmQIf5_@<0000>UKf=WIFmSIfE_HfMUKf=WIFmSIfE_@00UOfEg@@0000DUOfE
gIgmUMfEoIGMWOd009gmWMfMoIgMWOfMgIgmWMfMoIgMWOfMg@8001coo`03003ooooo02;oo`00AOoo
0P002Ooo0P0000jUoIglWOfMo:GmWObMoIglYOfMo000SIfEoXfM100001BEoHfM001eGGfnMEem_WEM
OKieGGfnMEd004cME?i<gECnC=eDoTcM100000P/OB@L000Cg1`l4m`L?1?L100002TdOB`L=7d004bn
A9e<_TBMC;i4WDbn001U?UdMICiM7FDnGAeU?UdMICiM7@00MEemOWEMOGieGGenMEemOWEMOGh008fn
QIf5_XFMSKj5WHFn00<0000=QKh009GnSIfEoHfMUOj=WIGmSIfEoXfMUOd0100000fEo9gmUOfMoIGl
WOfEoIgmUObMoIGmWOd00003WOd01IGlWOfMoIgmUO`00igm00>Eo000ool06ooo00<00?ooool08_oo
0015ool00`00ooooo`0:ool02@00WOfMg9gmWMbMoIgLWOfMg005000079FMUKfEWIFmUIfE_IFM001e
GWfnMEem_WENOKieGGfnMEh004cMC?i<gUCnC=e<oTcN000L72@M100000PCg1`L4m`L71?L000L72@M
1@00029<_CbMA;dlWDbm?9e4_@00ICiM7FDnIAeU?UdMICiU7FDn001eOWEMMGieGGEnMEeeOWEMMGie
GGEn0025_HFMQKf5W@80000:QKf5WHFmQIf5_@00UKf=WIFmSId600007IFmSIfE_@00WOfEgIGmUMfM
oIGMUOfEgIgmUMfEoIGM002MgIgmWMfMoIgMWOfMgIgmWMfMoIgMWOd00P006ooo0P008ooo0015ool2
000<ool01000YOfMo9gm100000fMo:GmWO`008fMUOf=WIGmSIfEoHfMUOf=W@0200005GfnMEem_WEM
OKieGGfnMEd004cME?i<gECnC=eDoTcM000T72am91`/O@0300002Q`l4m`L?1?L000T72`m91`/?B@L
100001]<_TBMC;i4WDbn001U?UdMICiM7FDnGAeU?UdMICh007enMEemOWEMOGieGGenMEemOWEMOGh0
100000J5WHfnQIf5_XFMSKh600006HfMUOj=WIGmSIfEoXfMUOf=W@00UOfMoIGlWOfEoIgmUObMoIGm
WOfEo9gmUOd009Gl00>Mo@03UObMoIgm00@00003WOd0000001coo`03003ooooo023oo`00AOoo00<0
0?ooool03?oo0`0002ZUoIgLWObMg:GmWMbMo9gL002EWIFmUIfE_IFMUKfEWIFmUIfE_@00OKieGGfn
MEim_WEMOKieGP00C=e<oTcNE?i<gDcnC=h001`L91dL72@M71`400002a`L4m`001`L91dL72`M71`T
7@00A;d01@0001A4_@00ICiM7FDnIAeU?UdMICiU7FDn001eOWEMMGieGGEnMEeeOWEM0`0000>5WHFm
QId01P000265_HFMQKd009FmSIfE_HfMUKf=WIFmSIfE_HfMUKf=W@00UMfMoIGMUOfEgIgmUMfEoIGM
WOfEgIGmUMd009gMWOd0100000JMgIgmWMfMoIgMWOd2000Kool00`00ooooo`0Pool0033oo`03003o
oooo00;oo`04003oooooool30003ool00`00ooooo`03ool00`00ooooo`0=ool07000YOfMo:GmWObU
oIglYOfMo:GmWO`008fMUOf=WIGmSIfEoHfMUOf=WIGm001m_WEMOKieGGfn200000a<gECnC=d002@L
;7dT72am91`001?K4o`4000032@L;3dT72`m91`/?@00A;dlWDBn?9e4_AX0000TQIf5_XFMSKj5WHFn
QIf=_XFMQKh009GnSIfEoHfMUOj=WIGmSIfEoXfMUOf=W@00UOfMoIGlWOfEoIgmUObMoIGmWOfEo9gm
0`000igm00FMo9gmWOfMoIgl00>Mo@8001_oo`03003ooooo01ooo`00;ooo00<00?oo00001ooo00<0
0?ooool00_oo00<00?oo00001?oo00<00?ooool03_oo01@009glWMbUoIgLWObMg:GmWMbMo9gL002E
WIFmUIfE_IFMUKfEWIFm1`0000Qm_WfMOKimWP00E=iE?UCN1`0000<L72@M71`00P0000<Co0_L4o`0
0`0001LT7A`L;1dL72@M0014_CbMA;dlWDBm?9e4_@00ICiM7EdnGAeU?UdMGCiM7FDn00@0000YMEee
OGEMMGieGGEmMEd008FMQKf5WHFmQIf5_HFMQKf5WHFmQId008fMUKf=WIFmSIfE_HfMUKf=WIFmSIfE
_HfM002EgIgmUMfEoIGMWOfEg@0400003YGmUMd009gMWOfMgIgmWMfMoIgMWOfMgIgmWMd2000Lool0
0`00ooooo`0Nool002ooo`03003oo`0000Soo`03003ooooo00?oo`05003oooooool0000Bool03`00
YOfMo:GmWObUoIglYOfMo:GmWO`008fMUOf=W@0400005YGmUIbMo@00OKimWHFnOIem_WfMQKimW@00
C=eE?TcMECi<gEDnC=d001`L100000H/O@004o`Cfa?l4m/400004R`m91`/?@00A;dlWDBn?9e4_CbM
A;h006DnG=eU?UcMICiLg@@0000WOGieGGEnMEemOWEMMGieGGenMEd008FMSKj5WHFnQIf=_XFMQKj5
WHfnQId008fMUOj=WIGmSIfEoXfMUOf=WIGnSIfEo@00WOfEoIgm00@00009UObMoIGmWOfEo9gm002M
oIgl00>Mo@05WObMoIgmWOfMo002WOd2000Kool00`00ooooo`0Nool002ooo`03003oo`0000Soo`04
003oooooool20004ool2000Bool02@00WObMg:GmWMbMo9gLYOfMg00500004IFMUOfEWIGmUIfEoIFM
UOd007fnOIem_WfNOKimWGfnOIh00P0000]E?UCNECiDgUDnE=h001@L91`L72@M00@000062m`Co0_L
000Cg1`L1@0000Y4_CbMA;dlWDBm?9e4_@00ICiM7@<0000WGAeM?UdMICh007EmMEeeOWEMMGeeGGEn
MEeeOGEM0025WHFmQIf5_HFMQKf5WHFmQIf5_HFM002=WIFmSIfE_HfMUKf=WIFmSIfE_HfM00@0000H
WOfEgIGmUMfMoIGMUOfEgIgmUMfEo@00WOfMgIgmWMfMoIgMWOfMgIgmWMfMoIgM0P006ooo00<00?oo
ool07Ooo000_ool00`00ool00007ool00`00ool00002ool00`00ooooo`03ool00`00ooooo`0Bool0
1000YOfMo:Gm100000jMo:GmWO`009FLWOfEWIGmUIbMoIFMUOfEW9gm0P0000mmWHFnOIem_WfMQKim
WGfn001E?TcMECi<gEDnC=d00P0000DT?A`L93dL72@m00<000084o`Cf`006m`T?A_L93`Kg0@00004
A;hlWDBm?9d300009UcMICiLgFDnG=eU?UcM001eGGenMEeeOWEMOGieGGEnMEemOP00QKj5WHfnQIf5
_XFMSKj5WHFnQIf=_XFM002=WIGnSIfEoHfMUOh400004hfMUOd009gmUOfMoIGlWOfEoIgmUObMoIGm
WOfEo9gm002MoIgl00>Mo@06WObMoIgmWOfMo9gm0`006_oo0P007_oo000`ool00`00ooooo`07ool0
1000oooooooo0`000ooo0P005?oo0`0001ZUoIgLYObMg:GmWMbUo9gL002EWIGmUIfEoIFMUOfEWIGm
UIfEoIFM001mWGfnOIim_WfM200000]E?UCNECh002@L71`T7A@L91`000^k0080000:2m`001?L71`C
g2@L4m`L7000?5d5000094Bm001U?UdMGCiM7FDnGAeM?UdM001eGGEmMEeeOWEMMGeeGGEnMEeeO@00
QKf5WHFmQIf5_HFMQKf5WHFmQIf5_@00UKf=W@@0000NUKfEWIFmSIfE_IFMUKd009GmUMfMoIGMUOfE
gIgmUMfEoIGMWOfEg@00WMfMoIgMWOfMgIgmWMfMoIgM100000>Mo@00ool06Ooo00<00?ooool07?oo
0014ool00`00ooooo`0Dool02`00YOfMo:GmWObUoIglYOfMo:GmWO`00P0000RMoIFMUOfEW9gmUIfE
oIFL1`0000QmWHFnQIf5_P00GCiE7Edn1P0000LL72@m71`T?@002k`;V`0300001Q_L93dKg2@l6m`T
?@800004?5dl_CaM?;d700005VDnG=eU?UcM001eGGenMEeeOWEMOGieGGEnMEemOP00QKj5WHfnQIf5
_XFM1`0001Z=WIGmSIfEoHfMUOf=WIGmSIfEoHfMUOd009gmUOfMoIGlWOfEoIgmUObMoIGmWOfEo000
0Ygm00>Mo9gmWOd00`000Ygm00BMo9gm000001_oo`03003ooooo00?oo`D000;oo`03003ooooo00;o
o`03003ooooo00Woo`00A?oo00<00?ooool05Ooo01000:GlWMbUoIgLYObMg:GmWMbUo9gLYOd009Gm
UIfEo@@0000DUMfMoIgM0025WHFnQIf5_XFMQKj5WHFn001E?UDNGCiE7UDnEAiM?P@0000651`T7000
2k/3V`^k0`00014L7000000001`L000lGCAM?5ddGCaM=5dlG@00G?iLgEcm01H0000SQIf5_HFMQKf5
WHFm002E_HfMUKfEWIFmSIfE_IFMUKf=WIFmUId009GMUOfEgIgmUMfEoIGMWOfEgIGmUMfMo@00WOfM
g@03000029gMWOfMgIgmWMfMoIgMWOd2000Jool20006ool01`00oooooooo003oo`0000;oo`03003o
o`0000[oo`00@ooo0P006?oo00/00:GmWObUoIglYOfMo:GmWObUoIgl00@0000AWOfEW9gmUIbMoIFL
WOfEW000OIf5_XFMQKimWHFnQIf5_P0200002EDMGCiE7EdnEAeM?P0093dL700400000`^l2i/;_005
0000@b@l6m`T?@00?;dlGCbm?5dl_CaM?;d005dnE=eM?UcMGCiDgEdnG=d007EMMGieGGEnMEeeOWEM
MGieGGEn0025_XFMSKj5WHFnQIf=_XFMQKj5WHfn002EoHfMUOf=WIGmSIfEoHfMUOf=WIGmSId009Gl
WOfEoIgmUObMoIGmWOfEo9gm00@000:Mo@05WObMoIgmWOfMo003WOd019gl002Mo@006_oo00<00?oo
ool01?oo00L00?ooooooo`00ool00002ool00`00ool0000:ool004?oo`03003oo`0001Soo`07002U
o9gLYOfMg:GlWM`00`0001jUg:Gl002MoIgMWOfEgIgmWMfMoIGMWOfMg@00QIf5_XFMQKj5WHFnQIf5
_XFM001E7UdnEAiE?UDNGCh200000a@L91dD700400001@^k0i/000_L4o`01@0003PlGCAM?5ddGCaM
=5dlG@00G?iLgEcmG=eLoUcMG?eLg@00MEeeOGEMMGieGGEmMEeeOWEMMGd008FmQIf5_HFMQKf5WHFm
QIf5_HFMQKd009FmSIfE_IFMUKf=WIFmUIfE_HfMUKfEW@00UMfEoIGM1P0001>MoIGMWOd009gmWMfM
oIgMWOfMgIgmWMfMoIgMWOfMg@00WMd0000Jool00`00ooooo`03ool01`00oooooooo003oo`0000;o
o`03003oo`0000[oo`00@ooo0P006_oo00<00:GmWO`00`0001NMo:GmWObUoIglYOd009gmUIbMoIFL
WOfEW9gmUIbMoIFL001mWHFnQIf5_WfM00T00003EAeM?UDM00@0000393d00000008000072i/00000
4o`Cfa?l4m/00`00038lGCbm?5dl_CaM001LgEdnE=eM?UcMGCiDgEdnG=d007EMMGieGGEnMEeeOWEM
MGieGGEn0025_XFMSKj5WHFnQIf=_XFMQKj5W@00SIfEoHfMUOf=WIGmSIfEoHfMUOf=WIGm100000^E
oIgmUObMoIGmWOfEo9gmUOfMo@0000>Mo@05WObMoIgmWOfMo003WOd00igl0000000Kool00`00oooo
o`02ool01`00oooooooo003oo`0000;oo`03003oo`0000[oo`000_oo10000ooo0P000_oo0`000ooo
0P000_oo10006Ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool06_oo
0P0001BUg:GlYMbUo:GLYObUg:GlYMbUo000WOfMgIgmUMfMoIgMWOfEgIgm1P0000V5WHfmQIf=_XFM
001M7UdnGAh01P0000HT7A@L91`000^k0e/400001A?l2m`Co0_L4o`0100002/dGCaM=5d005cMG?iL
gEcmG=eLoUcMG?d007EnMEeeOGEMMGieGGEmMEeeOWEM0025WHFmQIf5_HFMQKf5WHFmQIf5_HFM002E
WIFmSIfE_IFMUKf=W@04000079FmUId009GMWOfEgIgmUMfMoIGMWOfEgIgmUMfMo@00WOfMgIgmWMfM
oIgMWOfMgIgmWMfMoIgM0P006Ooo0P000ooo0P001?oo00<00?ooool00_oo00<00?ooool02Ooo0003
ool01P00ooooo`00ool000Goo`05003oooooool00002ool00`00ool00002000Iool00`00ool00007
ool00`00ool00003ool2000Lool04`00YOfMo:GmWObUoIglYOfMo:GmWObUo@00WOfEW9gmUIbMoIFL
0080000<WOfMo000QIf=_XFMSKj5WHfnQIf=_XFM100000AM?UdNGCiM7@@0000693d000000eX;^`=J
0`0000LCfa?l4m/Co000=7ddG00500008UcMGCiDgEdnG=eM?UCMGCh007EnMEeeOWEMMGieGGEnMEee
OWEM0025WHFnQIf=_XFMQKj5WHfnQIf5_XFM002=WIGm100001F=WIGmSIfEoHfMUOd009gmUObMoIGm
WOfEo9gmUOfMoIGlWOfEo@00WO`00igm00BMo9gmWOfMo@D00003YOd00?oo01Woo`03003ooooo01Oo
o`000ooo00D00?ooool00?oo00<000?oo`05003oooooool00006ool00`00ooooo`0Gool00`00ool0
0009ool01@00oooooooo00007_oo00l00:GlYMbUo:GLYObUg:GlYMbUo:GLYO`009gmWMd00`0000bM
gIgmWMbMoIgM0025WHfmQIf=_XFMSKd500002EdnGAiM?UdNGCiM7P0051`L7004000010=K2k/3F`^k
0`0000@Co0_L4o`000DdG@H0000FG=eLoUcMG?d007EnMEeeOGEMMGieGGEmMEeeOWEM0025WHFmQIf5
_HFMQKd7000079FmSIfE_IFMUKf=WIFmUIfE_HfMUKd009gmUMfMoIGMWOfEgIgmUMfMoIGMWOfEg@00
WMfMoIgM100000FMoIgMWOfMgIgm008001_oo`03003ooooo01Koo`000ooo00D00?ooool00?oo00<0
00?oo`03003ooooo00@000?oo`8001Woo`03003oo`0000Ooo`8000Coo`03003ooooo01goo`800008
WObUoIglYOfMo:GmWObUo@@0000=WObMoIglWOfMo9gmWObMoIgl0025WHfnQId00P00016=_XFMSKj5
WHfn001M?UdMGCiM7UdnGAd001`L73dL71`m00<000052k/3FP^k000;_00200003A?K000dG3Am=5`l
OCAL=7ddG000E=eLoUCM01H0000OSKf5WHfnQIf=_HFM002=WIGmSIfEoHfMUOf=WIGmSIfEoHfMUOd0
09gmUObMoIGmWOfEo9gmUOfMoIGlWOd010000Ygm00JMo:GmWOfMoIglYOd2WOd2000Iool2000Hool0
00?oo`04003ooooo0007ool01@00oooooooo00008?oo00<00?oo00001ooo00<00?ooool00_oo00<0
0?ooool08?oo00@00:GLYObUg0@0000>YObUg:Gl002MoIgMWOfMg9gmWMfMoIgLWOfMg@<00006QIf=
_XFMSKf5WHfn1P0000UM7UdnGAh001@L71`D71`L51`00`0000D3F`^k000;^`>K00<000LdG@0d001D
gEcnE=eLoECMG?iDgEcm001eOWEMMGeeGGEnMEeeOGEMMGieG@00QIf5_HFMQKf5WHFmQIf5_HFMQKf5
W@00UIfE_HfMUKfEWIFmSIfE_IFMUKf=WIFm002MoIGMWOfEgIgmUMd400004IgmWMd009gMWOfMgIgm
WMfMoIgMWOfMgIgmWMd009gM00006_oo00<00?ooool05Ooo0002ool40007ool2000Uool00`00oooo
o`06ool30002ool00`00ooooo`0Qool300001YglYOfUo:GlWObUo@:Uo007002MoIglWOfMo9gmWO`0
0`0000FMo000QIf=_XFM00@00006UKf=WIFn001UOVDM1P0000HL?A`L73dL70000aX200001@^k000;
_0^K2k`00`0003DdOCAL?7ddG3Am=5`005CMG?iDgEcnE=eLoUCMG?h007EnMAeeOWDMMGie7GEnMAee
OP00SKj5WHfmQIf=_XFMSKf5WHfnQIf=_HFM002=WIGmSIfEoHfMUOf=WIGmSIfEoHfM002EoIgm00@0
000:UObMoIGmWOfEo9gm002MoIglYOd2WOd02YglYOfMoIgmWObUoIgm002Mo0006Ooo00<00?ooool0
5Ooo0012ool2000Sool02`00YMbUo:GLYObUg:GlYMbUo:GLYO`00P0000RMg@00000009gMWOfMg9gm
100000n=WHfmSIf=_HfMSKf=WHfm001UOVENIGiUGVEnIEh0100000<L71@L00000P=J0`0000@;^`>K
2k/3V`@000<dG@0[001LoECMG?iDgEcmE=eLoUCMG?d007EnMEeeOGEMMGieGGEmMEeeOP00QKf5WHFm
QIf5_HFMQKf5WHFmQIf5_@00UKfEWIFmSIfE_IFMUKf=WIFmUId0100001RMoIGMWOfMgIgmUMfMoIgM
WOfEgIgm002MoIgMWOfMgIgmWMfMoIgMWOfMgIgmWMd2000Iool2000Fool004;oo`03003ooooo02?o
o`05002Uo:GlWObUo@02YO`00iglYOfUo00300000iglWOfMo00400005jGmWO`008fMUKj=WIFmSIfE
_XfMUKf=WIFn001UOVDMIGiU7VEnIAd001`L93d0100000<36P=k0aX00`0000H;V`^l2i/002`L;7d5
00008ecnE=eLoUCMG?iDgEcnE=d007DMMGie7GEnMAeeOWDMMGie7GEn002=_XFMSKf5WHfnQIf=_HFM
SKj5WHfm002EoHfMUOd01P0001B=WIGmSId009GmWOfEo9gmUOfMoIGlWOfEoIgmUObMo@00WOfMo:Gm
0Ygm00NMo:GmWOfMoIglYOfMo@02000Jool00`00ooooo`0Cool004;oo`03003ooooo02Coo`06002U
g:GlYMbUo:GL0`0000>Ug:Gl00000`0001VMg9glWMbUoIgLWObMg000SIf=_HfMSKf=WHfmSIf=_HfM
SKd006EnIEiUOVENIGiUGP0200000a`M51`L700300030eX3000020^k0i/002`L;1d/72`M;1`40000
6ecnE=eLoECMG?iDg@00MEeeOWEMMGeeGGEnMEeeOGEMMGh008FmQIf5_HFMQKf5WHFmQIf5_@050000
7iFmUIfE_IFMUKfEWIFmUIfE_@00WOfMgIgmUMfMoIgMWOfEgIgmWMfMoIGMWOd009gmWMfMoIgMWOfM
gIgm00D00003WOd00?oo01Soo`03003ooooo01?oo`00@_oo00<00?ooool09Ooo00<00:Gl00000P00
0ZGl0`000ZGl00X009glYOfMo:GmWObUoIglYOfMo0800008UKj=WIFmSIfE_XfMUKf=W@H00008IGiU
7FEn000T?A`L93dL70<000040aX3NP000g/200002P^K000/72am;1`dOB`L;7d005cn1P0000mDg@00
MAeeOWDMMGie7GEnMAeeOWDM0025WHfnQId01P0001f=_XFMSKd009GmSIfEoHfMUOf=WIGmSIfEoHfM
UOd009gmUOfMoIGlWOfEoIgmUObMoIGmWOfEo00000:Mo@03WO`0000000800005YOfMo:GmWObUo@02
000Iool2000Dool0047oo`03003oo`0002Goo`<00003YMbUo0000080000EYObUg:GlYMbUo:GL002M
g:GmWMbMo9gLYOfMg9glWMbUo@00SKf=WHfm00@00006UIfEo@00KGiUGVen1P0000<D71`L51`01000
00@3FP000eX3FP<0000=;1`/7B`L;1d/72`M001DoECME?eDgECmE=d03`0002:5WHFmQIf5_HFMQKf5
WHFmQId009FMUKfEWIFmUIfE_IFMUKfEWIFmUIfE_@00WOfMgIgmUMfMoIgMWOfEgIgmWMfMo@@0000:
WMfMoIgMWOfMgIgmWMfMoIgMWOd2000Jool00`00ooooo`0Aool0047oo`8002?oo`<000?oo`8000:U
o005YOfUo:GlYObUo@03YO`02@00WObUoIglYOfMo:GmWObUo@0500003iGmSIfEoIFMUOf=WIGm001]
OVeMKGi]GVenKEe]OP0500000b@m0003>P0300000`=k0eX3N`030000>2am;1`dOB`L;7d005cnE=eD
oUCMG?iDgECnE=d007DMMGi]7GEnMAeeOVdMMGie7@00QIf=_XFMSKf5WHfnQIf=_HFMSKj5W@00SIfE
oHfMUOf=WIGmSIfEoHfMUOf=WIGm002MoIGmWOfEo9gmUOd400003igmUO`009glYOfMo:GmWObUoIgl
YOfMo:GmWObUo@02000Iool00`00ooooo`0Aool002goo`03003ooooo00;oo`03003ooooo00;oo`03
003ooooo00;oo`03003ooooo00;oo`03003ooooo023oo`8000Ooo`0@002Ug:GlYMbUo:GLYObUg:Gl
YMbUo:GL002Mg:GmWM`400005JGlYMbUo000UOfEWIGmUIfEoIFMUOfEWIGm001]OVENKGiUGVenIEi]
OP0200000a@L71`0000200020aT200020eX00`=K0eX000030000<B`M;1`/7@00E?eDgECmE=eDoECM
E?eDg@00MEeeOWEMMGeeGGEnMEeeOGEM0025WHFmQIf5_HFMQKf5WHFmQIf5_HFM002EWIFmUIfE_IFM
UKfEWIFmUIfE_IFM002EgIgm00@0000CWMfMoIgMWOfMgIgm002MoIgMWOfMgIgmWMfMoIgMWOfMgIgm
WMd00P006Ooo0P004_oo000/ool00`00ool00008ool01`00oooooooo003oo`0000?oo`8001koo`<0
00[oo`05002Uo:GlYObUo@03YO`00jGmYObUo004000089glYOfMo:GmWObUoIglYOd009GmUIfEoHfM
UOfEWIGmSIfEo@00KGi]GFenKEi]OVeMKGi]GP0071`T?A`L73d200002P<I0cX000000eX3N`=J000S
g2@m1@0002QLoUCME?iDgEcnE=eDoUCM001e7GEnKAeeOWDMMGi]7GEnMAd008FMSKj5WHfmQIf=_XFM
SKf5WHfnQId008fMUOf=WIGmSIfEoHfMUOf=W@@0000HWOfEoIgmUObMoIGmWOfEo9gmUOfMo@00YOfM
o:GmWObUoIglYOfMo:GmWObUoIgl0P005Ooo0`0000?oo`00ool04Ooo0007ool3000Rool00`00ool0
0008ool00`00ooooo`03ool01@00oooooooo00007?oo0`003_oo0P0000JUo:GLYObUg:GlYM`20000
5ZGlYM`00:GLYObMg:GlYMbUo9gLYObUg:Gl002EoIFMUOfEWIGmUIfEoIFM3@0000<D71`M51`00P00
00`36P00000000=K0eX001`L91`L72@L71`400007eCmE=eDoECME?d007EmMEeeOWEMMGeeGGEnMEee
OGEM0025WHFmQIf5_HFMQKf5WHFmQIf5_@00UKfEWIFm00H0000IUIfE_IFM002MgIgmWMfMoIgMWOfM
gIgmWMfMoIgMWOd009gmWMfMoIgMWOfMgIgmWMd00`0000>Mg@0000004?oo10001?oo00<00?ooool0
4?oo0008ool00`00ooooo`0Qool00`00ool00009ool00`00ooooo`020004ool00`00ooooo`0Gool3
000Cool00`00YObUo0030005YO`03`00WObUoIglYOfMo:GmWObUoIglYOd009GmUIfEo@0400003IFL
WOd007fnMEem_WEMOKieGGfnMEd001aL00P0000=0cX000000eX002?L93dSg2@m8m`T?@00E?h01@00
01=DoP00MGie7GEnKAeeOWDMMGi]7GEnMAd008FMSKj5WHfmQIf=_P0700007IGmUIfEoHfLUOfEWIGm
SIbEoIFM002Eo9gmUOfMoIGlWOfEoIgmUObMoIGmWOd00:GmWObUoIglYOd00P0000BMo:GmWObUo@80
00goo`<000Soo`03003ooooo013oo`001?oo0P000_oo0`000ooo0P000_oo0`000ooo0P0000?oo`00
00000_oo00<00?ooool02_oo00<00?oo00001ooo00<00?oo00000_oo00<00?ooool00_oo0P005_oo
0`005ooo0P0000VUg:GlYMbUo:GLYObUg:GlYM`00P0000RUo9gLYObUg:GlWMbUo:GL1000012MoIGM
WOfMgIgmUMfMo@00OKieGWFnMEim_WENMKieGP80000395dLGBAM00D000030aX2f@000080000<71`T
71`L91`L72@L001DoEBME?e<WECm4`000265_HFMSKf5WHFm002E_IFMUKfEWIFmUIfE_IFMUKfEWIFm
UId009gMWOfMgIgmWMfMoIgMWOfMgIgmWMd009gMWOd00`0000NMoIgMWOfMgIgmWMfMo@020009ool3
000<ool00`00ooooo`0?ool000?oo`06003ooooo003oo`000_oo00<00?oo00000_oo00@00?ooool0
00?oo`06003ooooo003oo`000_oo00<00?ooool02ooo00<00?ooool01_oo0`000_oo0`000_oo00<0
0?ooool04_oo0`006ooo00<00:GlYO`02JGl00@00:GmWObUo@@000:Uo00J002MoIFLWOfEW9gmUIbM
oIFLWOd007fnMEem_WEMOKieGGfnMEem_P0097dLG2Am75`TO@<000030cX2f@<j00<0000j93dSg2@m
8m`T?@00E?i<WECnC9eDoTbME?h007EnMAeeOVdMMGie7GEnKAeeOWDM0025GHfnQEf=_HEMSKj5GHfm
QEd009FMUOf=W9GmUIfEoHfLUOfEWIGmSIbEo@00WOfEo9gmUOfMoIGlWOfEoIgmUO`400002jGmWObU
oIglYOfMo:GmWObUoIglYOd00P001?oo10003ooo00<00?ooool03ooo0003ool01P00ooooo`00ool0
00;oo`03003oo`0000Goo`05003oooooool00002ool00`00ool00002ool00`00ooooo`0Nool2000@
ool3000Oool02`00YObUg:GlYMbUo:GLYObUg:GlYM`0100001NUo:GLYObUg:GlYMbUo000WOfMgIgm
UMfMoIgMWOfEgIgm001m_WENMKieGWfn00L0000395dLG2AM00@000030]T36P;I00@0000a91`L7000
C9eDoEBME?e<WECmE9eDo@00MGee7GEmMAeeOGDMMGee7GEm002=_HFMQKf5WHfmQIf5_HFMSKf5W@00
UIfE_IFMUKfEWIFmUIfE_IFMUKfEWIFm002MoIgMWOd01P00012MgIgmWMd009gMWOfMgIgmWMfMoIgM
WOfMgIgmWMfMo@D001?oo`03003ooooo00ooo`000ooo00<00?ooool01@0000?oo`0000000P000_oo
0P001?oo0P0000?oo`0000000P008Ooo00<00?ooool03?oo0`008ooo00<00:GlYO`01:Gl0`0000JU
o:gl002Uo9glYOd2YO`03IglYOfUo:Gl002MoIFLWOfEW9gmUIbMoIFL00H00007QKj5WHFnQIf5_P00
=;d0100000<LG00000000P0000D3>P;I000Cfa_l00@0000YC9eDoTbME?i<WECnC9eDoP00MGie7GEn
KAeeOWDMMGi]7GEn002=_HEMSKj5GHfmQEf=_XEMSKf5G@00UIfEoHfLUOfEWIGmSIbEoIFMUOf=W004
0003WOd01IGlWOfMoIgmUO`00Ygm00`009glYOfMo:GmWObUoIglYOfMo:GmWO`2000Fool00`00oooo
o`0?ool000?oo`04003ooooo0006ool00`00ooooo`0`ool00`00ooooo`09ool3000Wool00`00YObU
g00300005:GLYObUg:GlYMbUo000YObUg:GlYMbUo:GLYObUg:Gl002MoIgMWOd4000039gLWO`008Fn
QIf5_XFMQKj5WHFnQIf5_P800003;9dd_BbM00<0000:0UL000000002f@002m`Ko0_L6o`400008UBM
E?e<WECmE9d007DMMGee7GEmMAeeOGDMMGee7GEm002=_HFMQKf5WHfmQIf5_HFMSKf5W@00UIfE_IFM
UKfEWIFm100001^EWIGm002MoIgMWOfMgIgmWMfMoIgMWOfMgIgmWMd009gMWOfMgIgmWMfMoIgMWOfM
gIgmWMd00P005Ooo00<00?ooool03ooo0004ool2000=ool00`00ooooo`0Zool20008ool2000[ool2
00000jGl[ObUo002YO`02JglYObUo:Gl[O`00:GlWObUo@02YO`00iglYOfUo00400001jGmWObUoIgl
YOfMo:Gm0080000?QIf5_XFMQKj5WHFnQIf5_XFM000/GCBm;5dd_BaM008000030WL0000000800007
4m/Ko1?K6o`Cf`00C9d01@0001U<W@00KAeeOWDMMGi]7GEnMAeeOVdMMGh008fmQEf=_XEMSKf5GHfn
QEf=_@00UOfEW@0400001iGmUIbEoIFMUOfEW00000:Mo@05UObMoIgmWOfEo003WOd02YGlWOd00:Gm
WObUoIglYOfMo:Gm100000>Mo00000005?oo00<00?ooool03ooo000oool00`00ooooo`05ool3000^
ool04000YObUg:GlYMbUo:GLYObUg:GlYMbUo000YObUg:Gl100001>Ug:Gl002Mo9gLWOfMg9glWMbM
oIgLWObMg000QIf5_XFMQKj5W@06000013Bm;9dd_BbM0P0000<2E`0000000`0000XKo0_L6o`;g000
C9e<_DbMC;e<W@P0000;MGee7GEmMAd008FMSKf5WHFmQIf=_@0600006iFMUOfEWIGmUIfEoIFMUOfE
WIGmUId009gMWOfMgIgmWMfMoIgMWOfMgIgmWMfMo@00WOfMg@0400001IgmWMfUoIgMWOd00P005?oo
00<00?ooool03ooo000oool30002ool3000bool01000YObUo:gl0jGl00B]o:GlYObUo0@000NUo00:
002UoIglYOfMo:GmWObUoIglYOd600001HfMUOj=WIGmSId01@0000</G@0000000`0001@2V0000000
01?K6o`Cf`00C9eD_TbMC;e<WEBnC9d006dMMGi]7GEn2`0001>=_HEMSKj5GHfm002EoIFMUOfEW9Gm
UIfEoIFLUOfEWIGmUI`00002WOd01IGlWOfMoIgmUO`00igm00jEo000000009glYSfMo:HmWObV?Igl
YSfMo:Hm0P005?oo00<00?ooool03_oo000oool00`00ool00002000fool200001ZGLYObUg:GlYMbU
o080000CYMbUo000YObUg:GlYMbUo:GLYObUg:Gl002Mo9gLWOfMg9glWM`00P0000bUo:GL002=WHfm
SIfE_HfMSKf=WIFmSId200000dCn==d0000200000`8E000000030000=P>K000001_l001<_DbMC;e<
WDbmC9e<_DbM001e7GDmMAee?GDMMCee7GDmMAd008FMSKf5WHfmQIf=_HFMSKf5WHfm002EoIFMUOfE
WIGmUIfEoIFMUOfEWIGmUId009gMWOfMgIgmWMfMo@@0000>WMfMo@00YOfMgIgmWMfUoIgMWOfMgJGm
WMfMo@8001?oo`03003ooooo00koo`00>?oo1@000_oo0P00>ooo00<00:Gl[O`00`0000J]o:GlYObU
o:gl0009YO`00`00YOfMo00300005IglYOfMo:GmWO`008fMUOj=WIGmSIfEoXfMUOf=WIGn0014oScM
A?hlg@0400001@8F000000]K2k/00`0002Y<_DbME;i<WDbmC9eD_TbM001]7GEnKAeeOVdMMGi]7GEn
KAd008EMSKf5GHfnQEf=_HEMSKj5GHfm002EoIFMUOfEW9GmUIfEoIFLUOfEWIGm0002WOd4000059gm
WObMoIglWOfMo000WObV?IglYSfMo:HmWObV?IglYSfMo:Hm000Cool00`00ooooo`0>ool003[oo`03
003ooooo00?oo`03003ooooo03[oo`80000BYObUg:GlYMbUo:GLYObUg:Gl002Uo:GLYObUg:GlYMbU
o:GL0`0001:Ug:GlYMbUo:GLYObUg:GlYM`008fMSKf=WIFmSIf=_HfMUKd600000cCMA?h000020000
1P7F000000>K2k/3V`<0000VC9e<_DbMC;e<WDbm001e?GDMMCee7GDmMAee?GDMMCee7@00QIf=_HFM
SKf5WHfmQIf=_HFM002EWIGmUIfEoIFMUOfEWIGmUIfEo@@0000GWMfMoIgMWOfMgIgmWMfMoIgMWOfM
g@00WMfUoIgMWOfMgJGmWMfMoIgMYOfMg@02000Bool00`00ooooo`0>ool003[oo`03003ooooo00Co
o`8003_oo`03002Uo:gl00>Uo006[ObUo:GlYOb]o0000jGl10000ZGl00l00:GmWObUoIglYOfMo:Gm
WObUoIgl002=WIGnSId0100000JMoIFLWOd006EnGAd700001P7E000;F`^k2e/;_0D0000LC;e<WEBn
001eOVdMMGi]7GEnKAeeOVdMMGh008fnQEf=_HEMSKj5GHfmQEf=_XEM002EW9GmUId600005igmUIbM
o@00WOfMo9gmWObMoIglWOfMo9gmWObMoIgl002Mo:HmWObV?IglYSd0100000>Mo00000004Ooo00<0
0?ooool03_oo000jool00`00ooooo`06ool00`00ooooo`0iool02P00YMbUo:GLYObUg:GlYMbUo:GL
100000NUo:GLYObUg:GlYMbUo00200002:GLYObUg:GlYMbUo:GLYO`400003igMWOfMg9gmWMfMoIgL
WOd006EnGAiUOVDNIGiM7P0300002P7F000000^k0i/;^`00C;dlWDbm1@00011e?GDMMCee7GDmMAee
?GDMMCd008fmQIf=_HFMSKf5W@L0000IUIfEoIFMUOfEWIGmUIfEoIFMUOd009gmWMfMoIgMWOfMgIgm
WMfMoIgMWOd009gmWMd0100000NUoIgMYOfMgJGmWMd0000Aool00`00ooooo`0>ool003[oo`03003o
oooo00Ooo`03003ooooo03Woo`03002Uo:gl00>Uo006[O`00000YOb]o0000ZGl00F]o:GlYObUo:gl
00>Uo004002Mo:GmWO`40002YO`04`00UIbMoIFLWOfEW9gmUIbMoIFLWOd006EnGAeUOUdNIGiM7FEn
00H000092e/;_000C;e4WDbmA9e<_DBM0140000MQEf=_HELSKf5G@00UIbMoIFLWOfEW9gmUIbMoIFL
WOfEW9gm002MoIglWOfMo9gmWObMoIglWOfMo003000039glYSfMo:HmWObV?IglYSfMo:HmWO`0013o
o`03003ooooo00koo`00>Ooo0P002_oo00<00?ooool0>Ooo00<00:GLYO`00`0000nUo:GLYObUg:Gl
002Uo:GLYObUg:GlYMbUo:GLYO`01000016Ug:GlYMbUo:GLYObUg000WMbMoIgMWOfMg9gmWMfMoIgL
00d0000e0aX000002k/004bm?9e<_DbMC;dlWDbm001e?GDMMCee7GDmMAee?GDMMCd008fmSIf=_HfM
SKf=WHfmSIf=_HfM002EWIGmUIfEoIFMUOfEWIGmUIfEoIFM002MgIgmWMfMoIgMWOfMg@0300003YgM
WOd00:GmWMfUoIgMYOfMgJGmWMfUoIgMYOd2000@ool00`00ooooo`0=ool004Koo`8003[oo`800005
[ObUo:GlYOb]o003YO`01Jgl002Uo:Gl[O`00jGl0P000ZGl00<00:GlYO`01jGl00L009FLWOfEW9gm
UIbMo@0200002iglYOd008FnOIf5_WfMQKimWHFnOId00`0000<36P<j00000P0002]<_DBMC;e4WDbm
A9d007DMMCe]7GDnMAee?FdMMCie7GDm002=_HEMSKf5G8fmQEf=_HELSKf5G@00UIbMoIFLWOfEW9gm
UIbMoIFLWOfEW000WObMo@0400004iglWOfMo:GmWObMo@00YSfMo:HmWObV?IglYSfMo:HmWObV?@00
013oo`03003ooooo00goo`00B?oo00<00?ooool0>?oo00h00:GLYObUg:GlYMbUo:GLYObUg:Gl002U
o:GL0`0001:Ug:GlYMbUo:GL002Ug:GlYMbUo:GLYObUg:GlYM`009gLWOd300003ZGlYMbUo:GLYO`0
08FnOIf5_XFMQKimWHFnQId300030aX300009CbMC;e<WDbm?9d007DMMCee7GDmMAee?GDMMCee7GDm
002=_HfMSKf=WHfmSIf=_HfMSKd009GmUIfEoIFMUOfEWIGmUIfEoIFM00@0000FWOfMgIgmWMfMoIgM
WOfMgIgmWMfMo@00YOfMgJGmWMfUoIgMYOfMgJGmWMd2000?ool00`00ooooo`0=ool004Woo`03003o
oooo03Soo`03002Uo:gl00>Uo004[ObUo:GlYO`300000jGl[ObUo002YO`01JglYObUo:Gl00002:Gl
0`0001:UoIglYObMo:GmWObUo9glYOd008FnOIf5_WfMQKimWHFnOId400000`<j0aX3>`04000074BM
C;e4W@00MAee?FdMMCie7GDmKAee?WDM0025G8fmQEf=_HELSKf5GHfmQEb=_@00WOfEW9gm1P0001NE
W9gmUI`009glYOfMo9gmWObUoIglWOfMo:GmWO`009glYSfMo:HmWObV?Igl00<00003WO`0000000ko
o`03003ooooo00goo`00B_oo00<00?ooool0>?oo00L00:GLYObUg:GlYMbUo00200004JGLYO`00:Gl
YMbUo:GLYObUg:GlYMbUo:GL002Ug:GlYM`01000016Uo:GL002Ug:GlYMbUo:GLYObUg:GlYMbUo000
QKimWHFn00@00003WMbMo@00008000836P04000lGDAM?5d400004GDmMAee?GDMMCee7GDmMAee?GDM
002=WHfmSIf=_HfMSKd01`0001VMoIGMWOfEgIgmUMfMoIGMWOd009gmWMfMoIgMWOfMgIgmWMfMoIgM
WOfMg@00WMfUo@0400001IgMYSfMgJHmWMd00P003Ooo00<00?ooool03Ooo001;ool2000iool00`00
YOb]o00300001ZglYObUo:Gl[O`000:Uo005[ObUo:GlYOb]o002YO`400000jGl[ObUo002YO`03:gl
YO`00000YOfMo:GlWObUoIglYObMo0@00007YOfMW:GmWIbUoIfLYOd0100000L36P00A5a4ODALC7e4
G00B00007HfmSEf=_HeLSKd009gmUIbMoIFLWOfEW9gmUIbMoIFLWOd009gmWObUoIglWOfMo:GmWObM
oIglYOd00`0000^V?IglYSfMo:HmWObV?IglYSfMo00000goo`03003ooooo00goo`00COoo00<00?oo
ool0=ooo0P00012Uo:GLYObUg:GlYMbUo:GLYO`00:GlYMbUo:GLYObUg080000AYObUg000YMbUo:GL
YObUg:GlYMbUo:GLYO`00:GlYMbUo00400003:GLYO`009gmWMbMo9gLWOfMg9glWMbMo@80000c0YT0
00<J000lGDAM?5e4GCaMA5d007DmMAee?GDMMCee7GDmMAee?GDM002=WHfmSIf=_HfMSKf=WHfmSIf=
_@00WOfEgIgmUMfMoIGMWOfEgIgmUMfMo@00WOfMgIgmWMfMoIgM00@0000?WOfMg@00WMfV?IgMYSfM
gJHmWMfV?IgMYSfMg@0000goo`03003ooooo00coo`00C_oo00<00?ooool0=ooo00<00:Gl[O`00jGl
00J]o:GlYObUo:gl0002YO`300000jGl[ObUo002YO`01@00YObUo:Gl[O`00jGl00>]o:Gl00000`00
0ZGl00j]o:GlYObUo:gl002UoIfLYOfMW:GmWIbUoIfL0`0002h2V000001<ODALA7e4G4amA5a4O@00
MCee7GDmMAee?GDMMCee7GDm002=_HeLSKf=GHfmSEb=_HeMSKf=G8fm002MoIFLWOfEW9gmUIbMoIFL
WOfEW000WObMo@@0000BWObUoIglYOfMo:GmWO`009glYSfMo:HmWObV?IglYSfMo:Hm0P003?oo00<0
0?ooool03?oo001?ool00`00ooooo`0gool200002:GlYMbUo:GLYObUg:GlYM`300003jGLYObUg:Gl
YMbUo:GLYO`00:GlYMbUo:GLYObUg00300004:GLYO`00:GlYMbUo:GLYObUg:GlYMbUo000WOfMg9gl
10000_oo0`0002P2V@00000lGDAM?5e4GCaMA5d007DmMAee?GDMMCee7GDmMAee?@00SKf=WHfmSIf=
_HfMSKf=WHfmSId009GMWOfEgIgmUMfMoIGMWOfEg@@0000CYOfMgIgmWMfUoIgMWOfMgJGmWMfMo@00
YSfMgJHmWMfV?IgMYSd00`0000>V?@0000002ooo00<00?ooool03?oo001@ool2000iool01000[ObU
o:Gl100000>Uo:gl00000ZGl00F]o:GlYObUo:gl00:Uo003002]o:Gl00<000>Uo005[ObUo:Gl002]
o003YO`01:glYObUo:Gl10001ooo0`0000<2^@0000000P0001e4G4amA5`007DMMCee7GDmMAee?GDM
MCee7GDm002=_HeLSKf=GHfmSEb=_HeMSKf=G000UIbMoIFL00D0000CUObMoIGl002Mo:GmWObUoIgl
YOfMo:GmWObUoIglYOd00:HmWO`0100000JV?IglYSfMo:Hm000;ool00`00ooooo`0<ool005;oo`03
003ooooo03Ooo`<0000@YObUg:GlYMbUo:GLYO`00:GlYMbUo:GLYObUg:GlYM`300004:GLYObUg:Gl
YMbUo:GLYObUg000YMbUo:GLYObUg:Gl0P003?oo00<0008G00000P0000=4GCAM00001000011e7GDm
MAee?GDMMCee7GDmMAd008fMSKf=WHfmSIf=_@P0000EWMfMoIgMWOfMgIgmWMfMoIgM002MgJGmWMfM
oIgMYOfMgIgmWMfUoIgM00<0000;WMfV?JGMYSfMgJHmYMfV?IgMYSd0000:ool00`00ooooo`0<ool0
05?oo`03003ooooo03Ooo`03002]o:Gl00:Uo006[ObUo:GlYOb]o0000ZGl00>]o00000000P000ZGl
00<00:glYO`00ZGl00V]o:GlYObUo:glYO`00:Gl[O`00`003ooo00<0008G0MH00P0000E4OCaLA7dl
G4Am0140000IUKf=W9FmSIbE_HfL002Eo9gmUObMoIGlWOfEo9gmUObMo@00YOfMo:GmWObUoIglYOd0
100000fMo:Hm002V?IglYSfMo:HmWObV?IglYSfMo0020009ool00`00ooooo`0<ool005Coo`03003o
oooo03Ooo`09002Uo:GLYObUg:GlYMbUo:GL00@00007YObUg:GlYMbUo:GLYO`00P0000RUg:GlYMbU
o:GLYObUg:Gl0`004ooo00<0008G0QL00P0002Y4GCAMA5ddG4AM=5d007DMMCee7GDmMAee?GDMMCee
7@00SIfE_HfMSKf=WIFmSIf=_HfMUKd009gmWMfMoIgMWOfMgIgmWMfMoIgMWOd009gmWMd400004jGm
WMfUoIgMYOfMg@00YMfV?IgMYSfUgJHmWMfV?JGMYSfMg@0000Woo`03003ooooo00coo`00EOoo0P00
>?oo00<00:glYO`00ZGl00J]o000002Uo:gl0002YO`01JglYObUo:Gl[O`00jGl00@00:GlYObUo0@0
01Ooo`80000Y0MH25`00000lG4Am?5a4OCaL001e77dmMAem?GDLOCee7GdmMA`008fLUKf=W9FmSIbE
_HfLUKf=W9Fm002MoIGlWOfEo9gmUObMoIGlWOfEo00300005YglYSfMo:HmWObV?IglYSfMo:HmWO`0
09glYSfMo:HmWObV?IglYSfMo:Hm0P002Ooo00<00?ooool02ooo001Gool00`00ooooo`0fool00`00
YObUg00200003jGlYMbUo:GLYO`00:GlYMbUo:GLYObUg:GlYMbUo004000Lool200020QL3000084AM
=5a4GCAM001e7GDmMAee?GDMMCee7GDmMAd008fMUKf=WHfmSIfE_HfMSKf=WIFm002MoIgMWOfMgIgm
WMd300005YgMWOd00:GmWMfUoIgMYOfMgJGmWMfUoIgMYOfMg@00YMfV?IgMYSfUgJHm0`0000>V?@00
00002?oo00<00?ooool02ooo001Hool00`00ooooo`0fool20003YO`01ZglYObUo:Gl[O`000:Uo004
[ObUo:GlYO`2000Rool01@000MH25`00A3d00`0001U4O@00OCee77dmMAem?GDLOCee7Gdm002E_HfL
UKf=W9FmSIbE_HfLUKf=W000UObMo@0400005IglWOfMo9gmWObMo@00YSfMo:HmWObV?IglYSfMo:Hm
WObV?@00YSfMo00400001JHmWObV?IgmYSd00P001ooo00<00?ooool02ooo001Iool00`00ooooo`0f
ool03@00YObUg:GlYMbUo:GLYObUg:Gl002Uo:GL00<002Goo`8000050QL004@L=1a47003000047Dm
MAee?GDMMCee7GDmMAee?@00SKf=WIFmSIf=_HfM1P0001JMoIgMWOfMg9gmWMfMoIgLWOfMgIgm002U
oIgMYOfMgJGmWMfUoIgMYOfMg@<0000;YQfV?IhMYSfV7JHmWQfV?JHMYSd00007ool00`00ooooo`0;
ool005[oo`8003Ooo`03002]o:Gl00:Uo004[ObUo:GlYO`3000Yool300001C`LA3dl74@m?1`04@00
01VEW9FmSIbE_IFL002Mo9gmWObMoIglWOfMo9gmWObMoIgl002Mo:HmWObV?IglYSfMo00300003igl
YSd00:HmWOfV?IglYSfMoJHmWObV?IgmYSd00006ool00`00ooooo`0;ool005coo`03003ooooo03Go
o`04002Uo:GLYO`4000]ool30000:S@LA1`d74@L=1a47000OCem77dmOAam?GdLOCem77dm002E_IFL
UKfEW9FmUIbE_IFLUKfEW000WMbMoIgMWOfMg9gmWMfMoIgLWOfMg@00WMfUo@@0000AWMfV?IgMYSfM
gJHm002V?JHMYSfN7JHmYQfV?IhMYSfV7@020005ool00`00ooooo`0;ool005goo`03003ooooo03Go
o`<003;oo`0X00014`000014?C`LA3dl74@m001m?GDLOCem77dmMAam?GdLOCd009FmUIbE_HfLUKfE
W9FmSIbE_IFL002Mo9gmWObMoIglWOfMo9gmWO`400004ZHmWObV?IglYSfMo:HmWObV?Igl002Mo:Hm
WOfV?IglYSfMo@<00003WOd0000000Coo`03003ooooo00_oo`00G_oo00<00?ooool0=?oo00<00?oo
ool0<ooo00<0003d00000P0001dd74@L=1a47000OCem77dmOAam?GdLOCem77dm002E_IFLUKfEW9Fm
UIbE_IFLUKfEW000WMbMoIgM00D0000BWMfMoIgM002MgJHmWMfV?IgMYSfMgJHmWMfV?IgM002N7JHm
100000FV7JHmWQfV?JHM008000Coo`03003ooooo00[oo`00Gooo0P00=?oo00<00?ooool0=?oo0P00
00=4?3`K00000P0001Dl7000OAam?GDLOCem77dmMAam?GdL002=W9FmUIbE_HfLUKfEW9FmSI`01@00
01BMo:GmWObUoIglYOfMo:GmWO`009glYSfMo:HmWObV?IglYSfMo:Hm0`0000VV?IgmYSfMo:HmWOfV
?IglYSd00P001?oo00<00?ooool02_oo001Qool00`00ooooo`0aool00`00ooooo`0dool01`000A@0
04@L?1a473`L00<0000=OAam?GdLOCem77dmOAam?GdL002EW9FmUI`01@0001JEW9fmUI`009gMWOfM
gJGmWMfMoIgMYOfMgIgm002V?IgMYSfMgJHmWMfV?@<0000=YSfV7@00WQfV?JHMYSfN7JHmYQfV?IhM
YSd00P000ooo00<00?ooool02_oo001Rool00`00ooooo`0`ool00`00ooooo`0eool200001S`LA3`l
6d@l?1a4?0h0000GUIbM_IFLWKfEW9fmUIbM_IFL002Mo:GmWObUoIglYOfMo:GmWObUo@00YSfMo004
00004JHmWOfV?IglYSfMo@00WObV?IgmYSfMo:HmWOfV?IglYSd00P000_oo00<00?ooool02_oo001S
ool00`00ooooo`0_ool00`00ooooo`0fool200009S`LA1`l74@L?1a473`L002578DlQAb5?8DLQCb5
78DlQA`009FLWKfEW9fmUIbM_IFLWKfEW9fm002UoIgMWOfMgJGmWMfMoIgMYOd400004YhMYSfV7JHm
WQfV?JHMYSfN7JHm002V?IhMYSfV7JHmWQfV?@<00005YSd00000ool0000<ool006Coo`8002ooo`03
003ooooo03Ooo`0R0014?3`LA3`l6d@l?1a4?000QCem78DmOAb5?GdLQCem78Dm002M_IFLWKfEW9fm
UIbM_IFLWKfEW9fm002UoIglYOd500004ZHmWObV?@00YSfMo:HmWOfV?IglYSfMoJHmWObV?@00YSfM
o0@00006YSfMoJHmWO`009gm0P003?oo001Vool00`00ooooo`0/ool00`00ooooo`0hool200006c`L
A1`l74@L?1a47000QCb578DlQAb5?8DLQCb578Dl002M_IFLWKfEW9fmUIbM_IFLWKfEW00400005:Hm
WMfV?IgMYSfMgJHmWMfV?@00YSfN7JHmYQfV?IhMYSfV7JHmWQd300002IhMYSfV7JHmWQfV?JHMYSfN
7@03000<ool006Ooo`03003ooooo02_oo`03003ooooo03Soo`D0000E?1]4?3`LA3`008DmOAb5?GdL
QCem78DmOAb5?@00WKfEW9fmUIbM_IFL00<0000EWObUo@00YSfMo:HmWObV?IglYSfMo:HmWO`009gm
YSfMo:HmWOfV?Igl00<0000=WObV?@00YSfMo:HmWOfV?IglYSfMoJHmWO`00`002ooo001Xool00`00
ooooo`0Zool00`00ooooo`0iool01000Dm]D6e?K1@0000b578DlQAb5?8DLQCb578DlQA`009FLWKd4
000059gLWOfMg9gmWMbMo@00YSfMgJHmWMfV?IgMYSfMgJHmWMd00:HMYSd400004IhMYSfV7JHmWQfV
?@00YSfN7JHmYQfV?IhMYSfV7JHmWQd00P002ooo001Yool2000Zool00`00ooooo`0jool01`00DmYL
>e?KG3]CfU`k00d0000DWOfMo:GmWObMoIglYOfMo9gmWO`009glYSfMo:HmWObV?IglYSfMo0@0000B
YSfMo:HmWOfV?IglYSfMoJHmWO`009gmYSfMo:HmWOfV?Igl1@002ooo001[ool00`00ooooo`0Wool0
0`00ooooo`0jool200008E?KE1]Cfe@KDm]D6e?K002=6hdlSAb=?8dKSCb=78dlSA/009gLWOfMg9gm
WMbMoIgLWOfMg9gmWM`009gMYSfMg@0500004ZHMYSfN7@00YQfV?IhMYSfV7JHmWQfV?JHMYSfN7@00
YQfV?@@000?oo`8000_oo`00K?oo00<00?ooool09_oo00<00?ooool0>ooo0P0001aCfU`kDm]L>e?J
G3/008dlSA^E?8dKSCb=6iDlSA^=?8dK002Mo9gmWObUoIglWOfMo:GmWObMo@@0000DWObV?IgmYSfM
o:HmWOfV?Igl002MoJHmWObV?IgmYSfMo:HmWOfV?@<000?oo`@000goo`00KOoo00<00?ooool09Ooo
00<00?ooool0>ooo0P0001UD6e?KE1]Cfe@KDm]D6`00SCb=6hdlSAb=?8dKSCb=78dl002MoIgLWOfM
g9gmWMbMo@0300005JHmWMd00:HMYSfN7JHmYQfV?IhMYSfV7JHm002V?JHMYSfN7JHmYQfV?@030002
ool4000Aool006koo`8002Goo`03003ooooo03coo`<0000CDmYL>e?KG3]CfU`k002=?8dKUCb=6hdl
SA^E?8dKSC`00:GmWO`0100001BV?IglYSfMo:HmWO`009gmYSfMo:HmWOfV?IglYSfMoJHm002V?Igm
100000?oo`0000000P005Ooo001`ool00`00ooooo`0Rool00`00ooooo`0lool2000047?I00000000
Dm]D6e?KE1/008dlSA^=?8dLSCb=6hdl100001BMgJHmWMfV?IgMYSfMgJHmWMfV?@00YSfV7JHmWQfV
?JHMYSfN7JHm100000?oo`0000000P006Ooo001aool00`00ooooo`0Qool00`00ooooo`0mool20000
0g?IO3Ucf@0500000hdKSCb=6`0400004ifmUIbM_@00YSfMo:HmWObV?IglYSfMo:HmWObV?@00YSfM
oJHm00D00003ool00000008001goo`00L_oo00<00?ooool08?oo00<00?ooool0?Ooo0P0000Md6G?I
M1UcfG@ILmUd6@0400004ifLWKbMW9fmWIbM_9fLWKd00:HmWMfV?IgMYSfMgJHmWMfV?IgM00@000;o
o`@0027oo`00Looo0P008?oo00<00?ooool0?_oo0P0001Yl>G?IO3UcfG`iLmUl>G?I002EW9fmUIbM
_IFLWKfEW9fmUI`009glYSfMo:HmWObV?Igl0`000_oo10009Ooo001eool00`00ooooo`0Mool00`00
ooooo`0nool200005W?IM1UcfG@ILmUd6G?IM1Ucf@00WIbM_IfLWKbMW9fmWIbM_9fL002MgJHm1000
0_oo0`00:Ooo001fool00`00ooooo`0Lool00`00ooooo`0oool04`00O3UcfG`iLmUl>G?IO3UcfG`i
002M_IFLWKfEW9fmUIbM_IFL00@000;oo`@002coo`00Mooo00<00?ooool06ooo00<00?ooool0?ooo
0P0000ed6G?IM1UcfG@ILmUd6G?IM1T009flWIbM_@040002ool4000`ool007Soo`8001[oo`03003o
oooo047oo`09001cfG`iLmUl>G?IO3UcfG`i00D000;oo`@003Coo`00N_oo00<00?ooool05ooo00<0
0?ooool0@Ooo0P0000=cfG@I000010000ooo1000>?oo001kool00`00ooooo`0Fool00`00ooooo`12
ool30004ool4000lool007coo`03003ooooo01Goo`03003ooooo04Goo`@0043oo`00OOoo0P005Ooo
00<00?ooool0@Ooo1000A?oo001oool00`00ooooo`0Bool00`00ooooo`0nool30018ool0083oo`03
003ooooo017oo`03003ooooo03[oo`@004_oo`00POoo00<00?ooool04?oo00<00?ooool0=_oo1000
Cooo0022ool2000@ool00`00ooooo`0bool4001Cool008Coo`03003ooooo00goo`03003ooooo02ko
o`@005Ooo`00QOoo00<00?ooool03?oo00<00?ooool0:_oo1000Fooo0026ool00`00ooooo`0;ool0
0`00ooooo`0Vool4001Oool008Ooo`8000_oo`03003ooooo02;oo`@006?oo`00ROoo00<00?ooool0
2?oo00<00?ooool07_oo1000Iooo002:ool00`00ooooo`07ool00`00ooooo`0Kool3001[ool008_o
o`03003ooooo00Koo`03003ooooo01Ooo`@006koo`00S?oo0P001_oo00<00?ooool04ooo1000L_oo
002>ool00`00ooooo`03ool00`00ooooo`0?ool4001fool008ooo`03003ooooo00;oo`03003ooooo
00_oo`@007[oo`00T?oo00D00?ooooooo`0000Woo`@007koo`00TOoo0P0000?oo`00ool01?oo1000
P_oo002Cool200000ooo000000020026ool009Coo`8008[oo`00oooo8Ooo003ooolQool00?ooob7o
o`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003o
oolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7o
o`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003o
oolQool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.28487, -0.0859866, \
0.0044785, 0.0044785}}]
}, Open  ]],

Cell[TextData[{
  "Here is the analytical expression for the theta of the put option ",
  StyleBox["xyzft", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.25"],

Cell[CellGroupData[{

Cell["Theta[xyzft, settlement, r]", "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(\(-3\)\ E\^\(\(-\(1\/2\)\)\ \((2\/\(5\ \@3\) + \@3\/20)\)\^2\)\ \@\(6\/\
\[Pi]\) + \(12\ \((1 + Erf[\(\(-\(2\/\(5\ \@3\)\)\) + \
\@3\/20\)\/\@2])\)\)\/\(5\ E\^\(1/25\)\)\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["This is a numerical approximation. ", "MathCaption",
  CellTags->"0.26"],

Cell[CellGroupData[{

Cell["N[%]", "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(\(-1.90083138203232859`\)\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[{
  "We define the theta of the option ",
  StyleBox["abcft", "MB"],
  " as a function of two variables, ",
  StyleBox["x", "MB"],
  " and ",
  StyleBox["t", "MB"],
  ", the price of the underlying asset and the time to maturity, \
respectively. "
}], "MathCaption",
  CellTags->"0.27"],

Cell["\<\
optiontheta[x_, t_] = Theta[abcft,
   ToCalendar[ToJulian[settlement] + Floor[t]], r] /.
   Price[ABC] -> x;\
\>", "Input",
  CellLabel->"In[22]:="],

Cell["\<\
This illustrates how the graph of the option theta changes as the \
time to maturity varies. \
\>", "MathCaption",
  CellTags->"0.28"],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Table[optiontheta[x, j],
   {j, 0, 110, 10}]], {x, 25, 45},
   PlotLabel ->
      \"    Call Option Theta\\nfor Different Maturities\",
   FrameLabel -> {\"Stock Price\", \"\"}];\
\>", "Input",
  CellLabel->"In[23]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.16667 0.0476191 0.603319 0.0361533 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -35 -24 ]
[.5 -0.0125 35 -9 ]
[-0.0125 .06102 -18 -4.5 ]
[-0.0125 .06102 0 4.5 ]
[-0.0125 .1514 -30 -4.5 ]
[-0.0125 .1514 0 4.5 ]
[-0.0125 .24179 -18 -4.5 ]
[-0.0125 .24179 0 4.5 ]
[-0.0125 .33217 -24 -4.5 ]
[-0.0125 .33217 0 4.5 ]
[-0.0125 .42255 -12 -4.5 ]
[-0.0125 .42255 0 4.5 ]
[-0.0125 .51294 -24 -4.5 ]
[-0.0125 .51294 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74 0 ]
[.5 .63053 74 31 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(25)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(30)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(35)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(40)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(45)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -96 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .06102 m
.00625 .06102 L
s
[(-15)] -0.0125 .06102 1 0 Mshowa
0 .1514 m
.00625 .1514 L
s
[(-12.5)] -0.0125 .1514 1 0 Mshowa
0 .24179 m
.00625 .24179 L
s
[(-10)] -0.0125 .24179 1 0 Mshowa
0 .33217 m
.00625 .33217 L
s
[(-7.5)] -0.0125 .33217 1 0 Mshowa
0 .42255 m
.00625 .42255 L
s
[(-5)] -0.0125 .42255 1 0 Mshowa
0 .51294 m
.00625 .51294 L
s
[(-2.5)] -0.0125 .51294 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .0791 m
.00375 .0791 L
s
0 .09717 m
.00375 .09717 L
s
0 .11525 m
.00375 .11525 L
s
0 .13333 m
.00375 .13333 L
s
0 .16948 m
.00375 .16948 L
s
0 .18756 m
.00375 .18756 L
s
0 .20563 m
.00375 .20563 L
s
0 .22371 m
.00375 .22371 L
s
0 .25986 m
.00375 .25986 L
s
0 .27794 m
.00375 .27794 L
s
0 .29602 m
.00375 .29602 L
s
0 .31409 m
.00375 .31409 L
s
0 .35025 m
.00375 .35025 L
s
0 .36832 m
.00375 .36832 L
s
0 .3864 m
.00375 .3864 L
s
0 .40448 m
.00375 .40448 L
s
0 .44063 m
.00375 .44063 L
s
0 .45871 m
.00375 .45871 L
s
0 .47678 m
.00375 .47678 L
s
0 .49486 m
.00375 .49486 L
s
0 .53101 m
.00375 .53101 L
s
0 .54909 m
.00375 .54909 L
s
0 .56717 m
.00375 .56717 L
s
0 .58524 m
.00375 .58524 L
s
0 .04294 m
.00375 .04294 L
s
0 .02487 m
.00375 .02487 L
s
0 .00679 m
.00375 .00679 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06102 m
1 .06102 L
s
.99375 .1514 m
1 .1514 L
s
.99375 .24179 m
1 .24179 L
s
.99375 .33217 m
1 .33217 L
s
.99375 .42255 m
1 .42255 L
s
.99375 .51294 m
1 .51294 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .0791 m
1 .0791 L
s
.99625 .09717 m
1 .09717 L
s
.99625 .11525 m
1 .11525 L
s
.99625 .13333 m
1 .13333 L
s
.99625 .16948 m
1 .16948 L
s
.99625 .18756 m
1 .18756 L
s
.99625 .20563 m
1 .20563 L
s
.99625 .22371 m
1 .22371 L
s
.99625 .25986 m
1 .25986 L
s
.99625 .27794 m
1 .27794 L
s
.99625 .29602 m
1 .29602 L
s
.99625 .31409 m
1 .31409 L
s
.99625 .35025 m
1 .35025 L
s
.99625 .36832 m
1 .36832 L
s
.99625 .3864 m
1 .3864 L
s
.99625 .40448 m
1 .40448 L
s
.99625 .44063 m
1 .44063 L
s
.99625 .45871 m
1 .45871 L
s
.99625 .47678 m
1 .47678 L
s
.99625 .49486 m
1 .49486 L
s
.99625 .53101 m
1 .53101 L
s
.99625 .54909 m
1 .54909 L
s
.99625 .56717 m
1 .56717 L
s
.99625 .58524 m
1 .58524 L
s
.99625 .04294 m
1 .04294 L
s
.99625 .02487 m
1 .02487 L
s
.99625 .00679 m
1 .00679 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Call) show
117.000000 15.000000 moveto
(Option) show
159.000000 15.000000 moveto
(Theta) show
63.000000 31.000000 moveto
(for) show
87.000000 31.000000 moveto
(Different) show
147.000000 31.000000 moveto
(Maturities) show
207.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.02381 .59732 m
.04262 .59574 L
.06244 .59373 L
.10458 .58815 L
.14264 .58133 L
.18314 .57199 L
.22214 .56087 L
.26358 .54679 L
.30351 .5312 L
.34193 .51466 L
.38279 .49586 L
.42214 .47715 L
.45998 .45914 L
.50027 .44054 L
.53904 .42373 L
.58026 .40754 L
.61997 .39397 L
.65817 .38302 L
.69881 .37379 L
.73794 .36725 L
.75935 .36462 L
.77952 .36274 L
.78929 .36203 L
.7996 .36141 L
.80841 .36099 L
.81807 .36064 L
.82331 .36049 L
.82828 .36039 L
.83273 .36031 L
.83525 .36028 L
.83758 .36026 L
.83878 .36025 L
.84007 .36025 L
.84129 .36024 L
.8424 .36024 L
.84364 .36023 L
.84434 .36023 L
.84499 .36023 L
.84631 .36023 L
.84705 .36024 L
.84772 .36024 L
.84911 .36024 L
.85038 .36025 L
.85327 .36027 L
.85581 .3603 L
.8585 .36033 L
.86343 .36041 L
.86793 .36051 L
.87807 .3608 L
.88747 .36115 L
Mistroke
.89638 .36156 L
.93463 .36403 L
.97533 .36772 L
.97619 .3678 L
Mfstroke
.02381 .59887 m
.04262 .59757 L
.06244 .59589 L
.10458 .59105 L
.14264 .58492 L
.18314 .57623 L
.22214 .56558 L
.26358 .55172 L
.30351 .53602 L
.34193 .51903 L
.38279 .49939 L
.42214 .47956 L
.45998 .46025 L
.50027 .44013 L
.53904 .42183 L
.58026 .40413 L
.61997 .38929 L
.65817 .37736 L
.69881 .36737 L
.73794 .36042 L
.75935 .35769 L
.76916 .35669 L
.77952 .3558 L
.78909 .35511 L
.7996 .35452 L
.80421 .35431 L
.80915 .35412 L
.81348 .35398 L
.81807 .35386 L
.82058 .3538 L
.82336 .35375 L
.82591 .35372 L
.82825 .35369 L
.82956 .35368 L
.83099 .35367 L
.83244 .35366 L
.83322 .35366 L
.83395 .35366 L
.83465 .35366 L
.83531 .35366 L
.83655 .35366 L
.83724 .35366 L
.83787 .35366 L
.83857 .35366 L
.83931 .35366 L
.84056 .35367 L
.8417 .35368 L
.84426 .3537 L
.84664 .35373 L
.84889 .35376 L
Mistroke
.85394 .35386 L
.85943 .35399 L
.86978 .35434 L
.87915 .35476 L
.90013 .35601 L
.91942 .35751 L
.94025 .35947 L
.97619 .3635 L
Mfstroke
.02381 .60022 m
.04262 .5992 L
.06244 .59786 L
.08426 .596 L
.10458 .59384 L
.14264 .5885 L
.18163 .58097 L
.22307 .57036 L
.263 .5574 L
.30142 .54243 L
.34228 .52402 L
.38164 .50433 L
.41947 .48415 L
.45976 .46205 L
.49853 .44098 L
.53975 .41963 L
.57946 .40084 L
.61766 .38498 L
.6583 .37093 L
.69743 .36038 L
.71741 .35616 L
.73901 .35247 L
.75988 .34974 L
.76981 .34872 L
.77908 .34793 L
.78893 .34725 L
.7979 .34678 L
.80268 .34658 L
.80788 .34641 L
.81073 .34633 L
.81337 .34627 L
.81608 .34622 L
.81857 .34619 L
.82082 .34616 L
.82196 .34615 L
.8232 .34615 L
.82445 .34614 L
.82515 .34614 L
.82579 .34614 L
.82703 .34614 L
.82819 .34614 L
.82929 .34614 L
.83045 .34615 L
.83144 .34615 L
.83253 .34616 L
.83496 .34619 L
.83723 .34622 L
.84242 .34631 L
.84716 .34643 L
.85783 .34682 L
Mistroke
.86771 .3473 L
.87686 .34785 L
.89759 .34946 L
.93678 .35362 L
.97619 .35897 L
Mfstroke
.02381 .60133 m
.04262 .60059 L
.06244 .59959 L
.08255 .59827 L
.10458 .59642 L
.12579 .59416 L
.14509 .59163 L
.18408 .58492 L
.22401 .57548 L
.26243 .56364 L
.30329 .54796 L
.34264 .52997 L
.38048 .51036 L
.42077 .4876 L
.45954 .46467 L
.50076 .44018 L
.54047 .41749 L
.57866 .39738 L
.61931 .37858 L
.65844 .36358 L
.67841 .35722 L
.70002 .35135 L
.71912 .34705 L
.74009 .34328 L
.76003 .3406 L
.77092 .33949 L
.78109 .33868 L
.7861 .33835 L
.79154 .33806 L
.79634 .33784 L
.80144 .33767 L
.80602 .33755 L
.80863 .3375 L
.80983 .33748 L
.81108 .33746 L
.81215 .33745 L
.81332 .33744 L
.81438 .33743 L
.81537 .33743 L
.81654 .33743 L
.81761 .33742 L
.81884 .33742 L
.82 .33743 L
.82115 .33743 L
.82239 .33744 L
.82356 .33745 L
.82463 .33746 L
.82724 .3375 L
.82972 .33755 L
.83464 .33767 L
Mistroke
.84001 .33784 L
.84959 .33827 L
.85847 .33879 L
.87903 .34043 L
.89765 .34238 L
.93777 .34781 L
.97619 .35422 L
Mfstroke
.02381 .60218 m
.04262 .6017 L
.06244 .60101 L
.08255 .60007 L
.10458 .5987 L
.12415 .59711 L
.14509 .59496 L
.16496 .59239 L
.18653 .58895 L
.22646 .58049 L
.26733 .56859 L
.30668 .55374 L
.34452 .5363 L
.3848 .5146 L
.42358 .49128 L
.4648 .46483 L
.50451 .43888 L
.5427 .41462 L
.58335 .39072 L
.62248 .37057 L
.66406 .35303 L
.68493 .3459 L
.70413 .34037 L
.72406 .33568 L
.74268 .33226 L
.7615 .32972 L
.77147 .32874 L
.77703 .32829 L
.78216 .32795 L
.787 .32769 L
.79234 .32746 L
.79492 .32737 L
.7977 .32729 L
.79924 .32726 L
.80064 .32723 L
.80198 .32721 L
.8034 .32719 L
.80467 .32717 L
.80583 .32716 L
.80699 .32716 L
.80808 .32716 L
.80936 .32715 L
.81054 .32716 L
.81184 .32716 L
.81249 .32717 L
.81321 .32717 L
.81578 .3272 L
.81722 .32723 L
.81854 .32725 L
.82352 .32738 L
Mistroke
.82831 .32755 L
.8334 .32777 L
.84255 .32831 L
.85343 .32914 L
.86329 .33007 L
.9034 .33535 L
.94201 .34222 L
.97619 .3493 L
Mfstroke
.02381 .60277 m
.03279 .60265 L
.04262 .60249 L
.06244 .60208 L
.07298 .60179 L
.08426 .60143 L
.10458 .60058 L
.12589 .59936 L
.14603 .59783 L
.166 .59586 L
.18444 .59357 L
.20476 .59043 L
.22379 .58682 L
.26163 .57745 L
.3004 .56439 L
.34162 .54633 L
.38133 .5249 L
.41952 .50102 L
.46017 .47298 L
.4993 .44467 L
.54088 .41475 L
.58095 .38768 L
.6195 .36459 L
.6605 .34431 L
.68092 .33611 L
.69999 .32966 L
.71949 .32429 L
.73796 .32034 L
.74771 .3187 L
.75831 .31725 L
.76795 .31623 L
.77687 .31553 L
.7815 .31526 L
.78393 .31515 L
.7865 .31504 L
.78875 .31497 L
.79121 .3149 L
.79345 .31485 L
.79453 .31483 L
.79553 .31482 L
.79682 .31481 L
.7975 .3148 L
.79822 .3148 L
.79942 .31479 L
.80011 .31479 L
.80075 .31479 L
.80195 .3148 L
.80304 .3148 L
.8043 .31482 L
.80549 .31483 L
Mistroke
.80814 .31488 L
.81058 .31494 L
.81613 .31513 L
.82123 .31537 L
.82673 .31571 L
.8367 .31649 L
.85532 .31853 L
.87529 .32147 L
.89637 .32531 L
.9344 .33369 L
.97487 .34401 L
.97619 .34436 L
Mfstroke
.02381 .60311 m
.03279 .60306 L
.04262 .60298 L
.06244 .60278 L
.07298 .60263 L
.08426 .60244 L
.10458 .60196 L
.1148 .60164 L
.12589 .60123 L
.14603 .60026 L
.16586 .59895 L
.18689 .59709 L
.20643 .59481 L
.22473 .59212 L
.2635 .58418 L
.28463 .57836 L
.30472 .5717 L
.34292 .55578 L
.38356 .53393 L
.42269 .50834 L
.46427 .47718 L
.50434 .44477 L
.54289 .41314 L
.58389 .38107 L
.62338 .35362 L
.66135 .33181 L
.6825 .32197 L
.70178 .31455 L
.72176 .30844 L
.74069 .30415 L
.75034 .30252 L
.7606 .30118 L
.76935 .30035 L
.77434 .30001 L
.77902 .29977 L
.78145 .29967 L
.78371 .2996 L
.78499 .29957 L
.78619 .29955 L
.78686 .29954 L
.78758 .29953 L
.78885 .29952 L
.79009 .29951 L
.7908 .29951 L
.79146 .29951 L
.79216 .29951 L
.7928 .29951 L
.79353 .29952 L
.79423 .29952 L
.79547 .29954 L
Mistroke
.79661 .29956 L
.7992 .29962 L
.80162 .29969 L
.8039 .29978 L
.80816 .29999 L
.81275 .30028 L
.8177 .30066 L
.82723 .30161 L
.83768 .30294 L
.85876 .30649 L
.89923 .31595 L
.9382 .32736 L
.97619 .33967 L
Mfstroke
.02381 .60327 m
.03279 .60325 L
.04262 .60322 L
.05288 .60319 L
.06244 .60315 L
.0731 .6031 L
.0828 .60303 L
.094 .60293 L
.10458 .60281 L
.11428 .60268 L
.12455 .6025 L
.14299 .60207 L
.1524 .60178 L
.16253 .60141 L
.18083 .60053 L
.20196 .59912 L
.22205 .59726 L
.24186 .5948 L
.26025 .59184 L
.28077 .58762 L
.29938 .58283 L
.33944 .56884 L
.37799 .54995 L
.419 .52363 L
.45848 .49264 L
.49646 .45881 L
.53688 .42051 L
.57579 .38393 L
.61715 .34827 L
.65699 .31954 L
.69532 .29881 L
.7151 .29106 L
.72521 .2879 L
.73611 .2851 L
.74626 .28304 L
.75071 .28231 L
.75558 .28162 L
.75988 .28111 L
.76448 .28067 L
.76703 .28047 L
.76934 .28031 L
.77167 .28018 L
.77386 .28008 L
.77617 .28001 L
.77739 .27997 L
.77871 .27995 L
.77936 .27994 L
.78008 .27993 L
.78139 .27992 L
.78266 .27992 L
Mistroke
.78384 .27992 L
.78504 .27993 L
.78618 .27995 L
.7872 .27997 L
.7883 .27999 L
.79077 .28007 L
.79304 .28017 L
.79787 .28045 L
.80316 .28087 L
.81384 .28207 L
.82407 .28363 L
.83339 .28538 L
.85432 .29035 L
.89421 .303 L
.93259 .31776 L
.97343 .33467 L
.97619 .33583 L
Mfstroke
.02381 .60331 m
.03279 .60331 L
.04262 .6033 L
.05288 .6033 L
.06244 .60329 L
.0731 .60328 L
.0828 .60326 L
.094 .60324 L
.10458 .6032 L
.11428 .60317 L
.12455 .60311 L
.13333 .60305 L
.14299 .60297 L
.15313 .60285 L
.1624 .60272 L
.17311 .60253 L
.18328 .6023 L
.19287 .60203 L
.20309 .60168 L
.22147 .60082 L
.23176 .6002 L
.24289 .59937 L
.26306 .59739 L
.283 .59468 L
.30406 .59079 L
.3237 .58599 L
.34203 .58031 L
.38094 .56366 L
.40218 .55159 L
.4223 .53808 L
.46063 .50674 L
.50141 .46626 L
.54068 .42261 L
.57843 .37947 L
.61863 .33622 L
.65732 .30088 L
.67697 .28623 L
.69846 .27318 L
.70838 .26826 L
.71899 .26378 L
.72892 .26033 L
.73808 .25779 L
.74833 .25566 L
.75372 .25483 L
.75647 .25449 L
.75943 .25418 L
.76202 .25396 L
.76439 .25379 L
.76677 .25367 L
.76795 .25362 L
Mistroke
.76903 .25358 L
.7703 .25355 L
.77099 .25354 L
.77165 .25353 L
.77281 .25352 L
.77408 .25351 L
.77474 .25352 L
.77547 .25352 L
.77624 .25354 L
.77695 .25355 L
.77822 .25358 L
.77958 .25363 L
.78215 .25375 L
.78488 .25392 L
.78978 .25434 L
.79505 .25495 L
.80086 .25582 L
.81125 .25783 L
.821 .26022 L
.84122 .2666 L
.85974 .27387 L
.89941 .29275 L
.93757 .3132 L
.97619 .33416 L
Mfstroke
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03793 .60332 L
.04262 .60332 L
.0522 .60332 L
.05746 .60332 L
.06244 .60332 L
.06754 .60332 L
.07295 .60332 L
.08265 .60332 L
.08804 .60331 L
.09308 .60331 L
.09858 .60331 L
.10458 .60331 L
.10996 .60331 L
.11496 .6033 L
.12483 .6033 L
.13379 .60329 L
.14335 .60328 L
.15364 .60326 L
.15943 .60324 L
.16476 .60323 L
.17457 .60319 L
.18493 .60314 L
.19441 .60307 L
.20457 .60298 L
.21416 .60286 L
.22291 .60272 L
.23282 .60253 L
.24199 .60229 L
.25206 .60197 L
.26275 .60153 L
.27212 .60105 L
.28222 .60041 L
.3005 .59883 L
.31007 .59775 L
.32054 .59632 L
.34164 .5925 L
.36125 .58754 L
.3822 .58037 L
.40355 .57069 L
.4237 .55898 L
.46217 .52888 L
.50309 .48528 L
.54249 .43373 L
.58038 .37921 L
.62072 .32194 L
.65954 .27408 L
.67929 .25428 L
Mistroke
.70082 .23702 L
.71081 .23067 L
.72145 .2251 L
.73149 .22099 L
.74058 .21821 L
.74547 .21709 L
.75063 .21619 L
.75503 .21564 L
.75753 .21542 L
.75986 .21527 L
.76116 .21521 L
.76189 .21519 L
.76257 .21517 L
.76381 .21515 L
.76513 .21514 L
.76631 .21515 L
.76741 .21517 L
.76862 .21521 L
.76992 .21527 L
.77123 .21534 L
.77266 .21544 L
.77555 .2157 L
.77822 .21602 L
.7807 .21637 L
.78576 .21726 L
.79125 .21849 L
.80119 .22137 L
.81979 .22883 L
.83971 .23936 L
.86076 .2527 L
.8987 .28026 L
.9391 .31104 L
.97619 .33773 L
Mfstroke
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03754 .60332 L
.04262 .60332 L
.04518 .60332 L
.04795 .60332 L
.053 .60332 L
.05791 .60332 L
.06244 .60332 L
.06747 .60332 L
.07218 .60332 L
.07734 .60332 L
.0829 .60332 L
.08567 .60332 L
.0887 .60332 L
.09422 .60332 L
.09959 .60332 L
.10458 .60332 L
.10966 .60332 L
.11515 .60332 L
.12033 .60332 L
.1251 .60332 L
.12942 .60332 L
.13415 .60332 L
.13909 .60332 L
.14371 .60332 L
.14872 .60332 L
.15416 .60332 L
.1593 .60332 L
.16406 .60332 L
.17306 .60332 L
.1776 .60332 L
.18262 .60331 L
.18753 .60331 L
.19271 .60331 L
.20196 .60331 L
.20712 .6033 L
.21193 .6033 L
.21715 .60329 L
.22282 .60329 L
.2283 .60328 L
.23334 .60327 L
.23807 .60326 L
.24328 .60324 L
.25231 .60321 L
.26187 .60316 L
.27203 .60309 L
.28131 .60299 L
.29203 .60284 L
Mistroke
.30221 .60264 L
.31182 .60239 L
.32205 .60203 L
.33171 .60157 L
.34045 .60105 L
.3505 .60027 L
.35974 .59937 L
.36987 .59811 L
.38057 .59644 L
.39007 .59457 L
.40025 .59213 L
.41859 .58628 L
.42879 .58207 L
.43987 .5766 L
.46001 .56388 L
.47982 .54733 L
.50084 .52488 L
.53864 .47121 L
.5789 .39771 L
.61764 .31903 L
.65883 .24053 L
.6794 .20803 L
.69851 .18374 L
.71697 .16652 L
.7273 .15974 L
.73176 .15745 L
.73667 .15539 L
.74153 .15381 L
.74419 .15313 L
.74668 .15263 L
.749 .15227 L
.75112 .15202 L
.75229 .15192 L
.75357 .15185 L
.75478 .1518 L
.75589 .15178 L
.75708 .15179 L
.75836 .15182 L
.75957 .15188 L
.76068 .15196 L
.76191 .15208 L
.76326 .15223 L
.76598 .15265 L
.76866 .15318 L
.77153 .15389 L
.7767 .15552 L
.78693 .16001 L
.79802 .16664 L
.81817 .1827 L
.85905 .22622 L
Mistroke
.89843 .27343 L
.93628 .31624 L
.97619 .35393 L
Mfstroke
.02381 .60332 m
.02605 .60332 L
.02846 .60332 L
.03072 .60332 L
.03279 .60332 L
.03521 .60332 L
.03784 .60332 L
.04032 .60332 L
.04262 .60332 L
.04498 .60332 L
.0472 .60332 L
.04963 .60332 L
.05224 .60332 L
.05355 .60332 L
.05497 .60332 L
.05757 .60332 L
.0601 .60332 L
.06124 .60332 L
.06244 .60332 L
.06382 .60332 L
.06509 .60332 L
.06795 .60332 L
.07043 .60332 L
.07183 .60332 L
.07314 .60332 L
.07559 .60332 L
.07782 .60332 L
.0804 .60332 L
.08284 .60332 L
.08546 .60332 L
.08825 .60332 L
.09063 .60332 L
.09325 .60332 L
.09606 .60332 L
.09909 .60332 L
.10196 .60332 L
.10458 .60332 L
.10706 .60332 L
.10932 .60332 L
.11192 .60332 L
.11438 .60332 L
.11666 .60332 L
.11876 .60332 L
.12106 .60332 L
.1235 .60332 L
.12596 .60332 L
.1286 .60332 L
.13109 .60332 L
.13336 .60332 L
.13602 .60332 L
Mistroke
.13892 .60332 L
.14166 .60332 L
.1442 .60332 L
.14686 .60332 L
.1493 .60332 L
.15197 .60332 L
.1548 .60332 L
.15726 .60332 L
.15955 .60332 L
.16207 .60332 L
.16477 .60332 L
.16717 .60332 L
.16977 .60332 L
.17224 .60332 L
.17451 .60332 L
.17882 .60332 L
.18099 .60332 L
.18339 .60332 L
.18832 .60332 L
.1908 .60332 L
.19351 .60332 L
.19583 .60332 L
.19831 .60332 L
.20277 .60332 L
.20548 .60332 L
.2084 .60332 L
.21098 .60332 L
.21371 .60332 L
.21618 .60332 L
.21888 .60332 L
.22364 .60332 L
.22615 .60332 L
.22887 .60332 L
.23127 .60332 L
.23383 .60332 L
.23612 .60332 L
.23866 .60332 L
.24313 .60332 L
.24583 .60332 L
.24831 .60332 L
.25098 .60332 L
.25391 .60332 L
.25884 .60332 L
.26153 .60332 L
.26403 .60332 L
.26907 .60332 L
.27192 .60332 L
.27454 .60332 L
.27936 .60332 L
.28447 .60332 L
Mistroke
.28903 .60332 L
.29331 .60332 L
.298 .60332 L
.30305 .60332 L
.30829 .60332 L
.31316 .60331 L
.3185 .60331 L
.3242 .60331 L
.32963 .60331 L
.33474 .6033 L
.33933 .6033 L
.34429 .60329 L
.34921 .60328 L
.35381 .60327 L
.35884 .60325 L
.36424 .60323 L
.36991 .6032 L
.37527 .60316 L
.38008 .60312 L
.38531 .60306 L
.39472 .60291 L
.40008 .6028 L
.4051 .60266 L
.41522 .6023 L
.4209 .60202 L
.42612 .6017 L
.43593 .60092 L
.44505 .5999 L
.45507 .59837 L
.46576 .59608 L
.47601 .59309 L
.48712 .58871 L
.49761 .58321 L
.50728 .57673 L
.52606 .5593 L
.53672 .54601 L
.5467 .53103 L
.567 .4921 L
.58554 .44618 L
.62533 .31833 L
.66359 .18001 L
.68496 .11121 L
.70431 .06192 L
.71402 .04324 L
.71913 .03523 L
.72451 .02818 L
.72924 .02321 L
.73174 .02104 L
.73441 .01907 L
.73688 .01758 L
Mistroke
.73912 .0165 L
.7402 .01607 L
.74138 .01567 L
.74247 .01536 L
.74351 .01512 L
.74473 .01491 L
.74586 .01478 L
.74706 .01472 L
.74838 .01473 L
.74952 .0148 L
.75075 .01496 L
.7519 .01517 L
.75294 .01542 L
.75551 .01626 L
.75829 .01752 L
.76334 .02071 L
.76866 .02532 L
.77429 .03149 L
.78436 .04559 L
.80399 .08235 L
.82232 .12429 L
.86122 .22038 L
.88102 .26574 L
.90257 .30871 L
.92188 .34053 L
.9424 .36733 L
.95846 .38365 L
.97619 .39755 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[23]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo003ooolX
ool00?ooobSoo`00oooo:?oo003ooolXool008;oo`<000?oo`8000?oo`8000;oo`<00004ool00000
ool2000;ool30003ool30002ool30002ool30003ool2001Zool008;oo`03003oo`0000;oo`06003o
oooo003oo`000_oo00<00?oo00001?oo00<00?oo00003Ooo00<00?ooool00ooo00<00?ooool00_oo
00D00?ooooooo`0000Coo`03003ooooo06[oo`00Q?oo00@00?ooool000Coo`06003ooooo003oo`00
1?oo0`003Ooo0`000ooo00<00?ooool00_oo00D00?ooooooo`0000Coo`<006[oo`00Pooo00<00?oo
ool010000ooo0P000_oo0`000_oo00@00?oo000000coo`05003ooooo003oo`0400000ooo00000003
ool30002ool3001Zool008;oo`03003oo`0000;oo`03003ooooo00coo`03003ooooo00goo`04003o
oooo001mool008;oo`<0013oo`8000koo`@000Soo`03003ooooo07?oo`00oooo:?oo003ooolXool0
0?ooobSoo`00oooo:?oo003ooolXool0047oo`<000?oo`03003ooooo02Goo`8000Coo`03003ooooo
02Koo`8000Coo`03003ooooo02Ooo`<000;oo`03003ooooo02Ooo`<000;oo`03003ooooo02;oo`00
@Ooo00<00?ooool00_oo00<00?oo0000:?oo00H00?ooool00?oo000Yool01P00ooooo`00ool002Wo
o`06003ooooo003oo`00:Ooo00H00?ooool00?oo000Sool004;oo`03003ooooo00?oo`03003ooooo
02Goo`07003oooooool00?oo0000:?oo00<00?ooool00ooo00<00?ooool09Ooo100000Coo`00ool0
02Ooo`@000?oo`03003ooooo027oo`00@_oo00@00?ooooooo`8002Woo`06003ooooo003oo`00:Ooo
00<00?ooool00P00:?oo00<00?oo00000_oo00<00?oo00009ooo00<00?oo00000_oo0P009?oo0011
ool00`00ool00002ool00`00ooooo`0Vool00`00ool00002ool00`00ool0000Wool00`00ool00002
ool00`00ooooo`0Xool20002ool00`00ool0000Xool20002ool00`00ooooo`0Sool004;oo`04003o
ooooool3000Wool00`00ooooo`02ool00`00ooooo`0Wool01000oooooooo0`00:Ooo00D00?oooooo
o`0002[oo`03003ooooo00<002?oo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo0010ooo6
000Qool0043oo`03003ooooo00;oo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03
003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Ooo`03
003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00;oo`03003ooooo01ooo`00@?oo0P000ooo00<0
0?ooool0:ooo00<00?ooool0;?oo00<00?ooool0;?oo00<00?ooool0;?oo00@00?ooooooo`80027o
o`00@?oo00<00?ooool0Sooo0`00<?oo00<00?ooool07ooo0010ool00`00ooooo`2=ool20003ool2
000^ool00`00ooooo`0Oool0043oo`8008goo`03003ooooo00Goo`03003ooooo02[oo`80027oo`00
@?oo00<00?ooool0S?oo00<00?ooool01_oo00<00?ooool0:_oo00<00?ooool07ooo0010ool00`00
ooooo`2;ool00`00ooooo`07ool00`00ooooo`0Zool00`00ooooo`0Oool0043oo`03003ooooo08[o
o`03003ooooo00Woo`03003ooooo02Woo`03003ooooo01ooo`00@?oo0P00Rooo00<00?ooool02_oo
00<00?ooool09ooo0P008Ooo000cool50002ool00`00ooooo`03ool00`00ooooo`29ool00`00oooo
o`0<ool00`00ooooo`0Wool00`00ooooo`0Oool003Goo`07003oooooool00?oo00001?oo00<00?oo
ool0ROoo00<00?ooool03?oo00<00?ooool09ooo00<00?ooool07ooo000_ool30003ool00`00oooo
o`03ool00`00ooooo`02ool20029ool00`00ooooo`0>ool00`00ooooo`0Uool2000Qool003Goo`04
003oooooool20005ool00`00ooooo`28ool00`00ooooo`0>ool00`00ooooo`0Vool00`00ooooo`0O
ool003Goo`05003oooooool00006ool00`00ooooo`28ool00`00ooooo`0?ool00`00ooooo`0Uool0
0`00ooooo`0Oool003Coo`8000?oo`<000Coo`03003ooooo08Ooo`03003ooooo013oo`03003ooooo
02Goo`03003ooooo01ooo`00@?oo0P00R?oo00<00?ooool04Ooo00<00?ooool08ooo0P008Ooo0010
ool00`00ooooo`26ool00`00ooooo`0Bool00`00ooooo`0Tool00`00ooooo`0Oool0043oo`03003o
oooo08Koo`03003ooooo01?oo`03003ooooo02?oo`03003ooooo01ooo`00@?oo0P00Q_oo00<00?oo
ool05?oo00<00?ooool08_oo0P008Ooo0010ool00`00ooooo`25ool00`00ooooo`0Eool00`00oooo
o`0Rool00`00ooooo`0Oool0043oo`03003ooooo08Coo`03003ooooo01Koo`03003ooooo02;oo`03
003ooooo01ooo`00@?oo00<00?ooool0Q?oo00<00?ooool05ooo00<00?ooool08Ooo00<00?ooool0
7ooo0010ool20025ool00`00ooooo`0Gool00`00ooooo`0Pool2000Qool0043oo`03003ooooo08?o
o`03003ooooo01Woo`03003ooooo023oo`03003ooooo01ooo`00@?oo00<00?ooool0Pooo00<00?oo
ool06Ooo00<00?ooool08?oo00<00?ooool07ooo0010ool00`00ooooo`23ool00`00ooooo`0Iool0
0`00ooooo`0Pool00`00ooooo`0Oool0043oo`8008Coo`03003ooooo01[oo`03003ooooo01koo`80
027oo`00:Ooo1@0000Coo`00000000?oo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo08;o
o`03003ooooo01_oo`03003ooooo01ooo`03003ooooo01ooo`00:ooo00D00?ooooooo`0000Woo`03
003oo`0000Coo`03003ooooo08;oo`03003ooooo01_oo`03003ooooo01ooo`03003ooooo01ooo`00
9Ooo0`000ooo00<00?ooool00_oo00<00?ooool02?oo00<00?ooool00_oo0P00Pooo00<00?ooool0
2_oo1P003?oo00<00?ooool07Ooo0P008Ooo000[ool00`00ooooo`02ool00`00ooooo`06ool20005
ool00`00ooooo`21ool00`00ooooo`09ool30005ool2000:ool00`00ooooo`0Nool00`00ooooo`0O
ool002_oo`07003oooooool00?oo00001ooo00<00?ooool01?oo00<00?ooool0POoo00<00?ooool0
2?oo00<00?ooool02?oo0P002Ooo00<00?ooool07Ooo00<00?ooool07ooo000Zool20004ool00`00
ooooo`06ool30004ool00`00ooooo`21ool00`00ooooo`06ool2000=ool20007ool00`00ooooo`0M
ool00`00ooooo`0Oool0043oo`8008;oo`03003ooooo00Goo`03003ooooo00ooo`03003ooooo00Co
o`03003ooooo01coo`80027oo`00@?oo00<00?ooool0P?oo00<00?ooool01Ooo00<00?ooool04Ooo
0P001Ooo00<00?ooool07?oo00<00?ooool07ooo0010ool00`00ooooo`20ool00`00ooooo`04ool0
0`00ooooo`0Dool00`00ooooo`02ool00`00ooooo`0Lool00`00ooooo`0Oool0043oo`80087oo`03
003ooooo00?oo`03003ooooo01Koo`05003oooooool0000Mool2000Qool0043oo`03003ooooo07oo
o`03003ooooo00?oo`03003ooooo01Soo`05003oooooool0000Mool00`00ooooo`0Oool0043oo`03
003ooooo07ooo`03003ooooo00;oo`03003ooooo01[oo`04003ooooo000Mool00`00ooooo`0Oool0
043oo`03003ooooo07ooo`03003ooooo00;oo`03003ooooo01_oo`04003ooooo000Lool00`00oooo
o`0Oool0043oo`80083oo`05003oooooool0000Nool01000ooooo`006ooo0P008Ooo0010ool00`00
ooooo`1nool01@00oooooooo00008?oo00<00?oo00007?oo00<00?ooool07ooo0010ool00`00oooo
o`1nool01@00oooooooo00003?oo2`002_oo00<00?oo00006ooo00<00?ooool07ooo0010ool2001o
ool01000ooooo`002ooo0P002ooo0`002?oo0P006_oo0P008Ooo0010ool00`00ooooo`1mool01@00
oooooooo00002Ooo0P004?oo0P001ooo00<00?ooool06Ooo00<00?ooool07ooo000cool50002ool0
0`00ooooo`03ool00`00ooooo`1mool01000ooooo`002?oo0P005?oo0P001_oo00<00?ooool06?oo
00<00?ooool07ooo000eool01`00oooooooo003oo`0000Coo`03003ooooo07goo`04003ooooo0006
ool2000Hool20004ool2000Iool00`00ooooo`0Oool002ooo`<000?oo`07003oooooool00?oo0000
1?oo0P00OOoo00@00?ooool000Koo`03003ooooo01[oo`03003ooooo00;oo`8001Ooo`80027oo`00
=Ooo00L00?ooooooo`00ool00004ool00`00ooooo`1lool00`00ool00005ool2000Nool20002ool0
0`00ool0000Gool00`00ooooo`0Oool003Goo`07003oooooool00?oo00001?oo00<00?ooool0O?oo
00<00?oo00001?oo00<00?ooool03?oo1`003Ooo00<00?ooool00P005ooo00<00?ooool07ooo000d
ool20004ool00`00ooooo`03ool00`00ooooo`1lool20004ool00`00ooooo`09ool40007ool50009
ool01@00ool00?oo00005_oo00<00?ooool07ooo0010ool2001lool00`00ool00003ool00`00oooo
o`06ool4000@ool30007ool300000ooo003oo`0Cool2000Qool0043oo`03003ooooo07_oo`8000?o
o`03003ooooo00Goo`8001Ooo`@000Goo`04003ooooo000Dool00`00ooooo`0Oool0043oo`03003o
oooo07_oo`8000;oo`03003ooooo00Coo`8001goo`8000Coo`04003ooooo000Cool00`00ooooo`0O
ool0043oo`8007_oo`8000;oo`03003ooooo00Coo`03003ooooo00goo`D000goo`8000;oo`<00003
ool00?oo013oo`80027oo`00@?oo00<00?ooool0N_oo0P0000?oo`00ool01?oo0P002Ooo20000ooo
1`002Ooo0P0000Koo`00ool00?oo000Aool00`00ooooo`0Oool0043oo`03003ooooo07[oo`04003o
oooo0004ool00`00ooooo`07ool2000Bool30008ool300000ooo0000000Aool00`00ooooo`0Oool0
043oo`03003ooooo07Woo`800003ool00?oo00?oo`03003ooooo00Goo`<001Ooo`@000Koo`800003
ool00000013oo`03003ooooo01ooo`00@?oo0P00N_oo00<00?oo00000ooo0P001Ooo0`002ooo2P00
2Ooo10000ooo0`0000?oo`00ool03Ooo0P008Ooo0010ool00`00ooooo`1iool20003ool00`00oooo
o`03ool20008ool6000:ool60007ool40002ool3000>ool00`00ooooo`0Oool0043oo`03003ooooo
07Soo`8000?oo`03003ooooo00;oo`8000Koo`@001Koo`@000Ooo`8000;oo`<000coo`03003ooooo
01ooo`00@?oo0P00NOoo0P000_oo00@00?ooooooo`8000Goo`<000coo`X000Soo`@000Coo`L000[o
o`80027oo`00@?oo00<00?ooool0Mooo0P000_oo00<00?ooool00P001Ooo0P001_oo2@002_oo1`00
1Ooo1@000ooo1@002Ooo00<00?ooool07ooo000`ool00`00ooooo`02ool00`00ooooo`02ool00`00
ooooo`03ool00`00ooooo`1fool300001Ooo003ooooo00001Ooo0P001Ooo0`006_oo200000?oo`00
00000P000_oo1@001ooo00<00?ooool07ooo000`ool00`00ooooo`06ool00`00ool00004ool00`00
ooooo`1fool200000ooo003oo`020004ool20004ool30008oolI0004ool400000ooo000000020000
0ooo000000020005ool00`00ooooo`0Oool002[oo`<000?oo`03003ooooo00Soo`03003ooooo00;o
o`8007Koo`@00003ool00?oo00?oo`8000Coo`8000?oo`P001Woo`H00003ool0000000<00003ool0
000000@000?oo`80027oo`00<Ooo00<00?ooool01Ooo0P001Ooo00<00?ooool0MOoo00D00?oo003o
o`0000?oo`8000?oo`<000;oo`<000SooaX000Goo`@000;oo`@00003ool0000000Coo`03003ooooo
01ooo`00;ooo00<00?oo00001ooo00<00?ooool01?oo00<00?ooool0M?oo00<00?oo00000P000_oo
0P000_oo0`000_oo0`001ooo10003Ooo0`002_oo1P0000?oo`00ool01@0000Coo`00000000Coo`03
003ooooo01ooo`00;ooo0`001ooo0`001?oo0P00M?oo10000_oo0P000_oo0P000ooo0P001_oo1000
0ooo3`0000?oo`0000006`000ooo0P008Ooo0010ool00`00ooooo`1cool400001?oo003ooooo0P00
0_oo0`000ooo30001Ooo6P000_oo1`0000?oo`0000000P001?oo00<00?ooool07ooo0010ool00`00
ooooo`1bool600001?oo00000?oo0`000_oo20001?oo2@001_oo4@000ooo3P001?oo00<00?ooool0
7ooo0010ool00`00ooooo`1aool300000ooo003oo`050002ool70004ool40004ool;000Aool<0000
0ooo000000020004ool00`00ooooo`0Oool0043oo`80077oo`T000?oo`D000Goo`<000;oo`H002Go
o`03003ooooo00D000?oo`80027oo`00@?oo00<00?ooool0L?oo0`0000Coo`00000000;oo`D000Co
o`T002coo`03003ooooo00Soo`03003ooooo01ooo`00@?oo00<00?ooool0Kooo1P000_oo1@000_oo
2000<_oo0P002?oo00<00?ooool07ooo0010ool2001_ool500000ooo0000000300000ooo00000006
000hool00`00ooooo`04ool2000Qool0043oo`03003ooooo06goo`@000;oo`/003goo`03003ooooo
00Coo`03003ooooo01ooo`00@?oo00<00?ooool0K?oo100000?oo`0000001`00@_oo00<00?ooool0
0ooo00<00?ooool07ooo0010ool00`00ooooo`1[ool300000ooo000000050017ool00`00ooooo`02
ool00`00ooooo`0Oool0043oo`8006_oo`X004goo`80027oo`00@?oo00<00?ooool0J?oo2@0000?o
o`00ool0C_oo00<00?ooool07ooo000jool00`00ooooo`03ool00`00ooooo`1Wool70004ool00`00
ooooo`1=ool00`00ooooo`0Oool003Woo`03003oo`0000Coo`03003ooooo06Koo`H00003ool00?oo
00?oo`03003ooooo04goo`03003ooooo01ooo`00=?oo0`001?oo00<00?ooool00_oo0P00IOoo1P00
0_oo00<00?ooool00_oo00<00?ooool0COoo0P008Ooo000iool20005ool00`00ooooo`1Sool40002
ool01000ooooo`001?oo00<00?ooool0C_oo00<00?ooool07ooo000iool00`00ooooo`04ool00`00
ooooo`1Qool50002ool01000ooooo`001Ooo00<00?ooool0C_oo00<00?ooool07ooo000iool30004
ool2001Pool60002ool01000ooooo`001Ooo00<00?ooool0C_oo0P008Ooo0010ool00`00ooooo`1M
ool400000ooo00000002ool01@00oooooooo00001Ooo00<00?ooool0Cooo00<00?ooool07ooo0010
ool00`00ooooo`1Kool500001?oo003oo`000_oo00@00?ooool000Koo`03003ooooo04ooo`03003o
oooo01ooo`00@?oo00<00?ooool0FOoo1P0000Coo`00ool000;oo`05003oooooool00005ool00`00
ooooo`1@ool00`00ooooo`0Oool0043oo`8005Ooo`L000;oo`03003oo`0000;oo`05003oooooool0
0006ool00`00ooooo`1?ool2000Qool0043oo`03003ooooo05Coo`P000;oo`03003oo`0000;oo`03
003ooooo00;oo`03003ooooo00Coo`03003ooooo053oo`03003ooooo01ooo`00@?oo00<00?ooool0
D_oo2@0000Goo`00003oo`0000;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo057oo`03
003ooooo01ooo`00@?oo0P00DOoo1P0000?oo`0000000_oo00@00?ooool000?oo`05003oooooool0
0007ool00`00ooooo`1@ool2000Qool0043oo`03003ooooo04koo`X000;oo`04003ooooo0003ool0
0`00ooooo`02ool00`00ooooo`05ool00`00ooooo`1Aool00`00ooooo`0Oool0043oo`03003ooooo
04coo`L00005ool00000003oo`020002ool01@00oooooooo00001?oo00<00?ooool01Ooo00<00?oo
ool0D_oo00<00?ooool07ooo0010ool00`00ooooo`1:ool70002ool20002ool01@00oooooooo0000
0ooo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool0D_oo00<00?ooool07ooo0010ool20019
ool800001?oo000000000_oo00D00?ooooooo`0000?oo`03003ooooo00?oo`03003ooooo00Goo`03
003ooooo05;oo`80027oo`00;ooo0`000ooo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool0
A_oo20000_oo0`0000?oo`0000000ooo00D00?ooooooo`0000Goo`03003ooooo00Koo`03003ooooo
05?oo`03003ooooo01ooo`00;ooo00<00?ooool01ooo00<00?oo00001?oo00<00?ooool0A?oo1`00
00?oo`00ool00`000_oo00<00?ooool00_oo00D00?ooooooo`0000Koo`03003ooooo00Goo`03003o
oooo05Coo`03003ooooo01ooo`00:_oo0`000ooo00<00?ooool02?oo00<00?ooool00_oo0P00@ooo
1`0000Coo`00003oo`<000;oo`03003ooooo00;oo`05003oooooool00006ool00`00ooooo`06ool0
0`00ooooo`1Cool2000Qool0033oo`03003ooooo00Koo`8000Goo`03003ooooo03ooo`T00003ool0
0?oo00<000;oo`8000?oo`8000?oo`03003ooooo00Coo`03003ooooo00Koo`03003ooooo05Goo`03
003ooooo01ooo`00;ooo00<00?oo00001ooo00<00?ooool01?oo00<00?ooool0?Ooo2@0000?oo`00
000010000_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool01Ooo00<00?ooool01_oo00<0
0?ooool0EOoo00<00?ooool07ooo000`ool00`00ooooo`06ool30004ool00`00ooooo`0kool90000
1?oo00000?oo0`000ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool01Ooo00<00?ooool0
1_oo00<00?ooool0E_oo00<00?ooool07ooo0010ool2000iool:00001?oo00000?oo0`000ooo0P00
0ooo0P001?oo00<00?ooool01Ooo00<00?ooool01ooo00<00?ooool0EOoo0P008Ooo0010ool00`00
ooooo`0fool900001Ooo00000000ool010000ooo00<00?ooool00_oo00<00?ooool00_oo0P001_oo
0P002Ooo00<00?ooool0Eooo00<00?ooool07ooo0010ool00`00ooooo`0cool700001?oo00000?oo
0P000_oo0P0000?oo`00ool00ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool01Ooo00<0
0?ooool02Ooo00<00?ooool0Eooo00<00?ooool07ooo0010ool2000aool700000ooo000000040000
1Ooo00000000ool00P000ooo0P000ooo0P001?oo00<00?ooool01Ooo00<00?ooool02Ooo00<00?oo
ool0Eooo0P008Ooo0010ool00`00ooooo`0^ool700000ooo000000030002ool20002ool20003ool2
0004ool00`00ooooo`02ool20007ool00`00ooooo`08ool2001Kool00`00ooooo`0Oool0043oo`03
003ooooo02_oo`d000;oo`<000;oo`8000?oo`8000Coo`8000Coo`03003ooooo00Goo`8000[oo`03
003ooooo05_oo`03003ooooo01ooo`00@?oo00<00?ooool0:?oo2`0000Coo`00003oo`<000?oo`80
00?oo`8000Coo`8000Goo`03003ooooo00Goo`03003ooooo00Woo`03003ooooo05coo`03003ooooo
01ooo`00@?oo0P009Ooo300000Goo`0000000?oo008000Coo`8000;oo`<000Coo`8000Goo`8000Oo
o`03003ooooo00Woo`03003ooooo05coo`80027oo`00@?oo00<00?ooool08?oo4@0000Coo`000000
00?oo`<000;oo`8000Goo`8000Koo`03003ooooo00Koo`03003ooooo00[oo`03003ooooo05goo`03
003ooooo01ooo`00@?oo00<00?ooool07?oo4P0000Coo`00000000;oo`@000;oo`<000Goo`8000Ko
o`8000Ooo`8000coo`03003ooooo05koo`03003ooooo01ooo`00@?oo00<00?ooool05_oo6@0000?o
o`0000000P000ooo0`001Ooo0`001Ooo0`001ooo0P003?oo0P00HOoo00<00?ooool07ooo0010ool2
000?oolH0002ool300000ooo000000020003ool40005ool30004ool40007ool3000<ool2001Rool2
000Qool003[oo`03003ooooo00?oo`03003ooooo00Soob/00003ool0000000H000?oo`@000Ooo`@0
00goo`8006Goo`03003ooooo01ooo`00>Ooo00<00?oo00001?oo00<00?ooool00_oo:P0000?oo`00
00001@000ooo20001Ooo1P002ooo1P00Iooo00<00?ooool07ooo000iool00`00ool00004ool20003
oomC001/ool2000Qool003Woo`03003oo`0000Coo`03003ooooo0<;oo`03003ooooo01ooo`00>Ooo
00<00?oo00001?oo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01ooo
00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo
00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo
00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo
00<00?ooool01ooo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool07ooo000jool00`00oooo
o`03ooo6000Qool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool0
05_oo`<000?oo`8000;oo`<000[oo`@000;oo`<000;oo`<000;oo`<000?oo`8000;oo`<000?oo`80
0003ool0000000;oo`03003ooooo0080013oo`800004ool00000ool40002ool20003ool300001?oo
000000000_oo0`000ooo0P000_oo0`000ooo0P000_oo0P00BOoo001Lool01@00oooooooo00000_oo
00@00?ooool000coo`04003ooooo0002ool00`00ooooo`02ool00`00ooooo`02ool01@00oooooooo
00001Ooo00D00?ooooooo`0000Coo`06003ooooo003oo`000_oo00<00?ooool03Ooo00H00?oooooo
o`00ool30002ool01P00ooooo`00ool000;oo`04003ooooo0004ool01@00oooooooo00000_oo00@0
0?ooool000?oo`03003ooooo00Coo`03003ooooo04Koo`00G?oo00D00?ooooooo`0000;oo`04003o
oooo000<ool01000ooooo`000_oo00<00?ooool00_oo00<00?ooool00_oo00@00?ooooooo`<000?o
o`04003oooooool30002ool01P00ooooo`00ool001;oo`05003oo`00ool00003ool01000ooooo`00
1?oo00@00?ooool000;oo`03003ooooo00;oo`05003oooooool00005ool01000oooooooo0`000ooo
00<00?ooool0Aooo001Kool30003ool20002ool4000:ool01@00ooooo`00ool00P000ooo0`000_oo
0`000_oo0`000_oo100000Goo`0000000?oo00@00003ool000000080013oo`800003ool0000000;o
o`800003ool0000000800004ool00000ool200000ooo0000000200000ooo00000002ool40002ool2
0003ool30003ool20018ool005coo`03003ooooo01Coo`04003ooooo0007ool00`00ooooo`02ool0
0`00ooooo`0Eool00`00ooooo`0@ool200000ooo00000006ool00`00ooooo`0Aool00`00ooooo`1G
ool005goo`03003ooooo01;oo`@000?oo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo02Oo
o`800003ool0000001Koo`03003ooooo00Ooo`03003ooooo057oo`00oooo:?oo003ooolXool00?oo
obSoo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool009Goo`<008ooo`00U_oo
00<00?ooool0S_oo001dool20002ool400001?oo000000000_oo0`003Ooo0P000_oo0`000ooo0P00
0_oo0`000ooo0P0000?oo`0000000_oo00<00?ooool02ooo0`0000Koo`0000000?oo0002ool20003
ool20002ool4001Dool007?oo`03003ooooo00;oo`<000?oo`03003ooooo00;oo`03003ooooo00_o
o`06003ooooo003oo`000_oo00<00?oo00000_oo00@00?ooool000?oo`06003ooooo003oo`000_oo
00<00?ooool03?oo00D00?ooooooo`0000;oo`03003oo`0000Coo`05003ooooo003oo`03001Eool0
07?oo`03003ooooo00Coo`05003oooooool00004ool00`00ooooo`0;ool01P00ooooo`00ool000;o
o`03003oo`0000Goo`05003oooooool00002ool00`00ool00002ool00`00ooooo`0<ool01@00oooo
oooo00000_oo00<00?oo00000P000_oo00<00?ooool01?oo00<00?ooool0Dooo001cool00`00oooo
o`03ool20003ool00`00ooooo`02ool00`00ooooo`0;ool00`00ooooo`0500000ooo000000020002
ool20004ool200000ooo00000002000?ool01000oooooooo0`000_oo0`0000?oo`0000000P000ooo
0P00EOoo001cool00`00ool00008ool00`00ooooo`02ool00`00ooooo`0;ool01000ooooo`001_oo
00<00?ooool07?oo00L00?oo003oo`00ool00009ool00`00ooooo`1Jool007?oo`<000Ooo`8000?o
o`8000koo`8000goo`03003ooooo01Koo`L006Koo`00oooo:?oo003ooolXool00?ooobSoo`00oooo
:?oo003ooolXool00001\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {17.6324, -20.4048, \
0.106644, 0.140465}}]
}, Open  ]],

Cell["Here is the equivalent three\[Hyphen]dimensional graph. ", "MathCaption",
  CellTags->"0.29"],

Cell[CellGroupData[{

Cell["\<\
Plot3D[optiontheta[x, t], {x, 25, 55}, {t, 0, 110},
   AxesLabel->{\"Stock Price\", \"Time\", \"Option \\nTheta\"}];\
\>", "Input",\

  CellLabel->"In[24]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -11.1734 -9 ]
[.3345 .12542 .8266 0 ]
[.56094 .0364 -10.3394 -9 ]
[.56094 .0364 1.66057 0 ]
[.29165 .07573 -65.1782 -15 ]
[.29165 .07573 4.82182 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.77605 .1102 0 -6.14908 ]
[.77605 .1102 12 2.85092 ]
[.84375 .21386 0 -6.04972 ]
[.84375 .21386 12 2.95028 ]
[.9051 .30781 0 -5.96165 ]
[.9051 .30781 12 3.03835 ]
[.96095 .39335 0 -5.88306 ]
[.96095 .39335 18 3.11694 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 28 4.94788 ]
[.02161 .2808 -18 -2.75557 ]
[.02161 .2808 0 6.24443 ]
[.01106 .3469 -18 -2.81154 ]
[.01106 .3469 0 6.18846 ]
[6e-05 .41589 -12 -2.8702 ]
[6e-05 .41589 0 6.1298 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[-0.05457 .39542 -46 -9.75946 ]
[-0.05457 .39542 0 21.2405 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.76373 .11471 m
.75757 .11697 L
s
[(25)] .77605 .1102 -1 .36646 Mshowa
.83134 .21814 m
.82514 .22027 L
s
[(50)] .84375 .21386 -1 .34438 Mshowa
.89262 .31187 m
.88638 .3139 L
s
[(75)] .9051 .30781 -1 .32481 Mshowa
.94841 .39721 m
.94213 .39913 L
s
[(100)] .96095 .39335 -1 .30735 Mshowa
.125 Mabswid
.70438 .02393 m
.70071 .02535 L
s
.71969 .04735 m
.71602 .04876 L
s
.73468 .07028 m
.731 .07167 L
s
.74936 .09273 m
.74567 .0941 L
s
.7778 .13624 m
.7741 .13758 L
s
.7916 .15734 m
.78789 .15866 L
s
.80511 .17801 m
.8014 .17932 L
s
.81836 .19827 m
.81464 .19957 L
s
.84407 .23761 m
.84035 .23888 L
s
.85656 .25671 m
.85283 .25797 L
s
.86881 .27545 m
.86507 .27669 L
s
.88083 .29383 m
.87709 .29506 L
s
.90419 .32957 m
.90044 .33077 L
s
.91555 .34695 m
.9118 .34814 L
s
.9267 .364 m
.92295 .36518 L
s
.93765 .38075 m
.93389 .38192 L
s
.95897 .41336 m
.9552 .41451 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03384 .27606 m
.03996 .27369 L
s
[(-15)] .02161 .2808 1 -0.38765 Mshowa
.02335 .34229 m
.02949 .33999 L
s
[(-10)] .01106 .3469 1 -0.37521 Mshowa
.01239 .41142 m
.01856 .40918 L
s
[(-5)] 6e-05 .41589 1 -0.36218 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(0)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03178 .28908 m
.03545 .28767 L
s
.0297 .30222 m
.03338 .30081 L
s
.0276 .31546 m
.03128 .31406 L
s
.02548 .32882 m
.02917 .32743 L
s
.0212 .35588 m
.02488 .3545 L
s
.01902 .36958 m
.02272 .36822 L
s
.01683 .38341 m
.02053 .38205 L
s
.01462 .39735 m
.01832 .396 L
s
.01015 .42561 m
.01385 .42428 L
s
.00788 .43992 m
.01158 .4386 L
s
.00559 .45436 m
.0093 .45305 L
s
.00328 .46893 m
.00699 .46763 L
s
.03589 .26314 m
.03956 .26171 L
s
gsave
-0.05457 .39542 -107 -13.7595 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Option) show
63.000000 31.000000 moveto
(Theta) show
93.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.646 .762 .934 r
.37465 .78679 .39806 .80578 .43696 .79556 .41391 .77629 Metetra
.646 .762 .934 r
.41391 .77629 .43696 .79556 .47642 .78519 .45374 .76563 Metetra
.65 .763 .932 r
.45374 .76563 .47642 .78519 .51647 .77466 .49417 .75447 Metetra
.703 .773 .906 r
.49417 .75447 .51647 .77466 .5571 .76322 .53518 .73735 Metetra
.824 .75 .781 r
.53518 .73735 .5571 .76322 .59794 .73323 .57624 .69027 Metetra
.847 .69 .687 r
.57624 .69027 .59794 .73323 .63642 .62479 .616 .60295 Metetra
.875 .777 .751 r
.616 .60295 .63642 .62479 .67349 .5232 .65553 .54118 Metetra
.512 .029 .046 r
.65553 .54118 .67349 .5232 .71695 .56251 .69807 .54985 Metetra
.464 0 0 r
.69807 .54985 .71695 .56251 .76361 .62065 .74339 .58378 Metetra
.413 .524 .862 r
.74339 .58378 .76361 .62065 .80863 .62917 .78911 .5987 Metetra
.583 .66 .891 r
.78911 .5987 .80863 .62917 .85313 .61942 .83454 .59481 Metetra
.638 .735 .918 r
.83454 .59481 .85313 .61942 .89813 .60722 .88019 .58384 Metetra
.65 .754 .926 r
.88019 .58384 .89813 .60722 .94382 .59469 .92643 .57119 Metetra
.652 .757 .927 r
.92643 .57119 .94382 .59469 .99022 .58197 .97338 .55811 Metetra
.646 .762 .934 r
.35061 .76729 .37465 .78679 .41391 .77629 .39022 .75649 Metetra
.647 .763 .933 r
.39022 .75649 .41391 .77629 .45374 .76563 .43043 .74544 Metetra
.665 .766 .925 r
.43043 .74544 .45374 .76563 .49417 .75447 .47128 .73249 Metetra
.747 .77 .872 r
.47128 .73249 .49417 .75447 .53518 .73735 .51273 .70836 Metetra
.827 .737 .765 r
.51273 .70836 .53518 .73735 .57624 .69027 .55429 .65659 Metetra
.85 .721 .721 r
.55429 .65659 .57624 .69027 .616 .60295 .59513 .58608 Metetra
.859 .822 .811 r
.59513 .58608 .616 .60295 .65553 .54118 .63595 .5396 Metetra
.134 .679 .812 r
.63595 .5396 .65553 .54118 .69807 .54985 .67858 .5373 Metetra
0 .394 .785 r
.67858 .5373 .69807 .54985 .74339 .58378 .72336 .55615 Metetra
.356 .568 .918 r
.72336 .55615 .74339 .58378 .78911 .5987 .7692 .5687 Metetra
.545 .651 .904 r
.7692 .5687 .78911 .5987 .83454 .59481 .81529 .56797 Metetra
.618 .713 .914 r
.81529 .56797 .83454 .59481 .88019 .58384 .86164 .55901 Metetra
.643 .744 .922 r
.86164 .55901 .88019 .58384 .92643 .57119 .9085 .54678 Metetra
.65 .754 .926 r
.9085 .54678 .92643 .57119 .97338 .55811 .95603 .5335 Metetra
.646 .762 .934 r
.3259 .74724 .35061 .76729 .39022 .75649 .36588 .73613 Metetra
.651 .763 .932 r
.36588 .73613 .39022 .75649 .43043 .74544 .40648 .72438 Metetra
.687 .769 .913 r
.40648 .72438 .43043 .74544 .47128 .73249 .44778 .70873 Metetra
.77 .764 .848 r
.44778 .70873 .47128 .73249 .51273 .70836 .48975 .67929 Metetra
.826 .74 .769 r
.48975 .67929 .51273 .70836 .55429 .65659 .53189 .62795 Metetra
.847 .746 .752 r
.53189 .62795 .55429 .65659 .59513 .58608 .57361 .5687 Metetra
.831 .826 .843 r
.57361 .5687 .59513 .58608 .63595 .5396 .61535 .52996 Metetra
.499 .836 .998 r
.61535 .52996 .63595 .5396 .67858 .5373 .65833 .52231 Metetra
.181 .603 .942 r
.65833 .52231 .67858 .5373 .72336 .55615 .70302 .53185 Metetra
.372 .615 .945 r
.70302 .53185 .72336 .55615 .7692 .5687 .74896 .54042 Metetra
.525 .661 .922 r
.74896 .54042 .7692 .5687 .81529 .56797 .79552 .54035 Metetra
.601 .705 .917 r
.79552 .54035 .81529 .56797 .86164 .55901 .8425 .53283 Metetra
.634 .735 .921 r
.8425 .53283 .86164 .55901 .9085 .54678 .88999 .52129 Metetra
.647 .75 .925 r
.88999 .52129 .9085 .54678 .95603 .5335 .93813 .50802 Metetra
.647 .763 .933 r
.3005 .72663 .3259 .74724 .36588 .73613 .34085 .71512 Metetra
.659 .765 .928 r
.34085 .71512 .36588 .73613 .40648 .72438 .38187 .70231 Metetra
.708 .769 .9 r
.38187 .70231 .40648 .72438 .44778 .70873 .42366 .68372 Metetra
.781 .761 .835 r
.42366 .68372 .44778 .70873 .48975 .67929 .46618 .65093 Metetra
.824 .747 .778 r
.46618 .65093 .48975 .67929 .53189 .62795 .50892 .60166 Metetra
.839 .762 .778 r
.50892 .60166 .53189 .62795 .57361 .5687 .5514 .55008 Metetra
.808 .821 .861 r
.5514 .55008 .57361 .5687 .61535 .52996 .5939 .51585 Metetra
.597 .83 .988 r
.5939 .51585 .61535 .52996 .65833 .52231 .63733 .50509 Metetra
.363 .692 .982 r
.63733 .50509 .65833 .52231 .70302 .53185 .68218 .50847 Metetra
.415 .655 .958 r
.68218 .50847 .70302 .53185 .74896 .54042 .72828 .51326 Metetra
.52 .675 .934 r
.72828 .51326 .74896 .54042 .79552 .54035 .77523 .51254 Metetra
.589 .705 .923 r
.77523 .51254 .79552 .54035 .8425 .53283 .82277 .50569 Metetra
.625 .73 .922 r
.82277 .50569 .8425 .53283 .88999 .52129 .87089 .49472 Metetra
.642 .745 .924 r
.87089 .49472 .88999 .52129 .93813 .50802 .91967 .48158 Metetra
.649 .763 .932 r
.27438 .70542 .3005 .72663 .34085 .71512 .31512 .69339 Metetra
.669 .766 .923 r
.31512 .69339 .34085 .71512 .38187 .70231 .35659 .67922 Metetra
.724 .769 .888 r
.35659 .67922 .38187 .70231 .42366 .68372 .3989 .65792 Metetra
.786 .76 .83 r
.3989 .65792 .42366 .68372 .46618 .65093 .44198 .62319 Metetra
.821 .754 .789 r
.44198 .62319 .46618 .65093 .50892 .60166 .48532 .57633 Metetra
.829 .772 .799 r
.48532 .57633 .50892 .60166 .5514 .55008 .52848 .53015 Metetra
.79 .815 .873 r
.52848 .53015 .5514 .55008 .5939 .51585 .57167 .49879 Metetra
.634 .816 .97 r
.57167 .49879 .5939 .51585 .63733 .50509 .61559 .48599 Metetra
.462 .728 .984 r
.61559 .48599 .63733 .50509 .68218 .50847 .66073 .48504 Metetra
.458 .683 .963 r
.66073 .48504 .68218 .50847 .72828 .51326 .70709 .48655 Metetra
.525 .688 .942 r
.70709 .48655 .72828 .51326 .77523 .51254 .75441 .48463 Metetra
.583 .708 .929 r
.75441 .48463 .77523 .51254 .82277 .50569 .80247 .47784 Metetra
.618 .727 .924 r
.80247 .47784 .82277 .50569 .87089 .49472 .8512 .46719 Metetra
.637 .742 .924 r
.8512 .46719 .87089 .49472 .91967 .48158 .90061 .45415 Metetra
.653 .764 .931 r
.2475 .68358 .27438 .70542 .31512 .69339 .28865 .67088 Metetra
.68 .767 .917 r
.28865 .67088 .31512 .69339 .35659 .67922 .33059 .65518 Metetra
.735 .768 .879 r
.33059 .65518 .35659 .67922 .3989 .65792 .37346 .63156 Metetra
.788 .762 .829 r
.37346 .63156 .3989 .65792 .44198 .62319 .41711 .59582 Metetra
.816 .761 .8 r
.41711 .59582 .44198 .62319 .48532 .57633 .46103 .55125 Metetra
.818 .778 .816 r
.46103 .55125 .48532 .57633 .52848 .53015 .50483 .509 Metetra
.775 .809 .88 r
.50483 .509 .52848 .53015 .57167 .49879 .54867 .47955 Metetra
.652 .805 .956 r
.54867 .47955 .57167 .49879 .61559 .48599 .5931 .46527 Metetra
.52 .744 .977 r
.5931 .46527 .61559 .48599 .66073 .48504 .63861 .46109 Metetra
.494 .703 .963 r
.63861 .46109 .66073 .48504 .70709 .48655 .6853 .45983 Metetra
.535 .7 .945 r
.6853 .45983 .70709 .48655 .75441 .48463 .73302 .45651 Metetra
.58 .712 .933 r
.73302 .45651 .75441 .48463 .80247 .47784 .78158 .44937 Metetra
.613 .727 .927 r
.78158 .44937 .80247 .47784 .8512 .46719 .83089 .43876 Metetra
.633 .74 .925 r
.83089 .43876 .8512 .46719 .90061 .45415 .88094 .42574 Metetra
.657 .764 .929 r
.21985 .66105 .2475 .68358 .28865 .67088 .26142 .64755 Metetra
.69 .768 .911 r
.26142 .64755 .28865 .67088 .33059 .65518 .30386 .63027 Metetra
.743 .768 .873 r
.30386 .63027 .33059 .65518 .37346 .63156 .34729 .60474 Metetra
.789 .763 .83 r
.34729 .60474 .37346 .63156 .41711 .59582 .39151 .56856 Metetra
.811 .765 .811 r
.39151 .56856 .41711 .59582 .46103 .55125 .43602 .52601 Metetra
.807 .782 .829 r
.43602 .52601 .46103 .55125 .50483 .509 .48043 .48669 Metetra
.763 .804 .885 r
.48043 .48669 .50483 .509 .54867 .47955 .52489 .45854 Metetra
.662 .797 .947 r
.52489 .45854 .54867 .47955 .5931 .46527 .56986 .44312 Metetra
.556 .752 .969 r
.56986 .44312 .5931 .46527 .63861 .46109 .6158 .43643 Metetra
.523 .717 .961 r
.6158 .43643 .63861 .46109 .6853 .45983 .66287 .4328 Metetra
.546 .709 .947 r
.66287 .4328 .6853 .45983 .73302 .45651 .711 .42803 Metetra
.581 .716 .936 r
.711 .42803 .73302 .45651 .78158 .44937 .76006 .42029 Metetra
.61 .728 .929 r
.76006 .42029 .78158 .44937 .83089 .43876 .80995 .4095 Metetra
.63 .739 .926 r
.80995 .4095 .83089 .43876 .88094 .42574 .86063 .39638 Metetra
.662 .765 .927 r
.19138 .63782 .21985 .66105 .26142 .64755 .23339 .62348 Metetra
.698 .769 .907 r
.23339 .62348 .26142 .64755 .30386 .63027 .27634 .60478 Metetra
.749 .77 .87 r
.27634 .60478 .30386 .63027 .34729 .60474 .32034 .57783 Metetra
.789 .768 .833 r
.32034 .57783 .34729 .60474 .39151 .56856 .36515 .54145 Metetra
.807 .771 .82 r
.36515 .54145 .39151 .56856 .43602 .52601 .41024 .50036 Metetra
.799 .784 .839 r
.41024 .50036 .43602 .52601 .48043 .48669 .45526 .46293 Metetra
.755 .797 .887 r
.45526 .46293 .48043 .48669 .52489 .45854 .50032 .43551 Metetra
.668 .787 .938 r
.50032 .43551 .52489 .45854 .56986 .44312 .54584 .41919 Metetra
.58 .752 .959 r
.54584 .41919 .56986 .44312 .6158 .43643 .59224 .41065 Metetra
.544 .724 .957 r
.59224 .41065 .6158 .43643 .66287 .4328 .63974 .40517 Metetra
.556 .716 .947 r
.63974 .40517 .66287 .4328 .711 .42803 .68833 .3991 Metetra
.583 .721 .938 r
.68833 .3991 .711 .42803 .76006 .42029 .7379 .39064 Metetra
.609 .73 .931 r
.7379 .39064 .76006 .42029 .80995 .4095 .78836 .37949 Metetra
.627 .739 .928 r
.78836 .37949 .80995 .4095 .86063 .39638 .83968 .36611 Metetra
.667 .766 .924 r
.16206 .61381 .19138 .63782 .23339 .62348 .20453 .59848 Metetra
.706 .769 .901 r
.20453 .59848 .23339 .62348 .27634 .60478 .24803 .57829 Metetra
.753 .769 .866 r
.24803 .57829 .27634 .60478 .32034 .57783 .29261 .55006 Metetra
.787 .767 .835 r
.29261 .55006 .32034 .57783 .36515 .54145 .33799 .51373 Metetra
.8 .772 .827 r
.33799 .51373 .36515 .54145 .41024 .50036 .38366 .47414 Metetra
.79 .785 .848 r
.38366 .47414 .41024 .50036 .45526 .46293 .42928 .43844 Metetra
.747 .796 .892 r
.42928 .43844 .45526 .46293 .50032 .43551 .47494 .41166 Metetra
.672 .788 .936 r
.47494 .41166 .50032 .43551 .54584 .41919 .52101 .3945 Metetra
.596 .759 .956 r
.52101 .3945 .54584 .41919 .59224 .41065 .56792 .38421 Metetra
.562 .733 .955 r
.56792 .38421 .59224 .41065 .63974 .40517 .61588 .37691 Metetra
.566 .723 .947 r
.61588 .37691 .63974 .40517 .68833 .3991 .66494 .36945 Metetra
.587 .724 .938 r
.66494 .36945 .68833 .3991 .7379 .39064 .71502 .36014 Metetra
.608 .731 .932 r
.71502 .36014 .7379 .39064 .78836 .37949 .76607 .34851 Metetra
.625 .738 .928 r
.76607 .34851 .78836 .37949 .83968 .36611 .81802 .3348 Metetra
.673 .766 .921 r
.13186 .58901 .16206 .61381 .20453 .59848 .17481 .57263 Metetra
.712 .769 .897 r
.17481 .57263 .20453 .59848 .24803 .57829 .21886 .55104 Metetra
.755 .769 .864 r
.21886 .55104 .24803 .57829 .29261 .55006 .26403 .52177 Metetra
.784 .769 .839 r
.26403 .52177 .29261 .55006 .33799 .51373 .31 .48559 Metetra
.794 .774 .835 r
.31 .48559 .33799 .51373 .38366 .47414 .35624 .44724 Metetra
.782 .785 .855 r
.35624 .44724 .38366 .47414 .42928 .43844 .40245 .41287 Metetra
.741 .793 .894 r
.40245 .41287 .42928 .43844 .47494 .41166 .4487 .38651 Metetra
.674 .784 .932 r
.4487 .38651 .47494 .41166 .52101 .3945 .49535 .36858 Metetra
.61 .76 .951 r
.49535 .36858 .52101 .3945 .56792 .38421 .54278 .35678 Metetra
.576 .738 .952 r
.54278 .35678 .56792 .38421 .61588 .37691 .59124 .34785 Metetra
.575 .728 .946 r
.59124 .34785 .61588 .37691 .66494 .36945 .64079 .33907 Metetra
.591 .728 .939 r
.64079 .33907 .66494 .36945 .71502 .36014 .69142 .32884 Metetra
.609 .732 .933 r
.69142 .32884 .71502 .36014 .76607 .34851 .74305 .31662 Metetra
.624 .739 .929 r
.74305 .31662 .76607 .34851 .81802 .3348 .79565 .30247 Metetra
.679 .767 .918 r
.10073 .56337 .13186 .58901 .17481 .57263 .14418 .54591 Metetra
.718 .769 .893 r
.14418 .54591 .17481 .57263 .21886 .55104 .1888 .52302 Metetra
.757 .77 .863 r
.1888 .52302 .21886 .55104 .26403 .52177 .23457 .49291 Metetra
.782 .77 .842 r
.23457 .49291 .26403 .52177 .31 .48559 .28112 .45691 Metetra
.789 .776 .841 r
.28112 .45691 .31 .48559 .35624 .44724 .32794 .41958 Metetra
.774 .785 .862 r
.32794 .41958 .35624 .44724 .40245 .41287 .37474 .38622 Metetra
.735 .79 .896 r
.37474 .38622 .40245 .41287 .4487 .38651 .42159 .36009 Metetra
.676 .781 .929 r
.42159 .36009 .4487 .38651 .49535 .36858 .46882 .34145 Metetra
.62 .761 .947 r
.46882 .34145 .49535 .36858 .54278 .35678 .5168 .32831 Metetra
.588 .742 .949 r
.5168 .32831 .54278 .35678 .59124 .34785 .56577 .3179 Metetra
.584 .732 .945 r
.56577 .3179 .59124 .34785 .64079 .33907 .61585 .30785 Metetra
.595 .731 .939 r
.61585 .30785 .64079 .33907 .69142 .32884 .66703 .29667 Metetra
.61 .734 .934 r
.66703 .29667 .69142 .32884 .74305 .31662 .71926 .28377 Metetra
.624 .739 .93 r
.71926 .28377 .74305 .31662 .79565 .30247 .77252 .2691 Metetra
.684 .767 .915 r
.06863 .53686 .10073 .56337 .14418 .54591 .1126 .51831 Metetra
.722 .77 .891 r
.1126 .51831 .14418 .54591 .1888 .52302 .15781 .49422 Metetra
.758 .77 .863 r
.15781 .49422 .1888 .52302 .23457 .49291 .20418 .4634 Metetra
.779 .772 .846 r
.20418 .4634 .23457 .49291 .28112 .45691 .25131 .42758 Metetra
.783 .777 .847 r
.25131 .42758 .28112 .45691 .32794 .41958 .29872 .39108 Metetra
.768 .785 .867 r
.29872 .39108 .32794 .41958 .37474 .38622 .34611 .35847 Metetra
.73 .788 .898 r
.34611 .35847 .37474 .38622 .42159 .36009 .39356 .33244 Metetra
.677 .779 .927 r
.39356 .33244 .42159 .36009 .46882 .34145 .44138 .31312 Metetra
.627 .762 .943 r
.44138 .31312 .46882 .34145 .5168 .32831 .48992 .29876 Metetra
.598 .745 .947 r
.48992 .29876 .5168 .32831 .56577 .3179 .53944 .28699 Metetra
.591 .736 .944 r
.53944 .28699 .56577 .3179 .61585 .30785 .59006 .2757 Metetra
.599 .733 .939 r
.59006 .2757 .61585 .30785 .66703 .29667 .64181 .26355 Metetra
.611 .736 .934 r
.64181 .26355 .66703 .29667 .71926 .28377 .69467 .24989 Metetra
.623 .74 .931 r
.69467 .24989 .71926 .28377 .77252 .2691 .74859 .23463 Metetra
.689 .768 .912 r
.03552 .50946 .06863 .53686 .1126 .51831 .08003 .48981 Metetra
.726 .77 .888 r
.08003 .48981 .1126 .51831 .15781 .49422 .12583 .46461 Metetra
.758 .771 .864 r
.12583 .46461 .15781 .49422 .20418 .4634 .1728 .43318 Metetra
.776 .773 .85 r
.1728 .43318 .20418 .4634 .25131 .42758 .22053 .39752 Metetra
.778 .778 .852 r
.22053 .39752 .25131 .42758 .29872 .39108 .26852 .36167 Metetra
.761 .784 .871 r
.26852 .36167 .29872 .39108 .34611 .35847 .31651 .32961 Metetra
.726 .786 .9 r
.31651 .32961 .34611 .35847 .39356 .33244 .36457 .30356 Metetra
.678 .778 .925 r
.36457 .30356 .39356 .33244 .44138 .31312 .41299 .28356 Metetra
.633 .762 .94 r
.41299 .28356 .44138 .31312 .48992 .29876 .46211 .26807 Metetra
.606 .747 .945 r
.46211 .26807 .48992 .29876 .53944 .28699 .5122 .25502 Metetra
.598 .739 .943 r
.5122 .25502 .53944 .28699 .59006 .2757 .56339 .24255 Metetra
.603 .736 .938 r
.56339 .24255 .59006 .2757 .64181 .26355 .61573 .2294 Metetra
.613 .737 .934 r
.61573 .2294 .64181 .26355 .69467 .24989 .66921 .21493 Metetra
.624 .741 .931 r
.66921 .21493 .69467 .24989 .74859 .23463 .72381 .199 Metetra
.693 .769 .91 r
.00134 .48118 .03552 .50946 .08003 .48981 .04639 .46051 Metetra
.728 .771 .887 r
.04639 .46051 .08003 .48981 .12583 .46461 .09278 .43434 Metetra
.758 .773 .865 r
.09278 .43434 .12583 .46461 .1728 .43318 .14038 .40235 Metetra
.774 .775 .853 r
.14038 .40235 .1728 .43318 .22053 .39752 .18871 .36672 Metetra
.774 .779 .857 r
.18871 .36672 .22053 .39752 .26852 .36167 .23731 .33122 Metetra
.757 .783 .875 r
.23731 .33122 .26852 .36167 .31651 .32961 .28592 .29941 Metetra
.723 .782 .9 r
.28592 .29941 .31651 .32961 .36457 .30356 .33459 .27319 Metetra
.679 .774 .923 r
.33459 .27319 .36457 .30356 .41299 .28356 .38362 .25251 Metetra
.638 .76 .937 r
.38362 .25251 .41299 .28356 .46211 .26807 .43333 .23601 Metetra
.612 .748 .942 r
.43333 .23601 .46211 .26807 .5122 .25502 .48399 .22181 Metetra
.603 .74 .941 r
.48399 .22181 .5122 .25502 .56339 .24255 .53577 .20824 Metetra
.606 .738 .938 r
.53577 .20824 .56339 .24255 .61573 .2294 .58872 .19413 Metetra
.614 .739 .934 r
.58872 .19413 .61573 .2294 .66921 .21493 .64286 .17884 Metetra
.624 .742 .931 r
.64286 .17884 .66921 .21493 .72381 .199 .69815 .16217 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[24]:=",
  ImageSize->{319.75, 259.312},
  ImageMargins->{{0, 0}, {0, 3}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004o00010a000`40n007h00Ooooo@?oo003ooom0
ool00?oood3oo`00oooo@?oo003ooom0ool00?oood3oo`00oooo@?oo003ooom0ool00?oood3oo`00
oooo@?oo003ooom0ool00?oood3oo`00oooo@?oo003ooom0ool00?oood3oo`00oooo@?oo003ooom0
ool00?oood3oo`00oooo@?oo003ooom0ool00?oood3oo`00oooo@?oo003ooom0ool00?oood3oo`00
oooo@?oo003ooom0ool00>goo`03003ooooo04ooo`00k?oo00<00?oo0000D?oo003/ool00`00ool0
001@ool00>coo`03003oo`00053oo`00k?oo00<00?oo0000D?oo003Wool20004ool00`00ooooo`1?
ool00<7oo`03003ooooo00;oo`03003ooooo01coo`D005Goo`00`?oo00<00?oo00000_oo00<00?oo
00006_oo0`000ooo0P00EOoo0032ool01P00ooooo`00ool001Soo`<000Goo`03003oo`0005Coo`00
`?oo0P000ooo00<00?oo00005Ooo0`000_oo00<00?ooool00ooo00@00?ooool005?oo`00`?oo00<0
0?ooool00_oo00<00?oo00004_oo0`002ooo00@00?ooool005?oo`00`?oo0`000ooo00<00?ooool0
3ooo0P003_oo00D00?ooooooo`0005;oo`00eOoo0`004?oo00H00?ooool00?oo001Aool00=?oo`80
0003ool00?oo017oo`05003oooooool0001Aool004Koo`<000?oo`8000?oo`8000;oo`<00004ool0
0000ool2000;ool30003ool30002ool30002ool30003ool2001?ool3000Fool00`00ooooo`02ool0
0`00ooooo`1>ool004Koo`03003oo`0000;oo`06003ooooo003oo`000_oo00<00?oo00001?oo00<0
0?oo00003Ooo00<00?ooool00ooo00<00?ooool00_oo00D00?ooooooo`0000Coo`03003ooooo04go
o`8001Woo`03003ooooo00;oo`03003ooooo04koo`00B?oo00@00?ooool000Coo`06003ooooo003o
o`001?oo0`003Ooo0`000ooo00<00?ooool00_oo00D00?ooooooo`0000Coo`<004[oo`<001_oo`03
003ooooo00?oo`03003ooooo04goo`00Aooo00<00?ooool010000ooo0P000_oo0`000_oo00@00?oo
000000coo`05003ooooo003oo`0400000ooo00000003ool30002ool30018ool2000Nool00`00oooo
o`04ool00`00ooooo`1<ool004Koo`03003oo`0000;oo`03003ooooo00coo`03003ooooo00goo`04
003ooooo001Hool30002ool00`00ooooo`0Kool00`00ooooo`03ool2001>ool004Koo`<0013oo`80
00koo`@000Soo`03003ooooo04coo`8002?oo`03003ooooo00Goo`03003ooooo04_oo`00`Ooo0`00
9Ooo00<00?ooool01_oo00<00?ooool0B_oo002nool3000Xool00`00ooooo`06ool00`00ooooo`1:
ool00;coo`<002[oo`03003ooooo00Ooo`03003ooooo04Woo`00^Ooo0`000ooo00<00?ooool09ooo
00<00?ooool01ooo0P00B_oo002gool2000`ool00`00ooooo`08ool00`00ooooo`18ool00;Coo`<0
03;oo`03003ooooo00Woo`03003ooooo04Ooo`00/_oo0P00=Ooo00<00?ooool02_oo00<00?ooool0
A_oo002_ool300000ooo003oo`0dool00`00ooooo`0:ool00`00ooooo`16ool00:goo`8003[oo`03
003ooooo00_oo`03003ooooo04Goo`00R?oo0`000_oo00<00?ooool06_oo0`00?Ooo00<00?ooool0
2Ooo0`001_oo0`000ooo00<00?ooool0=ooo0029ool01P00ooooo`00ool001Woo`80043oo`03003o
oooo00_oo`03003ooooo00Coo`03003ooooo00;oo`03003oo`0003Soo`00Qooo100000Coo`00ool0
01Koo`@0047oo`03003ooooo00coo`03003ooooo00Coo`03003ooooo00?oo`03003ooooo03Koo`00
Qooo00<00?oo00000_oo00<00?oo00004ooo0`00AOoo00<00?ooool03Ooo00<00?ooool00ooo00@0
0?ooooooo`8003Woo`00R?oo0P000_oo00<00?oo00004Ooo0P00B?oo00<00?ooool03Ooo00<00?oo
ool00_oo00<00?oo00000_oo00<00?ooool0>?oo0029ool01@00oooooooo00003ooo0`00B_oo00<0
0?ooool03_oo00<00?ooool00_oo00@00?ooooooo`<003Soo`00Vooo0P00COoo00<00?ooool03?oo
0`00@ooo002Hool30002ool00`00ooooo`1:ool00`00ooooo`0?ool00`00ooooo`10ool009Koo`80
05;oo`03003ooooo013oo`03003ooooo03ooo`00Tooo0`00E?oo00<00?ooool04?oo00<00?ooool0
?ooo002Aool2001Gool00`00ooooo`0Aool00`00ooooo`0nool008koo`<00003ool00?oo05Koo`03
003ooooo013oo`<003ooo`00S?oo0P001?oo00<00?ooool0EOoo00<00?ooool04_oo00<00?ooool0
?Ooo0029ool3001Nool00`00ooooo`0Cool00`00ooooo`0lool008Koo`<0067oo`03003ooooo01Co
o`03003ooooo03_oo`00Q?oo1000Hooo00<00?ooool04ooo00<00?ooool0>ooo0021ool3001Wool0
0`00ooooo`0Cool2000lool007ooo`8006Soo`<001Ooo`03003ooooo03Woo`00O?oo0`00I_oo1000
00>MoIgM00005ooo00<00?ooool0>Ooo001jool4001Tool300001YglWOfEo9gmWObMo@8001Ooo`03
003ooooo03Soo`00D_oo0P001?oo00<00?ooool07?oo0`00I?oo100000VMgIgmWMfMoIgMWOfMgIgm
WMd00P006?oo00<00?ooool0=ooo001Dool01P00ooooo`00ool001_oo`8006Coo`<0000@WOfMo9gm
UObMoIglWOfEo9gmWObMoIGlWOd009gm000Fool2000iool005?oo`07003oooooool00?oo00006?oo
0`00Hooo0`0001BMoIgM002MgIgmWMfMoIgMWOfMgIgmWMfMoIgMWOfMg@00WMfMo@005ooo00<00?oo
ool0=_oo001Dool01P00ooooo`00ool001Koo`<0067oo`@0000HWOfEoIgmUObMoIGm002Eo9gmWObM
oIGlWOfMo9gmUObMoIglWOd009gmWObMo@005_oo00<00?ooool0=_oo001Bool00`00ool00002ool0
0`00ool0000Cool3001Qool3000079GMWOfMgIgmUMfMoIgMWOfEgIgm002MoIgMWOfMgIgmWMfMoIgM
WOfMgIgmWMd009gMWOfMg@005ooo00<00?ooool0=Ooo001Cool00`00ooooo`02ool00`00ooooo`0?
ool3001Qool3000089GlWOfEoIgmUObMoIGmWOfEo9gmUOfMoIGlWOd009gmUObMoIglWOfEo9gmWObM
oIGlWOd009gmUObMoIgl000Gool00`00ooooo`0Jool30002ool300001_oo003oo`00ool000;oo`80
00Soo`00J?oo0P00HOoo0`0002:EgIGm002MoIGMWOfMgIgmUMfMoIgMWOfEgIgmWMfMoIGMWOd009gm
WMfMoIgMWOfMgIgmWMfMoIgM002MgIgmWMfMo@8001Koo`03003ooooo00Koo`03003ooooo00;oo`03
003ooooo00goo`03003ooooo00;oo`0:003ooooo003oo`00ool00?oo000:ool006Goo`@005koo`@0
000PUOfMoIGmWOfEoIgm002MoIGlWOfEoIgmUObMoIGmWOfEo9gmUOfMoIGlWOd009gmUObMoIglWOfE
o9gmWObMo@D00003WOfMo00001Koo`03003ooooo00Coo`03003oo`0000;oo`03003oo`0000koo`03
003ooooo00;oo`09003ooooo003oo`00ool00?oo00<000Soo`00Hooo0P00Gooo0`0002:MoIGMUOfE
gIgmUMfEoIGMWOfEg@00WMfMoIGMWOfMgIgmUMfMoIgMWOfEgIgmWMfMoIGM002MgIgmWMfMoIgMWOfM
g@<00007WMfMoIgMWOfMgIgm00005ooo00<00?ooool01Ooo00H00?ooool00?oo000>ool01000oooo
oooo0P000_oo0P0000Coo`00ooooo`<000Soo`00H?oo0`00GOoo1000026MoIGmWOfEoIgmUOfMoIGm
WOfEoIgmUOfMoIGm002EoIgmUObMoIGmWOfEo9gmUOfMoIGlWOfEoIgmUO`009glWOd0100000^Eo9gm
002MoIGlWOfMo9gmUObMo@0001Koo`03003ooooo00?oo`8000?oo`03003oo`0000coo`05003oo`00
ool0000Fool005koo`8005coo`@0000RUMfEoIGM002EgIgmUMfEoIGMWOfEgIGmUMfMoIGMUOfEgIgm
UMd009gMWOfEgIgmWMfMoIGMWOfMgIgmUMfMoIgMWOd3000049gmWMfMoIgMWOfMg@00WMfMoIgMWOfM
gIgmWMfMo@005_oo00<00?ooool00_oo00<00?ooool00_oo00<00?oo00003?oo1@000_oo00<00?oo
ool04Ooo001Kool3001Jool400008igmUOfMoIGmWOfEoIgmUOd009GmWOfEoIgmUOfMoIGmWOfEoIgm
UOfMoIGmWOfEo@00UOfMoIGlWOfEoIgmUObMoIGmWOd00`0001>MoIGl002Mo9gmUObMoIglWOfEo000
WObMoIGlWOfMo9gmUO`0000Gool01000oooooooo0`000ooo00<00?ooool09_oo001Iool20003ool0
0`00ooooo`1Cool400008iGMUOfEgIGmUMfEoIGMUOfEgIGmUMfEoIGM002EgIgmUMfEoIGMWOfEgIGm
UMfMoIGMUOfEgIgm002MoIgMWOfEgIgmWMd0100001NMoIGMWOfEgIgm002MoIgMWOfMgIgmWMfMo@00
WOfMgIgmWMfMoIgMWOfMg@0001Coo`<003;oo`00E_oo0`00F?oo0`0002BMoIGm002EoIgmUOfMoIGm
WOfEoIgmUOfMoIGmWOfEoIgmUOd009GmWOfEoIgmUOfMoIGmWOfEoIgmUOfMoIGmWOd009gmUOd30000
79GmWOfEo9gmUOfMoIGlWOfEoIgm002MoIglWOfEo9gmWO`009GlWOfMo9gmUObMoIglWOfEo0005_oo
00<00?ooool0;ooo001Dool2001Gool400008igmUMfMoIGMWOfEg@00UMfEoIGMUOfEgIGmUMfEoIGM
UOfEgIGmUMfEo@00UOfEgIgmUMfEoIGMWOfEgIGmUMfMoIGMUOd0100001nEgIgmUMfMoIGMWOfEgIgm
UMfMoIGMWOfEgIgm002MoIgMWOfMgIgm002MoIgMWOfMgIgmWMfMoIgMWOd0000Gool00`00ooooo`0^
ool0057oo`@005Goo`<0000SUOfMoIGmWOjEoIgmUOfMoYGmWOfEo@00UOfMoIGmWOfEoIgmUOfMoIGm
WOfEoIgmUOfMo@00WOfEoIgmUOfMoIGmWOfEo@0400008YgmUOfMo@00WOfEoIgmUObMoIGmWOfEo9gm
UOfMoIGlWOfEo@00UObMoIglWOfEo000WObMoIGlWOfMo9gmUObMoIgl0P005_oo00<00?ooool0;_oo
001>ool3001Fool300008YGMWOfEgIgmUMfMoIGMWOfEgIgmUMfMoIGMWOfEg@00UMfEoIGMUOfEgIGm
UMfEoIGMUOfEgIGmUMfEo@00UOfEgIgm100002:EgIGmUMfEoIGMUOfEgIGm002MoIGMWOfEgIgmUMfM
oIGMWOfEgIgmUMfMoIGM002MgIgmWMfMo@00WOfMgIgmWMfMo@@00003WMfMo@0001Goo`8002ooo`00
C?oo0P00E_oo0`00022MoJHm002MoYGmWOfEoIgnUOfMoIGmWOjEoIgmUOfMoYGmWOd009gmUOfMoIGm
WOfEoIgmUOfMoIGmWOfEoIgm1@0002>MoIGmWOfEoIgmUOfMoIGmWOfEoIgmUOd009GlWOfEoIgmUObM
oIGmWOfEo9gmUOfMoIGlWOfEo@00UObMoIgl002Eo9gm00<00007WOfMo9gmUObMoIgl00005ooo00<0
0?ooool0;?oo0019ool3001Dool400007igMYSfMgIhmWMfV?@00WOfEgIgmUMfMoIGMWOfEgIgmUMfM
oIGMWOfEgIgm002EoIGMUOfEgIGmUMfEoIGM00@0000TUOfEgIGm002EoIGMUOfEgIGmUMfEoIGMUOfE
gIGmUMfEoIGM002EgIgmUMfMoIGMWOfEgIgmUMfMoIGMWOfEgIgm002MoIgM100000^MoIgMWOfMgIgm
WMfMoIgMWOfMg@0001Koo`03003ooooo02coo`00Aooo0P0000?oo`00ool0DOoo0`0001nV?IgmYSfM
o:HmWOfV?IglYSfMoJHm002MoYGmWOfEoIgnUOfMoIGmWOjEoIgmUOfMoYGmWOd009gmUOfMo@040000
0iGmWOjEo@02UOd07ignUOfEo@00WOfEoIgmUOfMoIGmWOfEoIgmUOfMoIGmWOfEo@00UObMoIGmWOfE
o9gmUOfMoIGlWOfEoIgm00@0000@UObMo@00WOfEo9gmWObMoIGlWOfMo9gmUObMoIgl000Fool00`00
ooooo`0[ool004Goo`8005?oo`<0000NWSfMgJHmWMfN?IgMYSfMgIhmWMfV?IgMWSfMgJHm002MoIGM
WOfEgIgmUMfMoIGMWOfEgIgmUMfMoIGM100002BEoIGMUOfEgIGmUMfEoIGMUOfEgIGmUMd009GMUOfE
gIGmUMfEoIGMUOfEgIGmUMfEoIGMUOfEg@00UMfMoIGMWOfEgIgmUMd500004iGMWOd009gmWMd009gM
WOfMgIgmWMfMoIgMWOfMgIgmWMfMo@0001Koo`03003ooooo02_oo`00AOoo0P00DOoo0P0001j^?JHl
002Mo:HmWOfV?IglYSfMoJHmWObV?IgmYSfMo:HmWOd009GmWOjEoIgmUOfMoYGmWOfEoIgnUOd30000
19GmWOd009gn0iGm00FMoYGmUOfEoIgn00>Eo@0EWOjEo@00UOfMoIGmWOfEoIgmUOfMoIGmWOfEoIgm
UOfMo@00WOfEo9gm00H0000GUObMoIGmWOfEo9gm002MoIGl002Mo9gmUObMoIglWOfEo9gmWObMoIGl
WOd0000Eool2000/ool004Coo`800003ool00?oo04goo`80000L[Qb^?JHL[Sf^7000WMfN?IgMYSfM
gIhmWMfV?IgMWSfMgJHmWMfN?IgM002EgIgmUMfMoIGMWOd400008YGMWOfEgIGmUMfMo@00UOfEgIGm
UMfEoIGMUOfEgIGmUMfEoIGMUOfEg@00UMfEoIGMUOfEgIGmUMfEoIGMUOfEgIGm200001^EgIgmUMfM
oIGMWOfEgIgmUMd009gMWOfMg@00WMfMoIgMWOfMgIgmWMfMoIgMWOfMgIgm00005_oo00<00?ooool0
:Ooo0014ool01@00oooooooo0000B_oo0`0001^^?JHl[SfV?:hmYSb^?JHl002Mo:HmWOfV?IglYSfM
oJHmWObV?IgmYSfMo:HmWOd009GmWOh00`0000fMoYGmWOfEoIgnUOfMoIGmWOjEoIgm002MoP03UOd0
1IgnUOfEoIGmWOh00iGm00ZMoYGm002EoIgmUOfMoIGmWOfEo@@00003UOfEWIgm0080000NUObMoIGm
WOfEo9gmUOfMoIGlWOfEoIgmUO`009glWOfEo000WObMoIGlWOfMo9gmUObMoIglWOfEo0005_oo00<0
0?ooool0:Ooo0014ool00`00ooooo`02ool00`00ooooo`15ool200003:hmYQb^?JhL[SfV7:hm[Qb^
?JHL[Sf^7080000=WSfMgJHmWMfN?IgMYSfMgIhmWMfV?IgMWSd00`00026EoIGMWOfEgIGmUMfMoIGM
UOfEgIgmUMfEoIGMWOd009GmUMfEoIGMUOfEgIGmUMfEoIGMUOfEgIGm002EoIGMUOd0100000BEgIGm
UMfEo@<0000OUOd009gmUMfMoIGMWOfEgIgmUMfMoIGMWOfEgIgmUMd009gMWOd009gmWMfMoIgMWOfM
gIgmWMfMoIgMWOd00P005_oo00<00?ooool0:?oo0014ool20004ool00`00ooooo`12ool200006JHl
[SfV?:hmYSb^?JHl[SfV?:hmYSb^?JHl[SfV?:hm002V?IgmYSfMo:HmWOfV?Igl00@0000EYSfMo@00
UOfMoYGmWOfEoIgnUOfMoIGmWOjEoIgmUOfMoYGm002EoIgn00>Eo@05WOjEoIGmUOfMoP03UOd40000
1IgmUIfEoIFMWOd00`0001nMoIFMUOfEW@00UOfMoIGlWOfEoIgmUObMoIGmWOfEo9gmUOfMoIGl002M
o9gm002MoIglWOfEo9gmWObMo@0300000igmUO`0000Fool00`00ooooo`0Wool004Coo`03003ooooo
00Coo`03003ooooo03ooo`80000G]S`00:hmYQb^?JhL[SfV7:hm[Qb^?JHL[Sf^7:hmYQb^?JhL[Sd0
09hmWMfV?@04000089hMWSfN7IhmWQfN?IhM002EgIGmUMfMoIGMUOfEgIgmUMfEoIGMWOfEgIGmUMd0
09GMUOfEgIGmUMfEoIGMUOd400001YGMUOd009GmUMfEo@<0000NUOfEgIGmUMfEoIGMUOfEg@00UMfM
oIGMWOfEgIgmUMfMoIGMWOfEgIgmUMfMo@00WOfMgIgm002MoIgM100000NMoIgMWOfMgIgmWMd0000D
ool2000Yool003Ooo`D000;oo`03003ooooo00?oo`03003ooooo00Goo`03003ooooo03coo`80000E
]S^f?;Hk_S`00:hmYSb^?JHl[SfV?:hmYSb^?JHl[SfV?:hmYSb^?JHl00@0000PYSfMoJHmWOfV?Igm
YSfMoJHmWOfV?Igm002EoIgnUOfMoIGmWOjEoIgmUOfMoYGmWOfEoIgnUOd009GmWOjEo@@00003UOf=
oIGn00:Eo@03SOfEoP000080000NWOfEWIGmUIfMoIFMUOfEWIgmUIfEoIFM002EoIgmUObMoIGmWOfE
o9gmUOfMoIGlWOfEoIgm002MoIgl0`0000^Mo9gmUObMoIglWOfEo9gmWObMo@0001Koo`03003ooooo
02Koo`00>Ooo00L00?ooooooo`00ool00004ool00`00ooooo`06ool00`00ooooo`0iool200005KHl
]Qbf?;HL]Sbf7;Hl002^?JHL[Sf^7:hmYQb^?JhL[SfV7:hm[Qb^?@0200007jhL[Sd009hmWQfN?IhM
WSfN7IhmWQfN?IhMWSfN7IhmWQd009GMUOfEgIgmUMfEoIGMWOfEgIGmUMfMoIGM00D00008UMfEoIGM
UOfEgIGmUMfEo@@0000LUMfEoIGMUOfEgIGmUMfEoIGMUOfEgIGmUMfEoIGM002EgIgmUMfMoIGMWOfE
gIgmUMfMoIGMWOd400003igM002MgIgmWMfMoIgMWOfMgIgmWMfMoIgMWOd0000Fool00`00ooooo`0U
ool003?oo`<000?oo`03003ooooo00?oo`05003oooooool0000:ool2000gool200002[Hk_Sbf>kHl
]S^n?;Hk]Sbf>khl0P0000VV?:hmYSb^?JHl[SfV?:hmYS`00P0001f^?JHl[SfV?:hm002V?IgmYSfM
oJHmWOfV?IgmYSfMoJHmWOfV?Igm002EoIgnUOfMoIGmWOjEoIgm00@00006UOfMoYGm002=oIGn0YGm
00>=oIGn00000P0001bEoYGmUOf=o@00UIfEoIFMWOfEWIGmUIfMoIFMUOfEWIgmUIfEo@00WOfEoIgm
UObMoIGmWOfEo0@0000DWOfEWIgm002MoIgl002Eo9gmWObMoIGlWOfMo9gmUObMoIglWOd001Goo`03
003ooooo02Goo`00>Ooo00@00?ooooooo`8000Coo`03003ooooo00[oo`03003ooooo03;oo`80000D
]Sbf7;Hl]Qbf?;HL]Sbf7;Hl]Qbf?;HL]Sbf7000YQb^?JhL[SfV70<0000KYQb^?JhL[SfV7:hm[Qb^
?@00WSfN7IhmWQfN?IhMWSfN7IhmWQfN?IhMWSfN7@00UMfEoIGM00@0000;UOfEgIGmUMfEoIGMUOfE
g@00UMfEo@0300006iGmUMfEoIGMUOfEgIGmUMd009GMUOfEgIGmUMfEoIGMUOfEgIGmUMfEoIGMUOd0
09gmUMfMo@0400006IGMWOfEgIgmUMfMoIGMWOd009gmWMd009gMWOfMgIgmWMfMoIgMWOfMgIgmWMfM
o@0001Coo`8000Ooo`03003ooooo00;oo`03003ooooo01Ooo`00>Ooo00D00?ooooooo`0000Goo`03
003ooooo00_oo`03003ooooo02ooo`80000D]S^f?;Hk_Sbf>kHl]S^n?;Hk]Sbf>khl]S^f?;Hk_Sbf
>`00YSb^?@80000JYSb^?JHl[SfV?:hmYSb^?JHl[SfV?:hm002V?IgmYSfMoJHmWOfV?IgmYSfMoJHm
WOfV?@@0000<UOfEoYGmWOjEoIGnUOfMoYGmUOjEoIgn0`0000FEoYGmUOf=oIGn00:Eo@0BSOfEoYGm
UOf=o@00UIfEoIFMWOfEWIGmUIfMoIFMUOfEWIgm1@0001fMoIFLWOfEWIgmUIbMoIFMWOfEW9gmUId0
09GlWOd009gmUObMoIglWOfEo9gmWObMoIGlWOfMo00001Koo`03003ooooo00Coo`07003oooooool0
0?oo00006?oo000hool20003ool30003ool2000=ool00`00ooooo`0/ool200005;hk002f?;HL]Sbf
7;Hl]Qbf?;HL]Sbf7;Hl]Qbf?;HL]Sbf7;Hl]Q`200006Jhm[Qb^?JHL[Sf^7:hmYQb^?JhL[SfV7:hm
[Q`009hMWSfN7IhmWQfN?IhMWSfN7Ihm00<0000=WSfN7@00UMfEoIGMUOfEgIGmUMfEoIGMUOd00`00
01REo@00UOfEgIGmUMfEoIGMUOfEgIGmUMfEoIGMUOd009GmUMfEoIGMUOfEgIGmUMd400008IGmUMfE
o@00WOfEgIgmUMfMoIGMWOfEgIgmUMfMoIGMWOfEg@00WMfMo@00WOfMgIgmWMfMoIgMWOfMgIgmWMfM
o@02000Eool00`00ooooo`04ool00`00ooooo`03ool00`00ooooo`0Fool004?oo`03003ooooo00go
o`03003ooooo02[oo`03002n>/Hk00:n>`0@002n?;Hk]Sbf>khl]S^f?;Hk_Sbf>kHl]S^n?;Hk]S`2
00006;Hk002V?:hmYSb^?JHl[SfV?:hmYSb^?JHl[SfV?:hmYS`009gmYSfMoJHmWOfV?@<0000>WSjM
oIhmWOfN?Ygm002EoIgnUOfEoYGmWOjEo@800009WOjEoIGnUOfMoP00UOf=oIGn00:Eo@06SOfEoYGm
UOf=oIGn0YGm00@009gmUIfEo@@0000RUIfEoIFMUOfEWIGmUIfEo@00WOfEWIgmUIbMoIFMWOfEW9gm
UIfMoIFLWOfEW@00UObMo@00WOfEo9gmWObMoIGlWOd300000igmWO`0000Eool00`00ooooo`04ool0
0`00ooooo`02000Iool004?oo`03003ooooo00koo`03003ooooo02Ooo`80000C_Q^n>khK_S^n6khk
002f?;HL]Sbf7;Hl]Qbf?;HL]Sbf7;Hl]Q`00P0001Nf?;HL]Sbf7000YQb^?JhL[SfV7:hm[Qb^?JHL
[Sf^7:hmYQb^?JhL002N7Ihm00<0000>WSfN7IhmWQfN?IhMWSfN7IhmWQd009GMUOfEg@<0000CUMfE
oIGMUOfEgIGmUMfEo@00UOfEgIGmUMfEoIGMUOfEgIGmUMd01P0002:EoIGMUOfEgIGmUMfEoIGMUOfE
gIGmUMd009GMWOfEgIgmUMfMoIGMWOfEgIgmUMfMoIGMWOfEg@00WMfMo@00WOfMg@@00006WOfMgIgm
WMbMo@005_oo00L00?ooooooo`00ool00002ool00`00ooooo`0Hool004;oo`80017oo`03003ooooo
02Goo`04002n>khjaS/2_S/09[hjaS^n>khk002n?;Hk]Sbf>khl]S^f?;Hk_Sbf>`00]S^nO;Hk]Wbf
>kil]S/00:Hl[SfV?:hmYSb^?JHl[SfV?:hmYSb^?JHl[Sd300003YhnWOfN?IgmWSjMoIhmWOfN?Ygm
WSfMoIhnWOd3000039GmUOjEoIgnUOfEoYGmWOjEoIGnUOd000:Eo@03SOfEoP0000D0000USIfEoXfM
UOd009GmUIfEoIFMUOfEWIGmUIfEoIFMUOfEWIGmUId009FLWOfEWIgmUIbMoIFMWOfEW9gmUIfMoIFL
WOd009gmUO`00`0000^Eo9gmWObMoIGlWOfMo9gmUObMo@0001Coo`8000?oo`<000;oo`<001Soo`00
@_oo00<00?ooool04Ooo00<00?ooool08_oo0P0001>n>khK_S^n6khk_Q^n>khK_S^n6khk002f?;HL
]Sbf7;Hl]Qbf?00200005KHL]Sbf7;Hl]Qbf?;HL]Sbf7000YQb^?JhL[SfV7:hm[Qb^?JHL[Sf^7002
00003Zhm[Qd009hMWSfN7IhmWQfN?IhMWSfN7IhmWQd400003IGmUMfEoIGMUOfEgIGmUMfEoIGMUOfE
gIGm00D0000WUOfEgIGmSMfEoIGMUOf=gIGmUMfEo@00UOfEgIGmUMfEoIGMUOfEgIGmUMfEoIGMUOfE
g@00UMfMoIGMWOfEgIgmUMfMoIGMWOfEgIgm00@0000?WM`009gMWOfMg9gmWMfMoIgLWOfMgIgmWMbM
o@0001Goo`03003ooooo023oo`00@_oo00<00?ooool04_oo00<00?ooool08?oo00D00;hk_S^n>/Hk
00:n>`06_S[6>khk_S^n>/Hk0[hk00D00;hl]S^f?;Hk0080000E]Wbf>kil]S^fO;Hk_Wbf>kIl]S^n
O000[SfV?:hmYSb^?JHl[SfV?:hm0080000=YSb^?JHl[SfV?000WOfN?YgmWSfMoIhnWOd00`0000fM
oIhmWOfN?P00UOjEoIgnUOfEoYGmWOjEo@040000:9GnSOd008fMUOf=WIGnSIfEoHfMUOj=WIGmSIfE
oXfMUOd009GmUIfEoIFMUOfEWIGmUIfEoIFMUOfEWIGmUId009FLWOfEWIgmUIbMoIFM100001>MoIFL
WOd009gmUO`009glWOfEo9gmWObMoIGlWOfMo9gmUO`0000Fool00`00ooooo`0Oool004;oo`8001Co
o`03003ooooo01goo`80000B_Q^n>khK_S^n6khk_Q^n>khK_S^n6khk_Q^n>khK_S/00;Hl0P0001Bf
7;Hl]Qbf?;HL]Sbf7;Hl]Qbf?;HL]Sbf7;Hl002^?JHL[Sf^7:hm0`0000b^?JHL[Sf^7JhmYQb^?JhM
002N7IhmWQd3000039hMWSfN7IhmWQfN?IhMWSd009GmUMfEo@@0000XUMfEoIGMUOfEgIGmUMd009GM
UOf=gIGmUMfEoHgMUOfEgIGmSMfEoIGM002EgIGmUMfEoIGMUOfEgIGmUMfEoIGMUOfEgIGm002MoIGM
WOd4000069GMWOfEgIGmUMfMoIGM002MgIgmWM`009gMWOfMg9gmWMfMoIgLWOfMgIgmWM`001Goo`03
003ooooo01ooo`00@_oo00<00?ooool05?oo00<00?ooool06ooo00H00<Hk_S^n>khjaS/2_S/01[hj
aS^n>khk_S[6>`:n>`0I_S[6>khk_S/00;il]S^fO;Hk_Wbf>kIl]S^nO;Hk]Wbf>kil]S^fO;Hk_W`0
0:hmYS`00P0000b^?JHl[SfV?:hmYSb^?JHl[SfV?:hmYS`300002igmWSfMoIhnWOfN?IgmWSjMoIhm
WOd0100002JEoXgmUOj=oIGnSOfEoXgmUOj=oIGnSOd008fMUOf=WIGnSIfEoHfMUOj=WIGmSIfEoXfM
002EWIGmUIfEoIFMUOfEWIGmUIfEoIFM1P0001bMoIFLWOfEW9gmUIbMoIFLWOfEW9gmUI`009glWOd0
09gmWObMoIGlWOfMo9gmUObMoIglWOd001Goo`80023oo`00@_oo00<00?ooool05Ooo00<00?ooool0
6Ooo01<00<Hk002n>khK_S^n6khk_Q^n>khK_S^n6khk_Q^n>khK_S^n6`0200004khk002f?;HL]Sbf
7;Hl]Qbf?;HL]Sbf7;Hl]Qbf?;HL]Sbf7;Hl0080000;YQb^?JhM[SfV7:hm[Qf^?JHL[Sf^7@030000
2ZhM002N7IhmWQfN?IhMWSfN7Ihm100002BMgIhm002EoIGMUOfEgIGmUMfEoIGMUOfEgIGmUMfEoIGM
002EgIGmSMfEoIGMUOf=gIGmUMfEoHgMUOfEg@00UMfEoIGMUOd600008IFMUOfEWIGm002MoIGMUOfE
gIgmUMfEoIGMWOfEgIGmUMfMoIGM002MgIgm002MoIgMWOfMg9gmWMfMoIgLWOfMg@02000Eool00`00
ooooo`0Nool0047oo`03003ooooo01Ooo`03003ooooo01Koo`800005aS^n>/Hk0036>`02_S/01[hj
aS^n>khk_S[6>`:n>`0G_S[6>khk002n>/Hk_S[6>`00_Wbf>kIl]S^nO;Hk]Wbf>kil]S^fO;Hk_Wbf
>`0200002[il002^?JHl[SfV?:hmYSb^?JHl0`0000VV?:hmYSb^?JHl002MoIhnWOd0100002>N?YGm
WSjEoIhnUOfN?P00UOj=oIGnSOfEoXgmUOj=oIGnSOfEoXgmUOh009GnSIfEoHfMUOj=WIGmSIfEoXfM
UOf=WIGn00D0000TUOf=WIGmUIfEoHfMUOfEWIGmSIfEo@00WOfEW9gmUIbMoIFLWOfEW9gmUIbMoIFL
WOd009gmWObMo@00WOfMo9gmUObMoIgl0`0000>Mo9gm00005Ooo00<00?ooool07Ooo0011ool3000H
ool00`00ooooo`0Dool04`00aQ[6>lHJaS[66/Hk002n>khK_S^n6khk_Q^n>khK_S^n6khk0080000B
_Q^n>khK_S^n6khk002f?;HL]Sbf7;Hl]Qbf?;HL]Sbf7;Hl0P0000Vf7;Hl]Q^f?000[SfV7:hm[Qd0
0`0000R^7JhmYQb^?JhM[SfV7:hm100002>MgIhmWMfN?IgMWSfMgIhmWMfN?IgMWSd009GmUMfEoIGM
UOfEgIGmUMfEoIGMUOfEgIGm002EoIGMUOf=gIGmUMfEoHgM00@0000USOf=W@00UIfEoIFMUOfEWIGm
UIfEoIFMUOfEWIGmUId009GMWOfEgIGmUMfMoIGMUOfEgIgmUMfEoIGMWOd009gmWMd009gLWOd01000
00NMgIgmWMbMoIgMWOd0000Eool00`00ooooo`0Lool0047oo`03003ooooo01Woo`03003ooooo01;o
o`0;002n>/Hk_S[6>khjaS^n>/Hk0036>`02_S/06KhjaS^n>khk_S[6>`00aS^n>/Hk_S[6>khjaS^n
>/Hk002nO;Hk]Wbf>kil]S^fO;Hk00800009_Wbf>kil]S^nO;Hk_W`00:hm00800009YSb^?JHl[SfV
?:hmYSb^?JHl0080000S[SfV?000UOfN?YGmWSjEoIhnUOfN?YGmWSjEoIhnUOd008gmUOj=oIGnSOfE
oXgmUOj=oIGnSOfEoXgmUOh009GnSIfEo@0400009XfMUOj=WIGnSIfEoXfM002=WIGmUIfEoHfMUOfE
WIGmSIfEoIFMUOf=W@00UIbMoIFLWOfEW9gmUIbMoIFLWOfEW9gmUI`009GlWOd300002igmWObMoIGl
WOfMo9gmUObMoIgl00005Ooo0P007Ooo000dool50002ool00`00ooooo`03ool00`00ooooo`0Jool0
0`00ooooo`0?ool200004LHJaS_66/HjaQ[6>lHJaS[66/Hk002n>khK_S^n6khk_Q/00P00016n>khK
_S^n6khk_Q^n>khK_S^n6khk002f?;HL]Sbf7;Hl00800008]Q^f?;HL]Sbf6kHl]Qbf?0<00009[SfV
7:hm[Qf^?JHL[Sf^7Jhm0080000O[Qf^?JHL[Sf^7@00WMfN?IgMWSfMgIhmWMfN?IgMWSfMgIhmWMd0
09GMUOfEgIGmUMfEoIGMUOfEgIGmUMd01P0002NEoHfMSOf=WIGmSIf=oHfMUOf=WHgm002EoIFMUOfE
WIGmUIfEoIFMUOfEWIGmUIfEoIFM002EgIgmUMfEoIGMWOfEgIGmUMfMoIGMUOd00`0000nMoIgM002M
g9gmWMfMoIgLWOfMgIgmWMbMoIgM00005?oo0P007Ooo000fool01`00oooooooo003oo`0000Coo`03
003ooooo01_oo`03003ooooo00goo`0@0036>khjaS^n>/Hk_S[6>khjaS^n>/Hk_S[6>`00aS/2_S/0
4khj002n>/Hk_S[6>khjaS^n>/Hk_S[6>khjaS^n>/Hk002nO;Hk00800007_Wbf>kil]S^nO;Hk_W`0
0`0000VnO;Hk_W`00:hmYSb^?JHl[Sd00`0001^^?JHl[SfV?:hmYSb^?JHl002EoIhnUOfN?YGmWSjE
oIhnUOfN?YGmWSjEo@00SOfEoXgmUOh01P0002V=oIGnSOfEoP00UOj=WIGnSIfEoXfMUOj=WIGnSIfE
oXfMUOh009GmSIfEoIFMUOf=WIGmUIfEoHfMUOfEWIGmSId009FLWOfEW9gmUIbMoIFL00@0000CWOfE
W000UObMoIgl002Eo9gmWObMoIGlWOfMo9gmUObMoIgl00005Ooo00<00?ooool06_oo000`ool30003
ool01`00oooooooo003oo`0000Coo`03003ooooo01coo`8000coo`0B0036>/HJaS_66/HjaQ[6>lHJ
aS[66/HkaQ[6>/HJaS/00;hk0P00012n6khk_Q^n>khK_S^n6khk_Q^n>khK_S^n6khk_Q^n>`800006
]Qbf?;HK]Sbf7;Hl0`0000Zf?;HK]Sbf7;Hl]Q^f?000[SfV7080000I[SfV7:hm[Qf^?JHL[Sf^7Jhm
YQb^?@00WSfMgIhmWMfN?IgMWSfMgIhmWMfN?IgMWSd01@0002^=oHgMUOj=gHgmSMfEoXgMSOf=gIGn
002=oHfMUOf=WHgmSIfEoHfMSOf=WIGmSIf=o@00UOfEWIGmUIfEoIFMUOfEWIGmUIfEoIFMUOd009Gm
UMfMo@04000069GMUOfEgIgmUMfEoIGM002Mg9gm002MoIgLWOfMgIgmWMbMoIgMWOfMg9gmWMd001Co
o`03003ooooo01[oo`00=_oo00L00?ooooooo`00ool00003ool00`00ooooo`0Oool00`00ooooo`07
ool200008/Hk_S[6>khjaS^n>/Hk_S[6>khjaS^n>/Hk_S[6>khjaS/00<Hk_S[6>khjaS^n>/Hk_S[6
>khjaS^n>/Hk_S[6>khj0P0000G6>`00_Wbf>kil00<0000;_Wbf>kil]S^nO;Hk_Wbf>kil]S^nO002
00005jHl[SfV?:hmYSb^?JHl[SfV?:hmYSb^?JHl[Sd009hnUOfN?YGmWSjEoIhnUOd0100002ZN?YGm
002=oIGnSOfEoXgmUOj=oIGnSOfEoXgmUOj=oIGn002EoXfMUOj=WIGnSIfEoXfMUOj=WIGnSIfEoP00
UOf=WIGmUIfEoHfMUOfEWIGmSId6000079gmUIbMoIFLWOfEW9gmUIbMoIFLWOd009gmUObMo@00WOfE
o9gmWObMoIGlWOfMo9gmUObMo@005Ooo00<00?ooool06Ooo000fool01`00oooooooo003oo`0000?o
o`03003ooooo023oo`03003ooooo00Goo`0Y00366/HjaQ[6>lHJaS[66/HkaQ[6>/HJaS_66/HjaQ[6
>lHJaSX00<Hj002n>khK_S^n6khk_Q^n>khK_S^n6khk_Q^n>khK002n6/Hk_Q_6>`0300003;Hl]Q^f
?;HL]Sbf6kHl]Qbf?;HK]Sbf7080000E_W`00:hmYQb^?JhM[SfV7:hm[Qf^?JHL[Sf^7JhmYQb^?@00
WSfMgIhm00@0000XUMfN?YGMWSfEgIhnUMd008gMUOj=gHgmSMfEoXgMSOf=gIGnSMf=oHgM002=WHgm
SIfEoHfMSOf=WIGmSIf=oHfMUOf=W@00UIfEoIFMUOd600008IFMUKfEWIFm002EoIGMWOfEgIGmUMfM
oIGMUOfEgIgmUMfEo@00WOfMg9gm002MoIgLWOfMgIgmWMbMoIgMWOfMg002000Dool2000Jool003Go
o`8000Coo`03003ooooo00;oo`8002;oo`03003ooooo00;oo`80000A_SX00;hjaS^n>/Hk_S[6>khj
aS^n>/Hk_S[6>khjaS^n>P0200003lHkaS[6>`00aS^n>/Hk_S[6>khjaS^n>/Hk_S[6>`0200000khj
aS/0000200003LHk002nO;Hk_Wbf>kil]S^nO;Hk_Wbf>kil0080000C]S^nO;Hk_W`00:hmYSb^?JHl
[SfV?:hmYSb^?JHl[SfV?:hmYS`0100002JN?YGmWSjEoIhnUOfN?YGmWSjEoIhnUOd008gmUOj=oIGn
SOfEoXgmUOj=oIGnSOfEoXgm002=WIGnSIfEoXfMUOj=WIGnSIfEoXfM1P0002BEoHfMUOf=WIGmSIfE
oHfMUOf=W@00UIbMoIFLWOfEW9gmUIbMoIFLWOfEW9gmUIbMo@00WOfEo000WObMoIGlWOfMo9gmUO`3
00000iglWOd0000Dool00`00ooooo`0Hool0043oo`03003ooooo02;oo`0Y003ooooo0036>/HJaS[6
6P00aQ[6>/HJaS_66/HjaQ[6>lHJaS[66/HkaQX00<HJaS[66/HjaQ[6>P00_S^n6khk_Q^n>khK_S^n
6khk0036>`0300003/Hk_Q[6>khKaS/00;Hl]Qbf?;HK]Sbf7;Hl]Q/200001kil]Q^nO;HL_Wbf6kil
00800009YQb^?JhM[SfV7:hm[Qf^?JHL00<0000TYQf^?@00WSjEgIhmUMfN?YGMWSfEgIhnUMfN?IGM
WSjEg@00SMfEoXgMSOf=gIGnSMf=oHgMUOj=gHgmSMd008fMSOf=WIGm1P0002J=WHfmSId009FMUKfE
WIFmUIfE_IFMUKfEWIFmUIfE_IFM002EgIGmUMfMoIGMUOfEgIgmUMfEoIGMWOfEgIGm002MoIgL002M
gIgm100000JMg9gmWMfMoIgL000Eool00`00ooooo`0Gool000?oo`<00006ool00000003oo`000_oo
0P000ooo0P000_oo10009Ooo00<00?ooool08ooo0P0002;6>khjaS^n>/Hk_SX00;hjaS^n>/Hk_S[6
>khjaS^n>/Hk_SX00;hjaS_6>/Hk_S[6>lHjaS/00<Hk_S[6>khjaS^n>P@0000?aS^n>/Hk_S[6>khj
aS^n>/Hk002nO;Hk_Wbf>kil0080000B]S^nO;Hk_Wbf>kil]S^nO;Hk_Wbf>`00YSb^?JHl[SfV?:hm
0P00026V?:hmYSb^?JHl[Sd009hnUOfN?YGmWSjEoIhnUOfN?YGmWSjEoIhnUOd008gmUOj=oIGnSOfE
oXgmUOj=oIGnSOd01P0002V=oXfMSOj=WHgnSIf=oXfMSOj=W@00SIfEoHfMUOf=WIGmSIfEoHfMUOf=
WIGmSId009FLWOfEW9gmUIbMoIFLWOfEW9gmUIbMoIFL002Mo9gm00<0000;WOfMo9gmWObMoIglWOfM
o9gmWO`0000Eool00`00ooooo`03ool50002ool00`00ooooo`02ool00`00ooooo`04ool000Coo`05
003oooooool00002ool00`00ool00004ool01@00ooooo`00ool00`009_oo00<00?ooool08_oo01<0
0<HJaS[66/HjaQ[6>/HJaS[66P00aQ[6>/HJaS_66/HjaQ[6>`0200003/HJaS[66/HjaQ[6>/HJaS[6
6/Hj002n>khK_S/300004<Hk_Q[6>khKaS^n6/Hk_Q_6>khJaS^n6lHk002f?;HL0P00016nO;HL_Wbf
6kil]QbnO;HK_Wbf7;il]Q^nO;HL002V7:hm00<00009[SfV7JhmYQf^?JHM[SfV7Jhm0080000BUMfN
?IGMWSjEgIhmUMfN?YGMWSfEgIhnUMd008gMUOj=gHgm1P0002Z=gHgnSMd008fMSKf=WHfmSIf=_HfM
SKf=WHfmSIf=_HfM002EWIFmUIfE_IFMUKfEWIFmUIfE_IFMUKfEW@00UMfEoIGMWOfEgIGmUMfMoIGM
UOd500003igmWM`009gMWOfMg9gmWMfMoIgLWOfMgIgmWM`0000Cool20007ool01`00oooooooo003o
o`0000;oo`03003oo`0000Goo`001?oo00D00?ooooooo`0000;oo`03003oo`00008000;oo`03003o
oooo00Coo`03003ooooo02?oo`03003ooooo02;oo`0Q002n>/Hk_S[6>khjaS^n>/Hk_S[6>khj002n
>/Hk_S[6>khjaS/00<Hk_S[6>lHjaS^n>/HkaS[6>khjaS_6>/Hk00@0000@_S[6>khjaS^n>/Hk_S[6
>khjaS^n>/Hk_S[6>khjaS/200004KHk_Wbf>kil]S^nO;Hk_Wbf>kil]S^nO;Hk_Wbf>kil]S/00P00
01Z^?JHl[SfV?:hmYSb^?JHl[SfV?:hmYSb^?JHl002EoIhnUOfN?YGmWSjEoIhnUOfN?YGm1P0002Z=
oXfMSOj5WHgnSIf=oXFMSOj=W@00SIf=oXfMSOj=WHgnSIf=oXfMSOj=WHgn002EoHfMUOf=WIGmSIfE
oHfMUOf=WIGmSIfEo@00WOfEW9gmUI`6000059gmUIbMoIFL002Mo9gm002MoIglWOfMo9gmWObMoIgl
WOfMo9gm000Eool00`00ooooo`04ool01`00oooooooo003oo`0000;oo`03003oo`0000Goo`001?oo
00@00?ooooooo`<000;oo`<00003ool00000008000?oo`8002Goo`03003ooooo023oo`80000OaQ[6
>/HJaS[66/HjaQ[6>/HJaS[66/HjaQX00<HJaS[66/Hk0036>/HJaS[66/HjaQ[6>/HJaS[66/HjaQX0
0P0002G6>P00aS^n6lHk_Q[6>khKaS^n6/Hk_Q_6>khJaS^n6lHk_Q[6>`00aS/00;il]QbnO;HK_Wbf
7;il]Q^nO;HL_Wbf6kil]QbnO00200005[iK002V7JhmYQf^?JHM[SfV7JhmYQf^?JHM[SfV7JhmYQd0
09GMWSfEgIhn1P0002ZEgIHnUMd008gMSOj=gHgnSMf=oXgMSOj=gHgnSMf=oXgM002=WHfmSIf=_HfM
SKf=WHfmSIf=_HfMSKd009FmUIfE_IFMUKfEWIFmUIfE_IFMUKd600006iFMWOfEWIGmUIfMoIFMUOfE
WIgm002MoIgMWOd009gmWMfMoIgLWOfMgIgmWMbMoIgMWOd0000Eool00`00ooooo`03ool01`00oooo
oooo003oo`0000;oo`03003oo`0000Goo`000_oo00L00?oo003oo`00ool00009ool00`00ooooo`0Z
ool00`00ooooo`0Oool04`00aS^n>/Hk_S[6>khjaS^n>/Hk_S[6>khjaS^n>/Hk_SX00;hj0080000:
aS^n>/HkaS[6>khjaS_6>/Hk_SX300004khjaS/00<Hj0036>khjaS^n>/Hk_S[6>khjaS^n>/Hk_S[6
>khj0080000@aS^n>/Hk002nO;Hk_Wbf>kil]S^nO;Hk_Wbf>kil]S/200004kil]S^nO;Hk002V?:hm
YSb^?JHl[SfV?:hmYSb^?JHl[SfV?:hm00D0000ZUSjEoIHnUOfF?YGmUSjEoIHnUOd008fMSOj5WHgn
SIf=oXFMSOj=WHgnQIf=oP00SOj=WHgnSIf=oXfMSOj=WHgnSIf=oXfMSOh009GmSIfEoHfM1P00026E
_HfMUKd009gmUIbMoIFLWOfEW9gmUIbMoIFLWOfEW9gm002MoIglWOd009gmWObMoIglWOfMo9gmWObM
oIgl00005Ooo00<00?ooool00ooo00L00?ooooooo`00ool00002ool00`00ool00005ool000;oo`L0
03Koo`8001koo`80000LaS[66/HjaQ[6>/HJaS[66/HjaQ[6>/HJaS[66/HjaQ[6>/HJ00366/HjaQ[6
>/HJaS[66/HjaQX30000>lHJaS[66/Hj0036>/HJaSX00<Hk_Q_6>khJaS^n6lHk_Q[6>khKaS^n6P00
aQ[6>lHJaS_66/Hk002nO;HL_Wbf6kil]QbnO;HK_Wbf7000]U^nO;iK_WbfFkil_U/00:HM[SfV7Jhm
YQf^?JHM[SfV7JhmYQd00P0002V^?JHM002EgIHnUMfF?YGMUSjEgIHnUMfF?YGMUSjEg@00SMf=oXgM
SOj=gHgnSMf=oXgMSOj=gHgn002=_HfMSKf=WHfmSIf=_HfMSKf=WHfm00H0000USIfE_IFMUKf=WIFm
UIfE_HfMUKd009gmUIfEoIFMWOfEWIGmUIfMoIFMUOfEWIgm002MoIgMWOd009gmWMfMoIgLWOfMgIgm
WM`00`005?oo0P000ooo0P001?oo00<00?ooool00_oo00<00?ooool01?oo000oool00`00ooooo`0L
ool07000_S[6>khjaS^n>/Hk_S[6>khjaS^n>/Hk_S[6>khjaS^n>/Hk_SX00;hj002n>/HkaS[6>khj
0`0000Fn>/HkaS[6>khj008000G6>P0L0036>khjaS^n>/Hk_S[6>khjaS^n>P00_S[6>khjaS^n>/Hk
_S[6>`00_Wbf>kil]S^nO;Hk_W`200004[Hk_Wbf>kil]S^nO;Hk_W`00:hmYSb^?JHl[SfV?:hmYSb^
?@80000UYSf^OJHl[WfV?@00UOfF?YGmUSjEoIHnUOfF?YGmUSjEoIHnUOd008fMSOj5WHgnSIf=oXFM
SOj=WHgnQIf=oP00SOj=WHgnSId01P0002N=_XFMSKh009FmSIfE_HfMUKf=WIFmSIfE_HfMUKf=W@00
UIbMoIFLWOfEW9gmUIbMoIFLWOfEW9gmUIbMo@00WOfMo000WObMoIglWOd0100000BMo:GmWO`001Co
o`03003ooooo01?oo`00?ooo00<00?ooool06_oo0P0001:n6P00aQ[6>/HJaS[66/HjaQ[6>/HJaS[6
6/HjaQ[6>/HJaSX200001LHJaS[66P00aQX00`0001S66/HjaQ[6>/HJaS[66P00aQ[6>/HJaS[66/Hj
aQ[6>P00aS^n6lHk_Q[6>khKaS/200003lHJaS_66/HkaQ[6>lHJaS_66/Hk002nO;HL_Wbf6`020000
4Kil]U^nO;iK_WbfFkil_U^nO;IK_W`00:hmYQf^?JHM[Sd00`0001j^?JHM[SfV7JhmYQf^?JHM002E
gIHnUMfF?YGMUSjEgIHnUMfF?YGMUSjEg@00SMf=oXgMSOj=gHgnSMd90000:HfMSKf=WHfmSIf=_HfM
SKf=WHfm002E_IFMUKf=WIFmUIfE_HfMUKfEWIFmSId009FMWOfEWIGmUIfMoIFMUOfEWIgmUIfEoIFM
002Mg9gmWMd0100000RMoIgLWOfMgIgmWMbMo@005Ooo00<00?ooool04_oo000nool00`00ool0000J
ool06@00aS^n>/Hk_SX00;hjaS^n>/Hk_S[6>khjaS^n>/Hk_S[6>khjaS/00<Hk_S[6>[hj00<0000:
_S[6>lHjaS^n>/HkaS[6>khj0009aSX05`00_S[6>khjaS^n>/Hk0036>khjaS^n>/Hk_S[6>khjaS^n
>/Hk_S[6>`00_W`00P00016f>kil]S^nO;Hk_Wbf>kil]S^nO;Hk_Wbf>kil002^?JHl0080000H[WfV
?:imYSf^OJHl[WfV?JimYSb^OJHm002EoIHnUOfF?YGmUSjEoIHnUOfF?YGm2@0002j5WHgnQIf=oXFM
SOh008fnQIf=_XFMSKj5WHfnQIf=_XFMSKj5W@00SIfE_HfMUKf=WIFmSIfE_HfMUKf=WIFmSId009FL
WOfEW9gmUIbMoIFLWOfEW9gmUIbMo@@0000=WO`009glYOfMo9gmWObUoIglWOfMo:Gm00005Ooo00<0
0?ooool04Ooo000nool2000Iool200005[hk_QZn>khK_S^n6P00aQ[6>/HJaS[66/HjaQ[6>/HJaS[6
6/Hj0036>/HJ0`0003k66/HjaQX00<HJaS[66/HjaQ[6>/HJ00366/HjaQ[6>/HJaS[66/HjaQ[6>/HJ
002n6/Hk_Q_6>`00aS_66/HkaQ[6>lHJaS_66/HkaQ[6>lHJaS_66/Hk002nO;iK_WbfFkil_U^nO;IK
_WbnFkil]U^nO;iK_WbfFkil0P0001BV7JhmYQf^?JHM[SfV7JhmYQf^?JHM[SfV7JhmYQd009GMUSjE
gIHn1P0003>=gYGnSMd008FMSKj5WHFnQIf=_XFMQKj5WHfnQId008fMSKf=WHfmSIf=_HfMSKf=WHfm
SIf=_HfM002=WIFmUIfE_HfMUKfEWIFmSIfE_IFMUKf=W@00UIfMoIFMUOfEWIgmUId0100001:MoIFM
002Mg9gm002MoIgLWOfMgIgmWMbMoIgMWOfMg9gm000Dool2000Bool003Soo`03003ooooo00?oo`03
003ooooo01Ooo`0:002n>/Hk_S[6>khjaS^n>/Hk_SX200002<Hk_S[6>khjaS^n>/Hk_SX500003[hj
aS^n>/Hj_S[6>`00aS^n>/HkaS[6>khj000=aSX09000_SX00000aS^n>/Hk_S[6>khjaS^n>/Hk_S[6
>khjaS^n>/Hk0036>`00_Wbf>kil]S^nO;Hk_Wbf>kil]S^nO;Hk_Wbf>`80000A_W`00:imYSb^OJHm
[WfV?:imYSf^OJHl[WfV?JimYSb^O@050000=IGnSOfEoXgmUOj=oIGnSOfEoXgm0025WHgnQIf=oXFM
SOj5WHgnQIf=oXFM0025WHfnQIf=_XFMSKj5WHfnQIf=_XFMSKj5W@00SIfE_HfMUKf=WIFmSIfE_HfM
UKf=WIFm002MoIFLWOd0100001NEW9gmUIbMoIFLWOfEW000WObUo@00WOfMo:GmWObMoIglYOfMo9gm
WObUo@0001Coo`03003ooooo013oo`00=ooo00<00?oo00001?oo00<00?ooool05Ooo0P0001>n6khk
_QZn>khK_S^n6[hk_Q^n>khJ_S/00<HjaQ[6>/HJaS[66P0300003/HJaS[66/HjaQ[6>/HJaS[66/Hj
0036>/HJaSX200007lHJaS[66/HjaQ[6>/HJaS[66/HjaQ[6>/HJaS[66P00aQ[6>lHJaS_66/HkaQ[6
>lHJaS_66/HkaQ[6>lHJ0080000?aS[66/Hj002nO;iK_WbfFkil_U^nO;IK_WbnFkil0080000A_U^n
O;iK_W`00:hmYQf^?JHM[SfV7JhmYQf^?JHM[SfV7@020000=JHmYQd008gMUOj=gYGnSMfEoXgNUOj=
gIGnSMjEoXgM0025WHfnQIf5_XFMSKj5WHFnQIf=_XFM002=WHfmSIf=_HfMSKf=WHfmSIf=_HfMSKf=
W@00SIfE_IFMUKf=WIFmUIfE_HfMUKd01@0001^MoIFLWOfEWIgmUIbMoIFMWOfEW9gmUId009gLWOd0
09gmWMbMoIgMWOfMg9gmWMfMoIgL00005Ooo00<00?ooool03ooo000bool30004ool00`00ooooo`02
ool2000Eool04`00aS^n>/Hk_S[6>khjaS^n>/Hk_S[6>khjaS^n>/Hk0036>khj00<0000A_S[6>khj
aSZn>/Hk_S[6>[hjaS^n>/Hj_S[6>`00aS/0000@aSX05`00aSX00;hjaS^n>/Hk_S[6>khjaS^n>/Hk
_S[6>khj0036>/HkaS[6>lHjaS/00P0000Nf>kil]S^nO;Hk_Wbf>`0200001kil]S^nO;hk_Wbf>kil
00800008YSb^OJHm[WfV?:imYSf^O@80000aYSf^OJHm[WfV?@00SOfEoXgmUOj=oIGnSOfEoXgmUOj=
oIGn002=oXFMSOj5WHgnQIf=oXFMSOj5WHgnQId008FMSKj5WHfnQIf=_XFMSKj5WHfnQIf=_P00UKf=
WIFmSId01P0001nE_HfMUKd009gmUIbMoIFLWOfEW9gmUIbMoIFLWOfEW9gm002MoIglYOd009gmWObU
oIglWOfMo:GmWObMo@02000Dool00`00ooooo`0?ool003Ooo`8000Goo`03003ooooo01;oo`80000A
_S^n6khk_QZn>khK_S^n6[hk_Q^n>khJ_S^n6khk_QZn>`0400008<HJaS[66/HjaQ[6>/HJaS[66/Hj
aQ[6>/HJaS[66/Hj0036>/HJaS[66/HjaQ[6>/HJaS[66/HjaQ[6>/HJaSX200007/HJaS[66P00aQ[6
>lHJaS_66/HkaQ[6>lHJaS_66P00aQ[6>/HJaS[66/HjaQ[6>/HJ002nFkil]U^nO080000A_U^nO;iK
_WbnFkil_U^nO;iK_WbnF`00YQf^?JHM[SfV7@020000:JhmYQfV?JHM[SfV7JHmYQd008gMUOj=gYGn
SMfEoXgNUOj=gIGnSMjEoP00QKj5WHfnQIf5_XFMSKj5WHFnQIf=_P00SKf=WHfmSIf=_HfMSKd02P00
026=WIFmSIfE_HfMUKf=WIFmSId009FLWOfEWIgmUIbMoIFMWOfEW9gmUIfMoIFLWOd009gmWM`009gM
WOfMg9gmWMd0100000>MoIgL00004ooo0P004?oo0007ool3000]ool00`00ooooo`03ool00`00oooo
o`0Bool04@00_S[6>khjaS^n>/Hk_S[6>khjaS^n>/Hk_S[6>khjaS/00`0001K6>`00aSZn>/Hk_S[6
>[hjaS^n>/Hj_S[6>khjaSZn>/Hk_S[6>P00aSX000g6>P0O003>>/HjaS[6>LhjaSX00;hjaS^n>/Hk
_S[6>khjaS^n>P00aS[6>lHjaS_6>/HkaS[6>lHjaS_6>P00]S/00P00016nO;hk_Wbf>kil_S^nO;Hk
_Wbn>kil]S^nO;hk002V?:im0080000OYSf^OJHm[WfV?JimYSf^OJHm[WfV?@00SOfEoXgmUOj=oIGn
SOfEoXgmUOj=oIGn002=oXFMSOj5WHgnQId0300002J=_XFMSKj5WHfnQIf=_P00UKf=W9FmSIfE_HfL
UKf=WIFmSIbE_HfM002EW9gmUIbMoIFLWOfEW9gmUIbMoIFLWOfEW9gm002MoIgl1@0000NMo:GmWObU
oIglYOd0000@ool300000ooo003oo`0?ool000Soo`03003ooooo02coo`<000?oo`80017oo`80000>
]Q/00;hK_S^n6[hk_Q^n>khJ_S^n6khk_QZn>`<0000D_S^n6`00002n>`00aS[66/HjaQ[6>/HJaS[6
6/HjaQ[6>/HJaS[66P80000HaS[66/Hj0036>/HJaS[66/HjaQ[6>/HJaS[66/Hj0036>/HJaS[66/Hj
aQ[6>/HJ0P0002K6>lHJaS_66/HkaQX00<HJaS[66/HjaQ[6>/HJaS[66/HjaQ[6>/HJ002nFkil_U^n
O;iK_WbnFkil_U^nO;iK_WbnFkil_U^nO;iK0P0001JV?JHM[SfV7JHmYQf^?JHMYSfV7JhmYQfV?JHM
002=gIGnSMjEoXgMUOj=gP/0000^QIj5_WfNQKj5WXFn0025_HFMSKf5WHFmQIf=_HFMQKf5WHfmQId0
08fMUKf=WIFmSIfE_HfMUKf=WIFmSIfE_HfM002EW9gmUIfMoIFLWOfEWIgmUIbMoIFMWOd600002igL
WOfMg9gmWMbMoIgLWOfMg9gm00002ooo10001?oo00<00?ooool03_oo0004ool20002ool30003ool2
0002ool30003ool200000ooo00000002ool00`00ooooo`0Kool00`00ooooo`0?ool03P00_Sbf>khl
]S/00;hjaS^n>/Hk_S[6>khjaS/300006<Hk_S[6>khj002n>/Hk_S[6>`00aSZn>/Hk_S[6>[hjaS^n
>/Hj_S[6>khj002n>P?6>P03_S[6>P0000W6>P06003>>/HjaS[6>Lhj0/Hj00S6>LhjaS[6>P00aS^n
>/Hk0P0001k6>/HkaS[6>lHjaS_6>/HkaS[6>lHjaS_6>P00aSX00;hk_Wbf>kil_S^nO;Hk_Wbn>kil
]S^nO;hk_W`200004;ik002V?JimYSf^OJHm[WfV?JimYSf^OJHm[WfV?Jim200003F5oXgnQOj=oXGn
SOh008FnOIf5_WfMQKimWHFnOIf5_WfMQKh008fnQIf=_XFMSKj5WHfnQIf=_XFMSKj5W@00SIfE_HfL
UKf=WIFmSIbE_HfMUKf=W9FmSId009FLWOfEW9gmUIbMoIFL00@0000BWOfEW9gm002UoIgl002Mo:Gm
WObUoIglYOfMo:GmWObUo@001ooo0`002?oo00<00?ooool03_oo0003ool01P00ooooo`00ool000;o
o`03003oo`0000;oo`04003ooooo0003ool01P00ooooo`00ool000;oo`03003ooooo01_oo`03003o
oooo00goo`80000;]Sbf6kHk]Q^f?;HK002n6khk_QZn>`0300001Khk_Q^n>khJ_S/00P0001Zn6[hk
_Q^n>khJ_S/00<HjaQ[6>/HJaS[66/HjaQ[6>/HJ00366/HjaQ[6>/HJaS[66/Hj0P0002C66/HjaQ[6
>/HJaSX00<HjaQ[6>/HJaS[66/HjaQ[6>/HJaS[66/Hj0036>`00aS[66/HjaQ[6>/HJaS[66/HjaQ[6
>/HJaSX200003lHJaS[66P00_U^nO;iK_WbnFkil_U^nO;iK_WbnF`0200003kil_U^nNkiK002V7JHm
YQf^?JHMYSfV7JhmYQfV?@030000>JImYUd008gNSOj=gXgnSMj=oXgNSOj=gXgnSMj=oP00QKj5WXFn
OIj5_XFNQKimWXFnQIj5_P00QKf5WHfmQIf5_HFMSKf5WHFmQIf=_HFM002=WIFmSIfE_HfMUKf=WIFm
SIfE_HfMUKd009gmUIbMo@0400005iFMWOfEW9gmUIfMoIFL002Mg9gm002MoIgLWOfMg9gmWMbMoIgL
WOfMg9gm00000ooo0`003?oo00<00?ooool03Ooo0003ool01P00ooooo`00ool000;oo`03003oo`00
00Goo`05003oooooool00002ool00`00ool00002ool00`00ooooo`0Kool00`00ooooo`0;ool20000
2KHk_Sbf>khl]S^n?;Hk_Sbf>`0400006LHk_S[6>khjaS^n>/Hk0036>khjaS^n>/Hk_S[6>khjaS/0
0<Hj_S[6>khjaSZn>/Hk00800005_S[6>/HjaSZn>P03aSX01;hjaS[6>P000lHj0P0000G>>/HjaS[6
>Lhj00;6>P06aSW>>/HjaS[6>Lhj0/Hj01h00<HkaS[6>lHjaS_6>/HkaS[6>lHjaS_6>/Hk003>>/Hj
cS_6>/hjaSX00;hk_Wbf>kil_S^nO;Hk_W`200001kikaWbnNkil_W_6O;ik00800006[WfV?JimYSf^
OJHm0P0003N^OZImYWjVOJinYWd008GnSOj5oXgnQOj=oXGnSOj5oXgnQOj=oP00QKimWHFnOIf5_WfM
QKimWHFnOId008FMSKj5WHfnQIf=_XFMSKj5WHfnQIf=_XFM002=WIFmSIbE_HfMUKf=W9FmSIfE_@05
00006YgmUIbMoIFLWOfEW9gmUIbMoIFLWOfEW000WObUo@00YOfMo:GmWObUoIglYOfMo:GmWO`4000?
ool00`00ooooo`0=ool000?oo`03003ooooo00D00003ool00000008000;oo`8000Coo`800003ool0
0000008001koo`8000_oo`0:002f>kHK]Sbf6kHk]Q^f?;HK]S/300002;Hk002n>khJ_S^n6khk_QX2
0000D;hk_QZn>khK_S^n6[hk_Q^n>khJ00366/HjaQ[6>/HJaSX00<HjaQ[6>/HJaS[66/HjaQ[6>/HJ
aS[66/HjaQX00<HJ00366/HjaQ[6>/HJaS[66/HjaQ[6>/HJaS[66/HjaQ[6>P00cSX00<HjaQ[6>/HJ
aS[66/HjaQ[6>/HJaSX00<HjaQ[6>/HJaS[66/HjaQX00;iK_WbnFkil_U/200003[ik_U^nO;iK_W^n
Fkil_U^nNkiK_W`00:HmYQd30000<jIMYWfVGJImYUfVOJIMYWfVG@00SMj=oXgNSOj=gXgnSMj=oXgN
SOj=gP00OIj5_XFNQKimWXFnQIj5_WfNQKj5WP00QIf5_HFMSKf5WHFmQIf=_HFMQKf5WHfm002E_HfM
UKf=W@0600007iFmSIfE_@00WOfEW9gmUIfMoIFLWOfEWIgmUIbMoIFMWOfEW000WMbMo@00WOfMg9gm
WMbMoIgLWOfMg9gm0080017oo`03003ooooo00goo`000ooo00@00?ooool000Koo`03003ooooo02co
o`03003ooooo00Woo`800007_Sbf>khl]S^n?;Hk_S`00`00022n?;Hk_Sbf>khl0036>khjaS^n>P00
_S[6>khjaS^n>/Hk_S[6>khjaS^n>/Hk_SX00;hjaSZn>/Hk0036>[hj0lHj00Fn>/HjaS[6>[hj00?6
>P06_S[6>/Hj0036>Lhj0/Hj00K6>LhjaS[6>/HicSX2aSX00lHicS[6>P0200003<hjaSW>>P00aS_6
>/HkaS[6>lHjaS_6>P80000=cS[6>/hkaS[>>/HjcS_6>/hjaSX00;hk_W`00P0000jnNkil_W_6O;ik
_WbnNlIl_W^nO;ikaWbnNkil0P0002fVOJInYWf^OZImYWjVOJinYWfVOZIm[WjVO@00QOj=oXGnSOj5
oXgnQOj=oXGnSOj5oP00OIf5_WfMQKimWHFnOIf5_WfMQKimW@00QIf=_XFMSKj5WHfnQId02@0002:=
W9FmSIbE_HfLUKf=W9FmSI`009FLWOfEW9gmUIbMoIFLWOfEW9gmUIbMoIFLWOd00:GmWO`009glYOfM
o:GmWObUo@<00003YOfMo000013oo`03003ooooo00goo`001?oo0P003Ooo00<00?ooool09_oo00<0
0?ooool01ooo0P0000Jf6kHk]Q^f?;HK]S/300002kHk]Q^f?;HK]S^f6kHl]Q^f>`00_S/00P00016n
6khk_QZn>khK_S^n6[hk_Q^n>khJ_S^n6khk_QX00<HJ0080000laS[66/HjaQ[6>/HJaS[66/HjaQ[6
>/HJaS[66/HjaQX00<HJ00366/HjaQ[6>/HJaS[66/HjaQ[6>/HJaS[66P00aQ[>>/HIaS[66/hj0036
>/HJaS[66/HjaQX00<HJaS[66/HjaQ[6>/HJaS[66/HjaQ[6>/HJ0P0000jnO;iK_W^nFkil_U^nNkiK
_WbnFkik_U^nO;iK0P0001O6N`00YWfVGJImYUfVOJIMYWfVGJImYUfVOJIMYWfVG@00SMj=oXgNSOj=
gXgn01P0000XQIf5_HFMQKf5WHFm002E_HfMUKf=WIFmSIfE_HfMUKf=WIFmSId009FMWOfEW9gmUIfM
oIFLWOfEWIgmUIbMoIFMWOd009gmWM`009gLWOd300001YgmWMbUoIgLWOd0013oo`03003ooooo00go
o`00??oo00<00?ooool01Ooo0P0000Ff?:hl002f>khl00<0000Q_Sbf>khl]S^n?;Hk_Sbf>khl]S^n
?;Hk_S`00<Hk_S[6>khjaS^n>/Hk_S[6>khjaS^n>/Hk_S[6>khjaS^n>P0000;6>P05_S[6>/HjaSZn
>P03aSX01[hjaS[6>/Hj_S[6>P800006aSW6>/Hj0036>Lhj0/Hj04K6>LhjaS[6>/HicS[6>P00aSW>
>/HicS[6>LhjaSW>>P00aS_6>/HkaSX00<HjcS[6>/hkaS[>>/HjcS_6>/hjaS[>>lHj0036>@00_W^n
O;ikaWbnNkil_W_6O;ik_WbnNlIl_W/00;ikaWbnNlIl002^OZImYWjVOJinYWfVOZIm[WjVOJInYWf^
OPL0000mQOmmoXGoOOj5oggn001eGGfnMEem_WEMOKieGGfnMEem_WEM0025GHFnQEf5_HEMQKj5GHFm
QEf5_XEM002=W9FmSIbE_HfLUKf=W9FmSIbE_HfLUKf=W000UIbMoIFLWOfEW9gmUIbMoIFLWOfEW9gm
UI`009glYOd00`0000ZUoIglYOfMo:GmWObUoIglYOd000ooo`03003ooooo00goo`00??oo0P001?oo
0P0000F^7:hl[Qb^?:hL0080000>]S^f6kHl]Q^f>kHK]Sbf6kHk]Q^f?;HK]S^f6`80000A]S/00;hk
_QZn>khK_S^n6[hk_Q^n>khJ_S^n6khk_QZn>`0200008;hJ00366/HjaQ[6>/HJaS[66/HjaQ[6>/HJ
aS[66/Hj0036>/HJaS[66/HjaQX00<HJaS[66/HjaQ[6>/HJaSX200003<HJcS[66LHjaQ[>>/HIaS[6
6/hj0036>P80000LaQ[6>/HJaS[66/HjaQ[6>/HJaS[66/HjaQX00<HJcS[66P00_U^nO;iK_W^nFkil
_U^nNkiK_W`200004;iKaW^nFkik_U_6N`00YWfVGJImYUfVOJIMYWfVGJIm0`0003nVOZIM001mgXGn
QMj5oWgNQOj5gXGnOMj5oXGN001mWWfnOIim_WfNOKimWWfnOIim_WfN0025WHFmQIf5_HFMQKf5WHFm
QIf5_HFM002=WIFmSIfE_HfMUKf=WIFmSIfE_HfMUKf=W@00UIfMoIFLWOfEWIgmUIbMoIFMWOd01@00
00jMoIgL002Mg9gmWMbUoIgLWOfMg:GmWMbMo@003_oo00<00?ooool03Ooo000lool01000oooooooo
0P000Zhl00>f?:hl00000P0000j^?000]S^n?;Hk_Sbf>khl]S^n?;Hk_Sbf>khl0P0001Rf>kHl]S^n
?000aS^n>/Hk_S[6>khjaS^n>/Hk_S[6>khjaS/00<Hk_S[6>khj0002aSX01KhjaS[6>/Hj_SX00lHj
00Fn>/Hj0036>/Hi00?6>P06aSW6>/Hj0036>Lhj0/Hj02G6>Lhj003>>/HicS[6>LhjaSW>>/HicS[6
>LhjaSW>>P00cS_6>/hjaS[>>lHjcS[6>/hkaS[>>/HjcS_6>P00aSW>>/HicS[6>@0200001[il_W_6
O;ik_WbnN`80000@aWbnNlIl_W_6O;ikaWbnNlIl002^OZImYWjVOJinYWd20000?:InWWfVOYimYWjN
O@00OOj5oggnQOmmoXGoOOj5oggnQOmmoP00MEem_WEMOKieGGfnMEem_WEMOKieG@00QEf5_XEMQKf5
GHFnQEf5_HEMQKj5G@00SIbE_HfLUKf=W9FmSIbE_HfLUKf=W9Fm002MoIFLWOfEW0H0000DWOfEW9gm
UI`009glYOd00:GmWObUoIglYOfMo:GmWObUoIglYOd000koo`03003ooooo00coo`00??oo00L00?oo
00000:hL[Sb^700300001JhL[Sb^7:hl[Q`00P0000Rf>kHK]Sbf6kHk]Q^f?;HK0P0001:f?;HK]S^f
6kHl]Q^f>`00_S^n6[hk_Q^n>khJ_S^n6khk_QX200004;hk_QZn>khJ_S^n6P00aQ[6>/HJaS[66/Hj
aQ[6>/HJ0P0004[6>/HJaS[66/HjaQ[6>/HJaS[66P00aQ[6>/HJaSX00<HjaQ[>>/HIaS[66/hjaQW6
>/HJcS[66LHj003>>P00aS[66/HjaQ[6>/HJaS[66/HjaQ[6>/HJ00366/hjaQ[>>/HJcS[66/hj002n
O;iK_W^nF`00_U^nNkiKaW^nFkik_U_6NkiK_W^nFlIk002VOJIM0`0000VVGJInYUfVOZIMYWjVGJIn
YUd00P0002f5oXGNQOimgXGnQMj5oWgNQOj5gP00OIim_WfNOKimWWfnOIim_WfNOKimWP00QIf5_HFM
QKf5WHFmQIf5_HFMQKf5W@00SIfE_HfMUKf=WIFmSIfE_HfMUKd01P0001ZMW9gmWIbMoIfLWOfMW9gm
WIbMoIfL002Mg9gm002UoIgLWOfMg:GmWMbMoIgLYOfMg0003_oo00<00?ooool03?oo000kool30000
0kHl[S`000020003[S`01KHl[Sb^?:hl]S`00Zhl00H00;hl]S^n?;Hk_S`200002[Hk_Sbf>kHl]S^n
?;Hk]Sbf>khl0P0000Jn>/Hk_S[6>khjaS/200002KhjaS^n>/Hk_S[6>khjaS^n>P0200000lHj_S[6
>P02aSX01Khj0036>/HjaST00lHj00G6>LHjaS[6>/Hi00;6>P0O0036>@00003>>/HicS[6>LhjaSW>
>/HicS[6>LhjaSW>>P00cS[6>Lhj003>>lHjcS[6>/hkaS[>>/HjcS/00P0000c6>LhjaSW>>/HicS[6
>LhjaSW>>P00_W`200003[ikaWbnNlIl_W_6O;ikaWbnNlIl_W_6O;ikaW`20000=IimYWjNOJInWWfV
OYimYWjNOJInWWfVOYimYWh008GoOOj5oggnQOmmoXGoOOj5oggn001eGGfnMEem_WEMOKieGGfnMEem
_WEM0025GHFnQEf5_HEMQKj5GHFmQEf5_P00UKf=W9FmSI`01P0001nE_HfLUKd009gmUIbMoIFLWOfE
W9gmUIbMoIFLWOfEW9gmUI`009glYOd00:GmWObUoIglYOfMo:GmWObUo@02000=ool00`00ooooo`0<
ool003_oo`D0000A[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^?000]S^f6`020000L;Hk]Q^f?;HK
]S^f6kHl]Q^f>kHK]Sbf6kHk]Q/00;hJ_S^n6khk002n>khJ_S^n6[hk_QZn>khJ_S^n6[hk_QZn>`00
aS[66/HjaQX00<HJaS[66/HjaQ[6>/HJaS[66/HjaQ[6>/HJaS[66P00aQW6>/HJcS[66LHjaQ[>>/HI
aS[66/hjaQW6>P00cS[66LhiaQW>>P00aS[66/HjaQ[6>/HJaSX00<hjaQ[>>/HJcS[66/hjaQ[>>/HJ
cS[66/hj0036NkiK_W^nFlIk_U^nNkiKaW^nFkik_U_6NkiK0P000136N`00002VGJInYUfVOZIMYWjV
GJInYUfVOZIMYWjVGBL0000QUIfE_HfLUKfEWIFmSIbE_IFMUKd009gmWIbMoIfLWOfMW9gmWIbMoIfL
WOfMW9gm002UoIgLWOd00:GmWMbMoIgL00@00003YOfMg00000coo`03003ooooo00coo`00=Ooo00<0
0?ooool00ooo0P0000Coo`00[Sbf?0>^?005]Sb^?:hl[Sbf?003[S`00kHl[S`0000200004kHk]Sbf
>khl]S^f?;Hk_Sbf>kHl]S^n?;Hk]Sbf>khl]S/00;hj0080000AaS^n>/Hk_S[6>khjaS^n>/Hk_S[6
>khjaS^n>/Hk0036>P020002aSX01LHiaS[6>/HjaST00lHj04k6>LHjaS[6>/Hi0036>@00aSW>>/Hi
cS[6>LhjaSW>>/HicS[6>Lhj003>>/HicS[6>LhjaSW>>P00cS_6>/hjaS[>>`00cS[6>LhjaSW>>/Hi
cS[6>LhjaSW>>/HicSX00<hj0036O;ikaWbnNlIl_W_6O;ikaWbnNlIl_W/00;ikaWbnNlIk_W/009im
YWjNOJInWWfVOYimYWh40000@iinYWh007GoKIieoffNMOm]WWGoKIieoffN001]GGEnKEeeOVeMMGi]
GGEnKEeeOVeM001mGHEnOEf5OGeMQGimGHEmOEf5OP00UKf=W9FmSIbE_HfLUKf=W9FmSIbE_HfLUKd0
09gmUIbMoIFLWOfEW9gmUIbMoIFLWOfEW9gm002UoIgl00D00007WObUoIglYOfMo:Gm00003?oo00<0
0?ooool03?oo000dool00`00ool00005ool04000ooooo`00[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl
0P0003R^7:hl002f>kHK]Sbf6kHk]Q^f?;HK]S^f6kHl]Q^f>kHK]Sbf6kHk]Q/00;hJ_S^n6[hk_QZn
>khJ_S^n6[hk_QZn>khJ_S^n6[hk_QZn>`00aS[66/HjaQ[6>/HJaS[66/HjaQ[6>/HJaS[66/Hj0P00
00g66/HjaQX00<HIaS[66/hjaQW6>/HJcS[66@020000:LhjaQW>>LHIcS[66LhiaQW>>P00aS[66/Hj
003>>/HJcS[66/hjaQ[>>/HJcS[66/hjaQ[>>P00cS[>6Lhj0036NkiK_W^nFlIk_U^nNkiKaW/00P00
00O6FlIkaU_6NlIKaW_6F`0200000jInYUd000030000A9inWUjNOYiNWWjNGYin001eoWFNMOmeWWGn
MIieogFNMOieWP00IEieOWENMGiUGWEnMEieOVENMGh008EmQEf5OHEMQGf5GHEmQEf5OHEMQGd009Fm
SIbE_IFMUKf=W9FmUIfE_HfLUKfEW@00WIbMoIfLWOfMW9gmWIbMoIfLWOfMW9gmWI`500002igLYOfM
g:GmWMbUoIgLYOfMg:Gm00002ooo00<00?ooool03?oo000dool00`00ool00006ool200001?oo0000
0;Hl0jhl00Bf?:hl[Sb^?08000:^?00C[Sf^?:hl002n?;Hk]Sbf>khl]S^f?;Hk_Sbf>kHl]S^n?;Hk
]S`00P00016f>`00_S[6>khjaS^n>/Hk_S[6>khjaS^n>/Hk_S[6>khj00800004aS/00<HjaST3aSX0
1LHiaS[6>/HjaST00lHj03T00<HjaSW6>/HiaS[6>@00aSW>>/HicS[6>LhjaST00<HicS[6>LhjaSW>
>/HicS[6>LhjaSW>>P00cS/00<hjaSW>>/HicS[6>LhjaSW>>/HicS[6>Lhj003>>/HicS[6>Lhj0036
O;ikaWbnNlIl_W/00P0000_6NkikaWbnNlIk_W_6O;ikaW^nNlIl00800014WWjVOYinYWjNOZInWWjV
OYinYWjNOZIn001eoffNMOm]WWGoKIieoffNMOm]WP00KEeeOVeMMGi]GGEnKEeeOVeMMGh008EmOEf5
OWeMQGemGHEnOEf5OGeMQGh009FmSIbE_HfLUKf=W9FmSIbE_HfLUKf=W000UIbMoIFLWOfEW9gmUIbM
o@@0000AUIbMo@00YOfMo000WObUoIglYOfMo:GmWObUoIglYOd0000:ool00`00ooooo`0<ool003Co
o`03003oo`0000Soo`09003ooooo002^?:hL[Sb^7:hl0080000E[Qb^?:hL[Sb^7:hl[Qb^?000]S^f
6kHl]Q^f>kHK]Sbf6kHk]Q^f?;HK0080001X]Sbf6kHl]Q/00;hJ_S^n6[hk_QZn>khJ_S^n6[hk_QZn
>khJ002n6[hk_QZn>`00aS[66/HjaQ[6>/HJaS[66/HjaQ[6>P00aS[66/HjaQ[6>/HJaS[66P00aQW6
>/HJcS[66@00aQW>>/HIcSW66LhjaQW>>LHIcS[66LhiaQW>>P00cS[66/hjaQ[>>/HJcS[66/hjaQ[>
>/HJcSX00<hjcQW>>/hIcS[>6Lhj0036NkiK_W^nF`00aU_6NlIKaW_6FlIkaU_6NlIKaW_6F`800012
aW/009inWUjNOYiNWWjNGYinWUjNOYiNWWjNGYin001eoWFNMOmeWWGnMIieogFNMOh007EnIEieOWEN
MGiUGWEnMEieOVENMGh008EmQEf5OHEMQGf5GHEmQEf5OHEM002EWIFmSIbE_IFMUKf=W9FmUIfE_HfL
UKfEW@00WIbMoIfL100001JMoIfLWOfMW9gmWI`009gLYOd00:GmWMbUoIgLYOfMg:GmWMbUoIgLYOd0
00[oo`03003ooooo00_oo`00=?oo00<00?oo00002Ooo00H00?ooool00;Hl[S`200001Jhm[Sb^?:hl
[Sd00jhl00>^?Jhl[S`00P0000Rf>kHl]S^n?;Hk]Sbf>khl0P0001ff>kHl]S^f?;Hk]Sbf>`00_S[6
>khjaS^n>/Hk_S[6>khjaS^n>P00_S[6>khj_S^n>/Hk0036>/Hi00?6>P03aSW6>/Hj0080000ZaS[6
>LHjaSW6>/HiaS[6>LHjaST00<HicS[6>@00aSW>>/HicS[6>LhjaSW>>/HicS[6>LhjaSW>>P00cST0
0<hjaSW>>/HicS[6>LhjaSW>>/Hi0P0000_>>/HicS[6>LhjaSW>>/HicSX00<Il0080000M_W_6Nkik
aWbnNlIk_W_6O;ikaW^nN`00aW_>NlIjcW/00:InWWjVOYinYWjNOZInWWjVOYinYWjNOP0700009ffN
MOm]WWGo001eOVeMMGi]GGEnKEeeOVeMMGi]GGEn0025OGeMQGimGHEmOEf5OWeMQGemG@00SIbE_HfL
UKf=W9FmSIbE_HfLUKf=W00500006YfLWOfEW9gmWIbMoIFLWOfMW9gmUI`009glYOd00:GmWObUoIgl
YOfMo:GmWObUoIgl000:ool00`00ooooo`0;ool003Goo`03003ooooo00Woo`03003ooooo0080000E
[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL002f6kHl]Q^f>kHK0080000C]Sbf6kHl]Q^f?;HK
]Sbf6kHl]Q/00;hJ_S^n6[hk_QZn>khJ_S/00P0006Bn6[hk_QZn>khJ_S^n6[hk0036>/HJaS[66/Hj
aQX00<HJaS[66/HjaQ[6>/HJaS[66/HjaQ[6>/HJ00366@00aQW>>/HIcSW66LhjaQW>>LHIcS[66Lhi
aQW>>P00cSW>6Lhi003>>/HJcS[66/hjaQ[>>/HJ003>6LhjcQW>>/hIcS[>6LhjcQW>>/hIcSX00<Ik
aU_6NlIKaW_6FlIkaU_6NlIKaW_6F`00aU_6NlIKaW_6FlIk002NOYiNWWjNGYinWUjNOP@00007UYjF
_`00GGiEGUeoEEh02`0001IUGWEnMEieOVEN0025GHEmQEf5OHEMQGf5GHEmQEf5OHEM002EWIFmSIbE
_@H0000MUIbE_IFL002MW9gmWIbMoIfLWOfMW9gmWIbMoIfLWOd00:GmWMbUo@00YOfMg:GmWMbUoIgL
YOfMg0030009ool00`00ooooo`0;ool004;oo`800003ool00:hm00>^?005[Sf^?:hl[Sb^?@03[S`0
1jhm[Sb^?:hl002f>kHl0080000S]S^f?;Hk]Sbf>kHl]S^f?;Hk]Sbf>kHl]S/00;hjaS^n>/Hk_S[6
>`00_S^n>/Hk_SZn>khjaS^n>[hk_S[6>`00aS[6>@02aSX09@00aSW6>/HiaS[6>LHjaSW6>/HiaS[6
>LHjaSW6>/Hi0036>LhjaSW>>/HicS[6>LhjaSW>>/HicS[6>Lhj003>>LHicS[6>Lhi0080000NaSW>
>/HicS[6>@00aSW>>/HicS[6>LhjaSW>>/HicS[6>Lhj003F>@00aW^nNlIl_W_6NkikaWbnNlIk0P00
00_6NlikaW[>NlIkcW_6N/ik002VOYin00@00007U[nF_YJoU[jF_iJnU[l00P0000eEGUfoEEiM_eEN
GKmEGUfo001]?VDMKCiU7@0F00007iFmSIbE_HfLUKf=W9FmSIbE_@00WOfEW9gmWIbMoIFLWOfMW9gm
UIbMoIfLWOd00:GmWObUo@00YOfMo:Gm00@00004WObUoIgl0008ool00`00ooooo`0;ool004Coo`0B
003oo`00[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl0`0002Ff?;HK]Sbf6kHl]Q^f?;HK]Sbf
6kHl]Q^f?;HK]Sbf6`00_QZn>khJ_S/00;hk_QZn>khJ_S^n6[hk_QZn>khJ_S^n6[hk0036>P020000
D<HJaS[66/HjaQ[6>/HJaS[66/HjaQ[6>/HJaS[66P00aQX00<HIcSW66LhjaQW>>LHIcS[66LhiaQW>
>P00cSW>6LhicQW>>LhIcSW>6@00aQ[>>/HJ003>6LhjcQW>>/hIcS[>6LhjcQW>>/hIcSX00<hicQW>
>@00aW_6FlIkaU_6NlIKaW/00<IkaU_6NlIKaW_6FlIkaU_6NlIKaW/20000BiJNU[nFWYJoUYjF_iJN
U[nFWYJoUYjF_iJN001EGUeoEEiMOUENGGmEGUen001U?VDMICiU7VDnIAeU?VDNICiU7@00QEf5OGeM
QGf5GHEmOEf5OHEMQGemG@00UIbE_IFLUKfEW9FmUIbE_IFLUKfEW9Fm002MoIfLWOfMW9gmWIbMoIfL
WOfMW9gmWI`009gLYOfMg00400002:GmWMbUoJGLYOfMg:Gm0008ool00`00ooooo`0;ool004Goo`04
003oo`00[Sd3[S`01Jhm[Sb^?:hl[Sd00jhl0P0001J^?JHl002f>kHl]S^f?;Hk]Sbf>kHl]S^f?;Hk
]Sbf>kHl]S^f?;Hk002n>P80000O_S^n>/Hk_SZn>khjaS^n>[hk_S[6>khj_S^n>/Hk0036>/HiaS[6
>LHjaSW6>/HiaS[6>LHjaSW6>/HiaSX00P0000g6>LhjaST00<HicS[6>LhjaSW>>/HicS[6>@020000
6lhiaSW>>/HicSW6>LhjaSW>>LHi0036>@00aSW>>/HicS[6>LhjaSW>>/HicS[6>Lhj003F>@03cST0
5MHi00000;ikaWbnNlIk003>NlIkcW_6N/ikaW_>NlIjcW_6Nlik003>^`0200002iJnU[nF_YJoU[jF
_iJnU[nF_YJoU[h0100003MM_eENGKmEGUfoEEiM_`00KCiU7FdnIAe]?VDMKCiU7Fdn0025OGeMQGem
G8EmOEf5OGeLQGemGHEm002E_HfLUKf=W9FmSIbE_HfLUKf=W9FmSIbE_@00WOfEW9gmWIbMoIFLWOfM
W9gmUIbMo@0400003Igl002Mo:GmWObUoIglYOfMo:GmWObUo@0000Ooo`03003ooooo00_oo`00A_oo
00`00?oo00000:hL[Sb^7:hl[Qb^?:hL[S`200005ZhL[Sb^7:hl[Q`00;HK]Sbf6kHl]Q^f?;HK]Sbf
6kHl]Q^f?;HK]Sbf6kHl0P0000nn6[hk_QZn>khJ_S^n6[hk_QZn>khJ_S^n6[hk_QX00P0004Bn>`00
aS[66/HjaQ[6>/HJaS[66/HjaQ[6>/HJaSX00<HjaQ[6>/HIaS[66P00aQW>>LHIcS[66LhiaQT00<hI
cSW>6LhicQW>>LhIcSW>6LhicQW>>LhI003>6LhjcQW>>/hIcS[>6LhjcQW>>/hIcSX00<hicQW>>LhI
cSW>6LhicQT00<IK0P0000[6NlIKaW_6FlIkaU_6NlIKaW_6F`800004c[_>F/jkcUX2000019JoUYjF
_iJN1@0000=nWgjoOYl01@0002mEGUeoEEiMOP00ICiU7FDnIAiU?VDMICiU7VDn0025OHEMQGemGHEm
QEf5OGeMQGf5GHEm002E_IFLUKfEW9FmUIbE_IFLUKfEW9FmUIbE_@00WOfMW9gmWIbMoIfL00@0000B
WObMg000WMbUoJGL002Mg:GmYMbUoIgLYOfUg:GmWMbUo@001_oo00<00?ooool02ooo0017ool01000
ooooo`000jhl01Z^?Jhl00000:hm[Sb^?JHl[Sf^?:hmYS`00;Hk]Sbf>kHl]S^f?;Hk]Sbf>kHl]S^f
?;Hk0P0004ff?;Hk002n>/Hk_SZn>khjaS^n>[hk_S[6>khj_S^n>P00_SZn>khjaS/00<HjaSW6>/Hi
aS[6>LHjaSW6>/HiaSX00<HjaSW>>/HiaS[6>LhjaST00<HicS[6>LhjaST00<HicSW6>LhjaSW>>LHi
cS[6>LhiaSW>>/Hi0035n000aSW>>/HicS[6>LhjaSW>>/HicSX00=Hi00?>>@0KeSW>>LhicSWF>Lhi
0036N/ikaW_>NlIjcW_6NlikaW[>NlIk0036N/jkaW[>^lIjc[_6N/jk00@00005M[mn_gjoO[mf_`03
O[l01GJo000002cm99d0100002MM_`00KCiU7FdnIAe]?VDMKCiU7Fdn0025OGeMQGemG8EmOEf5OGeL
QGemGHEm002E_HfLUKf=W9FmSIbE_HfLUKf=W9FmSI`009fLWOd0100001JMo:GmWObUoIglYOfMo000
WObUoIgl002Mo:GmWObUoIglYOfMo:GmWO`000Ooo`03003ooooo00[oo`00B?oo0P0000Coo`00[Qb^
?080000;[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^700200002KHl]Q^f?;HK]Sbf6kHl]Q^f?0020000KkHK
]Sbf6kHl]Q/00;hJ_S^n6[hk_QZn>khJ_S^n6[hk_QX00;hJ_S^n6khk_QZn>`00aS[66/HjaQ[6>/HJ
aS[66/Hj0036>/HJaS[66LHjaQ[6>/HIaS[66P00aQW>>LHI003>6LhicQW>>LhIcSW>6LhicQW>>LhI
cSW>6@00cQW>>LhI003>6LhjcQW>>/hIcS[>6Lhj003>>LhIcSW>6LhicQW>>LhIcSW>6@00cQP00<IK
aW_6FlIkaU_6NlIKaW_6F`00cU[>^liJc[_>F/jkcU[>^liJ003>VP0200004GjoOYmn_gjOO[mnWgjo
OYmn_gjOO[l002cm;9d/oBbM;?d01@0001iU?VDNICiU7FDnIAiU?P00QGf5GHEmOEf5OHEMQGemGHEm
QEf5O@00UKfEW9FmUIbE_IFLUKfEW9FmUI`400006IgmWMbMo9gLWOfMg9glWMbMoIgLWObMg000WMbU
o@00YOfMg:GmYMbUoIgLYOfUg:Gm008000Koo`03003ooooo00[oo`00B_oo01T00?oo00000:hmYSb^
?Jhl[SfV?:hm[Sb^?JHl[Sf^?:hmYSb^?@00]Sbf>kHl]S^f?00300004KHl[S^f?;Hk]Sb^>kHl]S/0
0;hjaS^n>[hk_S[6>khj_S/00P0000Rn>[hk_S[6>khj_S^n>/Hk0P0003;6>LHjaSW6>/HiaSX00<Hj
aSW>>/HiaS[6>LhjaSW6>/HicS[6>@00aST00<HicSW6>LhjaSW>>LHicS[6>LhiaSW>>/Hi0035n<hi
cOW>>LGh0036>LhjaSW>>/HicSX00=Hi0lhi027F>LhicSW>>MHicST00<hheSW>>000aW[>NlIkcW_6
N/ikaW/00<Ijc[_6N/jkaW[>^lIjc[_6NP00cW[F^/iie[X00P0000If_gjoO[mn_gJoO[l6000022BM
;?hTWBcm99d/oP00G?d600004VDM001mG8EmOEf5OGeLQGemGHEmOEb5OGeM002=W9FmSIbE_@H0000I
UIbE_IFL002Mo:GmWObUoIglYOfMo:GmWObUoIglYOd00:GmWObUo@00YOfMo:GmWO`0100000>V?Igl
00001Ooo00<00?ooool02_oo001;ool05P00ool00:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^
7:hl002f?;HK0P0002Bf?;HK]Sbf6kHl]Q^f?;HK]Sbf6kHl]Q/00;hJ_S^n6[hk_QZn>`00_S^n6[hk
_Q^n>khJ_S^n6khk_QZn>khK00366/HjaQX20000>/HjaQ[6>/HIaS[66/HjaQW6>/HJaS[66LHjaQX0
0<hIcSW>6LhicQW>>LhIcSW>6LhicQW>>LhI003>6LhicQW>>LhIcST00<hjcQW>>/hIcSX00<hicQW>
>LhIcSW>6LhicQW>>LhI003>6=HicQSF>LhH0P0000?6NlIKaW/00P00017>F/jkcU[>^liJc[_>F/jk
cUX00<jJe[[>V]JjcY[F^/jJ00P000037GTEFAei00<0000<;?d/WBcm;9d/o@00G?eLgEcmG=eLoEcM
4P0001^E_9FLUKbEW9FlUIbE_9FLUK`009glWMbMoIgLWObMg9gmWMbMo9gLWOfMg9gl002UoIgLYOd0
100000NUgJGmYMbUoJGMYOd00005ool00`00ooooo`0:ool004coo`0B003oo`00[Sb^?JHl[Sf^?:hm
YSb^?Jhl[SfV?:hm[Sb^?JHl0`0005:^>kHl]S^f?:hk]Sbf>kHl[S^f?;Hk]Sb^>kHl]S/00;hjaS^n
>[hk0036>khj_S^n>/Hk_SZn>khjaS^n>[hk_S[6>khj0036>@00aSW6>/HicS[6>LHjaSW>>/HiaS[6
>LhjaSW6>/Hi0036>@00aSW>>/HicSW6>LhjaSW>>LHicS[6>@00aOS>>LgicSW5n<hicOW>>@00cS[6
>Lhj003F>@?>>@0/eSW>>LhicSWF>Lhi003>>=HicSSF>LhheSW>>=Hi003>N`00c[_6N/jkaW[>^lIj
c[_6N/jkaWX00<ije[[>NMJjcW[F^/ii003FNMjieWSN^@00gSOF=`T0000c99d/oBBM;?h005cmE=eL
oUcMG?eDgEcnG=d007dLQGem78EmOAb5OGdLQGem78EmOA`009FLWKfEW9FmUIbM_IFLUKfEW9fmUIbE
_@00YOfMo:GmWObUoIglYOfMo:GmWObUoIgl00D0000;WObV?IglYSfMo:HmWObV?IglYSd00004ool0
0`00ooooo`0:ool004goo`<0000<[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl0P0001FV7:hl002f?;HK
]Sbf6kHl]Q^f?;HK]Sbf6kHl]Q^f?;HK]Sbf6`00_QX00P0001nn>khJ_S^n6khk_QZn>khK_S^n6[hk
_Q^n>khJ_S^n6`00aQW6>/HJaS[66LHjaQ[6>/HIaS[66/HjaQW6>P0200003<HIaS[66P00cQW>>LhI
cSW>6LhicQW>>@80000/cQW>>LhIcSW>6LhicQW>>LhIcST00<hj003>>LhIcSW>6LhicQW>>LhIcSW>
6@00cQSF>LhHeSW>6=HicQSF>LhHeST00<jkcU[>^liJc[_>F/jkcU[>^`80000AcY[F^/jJe[[>V]Jj
cYX00=IIe[WFFMjieUT00=hGgSL00005ool60000;BbM001LgEcmG=eLoEcMG?eLgEcm0025?HDLQCf5
78DmQAb5?HDLQCf578Dm002E_9FLUKbEW9FlUIbE_9FLUKbEW9FlUI`009gLWObMg9gmWMbMo9gLWOfM
g00300004IgLYOd00:GmYM`00:GMYOfUg:GmYMfUoJGLYOfUgJGm00000ooo00<00?ooool02_oo001?
ool300002:hmYSb^?Jhl[SfV?:hm[S`200005JhmYSb^?JHl[Sd00;Hl[S^f?;Hk]Sb^>kHl]S^f?:hk
]Sbf>kHl[S^f?00200004;hjaS^n>[hk_S[6>khj_S^n>/Hk_SZn>khjaS^n>[hk0P0002bn>P00aSW>
>/HiaS[6>LhjaSW6>/HicS[6>LHj003>>/HiaS[6>LhjaST00<HicS[6>LhiaSW>>P00cSW5n<hicOW>
>LGhcSW=nLhiaOS>>LgicST00=Hi0lhi02kF>LhicSW>>MHicST00<hheSW>>=HicSSF>LhheSW>>=Hi
003F>000c[_6N/jkaW[>^lIjc[/00=JjcW[F^/iie[[>N]JjcWT00=Iig[WFN=jieWT00=HggSL000Wo
o`030003>0<H00<0000WG=eLoECMG?iLgEcmE=eLoP00QGem78EmOAb5OGdLQGem78EmOAb5O@00UKfE
W9fmUIbE_IFLWKfEW9FmUIbM_IFL002Mo:GmWObUoIgl00<0000DWObUoIglYOfMo000WObV?Igl002M
o:HmWObV?IglYSfMo:HmWO`000?oo`03003ooooo00[oo`00D?oo00P00?oo002^?:hL[Sb^7:hl0P00
01F^7:hmYQb^?:hL[SfV7:hl002f?;HK]Sbf6kHl]Q^f?;HK]Sbf6kHl]Q/00P00012f?;HL002n6[hk
_Q^n>khJ_S^n6khk_QZn>khK_S^n6P80001O_S^n6[hk_Q/00<HIaS[66/HjaQW6>/HJaS[66LHj0036
>/HIaS[66/HjaQW6>P00cSW>6LhicQW>>@00cSW>6LhicQW>>LhIcSW>6LhicQW>>LhIcST00<hi003>
>LhIcSW>6LhicQW>>LhIcST00=HicQSF>LhHeSW>6=HicQSF>@00eSSF6=Hh003>^liJc[_>F/jk003F
^/jJe[[>V]JjcY[F^/jJ003FFMJieUWN^MII003N5mhggQL0000:ool200020aP300008UcmG=eLoEcM
G?eLgEcm0025?HDLQCf578DmQAb5?HDLQCf578Dm002E_9FLUKbEW9FlUIbE_9FLUKbEW9Fl002MoIgL
0`0001JMg:GmWMbUoIgLYOfMg:GmWM`00:GMYOfUg000YMfUoJGLYOfUgJGmYMbUo@8000?oo`03003o
oooo00Woo`00DOoo00D00?oo002^?JHl0080000;[SfV?:hmYSb^?JHl[SfV?:hmYSb^?@0200002:hk
]Sbf>kHl[S^f?;Hk]S`20000A:hk]Sb^>kHl[S/00;hjaS^n>[hk_S[6>khj_S^n>/Hk_SX00;hj_S^n
>[hk_SZn>khj0036>LhjaSW6>/HicS[6>LHj003>>/HiaS[6>LhjaSW6>/HicSX00<hiaSW>>P00cSW5
n<hicOW>>LGhcSW=nLhiaOS>>LgicST00<hicOS>>@00eST3cST0:=HicSW>>@00eSW>>=HicSSF>Lhh
eSW>>=Hi003F><ggeSS=n=Hh003>^lIjc[/00=JjcW[F^/iie[[>N]JjcWT00=Iig[WFN=jieWWN^@00
0mhg00<00?ooool02_oo00@000<H0cP360D0000JG=eLoECMG?h008EmOAb5OGdLQGem78EmOAb5OGdL
QGd009FmUIbM_IFLUKfEW9fmUIbE_@@0000FWObUoIglYOfMo:GmWObUoIglYOfMo:GmWO`009glYSd0
0:HmWObV?IglYSd300000jHmWO`00002ool00`00ooooo`09ool005;oo`@0000EYQb^?:hL[SfV7:hl
[Qb^?JHL[Sb^7:hmYQb^?:hL002f6kHl]Q^f?;HK00800008]Sbf6kHl]Qbf?;HK]Sbf70800007_S^n
6khk_QZn>khK_S/00P00066n6khk_QZn>khK_S^n6[hk_Q/00<HIaS[66/HjaQW6>P00aS[66LHjaQ[6
>/HIaS[66/HjaQW6>P00cST00<hicQW>>LhIcSW>6LhicQW>>LhIcSW>6Lhi003>>LgHcSW=f<hi003>
>LhIcSW>6Lhi003F>LhHeSW>6=HicQSF>LhHeSW>6000eQSF>=HHeSSF6=Hh003>^`00e[[>V]JjcY[F
^/jJe[[>VP00eUWF^MIIg[WFFMJi003N=mhGgSL0000>ool010000aP360000UAL00=LGEAL00001000
00n578DmQAb5?HDLQCf578DmQAb5?HDL002EW9FlUI`01P0001RM_9fLWK`00:GmWMbUoIgLYOfMg:Gm
WMbUoIgLYOfMg:GmWM`00:GMYOd00:GmYMd200002JGmYMfUoJGLYOfUg@00ool0000;ool005Coo`80
000C[SfV?:hmYSb^?JHl[SfV?:hmYSb^?JHl[SfV?:hmYS`00:hk]S`00P00016^>kHl[S^f?:hk]Sb^
>kHl[S^f?:hk]S`00<Hk_SZn>khj0080000@_S^n>[hk_SZn>khj_S^n>[hk_SZn>khj0036>LhjaST2
00009LhjaSW6>/HicS[6>LHjaSW>>/HiaS[6>Lhj003>>LGhcSW=nLhiaOS>>LgicSW5n<hicOW>>@00
cSW=n<hicOS>>LghcST00=Hi00;>>@0V003F>LhheSW>>=HicSSF>LhheSW>>000cOOF><gheSS=mmHh
cOSF>000e[[>N]JjcWWF^/ije[[>N@00eWWN^MIhg[WFNMjieWP000;N=`03eSL00?oo00koo`800009
0cP005bmE5aL_EALG;eDG5bm0100000KUIbM_IFLWKbEW9fmUIbM_9FLWKd00:GmWObUoIglYOfMo:Gm
WObUoIglYOfMo:Gm002V?Igl00<00009WObV?IglYSfMo:HmWObV?Igl008000_oo`00EOoo0`0000jV
7:hl[Qb^?JHL[Sb^7:hmYQb^?:hL[SfV7:hl0`00016f?;HL]Sbf6kHl]Qbf?;HK]Sbf7;Hl]Q^f?;HL
]S`00;hk0080001U_QZn>khK_S^n6[hk_Q^n>khJ_S^n6khk_QZn>khK00366@00aQ[6>/HIaS[66/Hj
aQW6>/HJaS[66LHjaQ[6>P00aSX00<hicQW>>LhIcSW>6LhicQW>>LhIcST00<hicMS>>LgHcSW=f<hi
cMS>>@00cST00=HicQSF>LhHeSW>6=HicQSF>LhH003F6=HheQSF>=HHeSSF6=Hh003Em`00e[[>V]Jj
cY[F^/jJ003FFMJieUWN^MIIe[WFF@00gQON=mhGgSL0000@ool200001@<H001DG5ALG5d00eAL02QL
GEAL002578dlQAb5?8DLSCb578DlQAb=?8DL002MW9flWIbM_9fLWKbMW9flWIbM_9fLWK`00:GmWMbU
oIgLYOfMg:GmWMbUoIgLYOfMg0<0000<YMd00:GLYOfUgJGmYMbUoJGMYOfUg:Gm0P002ooo001Fool0
3@00ool00:Hl[SfV?:hmYSb^?JHl[SfV?:hm00<0000B[SfV?000[S^f?:hk]Sb^>kHl[S^f?:hk]Sb^
>kHl[S^f?:hk0P00022n>khj_S^n>[hk_SZn>khj_S^n>[hk_SZn>khj_S^n>[hk_SX00<HicS[6>LHj
aSW>>/HiaS[6>LhjaSW6>/Hi0P0002o6>/GicSX00<hiaOS>>LgicSW5n<hicOW>>@00cSW=n<hicOS>
>LghcSW=n<hicOS>>@00eSW>>=HicSSF>LhheSW>>=HicSP00<ggeSS=n=HhcOOF><gheSS=m`0000;E
m`80000<cW[F^/ii003FNMjieWSN^MIig[WFN0000]hg00?F=mhg00004_oo0P0002/3>000G;eDG5bm
E5aL_EALG;d008dlQAb=?8DKSCb578dlQA^=?8DLSC`009fmUIbM_9FLWKfEW9flUIbM_IFLWKbEW000
WObUoIglYOfMo:GmWObUo@0400004IglYSd00:HmWO`009glYSfMo:HmWObV?IglYSfMo:Hm00002ooo
001Gool300001jHL[Sb^7:hmYQb^?:hL0080000C[SbV7:hmYQb^?:HL002f6kHl]Qbf?;HK]Sbf7;Hl
]Q^f?;HL]S`00P0001:^7;Hl002n>khK_S^n6[hk_Q^n>khJ_S^n6khk_QZn>khK_S/20000E;hK0036
6LHjaQ[6>/HIaS[66/HjaQW6>/HJ00366LHjaQW6>/HIaSX00<hicQW>>LhIcSW>6Lhi003>>LgHcSW=
f<hicMS>>LgHcSW=f<hi003=n000eSW>6=HicQSF>LhHeSW>6000eQSF>=HHeSSF6=HheQSF>=HH003E
emGgeMOEmmGG003>VP00eUWF^MIIg[WFFMJieUWN^@00gSON5mhggQL001?oo`<000=DG00RG5eDG5AL
E5aLG@00QCb578dlQAb5?8DLSCb578DlQAb=?000WKbMW9flWIbM_9fLWKbMW9flWIbM_9fL002Mg:Gm
WM`400005:GmYMfUoJGLYOfUg@00YMbUoJGM002Ug:GmYMfUoJGLYOfUgJGmYM`2000:ool005Woo`<0
0003[SfV?00000800009YSb^?JHl[SfV?:hmYSb^?JHl00800008]Sb^>kHl[S^f?:hk]Sb^>`80001C
]Sb^>kHl[S^f?000_S^n>[hk_SZn>khj_S^n>[hk_SZn>khj_S/00;hk]SZn>khj0036>LhjaSW6>/Hi
cS[6>LHjaST00<GiaS[5nLhjaOW6>/GicSX00<hiaOS>>LgicST00<hicOS>>LghcSW=n<hicOS>>Lgh
cST00=HicOSF>000eSW>>=HicSSF>Lhh003=mmHhcOSF><ggeSS=n=HhcOL00007eOL03000eWWN^MIh
g[WFNMjieWSN^@00gSOF=`?N=`03003ooooo01;oo`0S001X0000001L_EALG;eDG5bmE5aL_@00SCb5
78dlQA^=?8DLSCb56hdlQAb=?000WKfEW9flUIbM_IFLWKbEW9fmUIbM_00400005IglYSfMo:HmWObV
?IglYSfMo:HmWO`009glYSfMo000WObV?IglYSfMo00300000ooo003oo`09ool005[oo`0H003oo`00
002V7:hmYQb^?:HL[SfV7:hlYQb^?JHL[SbV7:hm002f?;HL]Sbf6kHl0P0001>^7;Hl[Qbf?:hL]Sb^
7;Hl002n>khK_S^n6[hk_Q^n>khJ_S^n6`020000E[hk_Q^n>khK_S^n6`00aQW6>/HJaS[66LHjaQX0
0<HIaS[66LHjaQW6>/HIaS[66LHj003>>LhIcST00<hicMS>>LgHcSW=f<hicMS>>LgHcST00<ghcMS=
n<gHcOP00=HicQSF>LhHeST00=HheQSF>=HHeSSF6=HheQSF>000eOOEemGgeMOEmmGG003EUP00eUWN
^MIIe[WFFMji003N=mhGgSON5mhg000Fool00`00L0000003000065aME5aDG5AL002578DlQAb=?8DL
QCb578dlQAb5?8DLSC`009flWIbM_9fLWKbMW0@0000FYOfMg000YMfUoJGLYOfUgJGmYMbUoJGMYOfU
g:GmYMd00:GLYOd00:GmYM`30004ool00`00ooooo`08ool005_oo`0E003oo`00[SfV?:hmYSb^?JHl
[SfV?:hmYSb^?JHl[SfV?:hm002f?:hk0080000;]Sb^>kHl[S^f?:hk]Sb^>kHl[S^f?00200001[hj
_S^n>[hk_SZn>`800011_SZn>kHj_S^n>[hk]SZn>`00aS[6>LhjaSW6>/Hi0035nLHjaOW>>/GiaS[5
nLhjaOW6>/GicSX00<hi003>>LghcSW=n<hicOS>>LghcSW=n<hi003F>LgheSS=n=HicOSF>000eSW>
>=Hi003F><gheSS=mmHhcOSF><ggeSP00007eOL02`00eKKEUP00eWWN^MIhg[WFN@00eSL00mhg00?F
=`00ool05Ooo00H00700001T>f@JK3/200004UALG;eDG000QA^=?8DLSCb56hdlQAb=?8DKSCb57000
UIbM_@@0000GWObUoIglYOfMo:Gm002V?IglYSfMo:HmWObV?IglYSfMo:HmWObV?@00YSfMo0030007
ool00`00ooooo`08ool005coo`0A003oo`00002V7:hmYQb^?:HL[SfV7:hlYQb^?JHL[SbV70030000
9:hL]Sb^7;Hl[Qbf?:hL]Sb^7;Hl[Qbf?:hL]Sb^7000_Q^n>khJ_S/00;hk_Q^n>khK_S^n6khk_Q^n
>khK_S/00<HjaQW6>P80000maQW6>/HIaS[66LHjaQW6>/HIaS[66LHjaQW6>P00cSW=f<hicMS>>LgH
cSW=f<hicMS>>@00cOS=f<ghcMS=n<gHcOS=f<gh003F>@00eSSF6=HheQSF>=HHeSSF6=Hh003EmmGG
eOOEemGgeMOEm`00eKKEU]FfeIH00P0000[N^MII003N5mhggQON=mhGgSL001Ooo`07001`0000I1]T
6V@KI1X0100000N=?8DLQCb578dlQAb5?007000069glWMbUoIgLWObMg:GmWMbMo9gLYOd00:GmYMfU
oJGLYOfUgJGmYMbUoJGMYOfUg0<000;oo`03003ooooo00Goo`03003ooooo00Soo`00GOoo0P0000co
o`00YSb^?JHl[SfV?:hmYSb^?JHl[Sd200005JHl[Sd00;Hl[S^f?:hk]Sb^>kHl[S^f?:hk]Sb^>kHl
[S^f?:hk002n>P020000@khk_SZn>kHj_S^n>[hk]SZn>khj_S^f>[hk0036>P00cS[5nLHjaOW>>/Gi
aS[5nLhjaOW6>/GicS[5nLHj003>>P00cSW=n<hicOS>>LghcSW=n<hi003F>LgheSS=n=HicOSF><gh
eSW=n=Hh003F><gheSS=mmHhcOSF><ggeSS=n00000OEm`0:003EU]ffeIKE]]FFgKH00=ji0003gSL0
0mHggSL0000Iool200001f@JI3]T6V`kI1YT>f@J00P0000KUCb=6iDlSA^E?8dK002Mo:GmWObUoIgl
YOfMo:GmWObUoIglYOd00:HmWObV?IglYSfMo:Hm00@000Koo`03003ooooo00Coo`03003ooooo00So
o`00Gooo00T00?oo002V7:hmYQb^?:HL[Sd00`0001FV?JHLYSfV7:Hm002f?:hL]Sb^7;Hl[Qbf?:hL
]Sb^7;Hl[Qbf?:hL]S`00P0001nn6khk_Q^n>khK_S^n6khk_Q^n>khK_S^n6khk_Q^n>`00aS[66LHj
aQW6>/HIaS[66LHjaQW6>/HIaS[66@020000>lHjaQW6>P00cSW=f<hicMS>>LgHcSW=f000cMS=n<gH
cOS=f<ghcMS=n<gHcOP00<gh003F>=HHeSSF6=HheQSF>=HH003EemGgeMOEmmGGeOOEe`00eIKE]]FF
eKKEU]FfeIKE]P00gSON5mhggQON=mhG00006_oo0P0002ET6V@KI1YT6f@JI1]T6V@K002E?8dKUCbE
6iDlSA^E?9DKUCb=6iDl002UoIgLWObMg:GmWMbMo9gLYOfMg9glWM`00:GLYOfUg@04000:ool00`00
ooooo`04ool00`00ooooo`08ool0063oo`06003oo`00002^?JHl0P0001J^?JHl[SfV?:hmYSb^?JHl
[Sd00;Hl[S^f?:hk]Sb^>kHl[S^f?:hk]Sb^>`80000@]Sb^?000_SZn>kHj_S^n>[hk]SZn>khj_S^f
>[hk_SX20000<khk0036>/GicS[5nLHjaOW>>/GiaS[5nLhjaOT00<GicS[5nLHjaOW>>P00cSW=n<hi
cOS>>Lgh003=n=HhcOSF>LgheSS=n=HicOSF>000eOS=n=Gh003F><gheSS=mmHhcOP00008eOL02@00
gKKEU]FfeIKM]]FFeKKEUP0200001MhgeSON=mhg00007?oo028006`kI1YT>f@JK3]T6V@kI1X008dK
UCb=6iDlSA^E?8dKUCb=6iDlSA^E?000YOfMo:GmWObUoIglYOfMo:GmWObUo@@000ooo`03003ooooo
00?oo`03003ooooo00Soo`00HOoo00<00?ooool00P0000bV7:HmYQbV?JHLYSfV7:HmYQbV?JHLYSd2
00002:hL]Sb^7;Hl[Qbf?:hL]S`200004:hL[Sb^7:hl[Q`00;hK_S^n6khk_Q^n>khK_S^n6khk0P00
04fn6khk_Q^n>`00aS[66LHjaQW6>/HIaS[66LHjaQT00<HIaS[66LHjaQW6>/HI003=f<hicMS>>LgH
003=f<ghcMS=n<gHcOS=f<ghcMS=n000cOS=f<ghcMS=n000eSSF6=HheQSF>000eOOEemGgeMOEmmGG
eOL00=FfeIKE]]FFeKKEU]FfeIH00=EEeGD00=hggQON=`0001coo`80000LI1]T6V@KI1YT6f@JI1]T
6P00UA^E?8dKUCbE6iDlSA^E?9DKUCb=6iDl002UoIgLWObMg:GmWM`4000Dool00`00ooooo`03ool0
0`00ooooo`07ool006;oo`80000Fool00:hmYSb^?JHl[SfV?:hmYSb^?JHl[SfV?:hmYS`00:hk]Sb^
>kHl[S/200004;Hl[Sbf?:hl]Sb^?;Hl[S`00;hj_S^f>[hk_SZn>kHj0P0003Jn>kHj_S^f>khk]SZn
>`00aS[5nLhjaOW6>/GicS[5n@00aOW>>/GiaS[5nLhjaOW6>/Gi003=n<hicOP00<gheSS=n=HicOSF
><gheSW=n=HhcOP00<gheOS=mmGhcOP00<ggeSS=n=Hh0008eOL04@00eIKE]]FFgKKEU]FfeIKM]P00
eGGEE=Ee003N=mHg00007Ooo01T006@JK3]T6V@kI1Y/>f@JI3]T6P00SA^E?8dKUCb=6iDlSA^E?8dK
UCb=6`00WObUo@04000Hool00`00ooooo`03ool00`00ooooo`07ool006Coo`0D003oo`00YSfV7:Hm
YQbV?JHLYSfV7:HmYQbV?JHLYSfV7000[Qbf?080000@[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^7000_Q^n
>khK_S/20000C[hK_S^n6khk_Q^n>khK_S^n6khk0036>/HIaS[66LHjaQT00<HIaS[66LHjaQW6>/HI
aS[66LHjaQT00<gH003=f<ghcMS=n<gHcOS=f<ghcMS=n<gH003=f<ghcMS=n<gHcOS=f000eQSF>000
eOOEemGgeMOEmmGGeOOEe`00eIKE]]FFeKKEU]FfeIKE]P00eGGEEMEeeEGEM@8001ooo`<0000AI1YT
6f@JI1]T6V@KI1X009DKUCb=6iDlUA^E?8dKUCbE6`04000Mool00`00ooooo`02ool00`00ooooo`07
ool006Goo`0@003oo`00002V?:hmYSb^?JHl[SfV?:hmYSb^?JHl[Sd300004;Hl[Sbf?:hl]Sb^?;Hl
[Sbf?:hl]Sb^?;Hl[S`00;hj0P00016n>kHk_S^f>[hk]S^n>kHj_S^f>khk]SZn>`00aS[5nLhj0080
000VaOW>>/GiaS[5nLhjaOW6>/GicS[5nLHjaOT00<gheSS=n=HicOSF><gheSW=n=HhcOP00<gheOS=
mmGhcOSEn<ggeOS=n000cOL000OEm`0B003EU]FfeIKM]]FFeKKEU]ffeIH00=EDeGGEEMEeeECEM@00
8_oo1P0000ET>`00UCb=6iDl00H002;oo`05003oooooool00009ool006Koo`0;003ooooo002V7:Hm
YQbV?JHLYSfV70040000<jHmYQ`00:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^7000_Q^n>khK
_S^n6khk_Q^n>khK_S^n6khk_Q^n>khK_S/00<Hj0036>/HIaS[66LHjaQW6>/HIaS[66LHjaQW6>P02
0000</GI003=f<ghcMS=n<gHcOS=f<ghcMP00<gHcOS=f<ghcMS=n<gHcOS=f<ghcMP00=GGeOOEemGg
eMOEmmGGeOL00=FfeIKE]]FFeKKEU]FfeIH00=EEeGGEEMEeeEGEMMEE000Xool5000Yool01000oooo
o`002Ooo001Wool200001?oo002V?:hm100001BUo:HmYOb^?JGlYSfUo000[Sbf?:hl]Sb^?;Hl[Sbf
?:hl]Sb^?;Hl0P0003b^?000]S^n>kHj_S^f>khk]SZn>kHk_S^f>[hk]S^n>kHj_S/00<HjaOW>>/Gi
aS[5nLhjaOW6>/GicS[5nLHj003>>/GiaS[5n@00cOSF><gheSW=n=HhcOP00<gheOS=mmGhcOSEn<gg
eOS=n=GhcOL00<gg0006eOL04P00eKKEU]ffeIKE]]FFgKKEU]Ff003EMMEEeGGEE=EeeED005Ooo`04
003ooooo0009ool006Woo`0@003oo`00002V?JHMYSfV7:HmYQfV?JHLYSfV7JHmYQ`200002:hl[Qb^
?:hL[Sb^7:hl[Q`200004Zhl[Qb^?:hL002n6khk_Q^n>khK_S^n6khk_Q^n>khK_S^n6`800012_S/0
0<HjaQW6>/HIaS[66LHjaQW6>/HIaSX00<HjaMW6>/GIaS[5f@00cMS=n<gHcOS=f000cMS=n<gHcOS=
f<ghcMS=n<gHcOS=f000cMO=n000eOOEemGgeMOEmmGG003EU]FfeIKE]]FFeKKEU]Ff003EMMEEeGGE
EMEeeEGEM@00F?oo00<00?oo00002Ooo001Zool05`00ool00:Gl[SfUo:HmYOb^?JGlYSfUo:hmYObV
?JGl[Sd00;Hl[Sbf?:hl]S`00P000jhl00n^?Jhl[Sb^?000]S^n>kHj_S^f>khk]SZn>kHk_S/00P00
00ff>khk]S^n?000aS[5nLhjaOW6>/GicS[5n@0200007/hjaOW6>/GicS[5nLHj003F>LgheSS=n=Hi
003En<ggeOS=n=GhcOOEn<gheOS=m`00cOOEn<ggeOP000CEm`0C003EU]ffeIKE]]FFgKKEU]FfeIH0
0=EEeGGEE=EeeEGEMMED0000FOoo00<00?oo00002?oo001[ool05000ool00:HLYSfV7JHmYQbV?JHM
YSfV7:HmYQfV?JHLYSd00:hl[Q`200004Zhl[Qb^?:hL[Sb^7:hl[Qb^?:hL002n6khk_Q^n>khK_S^n
6`800015_S^f6khk]Q^n>kHK_S/00<HjaQW6>/HIaS[66@00aMW6>/GIaS[5fLHjaMW6>/GIaSX00<gh
cMS=n000cOS=f<ghcMS=n<gHcOS=f<ghcMS=n000cOS=emGhcMO=n000eOOEemGg003E]]FFeKKEU]Ff
eIKE]]FF003EEMEeeEGEMMEEeGGEE@0005_oo`8000Soo`00K?oo01000?oo00000:hmYObV?JGl[SfU
o:HmYOb^?JGlYSfUo0<00003[Sb^?Jhl00:^?005[Sf^?:hl[Sb^?@03[S`01@00]S^n>kHj_S/00P00
04Nf>khl]S^n>kHk_Sbf>khk]S^n?000aS[5nLhjaOT00<GicS[5nLHjaOW>>/GiaS[5nLhjaOW6>P00
eST00=GhcOOEn<gheOS=mmGhcOSEn<ggeOP00=GhcOOEn<ggeOS=mmGh003Em`00gKKEU]FfeIKM]]FF
eKKEU]ff003EMMEDeGGEEMEeeECEM@0005_oo`8000Soo`00KOoo0P0000Woo`00YSfV7JHmYQbV?JHM
YSd0100001>V7:Hm002^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL002n6`0200003khk]Q^n>kHK
_S^f6khk]Q^n>kHK_S^f6khk0036>P020000=lGIaS[5fLHjaMW6>/GIaS[5fLHjaMW6>/GIaSX00<gh
cMS=n<gHcOS=f<ghcMS=n<gHcOP00<ghcMOEn<gGcOS=emGhcML00=GG003EU]FfeIKE]]FFeKKEU]Ff
003EMMEEeGGEEMEeeEGEM@0005coo`8000Soo`00Kooo00D00?oo002^?JGl00@00008YSfUo:HmYObV
?JGlYSd000:^?005[Sf^?:hl[Sb^?@03[S`00jhm[Sb^?00200007kHk_S^f>khl]S^n>kHk_Sbf>khk
]S^n?;Hk_S^f>khl0036>/GicS[5nLHjaOW>>/GiaS[5nLhjaOW6>/Gi0080000YaSX00=GhcOSEn<gg
eOS=n=GhcOOEn000eOS=mmGhcOOEn<ggeOS=mmGhcOL00=FFeKKEU]ffeIKE]]FFgKKEUP00eECEMMEE
eGGEE=EeeED0001Hool4000:ool0073oo`0@003oo`00002V7JHmYQbV?JHMYSfV7:HmYQfV?JHLYSd2
00002JhL[Sb^7:hl[Qb^?:hL[Sb^700200004:hl[Q`00;HK_S^f6khk]Q^n>kHK_S^f6khk]Q^n>kHK
0P0003Zf>`00aS[5fLHjaMW6>/GIaS[5fLHjaMW6>/GI0035fLHjaM[6>P00cOS=f<ghcMS=n<gHcOP0
0<ghcMOEn<gGcOS=emGhcMO=n<gG003=e`00eIKE]]FFeKKEU]FfeIH00=EEeGGEEMEeeEGEMMEEeGD0
05Coo`@000koo`00LOoo01@00?oo002V?JGlYSfUo:HmYObV?JGlYSfUo:HmYObV?JGl002^?:hm0jhl
0`00012V?:hmYSb^?JHl002f>khk]S^n?;Hk_S^f>khl]S^n>`80000k]S^f?;Hk_S`00<HjaOW>>/Gi
aS[5nLhjaOW6>/Gi0035nLHj_OW6>/GiaSX00=GhcOSEn<ggeOP00=GhcOOEn<ggeOS=mmGhcOOEn<gg
003=mmGhcOL00=FFeKKEU]ffeIKE]P00eGGEEMEeeECEMMEEeGD0001Aool4000Bool007;oo`<0000A
YSfV7JHmYQbV?JHMYSfV7:HmYQfV?JHLYSfV7@00[Qb^?00200002JhL[Sb^7:hl[Qb^?:hL[Sb^7002
00005khk]Q^n>kHK_S^f6khk002f?;HK]S^f6kHl]Q^f>`00aS[5fLHjaMW6>/GIaSX00P0002c5fLHj
aM[6>/GIaS[5fP00cMS=n<gHcOS=f000cMOEn<gGcOS=emGhcMO=n<gGeOP00<ggcMOEn000eKKEU]Ff
eIKE]P00eGGEEMEeeEGEMMEEeGGEE@00C_oo0`005_oo001dool300003:GlYSfUo:HmYObV?JGlYSfU
o:HmYObV?@<0000B[SfV?:hmYSb^?JHl[SfV?:hmYSb^?JHl[Sd00;hk]S^n?;Hk0P0003jn?;Hk]Sbf
>khl]S^f?;Hk0035nLHjaOW>>/GiaSX00<HjaOW6>[giaS[5nLHj_OW6>/Gi003=mmGhcOP00<ggeOS=
mmGhcOOEn<ggeOS=mmGh003En<ggeOS=mmGh003M]]FFeKKEUP00eEGEMMEDeGGEEMEeeECEM@00B_oo
10006Ooo001eool02P00ool00:HMYSfV7:HmYQfV?JHL100001>V?JHM002^7:hl[Qb^?:hL[Sb^7:hl
[Qb^?:hL[Sb^7:hl002n>`020000?kHK]Sbf6kHk]Q^f?;HK]S^f6kHl]Q/00<GIaS[5fLHj0036>/GI
aS[5f/HjaMW6>/GJaS[5fLHjaMX00<gH003=emGhcMO=n<gGeOS=elghcMOEn000cOO=emGhcMO=mlgG
eOP00=FfeIH00=EEeGGEEMEeeEGEMMEEeGD00017ool4000Mool007Koo`05003oo`00YObV?@040000
5IglYSfUo:HmWObV?JGl002V?:hmYSb^?JHl[SfV?:hmYSb^?JHl[SfV?00200004;Hl]S^n?;Hk]Sbf
>khl]S^f?;Hk_Sbf>kHl]S/00<Gi0P0002o6>/GiaSZmnLHjaOW6>[giaS[5nLHj_OW6>/Gi003=mmGh
cOOEn<ggeOS=mmGhcOOEn000eOS=mmGhcOOEn<ggeOS=mmGh003M]P00eGGEE=EeeEGEMMEDeGGEE@00
04?oo`@0027oo`00Mooo100000bV?JHMYSfV7JHmYQfV?JHMYSfV7JHmYQd200001jhl[Qb^?:hL[Sb^
7:hl00@0000PYQbV?@00]Sbf6kHk]Q^f?;HK]S^f6kHl]Q^f>kHK]Sbf6`00aM[6>/GIaS[5f/HjaMW6
>/GJaS[5fLHjaM[6>P80000EaQX00<gGcOS=emGhcMO=n<gGeOS=e`00cMOEn<gGcOO=emGhcMO=mlgG
00800009eGGEEMEeeEGEMMEEeGGEE@00043oo`@002Goo`00NOoo0`00012V?IglYSfUo:HmWObV?JGl
YSfMo:HmYObV?@00[SfV?0@0000C[SfV?:hmYSb^?JHl[Sd00;Hl]S^n?;Hk]Sbf>khl]S^f?;Hk_S`0
0P00036^>`00aOW6>[giaS[5nLHj_OW6>/GiaSZmnLHj0036>[gjaS^mnP00cOOEn<ggeOS=mmGhcOL0
0<ggeOS=mmGhcOOEn<ggeOS=mmGhcOL00=EDeGGEEMEeeECEMMEEeGD0000mool3000Yool007[oo`0?
003oo`00YSfV7JHmYQfV?JHMYSfV7JHmYQfV?JHM00<0000EYQb^?JHLYSfV7:hmYQbV?JHL[SfV7:Hm
002f?;HK]S^f6kHl]Q^f>kHK0080000X]Sbf7;Hl[Q`00<GJaS[5fLHjaM[6>/GIaS[5f/Hj0036>/HJ
aSZn6/HjaQX00<gGcOS=emGhcML00<gGeOS=elggcMOEn<gGcOO=emGhcML200002MEeeEGEMMEEeGGE
EMEeeED0000iool4000/ool007_oo`0;003oo`00YSfMo:HmYObV?IglYSfUo00300005YglYSd00:hm
YSb^?JHl[SfV?:hmYSb^?JHl[SfV?:hm002f?;Hk_Sbf>kHl0P0000N^>kHl[S^f?:hk]Sb^>`020000
1/Hj_OW6>/GiaSZmn@80000SaSZmn/Hk_O[6>[gjaS/00=GhcOOEn<gg003=mmGhcOOEn<ggeOS=mmGh
cOOEn<gg003=mmGh003EMMEDeGGEEMEeeE@0000fool4000`ool007coo`@00003YQfV?@0000<0000G
YQfV?JHMYSfV7JHm002V?JHL[SfV7:HmYQb^?JHLYSfV7:hmYQbV?@00]Sbf6`020000=[Hl[Qbf?;HL
]Sb^7;Hl]Qbf?:hL]S`00<HjaMW6>/GJ002n6/HjaQ[6>[hJaS[66/Hj_Q[6>P00eOS=elgh003En<gG
cOO=emGhcMO=mlgGeOS=e`00cMS=n<gH003EEMEeeEGEMMEEeGD003;oo`@003Coo`00O_oo00l00?oo
00000:HmWObV?IglYSfMo:HmWObV?IglYSd00P0000^V?:hmYSb^?JHl[SfV?:hmYSb^?JHl00<0000@
[S^f?:hk]Sb^>kHl[S^f?:hk]Sb^>kHl[S^f?000aSX200009[gjaSZmn/Hk_O[6>[gjaS^mn/Hj_O[6
>`00eOP00=GhcOOEn<ggeOS=mmGhcOOEn<gg003=mmGhcOSEn<gg003EEMEeeECEMMEE000_ool3000h
ool007ooo`0H003oo`00YQfV?JHMYSfV7JHmYQfV?JHMYSfV7JHmYQd00:HL[SfV7:HmYQb^?JHL0`00
016V7:Hm002f?:hL]Sbf7;Hl[Qbf?;HL]Sb^7;Hl]Qbf?:hL0080000WaSZn6/HjaQ[6>[hJaS[66/Hj
_Q[6>/HJaSZn6/Hj003En<gGcOO=emGhcMO=mlgGeOS=e`00cMS=n<gHcOS=f<gh003EMMEEeGGEE@00
02coo`@003_oo`00P?oo01<00?oo002Mo:HmWObV?IglYSfMo:HmWObV?IglYSfMo000YSb^?@040000
4JGlYSfUo:HmYObV?@00]Sb^>kHl[S^f?:hk]Sb^>kHl[S/00`0000nV?:hm0036>[gjaS^mn/Hj_O[6
>kgjaSZmn/Hk_OX00P0001Rn>`00eOS=mmGhcOOEn<ggeOS=m`00cOOEn<gheOS=mmGhcOSEn000eGGE
EMEe000Xool4000oool0087oo`0?003oo`00002V?JHMYSfV7JHmYQfV?JHMYSfV7JHm00<0000;YSfV
7:HmYQfV?JHLYSfV7JHmYQbV?@0200001ZhL]Sbf7;Hl[Qbf?080000@[Qb^?:hL[Sb^7:hl0036>[hJ
aS[66/Hj_Q[6>/HJaSX200006KhK_S^n6`00cMOEn<gGcOO=emGhcMO=m`00cOS=f<ghcMS=n<gHcOS=
f000eEGEM@0002Goo`@004?oo`00P_oo0P0000Woo`00YSfMo:HmWObV?IglYSd00`0001>V?Igl002U
o:HmYObV?JGlYSfUo:HmYObV?JGlYSfUo000[S^f?00300001Jhm[Sb^?:Hl[Sd00Zhl00VV?:hm0036
>[gjaS^mn/Hj_OX00P0000>n>kHj_S/00[hk01Jf>P00cOOEn<ggeOS=mmGh003En<gheOS=mmGhcOSE
n<ggeOS=n000eE@0027oo`@004Ooo`00Q?oo00D00?oo002V?JHM00@0000CYSfN7JHmYQfV?IhM002V
7JHmYQbV?JHMYSfV7:HmYQfV?JHLYSd00`00016^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl[Q`00<HJaSZn
6/Hj0080000M_Q^n>khK_S^n6khk_Q^n>khK003=emGhcMO=m`00cOS=f<ghcMS=n<gHcOS=f<ghcMS=
n000eGD0000Nool3001;ool008Goo`0?003oo`00002Mo:HmWObV?IglYSfMo:HmWObV?Igl00800007
YSfUo:HmYObV?JGlYSd00`0000FV?Igl002V?:hm00:^?006YSb^?Jhl[SbV?:hm0Zhl00>V?000_OX0
0P000khk00Ff>[hk_S^n>kHj00>n>`0C]SX00<ggeOP00=GhcOSEn<ggeOS=n=GhcOOEn<gheOS=mmGh
00006ooo1000C_oo0026ool04`00ool00:HmYQfV?IhMYSfV7JHmWQfV?JHMYSfN7JHm002V?JHL00@0
000CYSfV7JHmYQfV?JHM002^7:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL[S`00P00022n6khk_Q^n>khK_S^n
6khk_Q^n>khK_S^n6khk003=m`00cOS=f<ghcMS=n<gHcOS=f<ghcMS=n<gHcOS=f0005ooo1000D_oo
0027ool300003:HmWObV?IglYSfMo:HmWObV?IglYSfMo0<0000;WObV?IglYSfMo:HmWObV?IglYSfM
o00200001Jhm[Sb^?:Hl[Sd00Zhl0`0000>^?JHl00000[hk00Ff>[hk_S^n>kHj00>n>`0D]SZn>khk
_S/00=GhcOSEn<ggeOS=n=GhcOOEn<gheOS=mmGhcOP001Coo`@005Koo`00ROoo0`0000NV7JHmWQfV
?JHMYSfN7@0300004ihMYSd00:HmYQfV?JHMYSfV7JHmYQfV?JHMYSfV7JHm002^?:hL00@0000BYSfV
7:HmYQbV?JHL002n6khk_Q^n>khK_S^n6khk_Q^n>khK0P0000ff?000cOS=f<ghcMS=n<gHcOS=f<gh
cMS=n002000Bool3001Jool008[oo`05003oo`00WObV?@0400004iglYSfMoJHmWObV?@00YSfMo:Hm
WObV?IglYSfMo:HmWObV?Igl00<0000<YSb^?JHl[SfV?:hmYSb^?JHl[SfV?0000[hk00Jf>[hk_S^n
>kHj_S/200003jhk]Sb^?;Hl003En<gheOS=mmGhcOSEn<ggeOP0000@ool4001Mool008_oo`0?003o
o`00002V?IhMYSfV7JHmWQfV?JHMYSfN7JHm00800007YQfV?JHMYSfV7JHmYQd00`0001FV7JHm002V
?JHLYSfV7:HmYQbV?JHLYSfV7:HmYQ`00;hK_S^n6khk_Q/00P00012^?:hL]Sb^7:hl[Qbf?000cOS=
f<ghcMS=n<gHcOP000goo`@0067oo`00S?oo0`00012MoJHmWObV?IgmYSfMo:HmWOfV?IglYSfMo@00
WObV?@@0000DWObV?IglYSfMo:Hm002^?JHl[SfV?:hmYSb^?JHl[SfV?:hmYS`000:n>`80000A[Sbf
?:hk]Sb^?;Hl[S^f?:hl003=mmGhcOSEn<ggeOP0000:ool4001Uool008koo`80000<YQfV?IhMYSfV
7JHmWQfV?JHMYSfN7JHm0`0000^V?JHMYSfN7JHmYQfV?IhMYSfV7JHm00800009YQbV?JHLYSfV7:Hm
YQbV?JHL00@0000@]Sb^7:hl[Qbf?:hL[Sb^7;Hl[Qb^?:hL003=f<ghcMP20007ool4001Yool008oo
o`<00007YSfMo:HmWOfV?IglYSd00`0001BV?Igm002Mo:HmWObV?IglYSfMo:HmWObV?IglYSfMo000
YSb^?JHl1@0001BMo:HmWO`00:hl]Sb^>kHl[Sbf?:hk]Sb^?;Hl[S^f?:hl003=m`001_oo0`00KOoo
002@ool01@00ool00:HmWQd0100001>V?JHMYSfN7JHmYQd009hMYSfV7JHmWQfV?JHMYSfN7JHmYQfV
?@0400005ZHMYSfV7JHmYQfV?JHMYSfV7@00[Qbf?:hL[Sb^7;Hl[Qb^?:hL]Sb^7:hl0P000ooo1000
L?oo002Aool400002iglYSfMoJHmWObV?IgmYSfMo:HmWOd00P0000NV?IglYSfMo:HmWObV?@030000
3ZHmWO`009glYSfMo:HmWObV?IglYSfMo:HmWO`200001kHl[S^f?:hl]Sb^>kHl00<00003ool00000
008007Coo`00Tooo0P00012V?IhMYSfV7JHmWQfV?JHMYSfN7JHmYQfV?@00YSfV7@@0000FYSfN7JHm
YQfV?IhM002V7JHmYQfV?JHMYSfV7JHmYQfV?JHMYSd00;Hl[Q`8001hool009Coo`80000<YSfMo:Hm
WOfV?IglYSfMoJHmWObV?Igm0`0000^MoJHmWObV?IgmYSfMo:HmWOfV?Igl00800009YSfMo:HmWObV
?IglYSfMo:Hm00@00004ool00000001lool009Goo`<00007WQfV?JHMYSfN7JHmYQd00`0001BV7JHm
002V?JHMYSfN7JHmYQfV?IhMYSfV7JHmWQfV?@00YSfV7JHm1@0000?oo`0000000P00Oooo002Fool0
1@00ool009glYSd0100001>MoJHmWObV?IgmYSd00:HmWOfV?IglYSfMoJHmWObV?IgmYSfMo0040002
ool40023ool009Ooo`@0000;YSfV7JHmWQfV?JHMYSfN7JHmYQfV?@0200001jHMYSfN7JHmYQfV?IhM
00<000;oo`@008Ooo`00VOoo0`0000nV?IgmYSfMo:HmWOfV?IglYSfMoJHmWO`009gmYSd0100000?o
o`0000000P00Rooo002Jool03@00ool00:HmYQfV?IhMYSfV7JHmWQfV?JHM00@000;oo`<008ooo`00
Vooo00L00?oo000009gmYSfMo0050002ool4002Bool009coo`800004ool000000003ool4002Fool0
09koo`800003ool00000008009[oo`00Wooo0P00W_oo003ooom0ool00?oood3oo`00oooo@?oo003o
oom0ool00?oood3oo`00oooo@?oo003ooom0ool00?oood3oo`00oooo@?oo003ooom0ool00?oood3o
o`00oooo@?oo003ooom0ool00?oood3oo`00oooo@?oo003ooom0ool00?oood3oo`00oooo@?oo003o
oom0ool00?oood3oo`00oooo@?oo003ooom0ool00?oood3oo`00\
\>"],
  ImageRangeCache->{{{0, 318.75}, {258.312, 0}} -> {-0.226667, -0.0535437, \
0.00379738, 0.00379738}}]
}, Open  ]],

Cell[TextData[{
  "Here is the analytical expression for the gamma of the put option ",
  StyleBox["xyzft", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.30"],

Cell[CellGroupData[{

Cell["Gamma[xyzft, settlement, r]", "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(E\^\(\(-\(1\/2\)\)\ \((2\/\(5\ \@3\) + \@3\/20)\)\^2\)\/\(4\ \@\(6\ \
\[Pi]\)\)\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell["This is a numerical approximation. ", "MathCaption",
  CellTags->"0.31"],

Cell[CellGroupData[{

Cell["N[%]", "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(0.0547512157350708772`\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[TextData[{
  "We define the gamma of the option ",
  StyleBox["abcft", "MB"],
  " as a function of two variables, ",
  StyleBox["x", "MB"],
  " and ",
  StyleBox["t", "MB"],
  ", the price of the underlying asset and the time to maturity, \
respectively. "
}], "MathCaption",
  CellTags->"0.32"],

Cell["\<\
optiongamma[x_, t_] = Gamma[abcft,
   ToCalendar[ToJulian[settlement] + Floor[t]], r] /.
   Price[ABC] -> x;\
\>", "Input",
  CellLabel->"In[27]:="],

Cell["\<\
This illustrates how the graph of the option gamma changes as the \
time to maturity varies. \
\>", "MathCaption",
  CellTags->"0.33"],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Table[optiongamma[x, j],
   {j, 0, 110, 10}]], {x, 25, 45},
   PlotLabel ->
      \"    Call Option Gamma\\nfor Different Maturities\",
   FrameLabel -> {\"Stock Price\", \"\"}];\
\>", "Input",
  CellLabel->"In[28]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.16667 0.0476191 0.0147151 3.05007 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -35 -24 ]
[.5 -0.0125 35 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16722 -24 -4.5 ]
[-0.0125 .16722 0 4.5 ]
[-0.0125 .31972 -18 -4.5 ]
[-0.0125 .31972 0 4.5 ]
[-0.0125 .47223 -24 -4.5 ]
[-0.0125 .47223 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74 0 ]
[.5 .63053 74 31 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(25)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(30)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(35)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(40)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(45)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -96 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .16722 m
.00625 .16722 L
s
[(0.05)] -0.0125 .16722 1 0 Mshowa
0 .31972 m
.00625 .31972 L
s
[(0.1)] -0.0125 .31972 1 0 Mshowa
0 .47223 m
.00625 .47223 L
s
[(0.15)] -0.0125 .47223 1 0 Mshowa
.125 Mabswid
0 .04522 m
.00375 .04522 L
s
0 .07572 m
.00375 .07572 L
s
0 .10622 m
.00375 .10622 L
s
0 .13672 m
.00375 .13672 L
s
0 .19772 m
.00375 .19772 L
s
0 .22822 m
.00375 .22822 L
s
0 .25872 m
.00375 .25872 L
s
0 .28922 m
.00375 .28922 L
s
0 .35022 m
.00375 .35022 L
s
0 .38072 m
.00375 .38072 L
s
0 .41122 m
.00375 .41122 L
s
0 .44173 m
.00375 .44173 L
s
0 .50273 m
.00375 .50273 L
s
0 .53323 m
.00375 .53323 L
s
0 .56373 m
.00375 .56373 L
s
0 .59423 m
.00375 .59423 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16722 m
1 .16722 L
s
.99375 .31972 m
1 .31972 L
s
.99375 .47223 m
1 .47223 L
s
.125 Mabswid
.99625 .04522 m
1 .04522 L
s
.99625 .07572 m
1 .07572 L
s
.99625 .10622 m
1 .10622 L
s
.99625 .13672 m
1 .13672 L
s
.99625 .19772 m
1 .19772 L
s
.99625 .22822 m
1 .22822 L
s
.99625 .25872 m
1 .25872 L
s
.99625 .28922 m
1 .28922 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .38072 m
1 .38072 L
s
.99625 .41122 m
1 .41122 L
s
.99625 .44173 m
1 .44173 L
s
.99625 .50273 m
1 .50273 L
s
.99625 .53323 m
1 .53323 L
s
.99625 .56373 m
1 .56373 L
s
.99625 .59423 m
1 .59423 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Call) show
117.000000 15.000000 moveto
(Option) show
159.000000 15.000000 moveto
(Gamma) show
63.000000 31.000000 moveto
(for) show
87.000000 31.000000 moveto
(Different) show
147.000000 31.000000 moveto
(Maturities) show
207.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.02381 .03023 m
.06244 .03779 L
.10458 .04852 L
.14415 .06099 L
.18221 .075 L
.22272 .09171 L
.26171 .10896 L
.30316 .12776 L
.34309 .14547 L
.3815 .16132 L
.42237 .17614 L
.46172 .18778 L
.49955 .19612 L
.51896 .19924 L
.53984 .20168 L
.54994 .20252 L
.55528 .20288 L
.56097 .20319 L
.56644 .20342 L
.57139 .20358 L
.57378 .20364 L
.57637 .20369 L
.57756 .2037 L
.57882 .20372 L
.57989 .20373 L
.58106 .20374 L
.58237 .20375 L
.58357 .20375 L
.5842 .20375 L
.5849 .20375 L
.58562 .20375 L
.5863 .20374 L
.58755 .20374 L
.58869 .20373 L
.58995 .20371 L
.59127 .2037 L
.59357 .20366 L
.59571 .20361 L
.60057 .20347 L
.60587 .20326 L
.61069 .20303 L
.62149 .20234 L
.63147 .2015 L
.64067 .20056 L
.66147 .1979 L
.70087 .19096 L
.73876 .1823 L
.7791 .17144 L
.81792 .15988 L
.8592 .14687 L
Mistroke
.89896 .13409 L
.93721 .12191 L
.97619 .10988 L
Mfstroke
.02381 .02636 m
.06244 .03281 L
.10458 .04238 L
.14415 .05398 L
.18221 .06749 L
.22272 .08414 L
.26171 .10188 L
.30316 .12177 L
.34309 .14103 L
.3815 .15874 L
.42237 .17574 L
.46172 .18953 L
.49955 .19982 L
.51896 .20384 L
.53984 .20717 L
.54994 .20841 L
.56097 .20948 L
.56602 .20987 L
.57139 .21022 L
.57609 .21047 L
.58106 .21068 L
.58362 .21076 L
.58642 .21084 L
.58897 .21089 L
.59011 .21091 L
.59135 .21092 L
.5921 .21093 L
.59279 .21094 L
.59344 .21094 L
.59416 .21095 L
.5954 .21095 L
.59672 .21095 L
.59746 .21095 L
.59815 .21095 L
.5989 .21094 L
.59969 .21094 L
.60102 .21093 L
.60248 .21091 L
.60512 .21086 L
.60753 .21081 L
.61292 .21064 L
.61792 .21042 L
.62265 .21016 L
.63237 .20949 L
.64266 .20855 L
.66111 .20633 L
.68069 .20325 L
.699 .19977 L
.73782 .19066 L
.7791 .17892 L
Mistroke
.81886 .1662 L
.85711 .1532 L
.8978 .13904 L
.93699 .12551 L
.97619 .11242 L
Mfstroke
.02381 .02293 m
.04262 .02523 L
.06244 .02816 L
.10458 .03637 L
.14264 .04635 L
.18314 .05982 L
.22214 .07548 L
.26358 .09458 L
.30351 .11466 L
.34193 .13467 L
.38279 .1556 L
.42214 .17432 L
.45998 .19006 L
.50027 .20355 L
.5188 .20845 L
.53904 .21277 L
.55 .21466 L
.56017 .21612 L
.56982 .21725 L
.58026 .21819 L
.58577 .21857 L
.59083 .21884 L
.59567 .21904 L
.59811 .21911 L
.60079 .21918 L
.60203 .2192 L
.60322 .21922 L
.60429 .21923 L
.60543 .21925 L
.60667 .21925 L
.60781 .21926 L
.60905 .21926 L
.60975 .21926 L
.61041 .21926 L
.61151 .21925 L
.61266 .21924 L
.61365 .21923 L
.61473 .21921 L
.61715 .21917 L
.61939 .21911 L
.62444 .21894 L
.62992 .21868 L
.63985 .21801 L
.64952 .21714 L
.65844 .21614 L
.6772 .21344 L
.69784 .2096 L
.73818 .19983 L
.77701 .18811 L
.81828 .17389 L
Mistroke
.85804 .15917 L
.89629 .14463 L
.93699 .12928 L
.97617 .11502 L
.97619 .11501 L
Mfstroke
.02381 .02004 m
.04262 .02176 L
.06244 .02402 L
.08426 .02712 L
.10458 .03067 L
.14264 .03924 L
.18163 .05091 L
.22307 .06665 L
.263 .08488 L
.30142 .10474 L
.34228 .12744 L
.38164 .1497 L
.41947 .17031 L
.45976 .19016 L
.49853 .20614 L
.51824 .21281 L
.53975 .21884 L
.56035 .22333 L
.57946 .22633 L
.59003 .22751 L
.59522 .22796 L
.59999 .2283 L
.60425 .22854 L
.60892 .22875 L
.61136 .22883 L
.61363 .22889 L
.61486 .22891 L
.61602 .22893 L
.61737 .22895 L
.61859 .22896 L
.61973 .22897 L
.62096 .22897 L
.62212 .22897 L
.62318 .22897 L
.62436 .22896 L
.62565 .22894 L
.62699 .22892 L
.62825 .2289 L
.63084 .22883 L
.63321 .22875 L
.6385 .22852 L
.64305 .22826 L
.64798 .22791 L
.65692 .22709 L
.66639 .22599 L
.6768 .22451 L
.69784 .22068 L
.73818 .21054 L
.77701 .19798 L
.81828 .18247 L
Mistroke
.85804 .16628 L
.89629 .15023 L
.93699 .13329 L
.97617 .11761 L
.97619 .1176 L
Mfstroke
.02381 .0178 m
.04262 .01896 L
.06244 .02055 L
.08255 .02262 L
.10458 .02553 L
.12579 .02906 L
.14509 .03296 L
.18408 .04316 L
.22401 .05711 L
.26243 .07395 L
.30329 .09522 L
.34264 .11822 L
.38048 .14161 L
.42077 .16648 L
.45954 .1889 L
.50076 .20956 L
.52135 .21821 L
.54047 .22508 L
.56014 .23089 L
.57866 .23514 L
.58852 .2369 L
.59919 .23841 L
.6039 .23895 L
.60888 .23943 L
.61346 .2398 L
.61779 .24007 L
.62017 .2402 L
.62275 .24031 L
.6249 .24038 L
.62727 .24044 L
.62859 .24047 L
.62983 .24049 L
.63114 .2405 L
.63187 .24051 L
.63255 .24051 L
.63368 .24051 L
.63493 .24051 L
.63622 .2405 L
.63743 .24049 L
.63858 .24047 L
.63982 .24045 L
.64208 .24039 L
.64427 .24031 L
.6463 .24023 L
.65089 .23999 L
.65576 .23966 L
.6652 .2388 L
.67534 .23755 L
.69365 .23449 L
.71483 .22973 L
Mistroke
.73493 .22413 L
.77317 .21101 L
.81387 .19436 L
.85305 .17669 L
.89469 .15719 L
.93481 .13853 L
.97341 .12131 L
.97619 .12011 L
Mfstroke
.02381 .01623 m
.04262 .01691 L
.06244 .01789 L
.08255 .01924 L
.10458 .02122 L
.12415 .02353 L
.14509 .02668 L
.16496 .03043 L
.18653 .03543 L
.22646 .04763 L
.26733 .06441 L
.30668 .08471 L
.34452 .10759 L
.3848 .13449 L
.42358 .1614 L
.4648 .18915 L
.50451 .2131 L
.5427 .23193 L
.56402 .24019 L
.58335 .24612 L
.59303 .24851 L
.6035 .25065 L
.61338 .25224 L
.62248 .25333 L
.62718 .25375 L
.62976 .25394 L
.63221 .2541 L
.63449 .25422 L
.63697 .25433 L
.63922 .25441 L
.6413 .25446 L
.64248 .25448 L
.64376 .2545 L
.64496 .25451 L
.64606 .25451 L
.64729 .25451 L
.64798 .2545 L
.64862 .2545 L
.64993 .25448 L
.65066 .25447 L
.65132 .25446 L
.65395 .25439 L
.6568 .25428 L
.65948 .25414 L
.66196 .25399 L
.66664 .25365 L
.67166 .25318 L
.68073 .25207 L
.69151 .25036 L
.70137 .24841 L
Mistroke
.74113 .23726 L
.77937 .22235 L
.82007 .20329 L
.85925 .18307 L
.90089 .16088 L
.94101 .13986 L
.97619 .12234 L
Mfstroke
.02381 .0153 m
.03279 .01543 L
.04262 .01562 L
.06244 .01611 L
.07298 .01646 L
.08426 .01691 L
.10458 .01799 L
.12589 .01956 L
.14603 .02157 L
.166 .0242 L
.18444 .02728 L
.20476 .03155 L
.22379 .03647 L
.26163 .04928 L
.3004 .06702 L
.34162 .09107 L
.38133 .11863 L
.41952 .1479 L
.46017 .17996 L
.4993 .20936 L
.54088 .23639 L
.56175 .24756 L
.58095 .25614 L
.59969 .26281 L
.60925 .26552 L
.6195 .2679 L
.62977 .26974 L
.63914 .27093 L
.64365 .27134 L
.64602 .27152 L
.64855 .27167 L
.65075 .27177 L
.65192 .27182 L
.65318 .27186 L
.65434 .27189 L
.65539 .27191 L
.6564 .27193 L
.65747 .27194 L
.6587 .27194 L
.6594 .27194 L
.66004 .27194 L
.66122 .27193 L
.66247 .27191 L
.66359 .27188 L
.66463 .27186 L
.66701 .27177 L
.66958 .27165 L
.67193 .2715 L
.67721 .27108 L
.68172 .27061 L
Mistroke
.68663 .26999 L
.69558 .26856 L
.71529 .26411 L
.73628 .25756 L
.77791 .23989 L
.81803 .21848 L
.85663 .19548 L
.89769 .17011 L
.93723 .14614 L
.97525 .12447 L
.97619 .12396 L
Mfstroke
.02381 .01487 m
.03279 .01491 L
.04262 .01497 L
.05288 .01505 L
.06244 .01515 L
.0828 .01545 L
.09421 .01568 L
.10458 .01595 L
.12373 .01661 L
.13453 .01711 L
.14451 .01766 L
.16324 .019 L
.18386 .02103 L
.20327 .02362 L
.22415 .02729 L
.24528 .03214 L
.26537 .03799 L
.30357 .05296 L
.34421 .07506 L
.38334 .10241 L
.42492 .13695 L
.46499 .17341 L
.50354 .2086 L
.54454 .24269 L
.56496 .2573 L
.58403 .26908 L
.60353 .27899 L
.622 .2862 L
.63175 .28912 L
.64235 .29157 L
.64703 .29241 L
.65199 .29314 L
.65623 .29364 L
.66091 .29404 L
.66326 .29419 L
.66583 .29431 L
.66712 .29436 L
.66784 .29437 L
.66851 .29439 L
.66982 .29441 L
.671 .29442 L
.67213 .29442 L
.67331 .29441 L
.67433 .2944 L
.67544 .29437 L
.67664 .29434 L
.67793 .29429 L
.68026 .29418 L
.68293 .294 L
.68585 .29376 L
Mistroke
.69116 .29318 L
.69632 .29244 L
.70111 .29161 L
.71171 .28928 L
.72168 .28648 L
.7403 .27981 L
.7789 .26074 L
.81995 .23471 L
.85949 .20646 L
.89752 .17842 L
.93799 .14948 L
.97619 .12429 L
Mfstroke
.02381 .01473 m
.03279 .01474 L
.04262 .01475 L
.05288 .01477 L
.06244 .01479 L
.0731 .01482 L
.0828 .01486 L
.094 .01492 L
.10458 .015 L
.11428 .01509 L
.12455 .01521 L
.13333 .01535 L
.14299 .01553 L
.1624 .01606 L
.17331 .01646 L
.18328 .01693 L
.20227 .01811 L
.21301 .01899 L
.22299 .01997 L
.24351 .02261 L
.26212 .02586 L
.28137 .0303 L
.30219 .03655 L
.32212 .0442 L
.34319 .05427 L
.38116 .0781 L
.42159 .11163 L
.46049 .15068 L
.50186 .19639 L
.5417 .24008 L
.58003 .27713 L
.59941 .29267 L
.62081 .30662 L
.63056 .31174 L
.64106 .31635 L
.65098 .31981 L
.66008 .3222 L
.66482 .32314 L
.66988 .32393 L
.67234 .32423 L
.67466 .32446 L
.67674 .32462 L
.679 .32475 L
.68029 .32481 L
.68149 .32485 L
.68281 .32488 L
.68356 .32488 L
.68423 .32489 L
.68494 .32489 L
.68559 .32488 L
Mistroke
.68631 .32487 L
.68708 .32486 L
.6878 .32484 L
.68849 .32482 L
.68977 .32476 L
.69226 .32462 L
.69455 .32443 L
.6997 .32385 L
.70442 .32312 L
.70946 .32213 L
.71857 .3198 L
.72939 .31617 L
.73924 .31207 L
.77914 .28888 L
.81752 .25895 L
.85836 .22267 L
.89767 .18675 L
.93548 .15381 L
.97573 .12227 L
.97619 .12194 L
Mfstroke
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03793 .01472 L
.04262 .01472 L
.0522 .01472 L
.05746 .01472 L
.06244 .01472 L
.06754 .01472 L
.07295 .01472 L
.08265 .01472 L
.08804 .01473 L
.09308 .01473 L
.09858 .01473 L
.10458 .01474 L
.10996 .01474 L
.11496 .01475 L
.12483 .01477 L
.13379 .01479 L
.14335 .01482 L
.15364 .01486 L
.16476 .01493 L
.17527 .01501 L
.18493 .01512 L
.19467 .01526 L
.20376 .01543 L
.21373 .01567 L
.22442 .016 L
.23459 .01641 L
.24566 .01698 L
.25611 .01767 L
.26578 .01846 L
.28445 .02051 L
.29507 .02206 L
.30505 .02381 L
.32523 .02842 L
.34374 .03417 L
.36266 .04187 L
.38336 .05276 L
.42392 .08276 L
.46297 .12317 L
.50446 .17681 L
.54445 .23401 L
.58291 .28723 L
.6024 .31112 L
.62383 .3336 L
.64419 .3504 L
.6533 .3563 L
.66323 .36151 L
.66863 .3638 L
Mistroke
.67364 .36558 L
.67883 .36706 L
.68352 .36809 L
.68575 .36847 L
.68815 .36881 L
.69042 .36906 L
.6925 .36922 L
.69365 .36929 L
.69472 .36934 L
.69589 .36937 L
.69715 .36938 L
.69847 .36938 L
.69972 .36935 L
.70084 .36931 L
.70206 .36924 L
.70328 .36915 L
.7044 .36906 L
.70692 .36878 L
.70915 .36847 L
.71148 .36807 L
.71645 .36699 L
.72187 .36545 L
.73277 .36126 L
.74289 .35611 L
.76339 .34232 L
.78199 .3264 L
.82202 .28419 L
.86054 .23823 L
.90151 .1894 L
.94097 .1466 L
.97619 .11389 L
Mfstroke
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.04262 .01472 L
.04518 .01472 L
.04795 .01472 L
.053 .01472 L
.05791 .01472 L
.06244 .01472 L
.06747 .01472 L
.07218 .01472 L
.07734 .01472 L
.0829 .01472 L
.0887 .01472 L
.09422 .01472 L
.09917 .01472 L
.10458 .01472 L
.10989 .01472 L
.1149 .01472 L
.11939 .01472 L
.12425 .01472 L
.12956 .01472 L
.13518 .01472 L
.13997 .01472 L
.14523 .01472 L
.15047 .01472 L
.15543 .01472 L
.16473 .01472 L
.16994 .01472 L
.17475 .01472 L
.18004 .01472 L
.18565 .01473 L
.19502 .01473 L
.20029 .01474 L
.20512 .01475 L
.21403 .01476 L
.2185 .01477 L
.2234 .01478 L
.22869 .0148 L
.23367 .01482 L
.24301 .01487 L
.25306 .01494 L
.25873 .01499 L
.26396 .01505 L
.27365 .0152 L
.28272 .01538 L
.29267 .01564 L
.30336 .01603 L
.31349 .01653 L
Mistroke
.32454 .01725 L
.33497 .01816 L
.34464 .01925 L
.35524 .02076 L
.3652 .02257 L
.38382 .02717 L
.39361 .03038 L
.40394 .03447 L
.42243 .04391 L
.4421 .0575 L
.46045 .07401 L
.49941 .12283 L
.54082 .19451 L
.58072 .27551 L
.6191 .35146 L
.63853 .38433 L
.64884 .39939 L
.65994 .41341 L
.67053 .42444 L
.68023 .43239 L
.6895 .43799 L
.69416 .44004 L
.69926 .44169 L
.7018 .44229 L
.70314 .44254 L
.70456 .44276 L
.7058 .44291 L
.70646 .44298 L
.70716 .44304 L
.7084 .44312 L
.70956 .44316 L
.71076 .44317 L
.71207 .44314 L
.7133 .44307 L
.71444 .44298 L
.71547 .44287 L
.71661 .44272 L
.7189 .44233 L
.72162 .44171 L
.7241 .44099 L
.72971 .43886 L
.73466 .4364 L
.73987 .43324 L
.75959 .41632 L
.77794 .39438 L
.81696 .3337 L
.85842 .26003 L
.89837 .19214 L
.93681 .13681 L
.97619 .09317 L
Mistroke
Mfstroke
.02381 .01472 m
.02605 .01472 L
.02846 .01472 L
.03072 .01472 L
.03279 .01472 L
.03521 .01472 L
.03784 .01472 L
.04032 .01472 L
.04262 .01472 L
.04498 .01472 L
.0472 .01472 L
.04963 .01472 L
.05224 .01472 L
.05497 .01472 L
.05757 .01472 L
.0599 .01472 L
.06244 .01472 L
.0653 .01472 L
.06799 .01472 L
.07041 .01472 L
.07302 .01472 L
.07588 .01472 L
.07731 .01472 L
.07889 .01472 L
.08169 .01472 L
.08429 .01472 L
.08692 .01472 L
.08942 .01472 L
.09165 .01472 L
.09408 .01472 L
.09673 .01472 L
.09954 .01472 L
.10193 .01472 L
.10458 .01472 L
.10693 .01472 L
.1095 .01472 L
.11218 .01472 L
.11467 .01472 L
.11702 .01472 L
.11915 .01472 L
.12161 .01472 L
.12393 .01472 L
.12646 .01472 L
.12913 .01472 L
.13142 .01472 L
.13393 .01472 L
.13664 .01472 L
.13954 .01472 L
.14228 .01472 L
.14478 .01472 L
Mistroke
.14729 .01472 L
.14956 .01472 L
.15219 .01472 L
.15465 .01472 L
.15905 .01472 L
.16153 .01472 L
.16381 .01472 L
.16862 .01472 L
.17135 .01472 L
.1739 .01472 L
.17659 .01472 L
.17904 .01472 L
.18187 .01472 L
.18454 .01472 L
.18915 .01472 L
.19177 .01472 L
.19422 .01472 L
.19917 .01472 L
.20195 .01472 L
.20449 .01472 L
.20879 .01472 L
.21122 .01472 L
.21348 .01472 L
.21805 .01472 L
.22061 .01472 L
.22293 .01472 L
.22779 .01472 L
.23024 .01472 L
.23293 .01472 L
.2377 .01472 L
.24215 .01472 L
.24484 .01472 L
.2474 .01472 L
.25219 .01472 L
.25487 .01472 L
.25735 .01472 L
.26027 .01472 L
.26296 .01472 L
.26758 .01472 L
.27257 .01472 L
.27697 .01472 L
.2816 .01472 L
.28669 .01472 L
.29143 .01472 L
.29663 .01472 L
.30219 .01472 L
.30751 .01472 L
.31242 .01472 L
.31781 .01473 L
.32351 .01473 L
Mistroke
.32847 .01474 L
.3331 .01474 L
.33819 .01475 L
.34366 .01477 L
.34891 .01479 L
.35377 .01481 L
.35912 .01484 L
.36481 .01488 L
.37024 .01493 L
.37535 .01499 L
.3849 .01515 L
.38956 .01526 L
.39468 .0154 L
.39966 .01557 L
.405 .0158 L
.41456 .01634 L
.42347 .01706 L
.43366 .01822 L
.43941 .01908 L
.44473 .02003 L
.45449 .02225 L
.46486 .02545 L
.47424 .02929 L
.48434 .03467 L
.49388 .04118 L
.50263 .04857 L
.52156 .07025 L
.53229 .08654 L
.54227 .10462 L
.58134 .20467 L
.62285 .35295 L
.64367 .43172 L
.66285 .49811 L
.68155 .55087 L
.69098 .57134 L
.6963 .58081 L
.70134 .58831 L
.70621 .59415 L
.70878 .59666 L
.71151 .59889 L
.71404 .60056 L
.71633 .60173 L
.71744 .60218 L
.71864 .60258 L
.71977 .60288 L
.7208 .60309 L
.72202 .60325 L
.72332 .60332 L
.72454 .60329 L
.72566 .60319 L
Mistroke
.72697 .60297 L
.72771 .6028 L
.72839 .60261 L
.73097 .60165 L
.73345 .60036 L
.73618 .59852 L
.7417 .59347 L
.74689 .58716 L
.75183 .57981 L
.7611 .5627 L
.78198 .51067 L
.82016 .38657 L
.86079 .2521 L
.89991 .14995 L
.92131 .10912 L
.94148 .07988 L
.95955 .06028 L
.97619 .04681 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[28]:=",
  ImageSize->{342.125, 211.438},
  ImageMargins->{{2, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005F0000da000`40n007h00OooooEooo003ooomG
ool00?oooeOoo`00ooooEooo003ooomGool009Ooo`<000?oo`8000?oo`8000;oo`<00004ool00000
ool2000;ool30003ool30002ool30002ool30003ool20024ool009Ooo`03003oo`0000;oo`06003o
oooo003oo`000_oo00<00?oo00001?oo00<00?oo00003Ooo00<00?ooool00ooo00<00?ooool00_oo
00D00?ooooooo`0000Coo`03003ooooo08Coo`00VOoo00@00?ooool000Coo`06003ooooo003oo`00
1?oo0`003Ooo0`000ooo00<00?ooool00_oo00D00?ooooooo`0000Coo`<008Coo`00V?oo00<00?oo
ool010000ooo0P000_oo0`000_oo00@00?oo000000coo`05003ooooo003oo`0400000ooo00000003
ool30002ool30024ool009Ooo`03003oo`0000;oo`03003ooooo00coo`03003ooooo00goo`04003o
oooo002Gool009Ooo`<0013oo`8000koo`@000Soo`03003ooooo08goo`00ooooEooo003ooomGool0
0?oooeOoo`00ooooEooo003ooomGool0043oo`<000?oo`03003ooooo037oo`8000Coo`03003ooooo
033oo`8000Coo`03003ooooo03;oo`<000;oo`03003ooooo03;oo`<000;oo`03003ooooo02Koo`00
@?oo00<00?ooool00_oo00<00?oo0000=?oo00H00?ooool00?oo000cool01P00ooooo`00ool003Co
o`06003ooooo003oo`00=?oo00H00?ooool00?oo000Wool0047oo`03003ooooo00?oo`03003ooooo
037oo`07003oooooool00?oo0000<_oo00<00?ooool00ooo00<00?ooool0<?oo100000Coo`00ool0
03;oo`@000?oo`03003ooooo02Goo`00@Ooo00@00?ooooooo`8003Goo`06003ooooo003oo`00<ooo
00<00?ooool00P00<ooo00<00?oo00000_oo00<00?oo0000<_oo00<00?oo00000_oo0P00:?oo0010
ool00`00ool00002ool00`00ooooo`0bool00`00ool00002ool00`00ool0000aool00`00ool00002
ool00`00ooooo`0cool20002ool00`00ool0000cool20002ool00`00ooooo`0Wool0047oo`04003o
ooooool3000cool00`00ooooo`02ool00`00ooooo`0aool01000oooooooo0`00=?oo00D00?oooooo
o`0003Goo`03003ooooo00<002Ooo`00ooooEooo003ooomGool00?oooeOoo`00ooooEooo003ooomG
ool003oooo8002Goo`00?ooo00<00?ooool00_oo00<00?ooool02Ooo00<00?ooool02?oo00<00?oo
ool02Ooo00<00?ooool02?oo00<00?ooool02Ooo00<00?ooool02?oo00<00?ooool02Ooo00<00?oo
ool02?oo00<00?ooool02Ooo00<00?ooool02?oo00<00?ooool02Ooo00<00?ooool02?oo00<00?oo
ool02Ooo00<00?ooool02?oo00<00?ooool02Ooo00<00?ooool02Ooo00<00?ooool02?oo00<00?oo
ool02Ooo00<00?ooool02?oo00<00?ooool02Ooo00<00?ooool00_oo00<00?ooool08ooo000iool0
0`00ooooo`03ool00`00ooooo`02ool00`00ooooo`0gool00`00ooooo`0fool00`00ooooo`0gool0
0`00ooooo`0gool00`00ooooo`02ool00`00ooooo`0Sool003Soo`03003oo`0000Coo`03003ooooo
0>koo`03003ooooo02?oo`00>?oo00<00?oo00001?oo0P000oooI000Qooo0P009Ooo000hool00`00
ool00004ool00`00ooooo`02oolZ0003ool60007ool9000:ool5000Bool60022ool00`00ooooo`0S
ool003Soo`03003oo`0000Coo`03003ooooo00;ooa`000Goo`@000Goo`D000Coo`X000Koo`@000_o
o`<001Goo`80083oo`03003ooooo02?oo`00>Ooo00<00?ooool00ooo00<00?ooool00_oo5P0000?o
o`0000002`0000?oo`0000000`001Ooo1@002Ooo10001_oo1@002Ooo1P004Ooo0`00OOoo00<00?oo
ool08ooo000oool00`00ooooo`05ool?0004ool30003ool40004ool30003ool50005ool50008ool2
0009ool3000<ool2000Bool2001kool00`00ooooo`0Sool003ooo`03003ooooo00[oo`@00003ool0
000000P000;oo`<000Coo`<000Coo`<000Goo`@000Koo`@000Koo`8000[oo`8000coo`8001;oo`03
003ooooo07Soo`03003ooooo02?oo`00?ooo00<00?ooool03_oo0`000ooo100000?oo`0000000P00
00?oo`0000000P000ooo0`001?oo0`001_oo0`001ooo0P001_oo0P002_oo0P003?oo0P004Ooo00<0
0?ooool0Mooo00<00?ooool08ooo000oool00`00ooooo`0Aool40003ool30002ool400000ooo0000
00020002ool30004ool30006ool30006ool20006ool30009ool2000<ool00`00ooooo`0?ool00`00
ooooo`1aool01000oooooooo0P009Ooo000oool00`00ooooo`0Eool30003ool30003ool20003ool4
00001?oo000000001?oo0`001_oo0`001Ooo0P001ooo0`002?oo0P002ooo00<00?ooool03ooo00<0
0?ooool0Kooo00<00?ooool00ooo00<00?ooool08ooo000oool00`00ooooo`0Hool30003ool30002
ool30004ool300000ooo000000020003ool20007ool20005ool20008ool20008ool00`00ooooo`09
ool2000@ool00`00ooooo`1]ool00`00ooooo`04ool00`00ooooo`0Sool003ooo`03003ooooo01_o
o`<000?oo`<000;oo`8000Goo`8000?oo`<000;oo`<000Koo`8000Goo`8000Soo`8000Ooo`8000_o
o`03003ooooo00koo`03003ooooo06_oo`03003ooooo00Goo`03003ooooo02?oo`00?ooo00<00?oo
ool07_oo0`000ooo1`001?oo0`000ooo0P000ooo0P001_oo0P001Ooo0P002?oo00<00?ooool01_oo
00<00?ooool02Ooo00<00?ooool03_oo00<00?ooool0JOoo00<00?ooool01_oo00<00?ooool08ooo
000oool00`00ooooo`0Qool30004ool60004ool20003ool20003ool20006ool20005ool20007ool2
0007ool00`00ooooo`09ool2000?ool00`00ooooo`1Wool00`00ooooo`07ool00`00ooooo`0Sool0
03ooo`03003ooooo02Coo`@000?oo`800004ool000000003ool20003ool20003ool20006ool20005
ool20007ool00`00ooooo`05ool2000;ool00`00ooooo`0=ool00`00ooooo`1Tool2000:ool00`00
ooooo`0Sool003ooo`03003ooooo02Soo`<000;oo`8000;oo`8000?oo`8000?oo`8000?oo`8000Ko
o`8000Goo`8000Koo`8000Ooo`03003ooooo00Woo`03003ooooo00goo`03003ooooo06;oo`03003o
oooo00Woo`8002Goo`00?ooo00<00?ooool0:ooo0P000_oo0P000_oo0P000ooo0P000ooo0P000ooo
0P001_oo00<00?ooool01?oo00<00?ooool01Ooo00<00?ooool01Ooo0P002_oo00<00?ooool03?oo
00<00?ooool0HOoo00<00?ooool02ooo00<00?ooool08ooo000oool00`00ooooo`0]ool20002ool2
0002ool20003ool20003ool20003ool20005ool20005ool20006ool00`00ooooo`06ool00`00oooo
o`08ool00`00ooooo`0<ool00`00ooooo`1Oool00`00ooooo`0<ool00`00ooooo`0Sool003ooo`03
003ooooo02ooo`8000;oo`8000;oo`8000?oo`8000?oo`8000?oo`8000Goo`8000Goo`03003ooooo
00Coo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00coo`03003ooooo05ooo`03003ooooo
00coo`03003ooooo02?oo`00?ooo00<00?ooool0<Ooo0`0000?oo`0000000_oo0P000ooo0P000ooo
0P000ooo0P001Ooo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool01_oo00<00?ooool01ooo
00<00?ooool03?oo00<00?ooool0GOoo00<00?ooool03Ooo00<00?ooool08ooo000oool00`00oooo
o`0dool200000ooo00000002ool20003ool20003ool20003ool20004ool20004ool20005ool20007
ool00`00ooooo`07ool00`00ooooo`0<ool00`00ooooo`1Kool00`00ooooo`09ool00`00ooooo`02
ool00`00ooooo`0Sool003ooo`03003ooooo03Koo`D000;oo`8000?oo`8000?oo`8000?oo`8000Co
o`03003ooooo00?oo`03003ooooo00Coo`03003ooooo00Goo`03003ooooo00Ooo`03003ooooo00_o
o`03003ooooo05[oo`03003ooooo00Woo`03003ooooo00?oo`03003ooooo02?oo`00?ooo00<00?oo
ool0>Ooo10000_oo0P000ooo0P000ooo00<00?ooool00_oo0P000ooo00<00?ooool00ooo00<00?oo
ool01?oo00<00?ooool01Ooo00<00?ooool01_oo00<00?ooool03?oo00<00?ooool0FOoo00<00?oo
ool02?oo00<00?ooool01?oo00<00?ooool08ooo000oool00`00ooooo`0kool40002ool20003ool2
0002ool20004ool01000oooooooo0P001?oo00<00?ooool01?oo00<00?ooool01Ooo00<00?ooool0
1_oo00<00?ooool02ooo00<00?ooool0F?oo00<00?ooool02?oo00<00?ooool01?oo0P009Ooo000o
ool00`00ooooo`0mool40002ool20003ool20002ool00`00ooooo`02ool20003ool00`00ooooo`02
ool20005ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`0;ool00`00ooooo`1Fool00`00
ooooo`08ool00`00ooooo`020004ool00`00ooooo`0Sool003ooo`03003ooooo03ooo`@000;oo`80
00?oo`03003ooooo008000Coo`04003oooooool20004ool00`00ooooo`03ool00`00ooooo`05ool0
0`00ooooo`06ool00`00ooooo`0:ool00`00ooooo`1Fool00`00ooooo`07ool60004ool00`00oooo
o`0Sool003ooo`03003ooooo047oo`@000;oo`8000;oo`8000;oo`03003ooooo00;oo`03003ooooo
00;oo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo
00[oo`03003ooooo05Goo`03003ooooo00Goo`T000Coo`03003ooooo02?oo`00?ooo00<00?ooool0
@ooo1@0000?oo`0000000_oo0P0000?oo`0000000ooo0P000ooo00<00?ooool00_oo00<00?ooool0
0ooo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool02_oo00<00?ooool0E?oo00@00?oooooo
o`d000Coo`03003ooooo02?oo`00?ooo00<00?ooool0AOoo1@0000?oo`0000000_oo00<00?ooool0
0P000ooo00@00?ooooooo`8000?oo`8000Coo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo
00Woo`03003ooooo05?ooa4000Goo`03003ooooo02?oo`00?ooo00<00?ooool0B?oo1`0000?oo`00
00000_oo0P000_oo0P000ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool01Ooo00<00?oo
ool01?oo00<00?ooool02_oo00<00?ooool0Cooo100000?oo`0000001@0000?oo`0000000`001ooo
00<00?ooool08ooo000oool00`00ooooo`1:ool60002ool20002ool20002ool01@00oooooooo0000
1?oo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool01Ooo00<00?ooool02Ooo00<00?ooool0
COoo0P000_oo1`0000?oo`00000010002?oo0P009Ooo000oool00`00ooooo`1=ool50002ool20002
ool200000ooo00000002ool20003ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`04ool0
0`00ooooo`09ool00`00ooooo`1:ool30002ool70002ool6000:ool00`00ooooo`0Sool003ooo`03
003ooooo04ooo`D000;oo`8000;oo`800003ool00?oo00;oo`05003oooooool00004ool00`00oooo
o`04ool00`00ooooo`04ool00`00ooooo`09ool00`00ooooo`17ool20002ool70003ool7000;ool0
0`00ooooo`0Sool003ooo`03003ooooo05;oo`@000;oo`8000;oo`04003oo`000002ool01@00oooo
oooo00001?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool02?oo00<00?ooool0A?oo3000
0_oo20003Ooo00<00?ooool08ooo000oool00`00ooooo`1Dool40002ool200001Ooo00000?oo0000
0_oo00D00?ooooooo`0000Coo`03003ooooo00?oo`03003ooooo00Coo`03003ooooo00Soo`03003o
oooo047oo`H000;oo`@000;oo`<00005ool00000003oo`02000>ool00`00ooooo`0Sool003ooo`03
003ooooo05Koo`D00006ool00000ool00?oo0P0000?oo`0000000_oo0P000ooo00<00?ooool00ooo
00<00?ooool01?oo00<00?ooool02?oo00<00?ooool0??oo1`000ooo10000ooo0P0000?oo`000000
1@003ooo00<00?ooool08ooo000Zool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool0
0`00ooooo`03ool00`00ooooo`1Hool500000ooo0000000200001Ooo003ooooo00000ooo00D00?oo
ooooo`0000Goo`03003ooooo00?oo`03003ooooo00Soo`03003ooooo03Woo`<00004ool000000003
ool50003ool500001_oo003oo`00ool0013oo`03003ooooo02?oo`00:Ooo00<00?oo00001ooo00<0
0?oo00000_oo00<00?oo00001?oo00<00?ooool0Fooo200000Goo`00003oo`0000?oo`05003ooooo
ool00005ool00`00ooooo`03ool00`00ooooo`07ool00`00ooooo`0fool300001?oo000000000ooo
1P000ooo0P0000Coo`00003oo`800004ool00?oo000Aool00`00ooooo`0Sool002Woo`03003oo`00
00Ooo`03003oo`0000Coo`03003ooooo00;oo`8005koo`P00004ool00?oo0003ool01@00oooooooo
00001?oo00<00?ooool00ooo00<00?ooool02?oo00<00?ooool0<_oo0`0000Coo`00000000;oo`@0
0003ool0000000Coo`800007ool00000003oo`00ool010004Ooo0P009Ooo000Yool00`00ool00007
ool00`00ool00002ool20005ool00`00ooooo`1Pool800000ooo00000002ool01@00oooooooo0000
1?oo00<00?ooool00ooo00<00?ooool01ooo00<00?ooool0;_oo20000_oo0`000_oo0`001?oo0P00
00?oo`0000000_oo0P0000Koo`00ool00?oo000Bool00`00ooooo`0Sool002Woo`03003oo`0000Oo
o`03003oo`0000;oo`03003ooooo00Coo`03003ooooo06;oo`P00005ool00?ooool00002ool00`00
ooooo`03ool00`00ooooo`03ool00`00ooooo`06ool00`00ooooo`0Yool500001?oo000000001?oo
0P000ooo0P001?oo0`0000?oo`0000000_oo0P000_oo00<00?oo00000P004ooo00<00?ooool08ooo
000Zool00`00ooooo`07ool01000oooooooo0`001?oo00<00?ooool0IOoo1P0000Goo`00ooooo`00
00;oo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00Ooo`03003ooooo02?oo`D000?oo`<0
00Coo`<000;oo`<000Coo`8000;oo`8000?oo`03003oo`0000800004ool00000000Dool00`00oooo
o`0Sool003ooo`03003ooooo06Soo`L00005ool00?ooool00004ool00`00ooooo`03ool00`00oooo
o`06ool00`00ooooo`0Oool40004ool40005ool20003ool20004ool30002ool20003ool20002ool0
0`00ooooo`03000Eool00`00ooooo`0Sool003ooo`03003ooooo06_oo`P00003ool00?oo00?oo`03
003ooooo00;oo`03003ooooo00Ooo`03003ooooo01Woo`D000Coo`@000Goo`@000;oo`<000Coo`80
00?oo`8000?oo`8000?oo`06003ooooo003oo`005_oo00<00?ooool08ooo000oool00`00ooooo`1]
ool;0002ool00`00ooooo`02ool00`00ooooo`06ool00`00ooooo`0Dool50005ool40005ool40004
ool20004ool30003ool20004ool01000oooooooo0`0000Coo`00ool001Ooo`03003ooooo02?oo`00
?ooo00<00?ooool0Kooo3P000ooo00<00?ooool01Ooo00<00?ooool03ooo1@001Ooo1@001Ooo1000
1Ooo0`001?oo0P001?oo0P001?oo0P000ooo00<00?ooool00P0000?oo`00ool05_oo0P009Ooo000o
ool00`00ooooo`1aoolY0005ool50007ool30006ool30004ool30005ool00`00ooooo`02ool20003
ool20002ool200000ooo0000000Hool00`00ooooo`0Sool003ooo`03003ooooo07?oo`@00003ool0
000000T000Koo`03003ooooo00_oo`P000Soo`@000Koo`<000Goo`8000Koo`8000Coo`03003ooooo
00;oo`04003oooooool20002ool00`00ooooo`0Gool00`00ooooo`0Sool003ooo`03003ooooo07Go
o`D000;oo`8000?oo`03003oo`0001<000coo`@000Koo`@000Goo`<000Koo`8000Coo`8000Coo`09
003oooooool00?oo003oo`0001[oo`03003ooooo02?oo`00?ooo00<00?ooool0M_oo3`001Ooo00<0
0?ooool03ooo1`001Ooo1@001_oo0`001ooo0P001?oo0P001?oo0P000ooo00@00?oo003oo`8001[o
o`03003ooooo02?oo`00?ooo00<00?ooool0N?oo2`000_oo5`001ooo1@002?oo0`002?oo0P001Ooo
00<00?ooool00ooo00<00?ooool00_oo00<00?ooool00`006ooo00<00?ooool08ooo000oool00`00
ooooo`1jool700000ooo000000030003ool00`00ooooo`0Cool3000:ool30008ool30005ool20005
ool00`00ooooo`02ool01`00oooooooo003oo`0001_oo`03003ooooo02?oo`00?ooo00<00?ooool0
Nooo1@0000Coo`00000000?ooaT000_oo`8000Soo`<000Koo`8000Goo`8000Coo`07003oooooool0
0?oo00006ooo0P009Ooo000oool00`00ooooo`1lool600001?oo000000001Ooo00<00?ooool06Ooo
10001ooo0`001ooo0P001_oo00<00?ooool00ooo00<00?ooool00_oo0P007Ooo00<00?ooool08ooo
000oool00`00ooooo`1mool400001Ooo00000000ool01P005ooo10002?oo0`002?oo0P001ooo00<0
0?ooool00ooo00<00?ooool00_oo00<00?oo00007Ooo00<00?ooool08ooo000oool00`00ooooo`1o
ool30002ool30004oolH0009ool30009ool20007ool20005ool00`00ooooo`02ool3000Nool00`00
ooooo`0Sool003ooo`03003ooooo083oo`@00003ool00?oo008000?oo`03003ooooo01Woo`@000[o
o`8000Ooo`8000Goo`8000Coo`03003oo`0001ooo`03003ooooo02?oo`00?ooo00<00?ooool0POoo
0P0000Coo`00000000;oo`@001Woo`8000_oo`<000Soo`03003ooooo00Coo`03003ooooo00?oo`04
003oo`00000Oool00`00ooooo`0Sool003ooo`03003ooooo08?oo`800003ool0000000Coo`X000Oo
o`T000_oo`8000Woo`8000Koo`03003ooooo00?oo`04003ooooo000Pool00`00ooooo`0Sool003oo
o`03003ooooo08?oo`<00003ool0000000800003ool00?oo00Ooo`P0017oo`<000Woo`8000Ooo`03
003ooooo00?oo`05003oooooool0000Pool00`00ooooo`0Sool003ooo`03003ooooo08Coo`@000?o
o`<001goo`<000_oo`03003ooooo00Koo`03003ooooo00?oo`05003oooooool0000Pool2000Uool0
03ooo`03003ooooo08Goo`800003ool0000000?oo`@001Ooo`<000coo`8000Soo`03003ooooo00Co
o`03003ooooo0080027oo`03003ooooo02?oo`00?ooo00<00?ooool0Q_oo0`0000Goo`00ooooo`00
00?oo`D000_oo`L000goo`8000Soo`8000Koo`04003oooooool2000Qool00`00ooooo`0Sool003oo
o`03003ooooo08Koo`06003oo`00003oo`000_oo00<00?ooool01Ooo2`004_oo0P002Ooo00<00?oo
ool01Ooo00@00?ooooooo`8002;oo`03003ooooo02?oo`00?ooo00<00?ooool0Qooo00<00?oo0000
0_oo0`008_oo0P002_oo00<00?ooool01Ooo00<00?ooool00_oo0P008_oo00<00?ooool08ooo000o
ool00`00ooooo`28ool00`00ool00003ool3000Mool3000:ool20007ool00`00ooooo`02ool00`00
ool0000Rool00`00ooooo`0Sool003ooo`03003ooooo08Soo`04003oo`000002ool00`00ooooo`03
000Gool3000<ool00`00ooooo`06ool00`00ooooo`03ool00`00ool0000Rool00`00ooooo`0Sool0
03ooo`03003ooooo08Woo`04003oo`000002ool00`00ooooo`02ool3000Aool3000>ool00`00oooo
o`06ool00`00ooooo`03ool00`00ool0000Rool2000Uool003ooo`03003ooooo08[oo`800004ool0
0?oo0007oolA000?ool20008ool00`00ooooo`04ool00`00ool0000Sool00`00ooooo`0Sool003oo
o`03003ooooo08_oo`800003ool0000002Goo`8000Woo`03003ooooo00Coo`04003ooooo000Sool0
0`00ooooo`0Sool003ooo`03003ooooo08coo`04003oooooool2000Rool00`00ooooo`08ool00`00
ooooo`04ool01000ooooo`009?oo00<00?ooool08ooo000oool00`00ooooo`2=ool01@00ooooo`00
ool00P007_oo0P002_oo00<00?ooool01Ooo00@00?ooool002Coo`03003ooooo02?oo`00;ooo00<0
0?ooool00_oo00<00?ooool01@000ooo00<00?ooool0SOoo0P0000?oo`00ool00_oo0P006_oo0P00
3?oo00<00?ooool01?oo00D00?ooooooo`0002Coo`03003ooooo02?oo`00;_oo00<00?oo00002?oo
00<00?ooool00ooo00<00?ooool0S_oo0`001Ooo0P005ooo00<00?ooool02ooo00<00?ooool01Ooo
00@00?ooool002Goo`03003ooooo02?oo`00;_oo00<00?oo00002?oo00<00?ooool00ooo0P00Sooo
00@00?oo000000Koo`<000ooo`D000goo`03003ooooo00Goo`05003oooooool0000Tool2000Uool0
02koo`03003oo`0000Soo`03003ooooo00?oo`03003ooooo08ooo`03003oo`0000Woo`D000Koo`@0
017oo`03003ooooo00Koo`05003oooooool0000Uool00`00ooooo`0Sool002koo`03003oo`0000So
o`03003ooooo00?oo`03003ooooo08ooo`03003oo`0000koo`H001Coo`03003ooooo00Koo`03003o
oooo00;oo`03003ooooo02?oo`03003ooooo02?oo`00;ooo00<00?ooool01_oo0P001Ooo00<00?oo
ool0T?oo00<00?oo00009_oo00<00?ooool01ooo00D00?ooooooo`0002Koo`03003ooooo02?oo`00
?ooo00<00?ooool0T?oo00@00?oo000002?oo`8000Woo`03003ooooo00;oo`03003ooooo02Coo`03
003ooooo02?oo`00?ooo00<00?ooool0TOoo0P0000?oo`00ool08?oo00<00?ooool02?oo00<00?oo
ool00ooo00<00?ooool09?oo00<00?ooool08ooo000oool00`00ooooo`2Aool20002ool2000Nool0
0`00ooooo`09ool00`00ooooo`02ool00`00ooooo`0Uool00`00ooooo`0Sool003ooo`03003ooooo
09;oo`8000?oo`03003ooooo01Woo`8000_oo`03003ooooo00?oo`03003ooooo02Goo`03003ooooo
02?oo`00?ooo00<00?ooool0T_oo0P001?oo0P005ooo0P003?oo00<00?ooool01?oo00<00?ooool0
9?oo0P009Ooo000oool00`00ooooo`2Cool00`00ooooo`04ool2000Dool00`00ooooo`0<ool00`00
ooooo`03ool00`00ooooo`0Vool00`00ooooo`0Sool003ooo`03003ooooo09?oo`8000Ooo`8000oo
o`<000koo`03003ooooo00Coo`03003ooooo02Koo`03003ooooo02?oo`00?ooo00<00?ooool0U?oo
00<00?ooool01ooo0P002ooo0P004?oo00<00?ooool01Ooo00<00?ooool09_oo00<00?ooool08ooo
000oool00`00ooooo`2Dool2000:ool;000Bool00`00ooooo`05ool00`00ooooo`0Vool00`00oooo
o`0Sool003ooo`03003ooooo09Coo`8002Koo`03003ooooo00Goo`03003ooooo02Ooo`03003ooooo
02?oo`00?ooo00<00?ooool0UOoo0P009Ooo00<00?ooool01Ooo00<00?ooool09ooo00<00?ooool0
8ooo000oool00`00ooooo`2Eool2000Tool00`00ooooo`06ool00`00ooooo`0Vool2000Uool003oo
o`03003ooooo09Goo`03003oo`0002;oo`03003ooooo00Koo`03003ooooo02Soo`03003ooooo02?o
o`00?ooo00<00?ooool0UOoo00@00?ooool0027oo`03003ooooo00Koo`03003ooooo02Soo`03003o
oooo02?oo`00?ooo00<00?ooool0U_oo00<00?oo00008?oo00<00?ooool01ooo00<00?ooool0:?oo
00<00?ooool08ooo000oool00`00ooooo`2Fool01000ooooo`007_oo00<00?ooool01ooo00<00?oo
ool0:Ooo00<00?ooool08ooo000oool00`00ooooo`2Fool01000ooooo`007Ooo00<00?ooool02?oo
00<00?ooool0:Ooo00<00?ooool08ooo000oool00`00ooooo`2Fool01@00oooooooo00006ooo00<0
0?ooool02Ooo00<00?ooool0:Ooo00<00?ooool08ooo000oool00`00ooooo`2Gool01@00oooooooo
00006_oo00<00?ooool02?oo00<00?ooool0:Ooo0P009Ooo000oool00`00ooooo`2Gool00`00oooo
o`02ool00`00ooooo`0Fool00`00ooooo`09ool00`00ooooo`0Zool00`00ooooo`0Sool003ooo`03
003ooooo09Ooo`03003ooooo00?oo`03003ooooo01Coo`03003ooooo00[oo`03003ooooo02[oo`03
003ooooo02?oo`00?ooo00<00?ooool0Uooo00<00?ooool01?oo00<00?ooool04_oo00<00?ooool0
2ooo00<00?ooool0:_oo00<00?ooool08ooo000oool00`00ooooo`2Hool00`00ooooo`04ool00`00
ooooo`0?ool2000=ool00`00ooooo`0[ool00`00ooooo`0Sool003ooo`03003ooooo09Soo`03003o
oooo00Goo`03003ooooo00goo`03003ooooo00goo`03003ooooo02_oo`03003ooooo02?oo`00?ooo
00<00?ooool0V?oo00<00?ooool01_oo00<00?ooool02ooo00<00?ooool03_oo00<00?ooool0:ooo
00<00?ooool08ooo000oool00`00ooooo`2Iool00`00ooooo`06ool30008ool2000@ool00`00oooo
o`0/ool00`00ooooo`0Sool003ooo`03003ooooo09Woo`03003ooooo00Woo`P001;oo`03003ooooo
02_oo`8002Goo`00?ooo00<00?ooool0VOoo00<00?ooool08ooo00<00?ooool0;?oo00<00?ooool0
8ooo000oool00`00ooooo`2Jool00`00ooooo`0Qool00`00ooooo`0]ool00`00ooooo`0Sool003oo
o`03003ooooo09[oo`03003ooooo027oo`03003ooooo02goo`03003ooooo02?oo`00?ooo00<00?oo
ool0V_oo00<00?ooool08Ooo00<00?ooool0;Ooo00<00?ooool08ooo000Zool00`00ooooo`02ool0
0`00ooooo`050002ool00`00ooooo`03ool00`00ooooo`2Kool00`00ooooo`0Pool00`00ooooo`0]
ool00`00ooooo`0Sool002Woo`03003oo`0000Soo`07003oooooool00?oo00001?oo00<00?ooool0
Vooo00<00?ooool07ooo00<00?ooool0;_oo00<00?ooool08ooo000Yool00`00ool00008ool00`00
ooooo`03ool00`00ooooo`02ool2002Lool00`00ooooo`0Oool00`00ooooo`0]ool2000Uool002Wo
o`03003oo`0000Soo`04003oooooool20005ool00`00ooooo`2Kool00`00ooooo`0Oool00`00oooo
o`0^ool00`00ooooo`0Sool002Woo`03003oo`0000Soo`05003oooooool00006ool00`00ooooo`2L
ool00`00ooooo`0Mool00`00ooooo`0_ool00`00ooooo`0Sool002[oo`03003ooooo00Koo`8000?o
o`<000Coo`03003ooooo09coo`03003ooooo01goo`03003ooooo02ooo`03003ooooo02?oo`00?ooo
00<00?ooool0W?oo00<00?ooool07Ooo00<00?ooool0;ooo00<00?ooool08ooo000oool00`00oooo
o`2Mool00`00ooooo`0Kool00`00ooooo`0`ool00`00ooooo`0Sool003ooo`03003ooooo09goo`03
003ooooo01_oo`03003ooooo033oo`03003ooooo02?oo`00?ooo00<00?ooool0WOoo00<00?ooool0
6ooo00<00?ooool0<?oo00<00?ooool08ooo000oool00`00ooooo`2Nool00`00ooooo`0Jool00`00
ooooo`0_ool2000Uool003ooo`03003ooooo09koo`03003ooooo01Woo`03003ooooo037oo`03003o
oooo02?oo`00?ooo00<00?ooool0W_oo00<00?ooool06Ooo00<00?ooool0<Ooo00<00?ooool08ooo
000oool00`00ooooo`2Oool00`00ooooo`0Hool00`00ooooo`0aool00`00ooooo`0Sool003ooo`03
003ooooo09ooo`03003ooooo01Ooo`03003ooooo03;oo`03003ooooo02?oo`00?ooo00<00?ooool0
Wooo00<00?ooool05ooo00<00?ooool0<_oo00<00?ooool08ooo000oool00`00ooooo`2Oool00`00
ooooo`0Fool00`00ooooo`0cool00`00ooooo`0Sool003ooo`03003ooooo0:3oo`03003ooooo01Go
o`03003ooooo03;oo`8002Goo`00?ooo00<00?ooool0X?oo00<00?ooool05?oo00<00?ooool0=?oo
00<00?ooool08ooo000oool00`00ooooo`2Pool00`00ooooo`0Dool00`00ooooo`0dool00`00oooo
o`0Sool003ooo`03003ooooo0:7oo`03003ooooo01?oo`03003ooooo03Coo`03003ooooo02?oo`00
?ooo00<00?ooool0XOoo00<00?ooool04_oo00<00?ooool0=Ooo00<00?ooool08ooo000oool00`00
ooooo`2Rool00`00ooooo`0Aool00`00ooooo`0eool00`00ooooo`0Sool003ooo`03003ooooo0:;o
o`03003ooooo013oo`03003ooooo03Koo`03003ooooo02?oo`00?ooo00<00?ooool0Xooo00<00?oo
ool03ooo00<00?ooool0=Ooo0P009Ooo000oool00`00ooooo`2Sool00`00ooooo`0>ool00`00oooo
o`0gool00`00ooooo`0Sool003ooo`03003ooooo0:Coo`03003ooooo00coo`03003ooooo03Soo`03
003ooooo02?oo`00?ooo00<00?ooool0YOoo00<00?ooool02ooo00<00?ooool0>?oo00<00?ooool0
8ooo000oool00`00ooooo`2Uool00`00ooooo`0:ool00`00ooooo`0iool00`00ooooo`0Sool003oo
o`03003ooooo0:Koo`03003ooooo00Soo`03003ooooo03[oo`03003ooooo02?oo`00?ooo00<00?oo
ool0Y_oo00<00?ooool02?oo00<00?ooool0>_oo00<00?ooool08ooo000oool00`00ooooo`2Wool0
0`00ooooo`06ool00`00ooooo`0kool00`00ooooo`0Sool003ooo`03003ooooo0:Ooo`8000Ooo`03
003ooooo03[oo`8002Goo`00?ooo00<00?ooool0ZOoo00<00?ooool00_oo0P00?_oo00<00?ooool0
8ooo000oool00`00ooooo`2Zool40010ool00`00ooooo`0Sool003ooo`03003ooooo0>koo`03003o
oooo02?oo`00?ooo00<00?ooool00_oo00<00?ooool0=ooo00<00?ooool0=_oo00<00?ooool0=ooo
00<00?ooool0=ooo00<00?ooool00_oo00<00?ooool08ooo000oooob000Uool00?oooeOoo`00oooo
Eooo003ooomGool00?oooeOoo`00ooooEooo003ooomGool00?oooeOoo`00L?oo0`000ooo0P000_oo
0`002_oo10000_oo0`000_oo0`000_oo0`000ooo0P000_oo0`000ooo0P0000?oo`0000000_oo00<0
0?ooool00P004?oo0P0000Coo`00003oo`@000;oo`8000?oo`<00004ool000000002ool30003ool2
0002ool30003ool20002ool2001Sool0077oo`05003oooooool00002ool01000ooooo`003?oo00@0
0?ooool000;oo`03003ooooo00;oo`03003ooooo00;oo`05003oooooool00005ool01@00oooooooo
00001?oo00H00?ooool00?oo0002ool00`00ooooo`0=ool01P00oooooooo003oo`<000;oo`06003o
oooo003oo`000_oo00@00?ooool000Coo`05003oooooool00002ool01000ooooo`000ooo00<00?oo
ool01?oo00<00?ooool0H?oo001aool01@00oooooooo00000_oo00@00?ooool000coo`04003ooooo
0002ool00`00ooooo`02ool00`00ooooo`02ool01000oooooooo0`000ooo00@00?ooooooo`<000;o
o`06003ooooo003oo`004_oo00D00?oo003oo`0000?oo`04003ooooo0004ool01000ooooo`000_oo
00<00?ooool00_oo00D00?ooooooo`0000Goo`04003oooooool30003ool00`00ooooo`1Qool0073o
o`<000?oo`8000;oo`@000[oo`05003ooooo003oo`020003ool30002ool30002ool30002ool40000
1Ooo00000000ool0100000?oo`0000000P004?oo0P0000?oo`0000000_oo0P0000?oo`0000000P00
00Coo`00003oo`800003ool0000000800003ool0000000;oo`@000;oo`8000?oo`<000?oo`8006;o
o`00LOoo00<00?ooool05?oo00@00?ooool000Ooo`03003ooooo00;oo`03003ooooo01Goo`03003o
oooo013oo`800003ool0000000Koo`03003ooooo017oo`03003ooooo077oo`00L_oo00<00?ooool0
4_oo10000ooo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool09ooo0P0000?oo`0000005_oo
00<00?ooool01ooo00<00?ooool0Jooo003ooomGool00?oooeOoo`00ooooEooo003ooomGool00?oo
oeOoo`00ooooEooo003ooomGool00?oooeOoo`00Z_oo0`00ZOoo002[ool00`00ooooo`2Xool008Wo
o`8000;oo`@00004ool000000002ool3000=ool20002ool30003ool20002ool30003ool200000ooo
00000002ool00`00ooooo`0<ool20002ool500000ooo003oo`0200001Ooo003oo`00ool01000K_oo
0028ool00`00ooooo`02ool30003ool00`00ooooo`02ool00`00ooooo`0;ool01P00ooooo`00ool0
00;oo`03003oo`0000;oo`04003ooooo0003ool01P00ooooo`00ool000;oo`03003ooooo00_oo`03
003oo`0000;oo`<00005ool00?oo003oo`0200001Ooo003oo`00ool00`00Kooo0028ool00`00oooo
o`04ool01@00oooooooo00001?oo00<00?ooool02ooo00H00?ooool00?oo0002ool00`00ool00005
ool01@00oooooooo00000_oo00<00?oo00000_oo00<00?ooool02ooo00@00?oo000000?oo`06003o
o`00ool00?oo0P0000Coo`00ool000?oo`03003ooooo06goo`00R?oo00<00?ooool00ooo0P000ooo
00<00?ooool00_oo00<00?ooool02ooo00<00?ooool01@0000?oo`0000000P000_oo0P001?oo0P00
00?oo`0000000P003_oo00<00?ooool00ooo0P0000Koo`00003oo`00ool200000ooo003oo`02ool2
001_ool008Soo`03003oo`0000Soo`03003ooooo00;oo`03003ooooo00_oo`04003ooooo0006ool0
0`00ooooo`0Mool00`00ooooo`23ool008Soo`<000Ooo`8000?oo`8000koo`8000goo`03003ooooo
01Ooo`<008?oo`00ooooEooo003ooomGool00?oooeOoo`00ooooEooo003ooomGool00001\
\>"],
  ImageRangeCache->{{{0, 341.125}, {210.438, 0}} -> {19.0191, -0.0414761, \
0.0868758, 0.00135634}}]
}, Open  ]],

Cell["Here is the equivalent three\[Hyphen]dimensional graph. ", "MathCaption",
  CellTags->"0.34"],

Cell[CellGroupData[{

Cell["\<\
Plot3D[optiongamma[x, t], {x, 25, 55}, {t, 0, 110},
   AxesLabel->{\"Stock Price\", \"Time\", \"Option Gamma\"}];\
\>", "Input",
  CellLabel->"In[29]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -11.1734 -9 ]
[.3345 .12542 .8266 0 ]
[.56094 .0364 -10.3394 -9 ]
[.56094 .0364 1.66057 0 ]
[.29165 .07573 -65.1782 -15 ]
[.29165 .07573 4.82182 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.77605 .1102 0 -6.14908 ]
[.77605 .1102 12 2.85092 ]
[.84375 .21386 0 -6.04972 ]
[.84375 .21386 12 2.95028 ]
[.9051 .30781 0 -5.96165 ]
[.9051 .30781 12 3.03835 ]
[.96095 .39335 0 -5.88306 ]
[.96095 .39335 18 3.11694 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 28 4.94788 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01527 .32052 -24 -2.78917 ]
[.01527 .32052 0 6.21083 ]
[.00611 .37795 -18 -2.83791 ]
[.00611 .37795 0 6.16209 ]
[-0.0034 .43754 -24 -2.88866 ]
[-0.0034 .43754 0 6.11134 ]
[-0.05457 .39542 -76 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.76373 .11471 m
.75757 .11697 L
s
[(25)] .77605 .1102 -1 .36646 Mshowa
.83134 .21814 m
.82514 .22027 L
s
[(50)] .84375 .21386 -1 .34438 Mshowa
.89262 .31187 m
.88638 .3139 L
s
[(75)] .9051 .30781 -1 .32481 Mshowa
.94841 .39721 m
.94213 .39913 L
s
[(100)] .96095 .39335 -1 .30735 Mshowa
.125 Mabswid
.70438 .02393 m
.70071 .02535 L
s
.71969 .04735 m
.71602 .04876 L
s
.73468 .07028 m
.731 .07167 L
s
.74936 .09273 m
.74567 .0941 L
s
.7778 .13624 m
.7741 .13758 L
s
.7916 .15734 m
.78789 .15866 L
s
.80511 .17801 m
.8014 .17932 L
s
.81836 .19827 m
.81464 .19957 L
s
.84407 .23761 m
.84035 .23888 L
s
.85656 .25671 m
.85283 .25797 L
s
.86881 .27545 m
.86507 .27669 L
s
.88083 .29383 m
.87709 .29506 L
s
.90419 .32957 m
.90044 .33077 L
s
.91555 .34695 m
.9118 .34814 L
s
.9267 .364 m
.92295 .36518 L
s
.93765 .38075 m
.93389 .38192 L
s
.95897 .41336 m
.9552 .41451 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02754 .31585 m
.03367 .31352 L
s
[(0.05)] .01527 .32052 1 -0.38019 Mshowa
.01842 .37341 m
.02457 .37113 L
s
[(0.1)] .00611 .37795 1 -0.36935 Mshowa
.00896 .43311 m
.01513 .4309 L
s
[(0.15)] -0.0034 .43754 1 -0.35807 Mshowa
.125 Mabswid
.0346 .27128 m
.03827 .26985 L
s
.03286 .2823 m
.03653 .28088 L
s
.0311 .29341 m
.03477 .29199 L
s
.02932 .30459 m
.033 .30318 L
s
.02574 .3272 m
.02942 .3258 L
s
.02393 .33862 m
.02761 .33724 L
s
.02211 .35013 m
.02579 .34876 L
s
.02027 .36173 m
.02396 .36036 L
s
.01655 .38517 m
.02025 .38382 L
s
.01468 .39702 m
.01837 .39567 L
s
.01278 .40896 m
.01648 .40762 L
s
.01088 .42099 m
.01458 .41966 L
s
.00702 .44532 m
.01073 .444 L
s
.00507 .45762 m
.00878 .45631 L
s
.00311 .47002 m
.00682 .46871 L
s
.00113 .48251 m
.00485 .48121 L
s
gsave
-0.05457 .39542 -137 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Option) show
105.000000 15.000000 moveto
(Gamma) show
135.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.38313 .58323 .40512 .60371 .44189 .59268 .42021 .57192 Metetra
.663 .741 .908 r
.42021 .57192 .44189 .59268 .47916 .5815 .45781 .56046 Metetra
.658 .74 .91 r
.45781 .56046 .47916 .5815 .51695 .57017 .49593 .5494 Metetra
.56 .713 .943 r
.49593 .5494 .51695 .57017 .55527 .55976 .53463 .54613 Metetra
.508 0 0 r
.53463 .54613 .55527 .55976 .59463 .57213 .57459 .57758 Metetra
.831 .401 .216 r
.57459 .57758 .59463 .57213 .6379 .67053 .61708 .64358 Metetra
.332 .555 .916 r
.61708 .64358 .6379 .67053 .68272 .73097 .66003 .65696 Metetra
.766 .604 .679 r
.66003 .65696 .68272 .73097 .72002 .61664 .70001 .5876 Metetra
.878 .749 .717 r
.70001 .5876 .72002 .61664 .75667 .5206 .73885 .51306 Metetra
.873 .928 .857 r
.73885 .51306 .75667 .5206 .79705 .48832 .77931 .4718 Metetra
.731 .834 .928 r
.77931 .4718 .79705 .48832 .83922 .47359 .82152 .45109 Metetra
.675 .759 .914 r
.82152 .45109 .83922 .47359 .88217 .4606 .86482 .43648 Metetra
.665 .744 .909 r
.86482 .43648 .88217 .4606 .92578 .44752 .90888 .42287 Metetra
.664 .742 .908 r
.90888 .42287 .92578 .44752 .97003 .43424 .95362 .4092 Metetra
.664 .741 .908 r
.36056 .56222 .38313 .58323 .42021 .57192 .39797 .55062 Metetra
.662 .741 .909 r
.39797 .55062 .42021 .57192 .45781 .56046 .4359 .53905 Metetra
.633 .734 .921 r
.4359 .53905 .45781 .56046 .49593 .5494 .47433 .52999 Metetra
.38 .654 .965 r
.47433 .52999 .49593 .5494 .53463 .54613 .51333 .53517 Metetra
.611 .053 0 r
.51333 .53517 .53463 .54613 .57459 .57758 .55355 .56922 Metetra
.706 .168 0 r
.55355 .56922 .57459 .57758 .61708 .64358 .59564 .61078 Metetra
.576 .637 .875 r
.59564 .61078 .61708 .64358 .66003 .65696 .63821 .60804 Metetra
.781 .658 .727 r
.63821 .60804 .66003 .65696 .70001 .5876 .67941 .55562 Metetra
.845 .737 .744 r
.67941 .55562 .70001 .5876 .73885 .51306 .7198 .49561 Metetra
.848 .837 .835 r
.7198 .49561 .73885 .51306 .77931 .4718 .76094 .45405 Metetra
.759 .832 .908 r
.76094 .45405 .77931 .4718 .82152 .45109 .80341 .42924 Metetra
.693 .778 .916 r
.80341 .42924 .82152 .45109 .86482 .43648 .84703 .41225 Metetra
.67 .751 .911 r
.84703 .41225 .86482 .43648 .90888 .42287 .89152 .39765 Metetra
.665 .743 .909 r
.89152 .39765 .90888 .42287 .95362 .4092 .93675 .38347 Metetra
.663 .741 .908 r
.33741 .54067 .36056 .56222 .39797 .55062 .37514 .52881 Metetra
.655 .739 .912 r
.37514 .52881 .39797 .55062 .4359 .53905 .41339 .51761 Metetra
.589 .725 .938 r
.41339 .51761 .4359 .53905 .47433 .52999 .45208 .51181 Metetra
.194 .572 .939 r
.45208 .51181 .47433 .52999 .51333 .53517 .49132 .52252 Metetra
.518 0 0 r
.49132 .52252 .51333 .53517 .55355 .56922 .53174 .55284 Metetra
0 .25 .692 r
.53174 .55284 .55355 .56922 .59564 .61078 .57374 .57836 Metetra
.636 .671 .866 r
.57374 .57836 .59564 .61078 .63821 .60804 .61638 .56815 Metetra
.782 .689 .762 r
.61638 .56815 .63821 .60804 .67941 .55562 .6584 .52428 Metetra
.827 .741 .768 r
.6584 .52428 .67941 .55562 .7198 .49561 .69992 .47342 Metetra
.825 .802 .829 r
.69992 .47342 .7198 .49561 .76094 .45405 .74185 .43372 Metetra
.767 .814 .89 r
.74185 .43372 .76094 .45405 .80341 .42924 .78478 .40689 Metetra
.707 .784 .912 r
.78478 .40689 .80341 .42924 .84703 .41225 .82877 .3878 Metetra
.677 .758 .912 r
.82877 .3878 .84703 .41225 .89152 .39765 .87368 .37196 Metetra
.667 .746 .909 r
.87368 .37196 .89152 .39765 .93675 .38347 .9194 .35707 Metetra
.661 .741 .909 r
.31365 .51856 .33741 .54067 .37514 .52881 .3517 .50656 Metetra
.641 .737 .918 r
.3517 .50656 .37514 .52881 .41339 .51761 .39023 .49632 Metetra
.531 .712 .955 r
.39023 .49632 .41339 .51761 .45208 .51181 .42914 .49388 Metetra
.091 .516 .905 r
.42914 .49388 .45208 .51181 .49132 .52252 .46861 .50715 Metetra
0 .216 .644 r
.46861 .50715 .49132 .52252 .53174 .55284 .50925 .53206 Metetra
.141 .52 .916 r
.50925 .53206 .53174 .55284 .57374 .57836 .55137 .54676 Metetra
.665 .692 .865 r
.55137 .54676 .57374 .57836 .61638 .56815 .59425 .53243 Metetra
.778 .709 .787 r
.59425 .53243 .61638 .56815 .6584 .52428 .63694 .49358 Metetra
.813 .746 .789 r
.63694 .49358 .6584 .52428 .69992 .47342 .67936 .44874 Metetra
.809 .787 .832 r
.67936 .44874 .69992 .47342 .74185 .43372 .72206 .41116 Metetra
.766 .8 .881 r
.72206 .41116 .74185 .43372 .78478 .40689 .76554 .38348 Metetra
.716 .783 .905 r
.76554 .38348 .78478 .40689 .82877 .3878 .80999 .36281 Metetra
.684 .762 .91 r
.80999 .36281 .82877 .3878 .87368 .37196 .85535 .34572 Metetra
.671 .749 .91 r
.85535 .34572 .87368 .37196 .9194 .35707 .90156 .33002 Metetra
.657 .74 .911 r
.28926 .49588 .31365 .51856 .3517 .50656 .32762 .48395 Metetra
.622 .734 .927 r
.32762 .48395 .3517 .50656 .39023 .49632 .3664 .47509 Metetra
.472 .694 .965 r
.3664 .47509 .39023 .49632 .42914 .49388 .40551 .47543 Metetra
.071 .504 .897 r
.40551 .47543 .42914 .49388 .46861 .50715 .4452 .48919 Metetra
0 .382 .807 r
.4452 .48919 .46861 .50715 .50925 .53206 .48611 .50865 Metetra
.356 .625 .954 r
.48611 .50865 .50925 .53206 .55137 .54676 .52846 .51573 Metetra
.681 .707 .867 r
.52846 .51573 .55137 .54676 .59425 .53243 .57167 .49885 Metetra
.773 .722 .806 r
.57167 .49885 .59425 .53243 .63694 .49358 .61496 .4632 Metetra
.802 .75 .805 r
.61496 .4632 .63694 .49358 .67936 .44874 .65816 .42251 Metetra
.796 .779 .837 r
.65816 .42251 .67936 .44874 .72206 .41116 .7016 .38681 Metetra
.762 .79 .876 r
.7016 .38681 .72206 .41116 .76554 .38348 .74568 .35885 Metetra
.72 .78 .9 r
.74568 .35885 .76554 .38348 .80999 .36281 .79063 .33705 Metetra
.69 .764 .908 r
.79063 .33705 .80999 .36281 .85535 .34572 .83648 .31883 Metetra
.674 .752 .909 r
.83648 .31883 .85535 .34572 .90156 .33002 .88319 .30226 Metetra
.651 .739 .914 r
.26419 .47266 .28926 .49588 .32762 .48395 .30284 .46102 Metetra
.598 .729 .936 r
.30284 .46102 .32762 .48395 .3664 .47509 .34185 .4537 Metetra
.422 .677 .968 r
.34185 .4537 .3664 .47509 .40551 .47543 .38115 .45602 Metetra
.102 .52 .909 r
.38115 .45602 .40551 .47543 .4452 .48919 .4211 .46902 Metetra
.087 .503 .901 r
.4211 .46902 .4452 .48919 .48611 .50865 .46231 .48349 Metetra
.466 .669 .951 r
.46231 .48349 .48611 .50865 .52846 .51573 .50498 .48497 Metetra
.691 .717 .869 r
.50498 .48497 .52846 .51573 .57167 .49885 .54857 .46637 Metetra
.767 .731 .82 r
.54857 .46637 .57167 .49885 .61496 .4632 .59243 .43287 Metetra
.791 .753 .818 r
.59243 .43287 .61496 .4632 .65816 .42251 .63633 .39513 Metetra
.785 .774 .843 r
.63633 .39513 .65816 .42251 .7016 .38681 .68047 .36098 Metetra
.757 .783 .874 r
.68047 .36098 .7016 .38681 .74568 .35885 .72518 .333 Metetra
.722 .777 .896 r
.72518 .333 .74568 .35885 .79063 .33705 .77068 .31037 Metetra
.694 .764 .906 r
.77068 .31037 .79063 .33705 .83648 .31883 .81704 .29117 Metetra
.677 .754 .909 r
.81704 .29117 .83648 .31883 .88319 .30226 .86428 .27373 Metetra
.642 .738 .918 r
.23843 .4489 .26419 .47266 .30284 .46102 .27735 .43775 Metetra
.573 .723 .944 r
.27735 .43775 .30284 .46102 .34185 .4537 .31656 .43192 Metetra
.387 .663 .968 r
.31656 .43192 .34185 .4537 .38115 .45602 .35606 .43544 Metetra
.156 .549 .927 r
.35606 .43544 .38115 .45602 .4211 .46902 .39629 .44697 Metetra
.232 .581 .944 r
.39629 .44697 .4211 .46902 .46231 .48349 .43785 .45704 Metetra
.53 .692 .942 r
.43785 .45704 .46231 .48349 .50498 .48497 .48087 .45424 Metetra
.698 .725 .871 r
.48087 .45424 .50498 .48497 .54857 .46637 .52489 .43437 Metetra
.762 .738 .831 r
.52489 .43437 .54857 .46637 .59243 .43287 .5693 .40238 Metetra
.782 .755 .828 r
.5693 .40238 .59243 .43287 .63633 .39513 .61386 .36678 Metetra
.777 .771 .848 r
.61386 .36678 .63633 .39513 .68047 .36098 .65868 .33386 Metetra
.753 .778 .874 r
.65868 .33386 .68047 .36098 .72518 .333 .70402 .30597 Metetra
.722 .774 .893 r
.70402 .30597 .72518 .333 .77068 .31037 .75009 .28271 Metetra
.697 .764 .904 r
.75009 .28271 .77068 .31037 .81704 .29117 .797 .26264 Metetra
.68 .755 .908 r
.797 .26264 .81704 .29117 .86428 .27373 .84478 .24437 Metetra
.633 .736 .922 r
.21193 .42455 .23843 .4489 .27735 .43775 .25111 .41391 Metetra
.552 .717 .949 r
.25111 .41391 .27735 .43775 .31656 .43192 .29052 .40918 Metetra
.374 .653 .966 r
.29052 .40918 .31656 .43192 .35606 .43544 .33024 .41319 Metetra
.219 .576 .942 r
.33024 .41319 .35606 .43544 .39629 .44697 .37077 .42307 Metetra
.329 .623 .957 r
.37077 .42307 .39629 .44697 .43785 .45704 .41268 .4297 Metetra
.566 .706 .936 r
.41268 .4297 .43785 .45704 .48087 .45424 .45609 .42387 Metetra
.703 .734 .875 r
.45609 .42387 .48087 .45424 .52489 .43437 .50056 .40307 Metetra
.759 .746 .841 r
.50056 .40307 .52489 .43437 .5693 .40238 .54553 .37195 Metetra
.776 .759 .838 r
.54553 .37195 .5693 .40238 .61386 .36678 .59072 .33768 Metetra
.77 .77 .853 r
.59072 .33768 .61386 .36678 .65868 .33386 .6362 .30554 Metetra
.749 .774 .874 r
.6362 .30554 .65868 .33386 .70402 .30597 .68217 .27767 Metetra
.722 .77 .891 r
.68217 .27767 .70402 .30597 .75009 .28271 .72883 .25389 Metetra
.698 .762 .901 r
.72883 .25389 .75009 .28271 .797 .26264 .77631 .23308 Metetra
.682 .754 .906 r
.77631 .23308 .797 .26264 .84478 .24437 .82467 .21405 Metetra
.62 .734 .928 r
.18467 .3997 .21193 .42455 .25111 .41391 .22408 .38974 Metetra
.528 .711 .956 r
.22408 .38974 .25111 .41391 .29052 .40918 .26367 .38609 Metetra
.362 .65 .966 r
.26367 .38609 .29052 .40918 .33024 .41319 .30362 .3902 Metetra
.268 .604 .953 r
.30362 .3902 .33024 .41319 .37077 .42307 .34447 .39805 Metetra
.401 .657 .962 r
.34447 .39805 .37077 .42307 .41268 .4297 .38678 .40124 Metetra
.595 .714 .927 r
.38678 .40124 .41268 .4297 .45609 .42387 .43062 .39261 Metetra
.705 .734 .874 r
.43062 .39261 .45609 .42387 .50056 .40307 .47556 .37096 Metetra
.753 .745 .846 r
.47556 .37096 .50056 .40307 .54553 .37195 .52108 .34061 Metetra
.768 .757 .843 r
.52108 .34061 .54553 .37195 .59072 .33768 .56689 .30755 Metetra
.763 .768 .857 r
.56689 .30755 .59072 .33768 .6362 .30554 .61301 .27617 Metetra
.745 .772 .875 r
.61301 .27617 .6362 .30554 .68217 .27767 .65962 .24836 Metetra
.721 .769 .891 r
.65962 .24836 .68217 .27767 .72883 .25389 .7069 .22413 Metetra
.699 .763 .901 r
.7069 .22413 .72883 .25389 .77631 .23308 .75497 .20262 Metetra
.684 .755 .906 r
.75497 .20262 .77631 .23308 .82467 .21405 .80391 .18282 Metetra
.607 .731 .933 r
.15659 .37427 .18467 .3997 .22408 .38974 .19621 .36502 Metetra
.508 .705 .959 r
.19621 .36502 .22408 .38974 .26367 .38609 .23599 .36216 Metetra
.365 .651 .966 r
.23599 .36216 .26367 .38609 .30362 .3902 .27619 .36595 Metetra
.322 .628 .96 r
.27619 .36595 .30362 .3902 .34447 .39805 .3174 .3717 Metetra
.456 .678 .96 r
.3174 .3717 .34447 .39805 .38678 .40124 .36013 .37186 Metetra
.616 .721 .921 r
.36013 .37186 .38678 .40124 .43062 .39261 .40442 .3609 Metetra
.707 .738 .875 r
.40442 .3609 .43062 .39261 .47556 .37096 .44984 .33852 Metetra
.749 .748 .851 r
.44984 .33852 .47556 .37096 .52108 .34061 .49591 .3087 Metetra
.762 .758 .849 r
.49591 .3087 .52108 .34061 .56689 .30755 .54233 .27653 Metetra
.757 .766 .86 r
.54233 .27653 .56689 .30755 .61301 .27617 .5891 .24571 Metetra
.741 .77 .876 r
.5891 .24571 .61301 .27617 .65962 .24836 .63635 .21793 Metetra
.719 .767 .89 r
.63635 .21793 .65962 .24836 .7069 .22413 .68425 .19328 Metetra
.7 .762 .9 r
.68425 .19328 .7069 .22413 .75497 .20262 .73294 .1711 Metetra
.685 .755 .905 r
.73294 .1711 .75497 .20262 .80391 .18282 .78249 .15056 Metetra
.594 .728 .938 r
.12767 .34824 .15659 .37427 .19621 .36502 .16749 .33964 Metetra
.492 .7 .961 r
.16749 .33964 .19621 .36502 .23599 .36216 .20746 .33731 Metetra
.374 .654 .966 r
.20746 .33731 .23599 .36216 .27619 .36595 .24792 .34047 Metetra
.369 .648 .964 r
.24792 .34047 .27619 .36595 .3174 .3717 .2895 .34412 Metetra
.498 .693 .955 r
.2895 .34412 .3174 .3717 .36013 .37186 .33268 .3416 Metetra
.631 .727 .916 r
.33268 .3416 .36013 .37186 .40442 .3609 .37744 .32866 Metetra
.709 .741 .877 r
.37744 .32866 .40442 .3609 .44984 .33852 .42336 .30561 Metetra
.745 .75 .856 r
.42336 .30561 .44984 .33852 .49591 .3087 .46998 .27613 Metetra
.756 .758 .854 r
.46998 .27613 .49591 .3087 .54233 .27653 .51701 .24459 Metetra
.752 .765 .864 r
.51701 .24459 .54233 .27653 .5891 .24571 .56442 .21416 Metetra
.737 .768 .878 r
.56442 .21416 .5891 .24571 .63635 .21793 .61232 .18634 Metetra
.718 .766 .89 r
.61232 .18634 .63635 .21793 .68425 .19328 .66086 .16129 Metetra
.7 .761 .899 r
.66086 .16129 .68425 .19328 .73294 .1711 .71017 .13849 Metetra
.686 .755 .904 r
.71017 .13849 .73294 .1711 .78249 .15056 .76035 .11721 Metetra
.581 .725 .942 r
.09787 .32156 .12767 .34824 .16749 .33964 .13787 .31353 Metetra
.481 .695 .963 r
.13787 .31353 .16749 .33964 .20746 .33731 .17803 .31146 Metetra
.388 .659 .966 r
.17803 .31146 .20746 .33731 .24792 .34047 .21878 .31376 Metetra
.408 .664 .964 r
.21878 .31376 .24792 .34047 .2895 .34412 .26076 .31536 Metetra
.529 .703 .95 r
.26076 .31536 .2895 .34412 .33268 .3416 .30439 .31043 Metetra
.643 .731 .913 r
.30439 .31043 .33268 .3416 .37744 .32866 .34963 .29576 Metetra
.709 .743 .878 r
.34963 .29576 .37744 .32866 .42336 .30561 .39608 .2721 Metetra
.741 .751 .86 r
.39608 .2721 .42336 .30561 .46998 .27613 .44326 .2428 Metetra
.751 .759 .859 r
.44326 .2428 .46998 .27613 .51701 .24459 .4909 .21169 Metetra
.747 .764 .867 r
.4909 .21169 .51701 .24459 .56442 .21416 .53895 .18152 Metetra
.733 .766 .879 r
.53895 .18152 .56442 .21416 .61232 .18634 .58749 .1536 Metetra
.716 .764 .89 r
.58749 .1536 .61232 .18634 .66086 .16129 .63668 .12814 Metetra
.7 .76 .899 r
.63668 .12814 .66086 .16129 .71017 .13849 .68664 .10471 Metetra
.687 .755 .904 r
.68664 .10471 .71017 .13849 .76035 .11721 .73747 .08271 Metetra
.568 .722 .945 r
.06714 .29418 .09787 .32156 .13787 .31353 .10731 .28662 Metetra
.473 .692 .963 r
.10731 .28662 .13787 .31353 .17803 .31146 .14768 .28458 Metetra
.404 .665 .966 r
.14768 .28458 .17803 .31146 .21878 .31376 .18874 .28585 Metetra
.442 .677 .963 r
.18874 .28585 .21878 .31376 .26076 .31536 .23112 .28545 Metetra
.554 .711 .945 r
.23112 .28545 .26076 .31536 .30439 .31043 .27523 .27834 Metetra
.652 .734 .91 r
.27523 .27834 .30439 .31043 .34963 .29576 .32097 .26214 Metetra
.71 .745 .879 r
.32097 .26214 .34963 .29576 .39608 .2721 .36794 .23787 Metetra
.738 .753 .864 r
.36794 .23787 .39608 .2721 .44326 .2428 .41569 .20864 Metetra
.747 .759 .862 r
.41569 .20864 .44326 .2428 .4909 .21169 .46395 .17779 Metetra
.743 .763 .87 r
.46395 .17779 .4909 .21169 .53895 .18152 .51264 .14775 Metetra
.73 .765 .88 r
.51264 .14775 .53895 .18152 .58749 .1536 .56184 .11967 Metetra
.715 .763 .891 r
.56184 .11967 .58749 .1536 .63668 .12814 .61169 .09377 Metetra
.7 .759 .898 r
.61169 .09377 .63668 .12814 .68664 .10471 .66231 .06973 Metetra
.687 .755 .903 r
.66231 .06973 .68664 .10471 .73747 .08271 .71381 .047 Metetra
.559 .718 .947 r
.03546 .26589 .06714 .29418 .10731 .28662 .07582 .25858 Metetra
.471 .689 .962 r
.07582 .25858 .10731 .28662 .14768 .28458 .1164 .25634 Metetra
.422 .669 .964 r
.1164 .25634 .14768 .28458 .18874 .28585 .15776 .25656 Metetra
.469 .685 .96 r
.15776 .25656 .18874 .28585 .23112 .28545 .20055 .25441 Metetra
.571 .717 .941 r
.20055 .25441 .23112 .28545 .27523 .27834 .24513 .24549 Metetra
.658 .738 .909 r
.24513 .24549 .27523 .27834 .32097 .26214 .29138 .228 Metetra
.711 .749 .882 r
.29138 .228 .32097 .26214 .36794 .23787 .3389 .20313 Metetra
.736 .755 .868 r
.3389 .20313 .36794 .23787 .41569 .20864 .38723 .17378 Metetra
.744 .761 .866 r
.38723 .17378 .41569 .20864 .46395 .17779 .43611 .14297 Metetra
.739 .764 .872 r
.43611 .14297 .46395 .17779 .51264 .14775 .48546 .11286 Metetra
.728 .764 .882 r
.48546 .11286 .51264 .14775 .56184 .11967 .53533 .0845 Metetra
.713 .762 .891 r
.53533 .0845 .56184 .11967 .61169 .09377 .58585 .05812 Metetra
.699 .758 .898 r
.58585 .05812 .61169 .09377 .66231 .06973 .63714 .03344 Metetra
.687 .754 .902 r
.63714 .03344 .66231 .06973 .71381 .047 .68932 .00998 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ImageSize->{343.188, 309.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005G0001=A000`40n007h00OooooF?oo003ooomH
ool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00
ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomH
ool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00
ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomH
ool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00
ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomH
ool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?ooo`Ooo`03
003ooooo04koo`00oooo1_oo00<00?oo0000Cooo003oool6ool00`00ool0001?ool00?ooo`Koo`03
003oo`0004ooo`00oooo1_oo00<00?oo0000Cooo003oool7ool00`00ooooo`1>ool00?ooo`7oo`80
05Goo`00fooo00<00?ooool00_oo00<00?ooool06ooo1@00E?oo003Jool00`00ool00002ool00`00
ool0000Iool30003ool2001Dool00=coo`06003ooooo003oo`005ooo0P0000Coo`00ooooo`D005?o
o`00f_oo0P000ooo00<00?oo00005?oo0`001?oo0P0000J]o:gL00000?oo001Bool00=[oo`03003o
oooo00;oo`03003oo`00017oo`<000Goo`800006[O^^?:Gk[S`00:hl0P00D_oo003Jool30003ool0
0`00ooooo`0>ool20006ool200002Jgl[Mb]o:gL[Ob]g000[Mb]o002001Aool00>koo`<000Koo`80
000>YO^^?:gk[SbUnjhl[O^^?000[Sb]n`00ool0053oo`00H_oo0`000ooo0P000ooo0P000_oo0`00
00Coo`00003oo`8000_oo`<000?oo`<000;oo`<000;oo`<000?oo`8004ooo`8000;oo`04003ooooo
ool300003Zgl[Mb]o:gL[Ob]g:gl[Mb]o:gL[O`00:gl[M`2001@ool006;oo`03003oo`0000;oo`06
003ooooo003oo`000_oo00<00?oo00001?oo00<00?oo00003Ooo00<00?ooool00ooo00<00?ooool0
0_oo00D00?ooooooo`0000Coo`03003ooooo04coo`<000Koo`80000B]Sb]n`00YO^^?:gk[SbUnjhl
[O^^?:Gk[Sb]n`00YO^^?:gk0P00Cooo001Tool01000ooooo`001?oo00H00?ooool00?oo0004ool3
000=ool30003ool00`00ooooo`02ool01@00oooooooo00001?oo0`00B_oo0P001ooo0P0001N]g:hl
[M^^?000[Ob]g:gl[Mb]o:gL[Ob]g:gl[Mb]o000[Ob]g:gl003oo`0004koo`00Hooo00<00?ooool0
10000ooo0P000_oo0`000_oo00@00?oo000000coo`05003ooooo003oo`0400000ooo00000003ool3
0002ool30017ool30007ool200005kHl[O^f?:gk]Sb]nkHl002^?:Gk[Sb]njhlYO^^?:gk[SbUn`00
[O^^?:Gk[S`00P00C_oo001Rool00`00ool00002ool00`00ooooo`0<ool00`00ooooo`0=ool01000
ooooo`00Eooo0`0000?oo`00ool01Ooo0P0001N]fjhl[Mb^?:gK[Sb]g:hl[M^^?000[Ob]g:gl[Mb]
o:gL[Ob]g:gl002]o:gL00800003[O`0000004goo`00H_oo0`004?oo0P003_oo10002?oo00<00?oo
ool0Booo0P001?oo00<00?ooool00_oo0P0001Jf?:gk]Sb]nkHl[O^f?:gk]Sb]nkHl[O/00:gk[SbU
njhl[O^^?:Gk[Sb]n`<00006[Ob^?:Gk003oo`00C?oo003Lool30009ool200005jgL[Sb]fjhl[Mb^
?:gK[Sb]g:hl[M^^?:gL[Sb]f`00[Mb]o:gL[Ob]g:gl[M`00P0000J]o:gL[Ob]g:gl[M`2001<ool0
0=[oo`8000[oo`80000G]S`00;Hl[O^f?:gk]Sb]nkHl[O^f?:gk]Sb]nkHl[O^f?:gk002]njhlYO^^
?00200002JGk002]o:hlYO^^?:gl[SbUn`02001;ool00=Ooo`<000[oo`80000G]Q^f?;HK002]fjhl
[Mb^?:gK[Sb]g:hl[M^^?:gL[Sb]fjhl[Mb^?000[Ob]g00200003Zgl[Mb]o000[Ob]g:gl[Mb]o:gL
[O`00?oo001:ool00=Goo`8000;oo`03003ooooo00Ooo`0G002f?:gk]Sb]nkHl[O/00:gk]Sb]nkHl
[O^f?:gk]Sb]nkHl[O^f?:gk]Sb]n`0300003Zgl[SbUnjhl[O`00:Gk[Sb]o:hlYO^^?:gl[S`2001:
ool00=;oo`<000coo`80000E]Sbf6kHl]Q^f?;HK]Sbf6`00[M^^?:gL[Sb]fjhl[Mb^?:gK[Sb]g:hl
0080000B[Mbf?000[Ob]g:gl[Mb]o000[Ob]g:gl[Mb]o:gL[Ob]g:gl0P00BOoo003?ool3000=ool2
00005Jgk]Sb]nkHl[O^f?:gk]Sb]nkHl002f?:gk]Sb]nkHl[O^f?:gk]Sb]n`0200005;Hl[O^f?:gk
002Unjhl[Ob^?:Gk002]o:hlYO^^?:gl[SbUnjhl[O`20019ool00<goo`8000koo`80000E]Sbf6kHl
]Q^f?;HK]Sbf6kHl]Q^f?;HK]S`00:hl[M^^?:gL[Sb]fjhl0080000G[M^^?:gL]Sb]fjhl[M`00:gL
[Ob]g:gl002]o:gL[Ob]g:gl[Mb]o:gL[Ob]g0020018ool00<[oo`<00003ool00?oo00coo`0F002]
nkHl[O^f?:gk]Sb]nkHl[O^f?:gk]Sb]nkHl[O^f?000]Sb]nkHl[O/200005kHl[O^f?:gk]Sb]nkHl
[O^f?:gk002Unjhl[O`00:Gk[Sb]o:hlYO^^?:gl[S`00P0000>]o0000000Aooo0038ool2000@ool2
00005;HK002f6kHl]Q^f?;HK]Sbf6kHl]Q^f?;HK]Sbf6kHl]Q/00:gL[S`200005jgL]Sb]fjhl[Mbf
?:gK[Sb]g;Hl[M^^?000[Ob]g:gl002]o:gL[Ob]g:gl[M`00P0000>]o:gL[O`00P00Aooo002Sool3
0002ool00`00ooooo`0Jool3000@ool200005;hl]O^n>kGk002]nkHl[O^f?:gk]Sb]nkHl[O^f?:gk
]Sb]nkHl[O/200005kHl[O^f?:gk]Sb]nkHl[O^f?:gk]Sb]nkHl[O^f?000[SbUnjhl002^?:Gk[S`0
0P0000JUnjhl[Ob^?:Gk[S`20007ool30003ool00`00ooooo`0fool00:Coo`06003ooooo003oo`00
6Ooo0P004Ooo0P0001Bf6kHk]Q^f>kHK]S/00;Hl]Q^f?;HK]Sbf6kHl]Q^f?;HK]Sbf6kHl0P0001Nf
6`00[Mbf?:gK[Sb]g;Hl[M^^?:gL]Sb]fjhl[Mbf?:gK[S`00:gl[M`00:gL00800009[Ob]g:gl[Mb]
o:gL[Ob]g:gl008000Koo`03003ooooo00;oo`03003oo`0003Ooo`00X_oo100000Coo`00ool001Ko
o`@0013oo`80000D_S^enkhl]O^n>kGk_Sbenkhk002f?:gk]Sb]nkHl[O^f?:gk]Sb]n`80000G]Sbe
nkHl[O/00:gk]Sb]nkHl[O^f?:gk]Sb]nkHl[O^f?:gk]Sb]n`00[Ob^?00200002jgl[SbUnjhl[Ob^
?:Gk[Sb]o:hlYO/00P001ooo00<00?ooool00ooo00<00?ooool0=Ooo002Rool00`00ool00002ool0
0`00ool0000Dool2000Bool200005;HK]S^f6kHk]Q^f>kHK]S^f6kHk]Q^f>`00]Sbf6kHl]Q^f?;HK
]S`200005[HK]Sbf6kHl]Q^f?000[Sb]g;Hl[M^^?:gL]Sb]fjhl[Mbf?:gK[Sb]g;Hl100000f]g:gl
[Mb]o:gL[Ob]g:gl[Mb]o:gL[Ob]g0020006ool01000oooooooo0P00>?oo002Sool20002ool00`00
ool0000Aool3000Bool200005;hl]O^n>kGk_Sbenkhk]O^n?;Gk_S^enkhl]O^n>`00]Sb]nkHl[O/2
00005[Hl[O^f?;Gk]Sb]nkHl]O^f?000]Sb]nkHl[O^f?:gk]Sb]nkHl[O^f?:gk0P0001:f?:gk0000
0:hlYO^^?:gl[SbUnjhl[Ob^?:Gk[Sb]o:hlYO/20004ool00`00ool00002ool00`00ooooo`0gool0
0:Coo`05003oooooool0000?ool3000Dool05@00]Q^f>kHK]S^f6kHk]Q^f>kHK]S^f6kHk]Q^f>kHK
]S^f6`00]Q^f?00200005KHK]Sbf6kHl]Q^f?;HK]Sbf6kHl]Q^f?000[Sb]g;Hl[M^^?:gL]Sb]f`03
00001:gL[Sb]g;Hl0P0000j]g:gl[Mb]o:gL[Ob]g:gl[Mb]o:gL[Ob]g:gl0P001Ooo00@00?oooooo
o`<003Ooo`00]_oo0P005Ooo0P0001>enP00]O^n>kGk_Sbenkhk]O^n?;Gk_S^enkhl]O^n>kGk_Sbe
n`0200005;Hl]O^f?:gk]SbenkHl[O^f?;Gk]Sb]nkHl]O^f?000]Sb]nkHl[O/300005jgk]Sb]nkHl
[O^f?:gk]S`00:hl[Ob^?:Gk[Sb]o:hlYO^^?:gl[SbUnjhl[O`00`00@_oo002cool30002ool00`00
ooooo`0@ool200004khk_Q^n>kHK002f6kHk]Q^f>kHK]S^f6kHk]Q^f>kHK]S^f6kHk0080000D]Q/0
0;HK]Sbf6kHl]Q^f?;HK]Sbf6kHl]Q^f?;HK]Sbf6`00[M^^?080000;[Mb^?:gL]Sb]g:hl[Mbf?:gL
[Sb]g00200002jgl[Mb]o:gL[Ob]g:gl[Mb]o:gL[O`00P0000B]g:gl0000047oo`00/Ooo0P005ooo
01@00;Gk_S^en[hk]O^n>kGj002enkhk]O^n?;Gk_S^enkhl]O^n>kGk0P0001Bn>kGk_Sben`00[O^f
?;Gk]Sb]nkHl]O^f?:gk]SbenkHl[O^f?;Gk0P0000ff?:gk]Sb]nkHl[O^f?:gk]Sb]nkHl[O^f?002
00002:Gk[Sb]o:hlYO^^?:gl[S`300001:hlYO^^?:gl0P00@Ooo002^ool3000Gool20000:;HK_S^n
6khk]Q^n>khK_S^f6`00]Q^f>kHK]S^f6kHk]Q^f>kHK002f6kHk]Q^f>kHK]S/00;Hl]Q^f?;HK]Sbf
6kHl]Q^f?;HK]Sbf6kHl0P0001Jf6`00[Mb^?:gL]Sb]g:hl[Mbf?:gL[Sb]g;Hl[M`00:gL002]g:gl
[Mb]o0<00008[Ob]g:gl[Mb]o:gL[Ob]g080043oo`00[?oo0P006?oo0P0001>n>kGk_S^en[hk]O^n
>kGj_S^enkhk002n?;Gk_S^enkhl]O^n>`0200004kGk_S^enkhl]O^n>kGk_S`00;Hl[O^f?;Gk]Sb]
nkHl]O^f?:gk0080000F]Sb]nkHl]O/00:gk]Sb]nkHl[O^f?:gk]Sb]nkHl[O^f?000]S`00:hlYO/2
00003:hlYO^^?:gl[SbUnjhl[Ob^?:Gk[Sb]o08003ooo`00ZOoo0`000_oo00<00?ooool04ooo0P00
01>n6khk]Q^n>khK_S^f6khk_Q^n>kHK_S^n6khk002f>kHK]S^f6`0200004kHk]Q^f>kHK]S^f6kHk
]Q^f>kHK]S/00;Hl]Q^f?;HK]Sbf6kHl0080000E]Q^f>kHK]Sbf6kHk002f?:gL[Sb]g;Hl[Mb^?:gL
]Sb]g:hl[M`00:gL00<0000>[Mb]o:gL[Ob]g:gl[Mb]o:gL[Ob]g:gl[Mb]o08003ooo`00Y_oo0`00
6_oo01@00;hk]OZn>kGk_S^en[hk]O^n>kGj_S^enkhk]OZn>kGk_S/00;hl0P0001>enkhl]O^n>kGk
_Sbenkhk]O^n?;Gk_S^enkhl002f?:gk]Sben`0200005KHl]O^f?:gk]SbenkHl[O^f?000]Sb]nkHl
[O^f?:gk]Sb]nkHl[O^f?00200004Zgk]S`00:hlYO^^?:gl[SbUnjhl[Ob^?:Gk[Sb]o:hlYO^^?080
03koo`00Y?oo0P006ooo0P0002Nn>`00_S^f6khk_Q^n>kHK_S^n6khk]Q^n>khK_S^f6khk_Q^n>`00
]S^f6kHk]Q^f>kHK]S^f6kHk]Q^f>kHK]S^f6kHk]Q/00;HK]S`00P0001Ff6kHl]Q^f>kHK]Sbf6kHk
]Q^f?;HK]S/00;Hl[Mb^?:gL]Sb]g:hl[M`00`0001J]g;Hl[Mb^?000[Ob]g:gl[Mb]o:gL[Ob]g:gl
[Mb]o:gL[Ob]g000ool003goo`00XOoo0`006ooo0P0001>en[hk]OZn>`00_S^en[hk]O^n>kGj_S^e
nkhk]OZn>kGk_S^enP0200004[hk002n?;Gk_S^enkhl]O^n>kGk_Sbenkhk]O^n?;Gk_S^en`80000D
]Sb]nkHl]O^f?:gk]SbenkHl[O^f?;Gk]Sb]nkHl002f?:gk]Sb]n`<0000F[O^f?000]Sb]nkHl[O/0
0:gl[SbUnjhl[Ob^?:Gk[Sb]o:hlYO^^?:gl[S`3000mool009ooo`8000;oo`03003ooooo01Soo`0D
002n>kgJ_S^mfkhk_MZn>`00_S^f6khk_Q^n>kHK_S^n6khk]Q^n>`80000B_Q^n>khK_S/00;Hk]Q^f
>kHK]S^f6kHk]Q^f>kHK]S^f6kHk0P0001Bf6`00]Q^f?;HK]S^f6kHl]Q^f>kHK]Sbf6kHk]Q^f?;HK
002]g;Hl0P0001N]g;Hl[Mb^?:gL]S`00:hl[Mbf?:gL002]g:gl[Mb]o:gL[Ob]g:gl[Mb]o:gL0080
0004[Ob]g000000lool009coo`<001goo`80000l_S^en[hk]OZn>kGj_S^en[hk002n>kGj_S^enkhk
]OZn>kGk_S/00;hk]OZn>kGj_S^en[hk002n?;Gk_S^enkhl]O^n>kGk_Sbenkhk002n?;Hk_S^f>`00
]O^f?:gk]SbenkHl[O^f?;Gk]Sb]nkHl]O^f?:gk0P0001Nf?:gk]Sb]nkHl[O^f?:gk002]nkHl[O^f
?:gk002]o:hlYO^^?:gl[SbUnjhl00800007YO^^?:gl[S`00?oo0000>ooo002Jool2000Nool20000
4kgK_S^mf[hk_M^n>kgJ_S^mfkhk_MX00;hK_S^f6khk_Q^n>kHK0080000B_S^n6khk_Q^n>khK_S^n
6khk002f>kHK]S^f6kHk]Q^f>kHK0P0001>n>kHK]S^f6khk002f>kHK]Sbf6kHk]Q^f?;HK]S^f6kHl
]Q^f>`0200005[HK002]g;Hl[Mb^?:gL]Sb]g:hl002f?:gL[Sb]g;Hl[M`00:gL[Ob]g:gl0`0000N]
o:gL[Ob]g:gl[Mb]o002000kool009Ooo`<001koo`80000C_S^en[hk]OZn>kGj_S^en[hk]OZn>kGj
_S^enP00]O^n>kGj_S/00P0001:en[hk]OZn>kGj_S^en[hk]OZn>kGj002enkhl]O^n>kGk_S`20000
4kHk_Sbf>khk]S^n?;Hk_S/00;Hl]O^f?:gk]SbenkHl[O^f?;Gk0080000F]Sbf>kHl[S/00:gk]Sb]
nkHl[O^f?:gk002]nkHl[O^f?:gk]S`00:hl[O`200002jhl[Ob^?:Gk[Sb]o:hlYO^^?:gl[S`00P00
>_oo002Eool20002ool00`00ooooo`0Kool05000_MZn>kgK_S^mf[hk_M^n>kgJ_S^mfkhk_MZn>kgK
_S^mfP00_Q/200009khk_Q^n>khK_S^n6khk_Q^n>khK_S^n6khk_Q/00;HK]S^f6kHk002f>kHK_S^f
6kHk]Q^n>kHK]S^f6khk002f>kHK]Sbf6kHk]Q^f?00200005KHK]Sbf6kHk]Q^f?000[Sb]g;Hl[Mb^
?:gL]S`00:hl[Mbf?:gL[Sb]g00300004:gL[Ob]g:gl[Mb]o:gL[Ob]g:gl[Mb]o:gL003oo`00>Ooo
001_ool20004ool00`00ooooo`0Jool3000Pool200009kGj002en[hk]OZn>kGj_S^en[hk]OZn>kGj
_S^en[hk]OZn>kGj002en[hk]OZn>kGj_S^en[hk]OZn>kGj_S^en[hk]OZn>kGj002en`0200004[hk
]S^n?;Hk_S^f>khl]S^n>kHk_Sbf>khk002f?;Gk]Sb]n`80000E]Sb^>kHl]S^f?:hk]Sbf>kHl002f
?:gk]Sb]nkHl[O/00:gk]Sb]nkHl0080000A[O^f?000[Sb]o:hlYO^^?:gl[SbUnjhl[Ob^?:Gk[Sb]
o003000hool0077oo`06003ooooo003oo`006?oo0`008_oo01@00;gk]M^mnkGK002mf[hk_M^n>kgJ
_S^mfkhk_MZn>kgK_S^mf[hk0P0002JmfP00_Q^n>khK_S^n6khk_Q^n>khK_S^n6khk_Q^n>khK_S^n
6`00]Q^f>kHK_S^f6kHk]Q^n>kHK]S^f6khk]Q^f>kHK002f6kHk0P0001Ff6kHk]Q^f?;HK]S^f6kHl
]Q^f>kHK]S`00:hl[Mbf?:gL[S`00;Hl[M`00P0001>f?:hL[Sb^7000[Mb]o:gL[Ob]g:gl[Mb]o:gL
[Ob]g:gl[Mb]o003000hool0073oo`07003oooooool00?oo00005_oo0P009?oo02P00;hk]OZn>kGj
_S/00;hk]OZn>kGj_S^en[hk]OZn>kGj_S^en[hk002n>kgj_S^enP00]OZn>kGj_S^en[hk]OZn>kGj
_S^en[hk]OZn>`80000A_OX00;Hk_Sbf>khk]S^n?;Hk_S^f>khl]S^n>kHk_Sbf>`0200005;Hl]S^f
?:hk]Sbf>kHl[S^f?;Hk]Sb^>kHl]S^f?000]Sb]nkHl[O/300005Jgk]Sb]nkHl[O^f?:gk002Unjhl
[Ob^?:Gk[Sb]o:hlYO^^?:gl[SbUn`0200000ooo003oo`0fool0077oo`06003ooooo003oo`004ooo
0`0000?oo`00ool08Ooo0P0001:mnkGK_O^efkgk]M^mn`00_S^mf[hk_M^n>kgJ_S^mfkhk_MX20000
9Khk_MZn>kgJ_S/00;hk_Q^n>khK_S^n6khk_Q^n>khK_S^n6khk002n>khJ_S^n6`00]Q^f>kHK_S^f
6kHk]Q^n>kHK]S^f6khk0080000D]Q/00;HK]S^f6kHl]Q^f>kHK]Sbf6kHk]Q^f?;HK]S^f6`00[Mb^
?0<0000D[Sb^7;Hl[Qb^?:hL]Sb^7:hl[Q`00:gL[Ob]g:gl[Mb]o:gL[Ob]g0<00004[Mb]o000000g
ool006ooo`03003oo`0000;oo`03003oo`00017oo`8002Koo`0X002en[hk]OZn>kGj_S^en[hk]OZn
>`00_S^en[hk]OZn>kGj_S^enP00]OZn>kgj_S^en[hk_OZn>`00_S^en[hk]OZn>kGj_S^en[hk]OX2
00009[hk_OZn>kGj_S/00;hk]S^n?;Hk_S^f>khl]S^n>kHk_S`00;hk]S^n>kHk002^>kHl]S^f?:hk
]Sbf>kHl[S^f?;Hk]Sb^>kHl]S/200005;Hl[O/00:gk]Sb]nkHl[O^f?:gk]Sb]nkHl[O/00:Gk[Sb]
o:hlYO/300002:Gk[Sb]o:hlYO/00?oo000Kool30002ool300001_oo003oo`00ool000;oo`8000Wo
o`00L?oo00<00?ooool00_oo00<00?ooool03Ooo0`009ooo01<00;GK_O^efkgk]M^mnkGK_O^efkgk
]M^mn`00_S^mf[hk_M^n>`0200009KgJ_S^mf[hk_MZn>kgJ_S^mf[hk002n>khK_S^n6khk_Q^n>khK
002n6khk_QZn>khK_S^n6[hk002n>kHK]S^f6khk]Q^f>kHK0080000C_S^f6khk]Q^n>`00]Sbf6kHk
]Q^f?;HK]S^f6kHl]Q^f>kHK]S`00P0001>f6`00[Qb^?000]Sb^7:hl[Qbf?:hL[Sb^7;Hl[Qb^?000
[Ob]g00300003:gL[Ob]g:gl[Mb]o:gL[Ob]g000ool000Ooo`03003ooooo00;oo`03003ooooo00co
o`03003ooooo00;oo`0:003ooooo003oo`00ool00?oo000;ool008?oo`8002Soo`80000V]OZn>kGj
_S^en[hk]OZn>kGj_S^en[hk]OX00;Gj_S^en[hk002n>kGj_S^mn[hk]OZn>kgj_S^en[hk_OZn>`00
_S^en[hk]OZn>`80000@]OZn>kgj_S^en[hk_OZn>kGj_S/00;hk]S^n?;Hk_S/200004kHk_S^f>khk
]S^n>kHk_S/00;Hl[S^f?;Hk]Sb^>kHl]S^f?:hk0080000C]Sbf>kHl]S/00:gk002]nkHl[O^f?:gk
]Sb]nkHl[O^f?:gk]S`00P0000fUnjhl[Ob^?:Gk[Sb]o:hlYO^^?:gl[SbUn`020006ool00`00ool0
0002ool00`00ool0000=ool00`00ooooo`02ool02@00ooooo`00ool00?oo003oo`030009ool0083o
o`<00003ool00?oo02Koo`0C002mnkGK_O^efkgk]M^mnkGK_O^efkgk]M^mnkGK_O^ef`00_M/00P00
03Vn>kgJ_S^mf[hk_MZn>kgJ_S^mf[hk_MZn>kgJ002n6khk_Q^n>`00_S^n6khk_QZn>khK_S^n6[hk
_Q^n>khJ_S/00;hk]Q^f>`00_S^f6khk]Q^n>kHK_S^f6khk]Q^n>`00]Sbf6kHk]Q^f?;HK]S/00P00
01>f6kHk]Q^f?;HK]S/00;Hl002^?:hL]Sb^7:hl[Qbf?:hL[Sb^700200004:hl002]o:gL[Ob]g:gl
[Mb]o:gL[Ob]g:gl[Mb]o:gL0P001ooo00H00?ooool00?oo000=ool01000oooooooo0P000_oo0P00
00Coo`00ooooo`<000Woo`00OOoo0`00:_oo0P0002Jen`00_S^en[hk]OZn>kGj_S^en[hk]OZn>kGj
_S^en[hk]OX00;gj_S^en[hk_OZn>kGj_S^mn[hk]OZn>kgj_S^en[hk_OX00;Gj0P00012n>kGj_S^m
n[hk]OZn>kgj_S^en[hk_OZn>kGj002f>`80000B_S^f>khk]S^n>kHk_S^f>khk]S^n>kHk_S/00;Hl
[S^f?;Hk0P0000Vf?;Hk]Sbf>kHl]S^f?;Hk]S`00P0000R]nkHl[O^f?:gk]Sb]nkHl0P0001F]nkHl
[O^f?000[SbUnjhl[Ob^?:Gk[Sb]o:hlYO^^?:gl[S`00?oo00001?oo0P000ooo00<00?oo00002ooo
00D00?oo003oo`0001Ooo`00Nooo0P00:ooo0P0001:efkGk]M^en`00_O^efkgk]M^mnkGK_O^efkgk
]M^mnkGK_O/20000>;GJ002mf[hk_MZn>kgJ_S^mf[hk_MZn>kgJ_S^mf[hk_MZn>kgJ002n6[hk_Q^n
>khJ_S^n6khk_QZn>khK_S^n6[hk_Q^n>khJ002f6khk]Q^n>kHK_S^f6khk]Q^n>kHK_S^f6khk]Q/0
0;HK]S`200004kHK]Sbf6kHk]Q^f?;HK]S^f6kHl]Q^f>`00]Sb^7:hl[Qbf?:hL0080000D[Sb^7:hl
[Qb^?:hL002]g:gl[Mb]o:gL[Ob]g:gl[Mb]o:gL[Ob]g0<000Coo`03003ooooo00;oo`03003oo`00
00_oo`D000;oo`03003ooooo01;oo`00N?oo0`00:ooo0P0002Neo:gk]O^]nkGl[O^en`00_S^en[hk
]OZn>kGj_S^en[hk]OZn>`00_O^en[gk]OX00;gj_S^en[hk_OZn>kGj_S^mn[hk]OZn>kgj_S/00P00
012mnP00]OZn>kgj_S^en[hk_OZn>kGj_S^mn[hk]OZn>`80000A_OX00;Hk_S^f>khk]S^n>kHk_S^f
>khk]S^n>kHk_S^f>`0200004kHl]S^f?;Hk]Sbf>kHl]S^f?;Hk]Sbf>kHl]S^f?000]Sb]nkHl0080
000D[O^f?:gk]Sb]nkHl[O^f?:gk002]o:hlYO^^?:gl[SbUnjhl[Ob^?0800004YOb^?0000003ool3
0003ool00`00ooooo`0Vool007Koo`8000?oo`03003ooooo02Koo`80000C]M^enkGK]O^efkGk]M^e
nkGK]O/00;gk]M^mnkGK_O^efkgk]M/00P0001:mnkGJ_O^efkgk]MX00;gJ_S^mf[hk_MZn>kgJ_S^m
f[hk_MX200008khk_MZn>[gJ002n6[hk_Q^n>khJ_S^n6khk_QZn>khK_S/00;hk_Q^n>khJ002f6khk
]Q^n>kHK_S^f6khk]Q^n>kHK_S/00P0001>f6`00]Q^f?;HK]S^f6kHl]Q^f>kHK]Sbf6kHk]Q^f?;HK
002^700200005:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^7000[Mb]o:gL[Ob]g:gl[M`200001:gl[Mb]
o:gL0P00<_oo001cool3000/ool200004kGk[O^eo:gk]O^]nkGl[O^enjgk]Ob]n`00]OZn>kGj_S^e
n[hk0080000U]OZmnkGj_O^en[gk]OZmnkGj002mn[hk]OZn>kgj_S^en[hk_OX00;gj_S^mn[hk_OZn
>`00_S^en[hk_OZn>kGj_S^mn[hk]OX00P0002Fn>kgj_S^mn[hk002n>kHk_S^f>khk]S^n>kHk_S^f
>khk002n>kHk_S^f>`00]S^f?;Hk]Sbf>kHl]S^f?;Hk]Sbf>kHl]S^f?00200005:gk]Sb]nkHl[O^f
?:gk]Sb]nkHl[O^f?:gk]Sb]n`00[Ob^?:Gk[S`200001jGk[SbUo:hlYO^^?:Gl0080037oo`00LOoo
0P00;?oo0`0002RefkGk]M^enkGK]O^efkGk]M^enkGK]O^efkGk]M/00;GK_O^efkgk002mnkGK_O^e
f[gk]M^mnkGJ_O^efkgk002n>kgJ_S^mf[hk_MZn>`80000S_MZn>kgJ_SZmf[hk_MZn>P00_S^n6[hk
_Q^n>khJ_S^n6`00_QZn>khK_S^n6[hk_Q^n>`00_S^f6khk]Q^n>kHK_S^f6`0200004khk]Q^n>khK
_S/00;Hk]Q^f?;HK]S^f6kHl]Q^f>kHK]Sbf6kHk0080000C]Q/00:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl
[Qb^?:hL[S`00:gl[M`00P0000Z]o:gL[Ob]g:gl[Mb]o:gL[Ob]g080033oo`00K_oo1000:_oo0`00
0ZGl01<00;Gk[O^eo:gk]O^]nkGl[O^enjgk]Ob]nkGk[O^eo:gk002enP0200004[gk]OZmnkGj_O^e
n[gk]OZmnkGj_O^en[gk002n>kgj_S^enP80000A_S^mn[hk_OZn>kgj_S^mn[hk_OZn>`00_S^en[hk
_OZn>`0200004;gj_S^mn[hk_OZn>kgj_S^mn[hk002n>kHk_S^f>khk0P0001>f>khk]S^n>kHk_S^f
>khk002f?;Hk]Sbf>kHl]S^f?;Hk]Sbf>`0200004[Hl002f?000]Sb]nkHl[O^f?:gk]Sb]nkHl[O^f
?:gk]Sb]n`<0000<YOb^?:Gk[SbUo:hlYO^^?:Gl[SbUnjhl0P00<?oo001[ool3000/ool20000:ZGL
YObUg:GlYMbUo000]O^efkGk]M^enkGK]O^efkGk]M^enkGK]O^efkGk]M/00;GJ_O^efkgk]MZmnkGK
_O^ef[gk]M^mnkGJ_O^efkgk002n>`80000h_MZn>[gJ_S^mf[hj_MZn>kgJ_SZmf[hk_MZn>P00_S^n
6[hk002n>khJ_S^n6khk_QZn>khK_S^n6[hk_Q^n>`00_S^f6khk002n>khK_S^f6khk_Q^n>kHK_S^n
6khk002f>kHK]Sbf6kHk]Q^f?080000B]Q^f?;HK002f6kHl002^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl
0P00012^7:hl002]o:gL[Ob]g:gl[Mb]o:gL[Ob]g:gl[Mb]o08002ooo`00JOoo0P00;?oo0`002JGl
00h00;Gk[O^eo:gk]O^]nkGl[O^enjgk]Ob]nkGk0P0002F]n`00]OZmnkGj_O^en[gk]OZmnkGj_O^e
n[gk]OZmnkGj_O/00;hk_OZn>kgj_S^mn[hk_OZn>kgj_S^mn[hk_OZn>kgj002mnP0200004;hk_OZn
>kgj_S^mn[hk_OZn>kgj_S^mn[hk_OX00;Hk0P0001:n>kHk_S^f>khk]S^n>kHk_S^f>khk]S^n>`00
]Sbf>kHl]S/200004[Hl]S^f?;Hk]S`00;Hl]S^f?000]Sb]nkHl[O^f?:gk]Sb]n`80000E]Sb]nkHl
[O/00:Gk[SbUo:hlYO^^?:Gl[SbUnjhlYOb^?:Gk003oo`0002koo`00I_oo0`00:_oo100001RUo:GL
YObUg:GlYMbUo:GLYObUg:GlYMbUo000]O^efkGk]M^enkGK]O^efkGk]M/200004[Gk[M^enkGK002e
f[gk]M^mnkGJ_O^efkgk]MZmnkGK_O^efP80000g_O/00;hj_MZn>kgJ_SZmf[hk_MZn>[gJ_S^mf[hj
_MZn>kgJ002n6khk_QZn>khK_S^n6[hk_Q^n>khJ_S^n6khk_QZn>khK002f6khk_Q^n>kHK_S^n6khk
]Q^n>khK_S^f6khk_Q/00;HK]S/00P0000Jf6kHl]Q^f?;HK]S`200002KHK]Sbf6kHl002^?:hL[Sb^
700300005:hL[Sb^7:hl[Qb^?:hL002]g:gl[Mb]o:gL[Ob]g:gl[Mb]o:gL[O`3000^ool006Coo`80
0003ool00?oo02Coo`H00004SIfE_HfM000=YO`02@00[O^enjgk]Ob]nkGk[O^eo00200009Zgk]Ob]
nkGk[O^eo:gk002en[gk]OZmnkGj_O^en[gk]OZmnkGj002en[gk]OZmn`00_S^mn[hk_OZn>kgj_S^m
n[hk_OZn>kgj_S/200004;gj002mn[hk_OZn>kgj_S^mn[hk_OZn>kgj_S^mn[hk0P00016n>P00]S^n
>kHk_S^f>khk]S^n>kHk_S^f>khk]S^n>kHk00800005]Sbf>kHl]S^f?00300002KHl]S/00;Hk]Sbf
>`00[O^f?00200005:gk]Sb]nkHl[O^f?:gk]Sb]nkHl[O/00:Gk[SbUo:hlYO^^?:Gl[S`300001:hl
YO`00000;Ooo001Rool2000Qool800007XfmSIf=_HfMSKf=WHfmSIf=_HfM002Ug:GlYMbUo:GLYObU
g:GlYMbUo:GLYObUg000]M^enkGK]O^ef`80000C]O^efkGk[M^enkGK]O^]fkGk]M/00;GJ_O^efkgk
]MZmnkGK_O/00P0003Jmf[gk]MZmnkgJ_O/00;hj_MZn>kgJ_SZmf[hk_MZn>[gJ_S/00;hj_MZn>[gJ
002n6khk_QZn>khK_S^n6[hk_Q^n>khJ_S/00;hk_QZn>khJ002f6khk_Q^n>kHK_S^n6khk]Q^n>khK
_S/200001;hK002f6kHl0`0000Zf?;HK]Sbf6kHl002f?;HK]Sbf6`80000D[Sb^7:hl[Qb^?:hL[Sb^
7:hl[Qb^?:hL[Sb^7000[Mb]o:gL[Ob]g0800008[Ob]g:gl[Mb]o000ool002coo`00H_oo0P001Ooo
700001AeGGEnMEeeOWEMMGh009FmSIfE_HfMUKf=WIFmSIfE_HfMUKf=W@003JGl00<00:gk]O/00P00
01>]nkGk[O^eo:gk]O^]nkGl[O^enjgk]O`00;gk]OZmnkGj_O^enP0200004[gk]OZmnkGj_O^en[gk
]OZmn`00_S^mn[hk_OZn>kgj_S^mnP80000@_S^mn/Hk_OZn>`00_S^mn[hk_OZn>kgj_S^mn[hk_OX2
00004<Hk_SZn>khjaS^n>P00]S^n>kHk_S^f>khk]S^n>kHk0P0000>n>kHj_S/00`0000^f?;Hk]Sbf
>kHl]S^f?;Hk]S`00;Hl0080000C]S/00:gk]Sb]nkHl[O^f?:gk]Sb]nkHl[O^f?:gk]S`00:hlYO/0
0`0000RUo:hlYOb^?:Gl[SbUo:hl0P00;?oo001Rool00`00ool000040000?HfmSIf=_@00MGieGWEn
MEieOWENMGieGWEn001]OVENKGiUGVenIEi]OVENKGh007EnMEeeOWENMGieGGEnMEieOWEMMGh008fm
SIf=_HfMSKf=WHfmSIf=_HfMSKf=W@00YMbUo:GLYObUg:GlYMbUo:GLYObUg:Gl00<0000W]O^]fkGk
]M^enjgK]O^efkGk[M^enkGK]O^]fkGk002mnkGJ_O^ef`00]MZmnkgJ_O^ef[gk_MZmnkGJ_O^mfP00
_MZn>[gJ_S^mf[hj0080000R_MZn>[gJ_SZmf[hj_MZn>P00_S^n6khk_QZn>khK_S^n6P00_QZn>khJ
_S^n6[hk_QZn>`00_S^f6khk_Q^n>kHK_S/200000khK_S^n6`0200003;hk_Q/00;HK]Sbf6kHl]Q^f
?;HK]Sbf6`80000B]Sbf6kHl002^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL0`0000b]g:gl[Mb]
o:gL[Ob]g:gl[Mb]o:gL[O`2000[ool005coo`03003ooooo00?oo`<0000BSIf=_XFMSKj=WHfnQIf=
_P00MGieGGEnMEeeOWEMMGieGGEn0P00025U7FenIAe]OVDMKGiU7Fen001eOWEMMGieGGEnMEeeOWEM
MGieGGEn002E_HfMUKf=WIFmSIfE_HfMUKf=WIFm00002JGl0`0001FUo9fL002]nkGk[O^eo:gk]O^]
nkGl[O^enjgk]Ob]nkGk[O^eo000_O/00P0002Ben[gk]OZmnkGj_O^en[gk]OZmnkGj_O^enP00_OZn
>kgj_S/00<Hk_OZn>kgjaS^mn[hk_O[6>kgj_S/00;hk_OZn>kgj_S/200003khjaS^n>[hk_S[6>khj
_S^n>/Hk002n>kHk_S^f>`0200000khk]S/0000200003;Hk_S^f>[hk002f?;Hk]Sbf>kHl]S^f?080
000B]S^f?000]Sbf>kHl002f?:gk]Sb]nkHl[O^f?:gk]Sb]nkHl0P00012]nkHl002^?:Gl[SbUo:hl
YOb^?:Gl[SbUo:hlYOb^?08002[oo`00Fooo00<00?oo00000ooo0`0003f=WHfmSIf=_HfMSKf=WHfm
SIf=_@00MGieGWEnMEieOWENMGieGWEnMEh006ENKGiUGVenIEi]OVENKGh007EnMEeeOWENMGieGGEn
MEieOWEMMGh008fmSIf=_HfMSKf=WHfmSIf=_HfMSKd00:GlYMbUo:GLYObUg0020000:ZGlYMbUo:GL
YObUg000]M^enjgK]O^efkGk[M^enkGK]O^]fkGk]M^enjgK]O/00;gk]MZmnkgJ_O^ef[gk_MZmnkGJ
_O^mf[gk]MZmnkgJ002mfP80000Q_SZmf[hj_MZn>[gJ_SZmf[hj_MZn>[gJ_SX00;hk_Q^n>`00_S^n
6[hk_QZn>khJ_S^n6[hk_QZn>khJ_S/00;hk0080000A_Q/00000002n6khk_Q^n>khK_S^n6khk002f
?;HK]Sbf6`0200004[Hl]Q^f?;HK002f6kHl]Q^f?000[Sb^7:hl[Qb^?:hL[Sb^7080000B[Sb^7:hl
[Q`00:gL[Ob]g:gl[Mb]o:gL[Ob]g:gl[Mb]o:gL0P00:_oo001Kool00`00ool00003ool03P00oooo
o`00QIf=_XfMSKj5WHfnSIf=_XFMSKh200004WEMMGieGGEnMEeeOWEMMGieG@00IAe]OVDMKGiU7Fen
IAe]OP80000GMEeeOWEMMGieGGEnMEeeOWEM002=WIFmSIfE_HfMUKf=WIFmSIfE_HfMUKd00002YO`3
00005ifLYObMW:GlWIbUo9fLYObMW000[O^enjgk]Ob]nkGk[O^eo:gk]O^]nkGl[O/00P0002Ben`00
_O^en[gk]OZmnkGj_O^en[gk]OZmnkGj_O^en[gk]OX00;gjaS^mn[hk_O[6>kgj_S^mn/Hk_OZn>kgj
aS^mnP00_OX200003khk_S[6>khj_S^n>/Hk_SZn>khjaS^n>[hk_S[6>`0400003[Hk_S^f>[hk]S^n
>kHj_S^f>khk]SZn>`00]S`200004KHk]Sbf>kHl]S^f?;Hk002f>kHl]S^f?000]Sb]nkHl[O/00`00
01B]o;Hl[O^f?:gl]Sb]n`00YOb^?:Gl[SbUo:hlYOb^?:Gl[SbUo:hl0`00:Ooo001Kool00`00ool0
0003ool06P00oooooooo002=WHfmSIf=_HfMSKf=WHfmSIf=_HfM001eGWEnMEieOWENMGieGWEnMEh2
00007FenIEi]OVENKGiUGVenIEh007EMMGieGWEnMEeeOWENMGieG@00SIf=_HfMSKf=WHfmSIf=_HfM
SKd0100001RUg:GlYMbUo:GLYObUg:GlYMbUo:GLYObUg000]M^enjgK]O^efkGk[M^enkGK]O/20000
4[GK]O^]f`00_MZmnkGJ_O^mf[gk]MZmnkgJ_O^ef[gk_MZmn`80000Q_MX00;gJ_SZmf[hj_MZn>[gJ
_SZmf[hj_MZn>[gJ_SZmfP00_QZn>khJ_S^n6[hk_QZn>khJ_S^n6[hk_QZn>khJ00@0000Q_S^n6khk
_Q^n>khK_S^n6khk_Q^n>khK_S^n6khk002f?;HK]Sbf6kHl]Q^f?;HK]Sbf6`00]Q^f?;HK002^7:hl
0080000D[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^7000[Mb]o:gL[Ob]g:gl[Mb]o0<00004[Ob]g000000X
ool005_oo`03003oo`0000?oo`8000?oo`0C0025WHfnSIf=_XFMSKj=WHfnQIf=_XfM001eGGEnMEee
OWEMMGh02@00019]OVDMKGiU7@00MEeeOWEMMGieGGEnMEeeOWEM002=WIFmSId600006XfmQIf=_P00
YObMW:GlWIbUo9fLYObMW:GlWIbUo9fLYO`00;Gl[O^enjgk]Ob]nkGk[O/200009KGk[O^enjgk]O^]
n`00]OZmnkGj_O^en[gk]OZmnkGj_O^en[gk002mnkGj_O^enP00_O[6>kgj_S^mn/Hk_OZn>kgjaS^m
n[hk0080000=_OX00;hjaS^n>[hk_S[6>khj_S^n>/Hk_SX00`00016n>/Hk_SX00;Hk_S^f>[hk]S^n
>kHj_S^f>khk]SZn>kHk0080000@_S/00;Hl]S^f?;Hk]Sbf>kHl]S^f?000]Sbf>kHl]S/200005;Hl
[O^f?:gl]Sb]nkHl[Obf?:gk]Sb]o;Hl[O/00:Gl[SbUo:hlYO`200001JhlYOb^?:Gl[S`00P00:?oo
001Lool00`00ooooo`02ool00`00ooooo`03ool02P00SIf=_HfMSKf=WHfmSIf=_HfM200000UeOWEN
MGieGWEn001UOVDNIGh04P0001j5WHfmSIf=_HFMSKf=WHfmQIf=_@00YObUg:GlYMbUo:GLYObUg:Gl
YMbUo:GLYO`00;Gk]M^enjgK]O/200004jgK]O^efkGk[M^enkGK]O^]f`00_MZmnkGJ_O^mf[gk]MZm
nkgJ0080000N_OZmf[gk_MZmnP00_SZmf[hj_MZn>[gJ_SZmf[hj_MZn>P00aSZmf[hj_MX00;hJ_S^n
6[hk_QZn>khJ1@00012n6[hj_Q[6>khJ002n6khk_Q^n>khK_S^n6khk_Q^n>`80000@_Q^n>khK002f
6kHl]Q^f?;HK]Sbf6kHl]Q^f?000]S`200004kHK002^7:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl
002]o:gL00<00008[Mb]o:GL[Ob]g:glYMb]o08002Ooo`00HOoo00<00?ooool01?oo00@008FMSKj=
W@D0000oSIfE_XfM001eGGfnMEee_WEMOKieGGFnMEem_P00IGiM7FEnIAiUOUdMIGiU7P00KEeeOVeM
KGi]GGEnKEe]OVeM0025WHfmQIf=_XFMSKf5WHfnQIf=_HFMSKh00:GlWIbUo9fLYObMW:GlWIbUo9fL
YObMW:Gl002eo:gk0080000V]O^]nkGk[O^enjgk]O^]nkGk[O^en`00_O^en[gk]OZmnkGj_O^enP00
]OZmnkGj_O^en[gk]OZmn`00_S^mn/Hk_OZn>kgjaS^mnP80000;aS^mn/Hj_O[6>kgj002n>/Hk_SZn
>`0200005khj_S/00<Hk_S[6>khjaS^n>/Hk_SX00;Hk_S^f>[hk]S^n>kHj_S/00;hk]SX00khk00^f
>P00]S^f?;Hk]Sbf>kHl]S^f?;Hk0080000B]Sbf>kHl002f?:gl]Sb]nkHl[Obf?:gk]Sb]o;Hl[O^f
?:gl0`0000bUo:hlYOb^?:Gl[SbUo:hlYOb^?:Gl[S`20007ool00`00ooooo`02ool00`00ooooo`0G
ool0063oo`03003ooooo00Koo`<00011SIf=_HfMSKf=WHfmSIf=_HfM001eGWEnMEieOWENMGieGWEn
MEieOP00IGiU7VEnIAiUOVDNIGiU7P00IEi]OVENKGiUGVenIEi]OVEN002=WHfmQIf=_HfMSKf5WHfm
SIf=_HFMSKd00:GlYMbUo:GLYObUg:GlYMbUo:GLYObUg00300005;GK]O^]fkGk]M^enjgK]O^efkGk
[M^enkGK]O/00;gk_MZmnkGJ_O/200004;gJ_OZmf[gk_MZmn[gJ_O^mf[gj002n>[gJ_SZmf[hj0P00
00Zmf/Hj_MZn>[gJaSZmf[hj002n>`<0000D_S^n6P000036>khJ_SZn6/Hk_QZn>[hJaS/00;hk_Q^n
>khK_S^n6`80000?_S^n6khk_Q^n>khK_S^n6`00]Q^f?;HK]Sbf6kHl0080000B]Q^f?000]Sbf6kHl
002^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl0P00016^7:hl002]o:gL[ObUg:gl[Mb]o:GL[Ob]g:glYMb]
o00000Ooo`07003oooooool00?oo00006?oo001Pool00`00ooooo`07ool0@000SIfE_XfMSKf=WIFn
SIf=_HfMUKj=W@00MEem_WEMMKieGGfnMEee_WEMOKh006EnGAeUOVDNIGiM7FEnIAh006eMMGi]GFen
KEeeOVeMKGi]G@00QIf=_HFMSKj5WHfmQIf=_XFMSKf5W@00WIbUo9fLYObMW:GlWIbUo9fL0`0003:M
W:Gl002enjgk]O^]nkGk[O^enjgk]O^]nkGk[O^enjgk]O/00;gk]OZmn`00_O^en[gk]OZmnkGj_O^e
n[gk]OZmnkGj_O/00;hk_O[6>`00aSZmn/Hk_O[6>[gjaS^mn/Hj0`0001Fn>khjaS^n>P00_S[6>khj
aS^n>/Hk_S[6>khjaS^n>/Hk002n>kHk_S/00P000[hk00Ff>[hk_S^n>kHj00>n>`05]SX00;Hk]Sbf
>`0200004[Hl]S^f?;Hk002f>kHl]S^f?000]Sb]o;Hl[O^f?:gl]Sb]n`80000B[Sb]nkHl[O`00:Gl
[SbUo:hlYOb^?:Gl[SbUo:hlYOb^?:Gl0P001_oo00<00?ooool00ooo00<00?ooool05_oo001Pool2
0009ool03000SIf=_HfMSKf=WHfmSIf=_HfMSKf=W@80000LMGieGWEnMEieOWENMGieGWEn001UOVDN
IGiU7VEnIAiUOVDN001UGVenIEi]OVENKGiUGVenIEh200004HfmQIf=_HfMSKf5WHfmSIf=_HFM002U
g:GlYMbUo:GLYO`00P0001NMg:GlWMbUo9gLYO`00;Gk]M^enjgK]O^efkGk[M^enkGK]O^]fkGk]M/0
0;GJ0080000@_O^mf[gj_MZmnkgJ_OZmf[gk_MZmn[gJ_O^mfP00_MX200001khj_M[6>[gJ_SZmf/Hj
00<00005aSZmf[hj002n>`0200003khJaS^n6[hj_Q[6>khJ_SZn6/Hk_QZn>[hJ002n6`0200003khk
_Q^n>khK_S^n6khk_Q^n>khK_S^n6khk002f?00200004KHK]Sbf6kHl]Q^f?;HK002f6kHl]Q^f?000
[Sb^7:hl[Q`00`0001B^7:hl[Qb^?:hL[Sb^7000YMb]o:gL[ObUg:gl[Mb]o:GL[Ob]g:gl0`001_oo
00<00?ooool00P006Ooo001Pool00`00ooooo`09ool0>@00SIfE_XfMSKf=WIFnSIf=_HfMUKj=WHfm
001m_WEMMKieGGfnMEee_WEMOKh006EnGAeUOVDNIGiM7FEnIAh006eMMGi]GFenKEeeOVeMKGi]GGEn
002=_HFMSKj5WHfmQIf=_XFMSKf5W@00WIbUo00300005jGlWIbUoIfLYObMW:GmWIbUo000]O^]nkGk
[O^enjgk]O^]nkGk[O^enjgk]O/00P0001Ren[gk]OZmnkGj_O^en[gk]OZmnkGj_O^en[gk]OZmnkGj
002mn/Hj_O[6>kgjaSX300006/Hj_O[6>kgjaSZmn/Hk0036>khjaS^n>/Hk_S[6>khjaS^n>/Hk_S[6
>khjaS^n>P00]SX3_S/01KHj_S^n>khk]SX00khk01Jf>[hk_S^n>`00]Sbf>kHl]S^f?;Hk]Sbf>kHl
]S/00;Hk]Sbf>`00[O^f?080000D[O^f?:gl[Sb]nkHl[Ob^?:gk]S`00:hlYOb^?:Gl[SbUo:hlYOb^
?0<00003[ObUo00000Coo`03003oo`0000;oo`03003ooooo01Soo`00H?oo00<00?ooool02_oo0P00
016=_HfMSKf=WHfmSIf=_HfMSKf=WHfm001eOWENMGieGWEn00T0000FIGiU7VEnIAh006ENKGiUGVen
IEi]OVENKGiUGVen002=_HFMSKf=WHfmQId600006:GlWMbUo9gLYObMg:GlWMbUo9gLYObMg:Gl002e
nkGK]O^]fkGk]M^enjgK]O^ef`80000A]O^ef`00_MZmn[gJ_O^mf[gj_MZmnkgJ_OZmf[gk_MZmnP02
00001;gJ002mf/Hj0`0000S6>[gJ_SZmf/Hj_MZn>[gJ0P0000o5nP00aS^n6[hj_Q[6>khJ_SZn6/Hk
_QZn>[hJaS/00P0000o66P00_Q^n>khK_S^n6khk_Q^n>khK_S^n6khk_Q/00P0000nn>`00]Sbf6kHl
]Q^f?;HK]Sbf6kHl]Q/00;HK]S`00`0001>^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^?000[ObUg:gl
[Mb]o00300001JglYMb]o:GL[O`00P000ooo0`000_oo0`006?oo001Pool2000=ool02P00UKj=WHfm
SIfE_XfMSKf=WIFn1`0000Um_WEMOKieGGfn001U?UdMICh05P0001amGHFnQEf5_WeM002MW:GlWIbU
oIfLYObMW:GmWIbUo9fLYOfMW000[O^enjgk]O^]nkGk[O^en`80000D[O^enjgk]O^]n`00]OZmnkGj
_O^en[gk]OZmnkGj_O^en[gk002mn`:mnP<0000RaSZmn/Hk_O[6>[gjaS^mn/Hj_OX00;gjaSZmnLHj
0036>khjaS^n>/Hk_S[6>khjaS^n>/Hk0036>khjaS^n>P00]SX3_S/01KHj_S^n>khk]SX00[hk00<0
0;hj_S/00[hk00X00;Hl]S^f?;Hk]Sbf>kHl]S^f?0<0000C]Sbf>`00[O^f?:gl[Sb]nkHl[Ob^?:gk
]Sb]o:hl[O/00:Gl[S`00`0000V]o:Gl[ObUo:glYOb]o:Gl[O`00P008_oo001Pool00`00ooooo`0=
ool01000SKf=WHfm1@0000fE_HfMUKd007EnMEimOWENMGieGWenMEieOP020000<EdNGCiM7VDnGAiM
?UdN001U7VDnIAiU?VDNICiU7VDnIAiU?P00QKj5WHFmQIf5_XFMQKf5WHFnQId009gLYObMg:GlWMbU
o9gLYObMg:GlWMbUo9gL002]fkGk]M^enjgK0080000E]O^]fkGk]M^enjgK]O^ef`00_MZmn[gJ_O^m
f[gj_MZmnkgJ_OX00;gj00<0000L_OX00;hj_M[6>[gJ_SZmf/Hj_MZn>[gJ002mf/Gj_M[5n[gJaOX0
0<Hk_QZn>[hJaS^n6[hj_QX200003lHjaQ[6>[hJaS[66P00_Q^n>khK_S^n6khk_Q^n>`0200003[hK
_S^n6khk_Q^n>`00]Sbf6kHl]Q^f?;HK]S`300004KHl]Q^f?;HL002^7:hl[Qb^?:hL[Sb^7:hl[Qb^
?:hL[S`00`0000b]o:GL[ObUg:glYMb]o:GL[ObUg:glYM`2000Rool004_oo`03003ooooo00;oo`03
003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00ooo`<00013UOf=WIGnSIfE
oHfMUOj=WIGm001m_WEMOKieGGfnMEem_WEMOKieG@00GAeU?UdNICiM7FDnGAh006DMIGiU7FEnIAeU
OVDMIGiU7FEn0025_WeMQKj5GHFnOEf5_XEMQKimG@00WIbUo9fLYOfMW:GlWIbUoIfLYObMW:GmWI`0
0:gk]O/00P0001>]nkGk[O^enjgk]O^]nkGk[O^enjgk002en[gk]OZmnkGj_O^enP0400000kgj]OZm
n`02_OX02000aS^mn/Hj_O[6>kgjaSX200003[gjaSZmnLHj_O[6>[gi002n>/Hk_S[6>khjaS/20000
2khjaS^n>/Hk_S[6>khjaS/00;hk]SX00khk00Ff>P00002n>khj00>n>`09_SZn>khk002f>kHl]S^f
?;Hk0080000A]Sbf>kHl002f?;Hk]Sbf>`00[O^f?:gl[Sb]nkHl[Ob^?00300004:hl[O`00:Gl[ObU
o:glYOb]o:Gl[ObUo:glYOb]o:Gl0P008Ooo001:ool00`00ool00007ool00`00ool00002ool00`00
ool00003ool2000Aool03000UKf=WIFmSIfE_HfMUKf=WIFmSIfE_@80000AMEimOWENMGieGWenMEie
OWEN001M7UdnGAiU?UdNGCiM7P0200008FDnIAiU?VDNICiU7VDnIAiU?P00QKj5WHFmQIf5_XFMQKf5
WHFnQId009gLYObMg:GlWMbUo9gLYObMg:GlWMbUo00300005;Gk]M^enjgK]O^efkGk[M^enkGK]O^]
fkGk002mnkgJ_OZmf[gk_MX30000?[gJ_OZmf[gj_MZmn[gJ_OX00;hj_M[6>[gJ_SX00<Gj_M[5n[gJ
aOZmf/Gj_M[5n[gJ002n6/Hk_QZn>P00aSZn6/HjaQ[6>[hJaS[66/Hj_Q[6>P00_S^n6khk_Q/00;hK
_S^n6khk_Q^n>khK_S^n6khk_Q/00;HK]S`200004KHK]Sbf7;Hl]Q/00;HL]Sbf6kHl002^?:hL[Sb^
7:hl[Q`00P0001J^?:hL[Sb^7:hl[Q`00:GL[ObUg:glYMb]o:GL[ObUg:glYMb]o000ool0023oo`00
B_oo00<00?oo00001ooo00<00?oo00001?oo00D00?ooooooo`0001?oo`0G002EoXfMUOf=WIGnSIfE
oHfMUOj=WIGmSId007EMOKieGGfnMEem_WEMOKieG@02000096DnGAiU?UdMICiM7VDn001UOVDMIGiU
7FEnIAeUOVDMIGh008FnOEf5_XEMQKimGHFnQEf5_WeM002MW:GlWIbUoIfLYObMW0@0000DYOfMW000
[O^enjgk]O^]nkGk[O^enjgk]O^]nkGk[O^en`00_O^enP<00006]OZmnkgj_OZen[gk0[gj01Nen[gk
_OZmnP00aS^mn/Hj0036>[gjaSZmnLHj_O[6>[giaSZmn/Hj_OT00;hj0080000?aS^n>/Hk_S[6>khj
aS^n>/Hk_S[6>khjaS/00;hk008000:n>`05_SZn>khk_S^n>P03_S/00khj_S^n>`0200004;Hl]S^f
?;Hk]Sbf>kHl]S/00;Hk]Sbf>kHl002^?:gk0`0001F]o:hl[Ob^?:gl[Sb]o:hl[O`00:Gl[ObUo:gl
YOb]o:Gl[ObUo:glYO`00`008?oo001:ool00`00ool00007ool00`00ool00002ool20004ool2000C
ool200004XfMUKf=WIFmSIfE_HfMUKf=WIFmSId007ENOGieGWEnMEimOPT0000KGCiM7VDn001U?VDN
ICiU7VDnIAiU?VDNICh008FnQIf5_HFMQKj5WHFmQIf5_XFM002Mg:Gl00@0000EWIbMo9fLWObMW9gl
WI`00:gK]O^efkGk[M^enkGK]O^]fkGk]M^enjgK00D0000?_MZmn[gJ_OZmf[gj_MZmn[gJ_OZmf[gj
_MX00;gJ0080000]aOZmf/Gj_M[5n[gJaOZmf/Gj_M[5n[gJaOZmfP00aQ[6>[hJaS[66/Hj_Q[6>/HJ
aSZn6/HjaQ[6>[hJaSX00;hk_Q^n>khK_S^n6khk_Q^n>khK_S^n6khk0080000@_Q/00;HK]Sbf7;Hl
]Q^f?;HL]Sbf6`00]Qbf?;HK]S`200005:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^?000[ObUg:glYMb]
o:GL[O`400001:GLYO`000007ooo001:ool00`00ool00007ool00`00ool00002ool00`00ooooo`03
ool00`00ooooo`0Dool02P00SIfEoHfMUOj=WIGmSIfEoXfM200000Um_WEMOKieGGfn001M?UdNGCh0
2P0000]U7FEnIAeUOP00QKimGHFnQEf5_WeM00H0000FWOfMW:GmWIbMoIfLYOfMW9gmWIbUoIfL002]
nkGk[O^enjgk]O^]nkGk[O/300001Zgk00000;gj]OZmn`:mnP06]OZmnkgj_OZen[gk0[gj02>en[gk
_OX00;giaSZmn/Hj_OW6>[gjaSZmnLHj_O[6>[giaSZmnP00_OT00;hjaS^n>/Hk_S[6>khjaS^n>/Hk
_S[6>khj00800004aS/00;hk_SX3_S/05khj_S^n>khk_SZn>`00_S^n>/Hk002f?;Hk]Sbf>kHl]S^f
?;Hk]Sbf>`00]S/00P0001:f?000[Sb]o:hl[Ob^?:gl[Sb]o:hl[Ob^?:gl[S`00:glYO`400001jgl
YOb]o:Gl[ObUo:gl008001koo`00Booo00<00?ooool01ooo00@00?ooooooo`<000?oo`03003ooooo
01Goo`04002=WIFmSId500006iFMUOfEW@00OIim_WFNOKimWWfnMIim_WfNOKh005dnGAiM?UdNGCiM
7Udn001M?UdNGCiM7P0;00006GeMOGimGGenOEd009fLWObMW9glWIbMo9fLWObMW9glWIbMo9fL002]
fkGk]M^enjgK00<0000D[M^en`00002]fkGk002mn[gJ_OZmf[gj_MZmn[gJ_OZmf[gj_MZmnP80000>
_MX00;gJaOZmf/Gj_M[5n[gJaOZmf/Gj_M[5nP80000MaM[6>/GJ00366/Hj_Q[6>/HJaSZn6/HjaQ[6
>[hJ00366/HjaQ[6>P00_S^n6khk_Q^n>khK_S^n6`0200003khk_Q^n>khK_S/00;Hl]Q^f?;HL]Sbf
6kHl]Qbf?00200004KHL]Sbf7000[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl[Q`00`0000fUg:glYMbU
o:GL[ObUg:GlYMb]o:GLYO`0000Nool005koo`8001Soo`<0000DUIfEoIFMUOfEWIGmUIfEoIFM001e
GGfnMEem_WEMOKieGGfnMEem_P80000[GAiM?UDMGCiM7Udn001M?UDMGCiE7EdnEAeM?UDMGCh007fn
MEem_WeMOKieGGfnOEem_WEM002MW9gmWIbUoIfLWOfMW:GmWIbMoIfLYOd00;Gk[O/00`0000>]nkGk
[O/00P0000Venjgk]O^]n[Gk002mn[Gj_O/00[gj00Nen[gk_OZmn[Gj_O/00004_OX09P00_OW6>[gj
aSZmnLHj_O[6>[giaSX00<Hj_OW6>[giaSX00<Hk_S[6>khjaS^n>/Hk_S[6>khj002n>/Hk_S[6>[hj
aS/00;hk_SX3_S/20002_S/03KhjaS^n>khk_S[6>`00]Sbf>kHl]S^f?;Hk0080000A]S`00;Hl]S^f
?;Hk002]o:hl[Ob^?:gl[Sb]o:hl[Ob^?00200003jgl[S`00:glYOb]o:Gl[ObUo:glYOb]o:Gl[ObU
o002000Mool005koo`03003ooooo01Soo`0<002EWIGmUIfEoIFMUOfEWIGmUIfEoIFM0P00015m_WFN
OKimWWfnMIim_WfNOKieWP00GAiM?UdNGCiM7Udn0080000PGAiM?UdNGCiM7UdnGAiM?P00OGimGGen
OEemOWeMOGimGGenOEd009fLWObMW9glWIbMo9fLWObMW9glWIbMo0800004[M^enkGK]O/20000<ZgK
]O^]fkGk[M^enjgK002mf[gj_MZmn[gJ_OZmf[gj_MZmnP00_OZmf[gj_MZmnP00aOZmf/Gj_M[5n[gJ
aOZmf/Gj0036>/GJaS[5f/HjaM[6>P00aS[66/Hj_Q[6>/HJaSX200007<HJaS[66/HjaQ[6>/HJ002n
6khk_Q^n>`00_S^n6khk_Q^n>khK_S^n6khk_Q^n>`00]Sbf6kHl0P00016f7;Hl]Qbf?000]Sbf7;Hl
]Q`00:hL[Sb^7:hl[Qb^?:hL0080000B[Sb^7:hl[Q`00:GLYObUg:glYMbUo:GL[ObUg:GlYMb]o:GL
0P007?oo001Nool00`00ooooo`0Iool0?@00UIfEoIFMUOfEWIGmUIfEoIFMUOfEWIGm001m_WEMOKie
GGfnMEem_WEMOKieG@00GAiM?UDMGCiM7UdnEAd005DMGCiE7EdnEAeM?UDMGCh007fnMEem_WeMOKie
GGfnOEem_WEM002MW9gmWIbUoIfLWOfMW:Gm00<00004YOd00;Gk[O/200002kGk[OZenjgk]O^]n[Gk
[O^enjgj00000[gj00Fen[gk_OZmn[Gj008000NmnP0U0036>[giaSZmn/Hj_OW6>P00aSZmnLHj_OW6
>[giaSZmnLHj0036>khjaS^n>/Hk0036>[hjaS^n>/Hj_S[6>khjaSZn>P00_S/00P0000G6>khk_S^n
>/Hk00:n>`07_S[6>khk_S^n>P00]S/00P00016f?;Hk]Sbf>kHl]S/00;Hk]Sbf>kHl]S/00:gl[Sb]
o:hl0080000DYOb^?:gl[SbUo:hl[O`00:Gl[ObUo:glYOb]o:Gl[ObUo:glYOb]o08001coo`00G_oo
0P006ooo0P0001:EoIFMUOfEWIGmUIfEoIFMUOfEWIGm001m_WFNOKimWWfnMIh9000075dNGCiM7P00
GAiM?UdNGCiM7UdnGAh007eMOGimGGenOEemOWeMOGimGGen002Mo9fLWObMW9gl0`0000BMo9fLWObM
W0<0001S[M^enjgK]O^]fkGk[M^enjgK]O^]fkGk[M/00;gJ_OZmf[gj_MX00;gJ_OZmf[gj_MZmn[gJ
_OZmf[gj0035n[gJaOZmf/Gj0036>/GJaS[5f/HjaM[6>/GJaS[5f/Hj0036>/HJaSX00<HjaQ[6>/HJ
aS[66/HjaQ[6>/HJaS[66P00_Q^n>khK_S^n6khk_Q^n>khK_S^n6khk_Q^n>khK002f7;Hl]Qbf?;HL
]Sbf7;Hl]Q`00;HL]Sbf7;Hl002^?:hL0080000C[Sb^7:hl[Qb^?:hL[Sb^7:hl002]o:GLYObUg:gl
YMbUo:GL[O`00`0000>Uo:GL00006ooo001Nool00`00ooooo`0Lool02P00UOfEWIGmUIfEoIFMUOfE
WIGm200000UmWHFnOIf5_WfM001E7UdnEAd01`00019E7EdnEAeM?UDM001mGGfnMEem_WeMOKieGGfn
OEem_P00YOd300000jGmWIbMo@0400004YFLWKd00;Gk[OZenjgk]O^]n[Gk[O^enjgj]O^]nkGk[OX0
00:mnP03]OX00;gj00^mnP030036>[gi0080000>aSZmnLHj_OW6>[giaSZmnLHj_OW6>[gi002n>P80
000?aSZn>/Hk_S[6>[hjaS^n>/Hj_S[6>khj0036>@0000:n>`06_S[6>khk_S^n>/Hk0[hk01>n>/Hk
00000;hk002f>kHl]S^f?;Hk]Sbf>kHl]S/00;Hk]Sbf>`0300004Zgl[SbUo:hl[Ob^?:Gl[Sb]o:hl
YOb^?000[ObUo:glYOb]o0<00006[ObUo:glYOb]o0006ooo001Nool00`00ooooo`0Mool01000UOfE
WIGm1@0001RMoIGMUOd007fnOIem_WfNOKimWGfnOIim_WfM001M7UdnEAiM?UdNGCiE7P00C=h50000
2UdN001mGGenOEemOWeMOGimGGen0`0000>Mo9fL00000`0001NM_IFLWKbMW9fmUIbM_000]O^]fkGk
[M^enjgK]O^]fkGk[M^enjgK]O/00;gj0080000/_MZmn[gJ_OZmf[gj_MZmn[gJ_OZmf[gj_MX00;gJ
0035f/HjaM[6>/GJaS[5f/HjaM[6>/GJaS[5f/HjaMX00<HJaS[66/HjaQ[6>/HJaS[66/HjaQ[6>P80
000=aQ[6>/HJ002n6khk_Q^n>khK_S^n6khk_Q/00P0000jnNkhKaW^n6`00]Qbf?;HL]Sbf7;Hl]Qbf
?;HL0`0001:f7;Hl002^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl[Q`00:GL[O`300002ZGlYMbUo:GLYObU
g:GlYMbUo0006_oo001Mool3000Oool300008YgmUIbMoIFLWOfEW9gmUIbMo@00QKimWHFnOIf5_WfM
QKimWHFnOId005DNGCiE7EdnEAiM?UDM001<gECnC=eDoTcM3`0001VEW9fmUIbM_IFLWKfEW9fmUIbM
_IFL002]nkGk[OZenjgk]O^]n[Gk[O^enjgj]O^]n`02000@_OX03`00_OW6>[giaSZmnLHj_OW6>[gi
aSZmnLHj_OW6>P0200003lGi002n>/Hk_S[6>[hjaS^n>/Hj_S[6>`00aS[6>@03aSX01/Hi002n>khk
_S[6>`:n>`80000?_S_6NkhkaW^n>lIk_S/00;Hk]Sbf>kHl]S^f?;Hk0080000A]Sb^>kHl]S`00:Gl
[Sb]o:hlYOb^?:gl[SbUo:hl[Ob^?00300003:glYOb]o:Gl[ObUo:glYOb]o:Gl[ObUo08001Woo`00
GOoo00<00?ooool08?oo00`009gmUMfEoIGMWOfEgIGmUMfMoIGMUOd200004GfMOKimWWfnOIem_WfN
OKimW@00GAiM?UDNGCiM7UdnEAh00P0000I<oTcMC?i<gTcnC=d400007gEnIEieOVEMMGiUGWEn002M
_9fLWKfEW9flWIbM_IFLWKbMW9fmUI`00:gK]O^]fkGk[M^enjgK]O^]fkGk0080000@[M^en`00_OZm
f[gj_MZmn[gJ_OZmf[gj_MZmn[gJ_OX20000:KgJ0035f/HjaM[6>/GJaS[5f/HjaM[6>/GJaSX00<Gj
aMW5n@00aS[66/HjaQ[6>/HJaS[66/Hj0036>/HJaS[66/HjaQ[6>P00_S^n6khk_Q/00P0000o6NkhK
_W^n6lIk_Q^nNkhKaW/00;Hl]Qbf?;HL]S`00P00012f7;Hl002f?;HL]Sbf7000[Qb^?:hL[Sb^7:hl
[Qb^?0<0000A[SbUg000YMbUo:GLYObUg:GlYMbUo:GLYObUg:GlYM`00006ool50002ool00`00oooo
o`02ool00`00ooooo`04ool004goo`03003ooooo00;oo`03003ooooo00D000?oo`03003ooooo027o
o`0T002MoIFLWOfEW9gmUIbMoIFLWOfEW9gmUI`007fMQKimWHFnOIf5_WfMQKimW@00EAiM?UDMGCiE
7UdnEAeM?P00E?i<gECn100001m]GGEnKEeeOVeMMGi]GGEnKEeeOP00WKfEW9fmUIbM_IFLWKfEW9fm
UIbM_IFL002]nkGk[OZenjgk]O^]nP0200001[Gk[IZenjfK]O/000^mnP0Q0035n[gjaOZmn@00_OW6
>[giaSZmnLHj_OW6>[giaSX00<HjaOW6>/GiaSX00<Hj_S[6>khjaSZn>/Hk0036>/Hi00?6>P06aSW6
>/HjaSX00<Hk0P0000nn>lIk_S_6NkhkaW^n>lIk_S_6NkhkaW/00;Hl]S/00P000kHl00F^>kHl002f
?:hk00:f?006002Uo:hl[Ob^?:Gl0P0001>^?:Gl[SfUo:hlYO`00:Gl[ObUo:glYOb]o:Gl[ObUo:gl
YOb]o0020007ool01`00oooooooo003oo`0000;oo`03003oo`0000Goo`00C?oo00<00?oo00002?oo
00<00?ooool00ooo0P008ooo01<009gmUMfEoIGMWOfEgIGmUMfMoIGMUOfEg@00OIem_WfNOKimW@09
000015dNGCiE7Udn0`0000A<oTcNC?i<g@80000KMGiUGGEnIEieOVEMMGiUGWEn002M_9fLWKfEW9fl
WIbM_IFLWKbMW9fmUI`00:gK]O^]fkGk0080000A[M^enjgK]O^]fkGk[M^en`00_OZmf[gj_MZmn[gJ
_OZmfP0200003[gj_MZmn[gJ_OZmfP00aM[6>/GJaS[5f/HjaMX20000:LGjaMW5nLGIaO[5fLGi0036
>/HJaS[66/Hj0036>/HJaS[66/HjaQ[6>/HJaS[66/Hj002nNkhKaW^n6kik_Q_6NkhK_W^n6lIk_Q^n
NkhKaW/00P0000nf7;Hl]Qbf?;HL]Sbf7000]Qbf?;HL]S`00:hl[Q`00`0001FUg:hl[Mb^?:GL[Sb]
g:hlYM`00:GLYObUg:GlYMbUo:GLYObUg:GlYM`00`001_oo00L00?ooooooo`00ool00002ool00`00
ool00005ool000Ooo`<004;oo`03003oo`0000Soo`03003ooooo00?oo`03003ooooo02?oo`0<002M
oIFLWOfEW9gmUIbMoIFLWOfEW9gm1P0000UmWHFnQIf5_WfM001E7UdnEAd0200001iDoTcME?i<gECn
001eOVeMMGi]GGEnKEeeOVeM002EW9fmUIbM_IFLWKfEW9fmUIbM_IFLWKd00;Gk[O/200002kGk[I^e
njfJ]O^]VkGk[IZenjfK00001[gj0P0001fmnLGj_O[5n[giaOZmn/Gj0036>[giaSZmnLHj_OT00<Gi
aS[5nLHjaOW6>/GiaS[5nLHj0036>[hj00800003aS[6>LHj00;6>P0EaSW6>/HjaS[6>LHj003>>P00
aW^n>lIk_S_6NkhkaW^n>lIk_S_6Nkhk00800003aW/00;Hl00:f?006[S^f?;Hl]Sb^>`000[Hl01R^
>`0000000:Gl[SfUo:hlYOb^?JGl[SbUo:hmYOb^?000[ObUo:glYOb]o:Gl[O`400000jGl[O`00006
ool01`00oooooooo003oo`0000;oo`03003oo`0000Goo`002?oo00<00?ooool0@Ooo00<00?oo0000
2?oo00<00?ooool00ooo00<00?ooool09?oo00P009gmUMfEoIGMWOfEgIGm0`0000jMoIgM0025WHFn
QIf5_XFMQKj5WHFnQId005DN0`0000IE7UdnEAiM?P00A?h500005Dcn001eOVEMMGiUGWEnIEeeOVEN
002EW9flWIbM_IFLWKbMW9fmUIbM_0040000C:gK]O^]fkGk[M^enjgK]O^]fkGk[M^enjgK002mf[gj
_MZmnP00_OZmf[gj_MZmn[gJ_OZmf[gj_MZmnP00aS[5f/HjaMX00<GIaO[5fLGiaMW5n/GIaOW5fLGj
aMT00<HJ00366/HjaQ[6>/HJaS[66/HjaQ[6>/HJaSX00<HjaQ[>>P00_W^n6lIk_Q^nNkhKaW^n6kik
0P0000fnFlIk_U_6N`00]Sbf7;Hl]Qbf?;HL]Sbf700300004jhL]S`00:hlYMb^?:gL[SbUg:hl[Mb^
?:GL[Sb]g:hl002Uo:GL00@00006YObUg:GlYMbUo:GL0P001Ooo00L00?ooooooo`00ool00002ool0
0`00ool00005ool000Coo`8000;oo`<000?oo`8000;oo`<000?oo`800003ool0000000;oo`03003o
oooo00coo`8000;oo`D00003ool00?oo00800005ool00?oo003oo`040007ool00`00ool00008ool0
0`00ooooo`02ool2000Wool00`00WOfEW00400003YgmUIbMoIFLWOfEW000OIf5_XFMQKimWHFnQId4
00003EdnEAeM?UDNGCiE7Edn0014oSbMA?hlWDCn00L00008MGi]GGEnKEd009FLWKfEW0H0000DUKfE
W9Fm002enjfK]O^]V[Gk[I^enjfJ]O^]VkGk[IZenjfK002mnP80000?aOZmnLGj_O[5n[giaOZmn/Gj
_OW5n[gjaOX00<Hj0080000>aOW6>/GiaS[5nLHjaOW6>/GiaS[5nLHjaOT000;6>P05aSW6>/HjaS[6
>@03aSX03lHiaSX00<hjaSW>>/HicSX00<Ik_S_6NkhkaW^n>`0200002<Il_W_6NkikaWbnNlIk0003
]S`00jhk]S`0000300004Jhl]Sb^?;Hm002^?:Gl[SfUo:hlYOb^?JGl[SbUo:hmYO`00`0000^Uo:gl
YOb]o:Gl[ObUo:glYOb]o:Gl008000?oo`8000Coo`03003ooooo00;oo`03003ooooo00Coo`000ooo
00H00?ooool00?oo0002ool00`00ool00002ool01000ooooo`000ooo00H00?ooool00?oo0002ool0
0`00ooooo`0;ool00`00ool00002ool300001Ooo003oo`00ool00P0000Goo`00ool00?oo00<000Wo
o`03003ooooo00Koo`8000Coo`03003ooooo02Ooo`80000?WMbMoIgMWOfMg9gmWMfMoIgLWOfMg@00
QIf5_XFM00<0000<QIf5_XFMQKh005dnEAiM?UDNGCiE7Udn0P0000XdWDCm=9e4oSBMA?d006DnIAiU
?PP0001BUIfE_IFLUKfEWIFmUIbE_IFMUKd00;Gk[M^enjgK]O^]fkGk[M^enjgK]O^]fkGk[M/00;gJ
_OZmf[gj_MZmn[gJ_OZmf[gj_MZmn[gJ_OZmf[gj0035nLGIaO[5fLGiaMW5n/GIaOW5fLGjaMW5nLGI
0035f@00aQ[6>/HJaS[66/HjaQ[6>/HJaSX00<HjaQ[>>/HJaS[66P00_Q^nNkhKaW/200003KiKaW^n
FlIk_U_6NkiKaW^nFlIk002f?;HL0080000B]Sb^7;Hl002f?:hL]Sb^7;Hl002^?:GL[Sb]g:hlYMb^
?:gL0`00012Ug:gl002Uo:GLYObUg:GlYMbUo:GLYObUg:GlYM`001Goo`000ooo00H00?ooool00?oo
0002ool00`00ool00005ool01@00oooooooo00000_oo00<00?oo00000_oo00<00?ooool02ooo00@0
0?oo000000?oo`06003oo`00ool00?oo0P0000Coo`00ool000?oo`03003ooooo01Koo`03003ooooo
02Soo`0=002MoIFLWOfEW9gmUIbMoIFLWOfEW9gmUI`00`0003Z5WHFnOIf5_XFMQKimWHFn001M?UDM
GCiE7UdnEAeM?UDN000lWDCn?9e4oSbMA?h006DnGAeU?UdMICiM7FDnGAd009FLUKfEW9FmUIbE_IFL
UKfEW9FmUI`00:fJ]O^]VkGk[IZenjfK]O^]V[Gk[I^en`80000?[I/00;giaOZmn/Gj_OW5n[gjaOZm
nLGj_O[5n[gi0080000CaOX00<HjaOW6>/GiaS[5nLHjaOW6>/GiaS[5n@00aOW=nLGi00000/Hj00G6
>LHjaS[6>/Hi0080000:cS[6>LhjaSW>>/HicS[6>@00_S/200003LIk_W_6O;ikaW^nNlIl_W_6Nkik
aWbnNlIk0080000B[Sbf?:hl]Sf^?;Hl002f?Jhl]Sb^?000YOb^?:Gl[SfUo:hl0P0001:Uo:glYOb]
oJGl002Uo:glYOb]o:Gl[ObUo:glYOb]o:Gl[O`2000Dool000?oo`03003ooooo00D00003ool00000
008000;oo`8000Coo`800003ool00000008000koo`03003ooooo00?oo`800006ool00000ool00?oo
0P0000?oo`00ool00_oo0P006?oo0P00:_oo00T009gmWMbMoIgMWOfMg9gmWMd00`0000RMg@00QIf5
_XFMQKj5WHFn2@0002YM?UDNGCiE7P00=9e4oCBMA?hdWDCm001U?VDNICiU7VDnIAiU?VDN002EW9Fm
UIfE_IFLUKfEWIFmUIbE_IFM002]fkGk[M^enjgK]O^]fkGk[M/20000A[Gk[M^]njgK002mf[gj_MZm
n[gJ_OZmf[gj_MZmn[gJ002mfKgj_MW5nP00aOW5fLGjaMW5nLGIaO[5fLGiaMT00<GIaOW5fLGiaMT0
0<HJaS[66/HjaQX00<HJaS[66/hjaQ[6>/HJcS[66/HjaQX00;iKaW^nFlIk_U_6NkiKaW^nFlIk_U_6
NkiK0P000176O000]Sb^7;Hl[Qbf?:hL]S`00;Hl[Qbf?:hL002]g:hl00<0000D[ObUg:GlYMb]o:GL
YObUg000YMbUo:GLYObUg:GlYMbUo:GLYObUg0<001?oo`000ooo00@00?ooool000Koo`03003ooooo
01goo`03003ooooo02coo`03003ooooo02[oo`800004UIbMoIFLWOd2000019FLWOfEW9gm1`0000V=
_XFMSKj5WHfn001M?UDMGCh02000020lWDCn?9e4oP00ICiM7FDnGAeU?UdMICiM7@00UIbE_IFLUKfE
W9FmUIbE_IFLUKfEW000[IZenjfK]O^]V[Gk0P0002Z]V[Gk[I^enjfJ]O/00<Gj_OW5n[gjaOZmnLGj
_O[5n[gi002mnLGj_OW5n[gi0035nLHjaOW6>/GiaS[5nLHjaOT00<GicOW5nLgjaOW=nLGi0002aSX0
;<Hi0036>LhjaSW>>/HicS[6>LhjaSW>>/Hi003>>@00_W_6O;ikaW^nNlIl_W_6NkikaWbnN`00_W_6
O;ik002^?;Hm[Sbf?:hl]Sf^?;Hl002f?Jhl]S`300004jglYOb]oJGl[ObUo:gmYOb]o:Gl[OfUo000
YOb]o:Gl[ObUo:gl00@000:Uo003003ooooo017oo`001?oo0P003Ooo00<00?ooool05ooo0`00;?oo
00<00?ooool0;?oo100000>MoIgLWOd00`0001RMoIgL0025WHfmSIf=_HFMSKf=WHfmQIf=_@00GCiM
7UdnGAiM?UdNGCiM7P00=9d400006TCm001U?VDNICiU7VDnIAiU?VDN002EW9FmUIfE_IFLUKfEWIFm
UIbE_IFM002]fkGk[M/200004Jgk[M^enjgK[O^]fkGk[M^]n`00_OZmf[gj_MZmn[gJ_OX00P0000jm
fKgj_MW5n[gI_OZmf@00aMW5nLGIaO[5fLGi0P0002C5fLGiaMW5nLGIaOW5fLGiaMT00<HJ00366/Hj
aQ[>>/HJaS[66/hjaQ[6>/HJ003>6LhjcQT00;iKaW^nFlIk_U_6NkiKaW/200003KiKaWbnFlIk_U/0
0:hL]Sb^7;Hl[Qbf?:hL00@0000B[Sb^7000YMb]o:GLYObUg:glYMbUo:GL[ObUg:Gl002Uo:GL1000
00JUo:GLYObUg:GlYM`2000Bool005_oo`8002coo`@00003UIbMo@000080000AYOfMo:GmWObUoIgl
0025WHfnQIf=_XFMSKj5WHfnQIf=_P02000035DMGCiM7UdnEAeM?UdN000dGCBn=5dd_@D0000CICiM
7FDnGAeU?UdM002EW9FmUIbE_IFLUKfEW9FmUIbE_@00]O/00P0004N]VkGk[IZenjfK]O^]V[Gk[I^e
njfJ]O/00<Gj_OW5n[gjaOX00<Gj_OW5n[giaOZmnLGj_OW5n[gi0035nLHjaOW6>P00cO[5nLgiaOW=
n/GicOW5nLgjaOW=nLGi0036>LhjaSW>>/HicS[6>LhjaSW>>/Hi003>>LijaSW>N/hi002nNlIl_W_6
Nkik0080000>aWbnNlIl_W_6O;ikaWbnN`00[Sbf?Jhl]Sb^?0<0000A[Sbf?Jhl[Sd00:gmYOb]o:Gl
[OfUo:glYOb]oJGl[ObUo00300000jGl[ObUo002YO`01ZglYObUo:Gl[ObUo080017oo`00Fooo00<0
0?ooool0:?oo0`001?oo0P0000ZMoIgLWOfMg9gmWMbMoIgLWOfMg080000BSKf=WHfmQIf=_HfMSKf5
WHfmSId005dNGCiM7UdnGAiM?UdN0P0000Ld_CBM=;ddWCBm001DoP06000026DN002EW9FmUIfE_IFL
UKd50000E[Gk[M^]njgK]O^]fjgk[M^enjgK[O^]fkGk[M^]n`00_OZmf[gj0035n[gI_OZmfLGj_MVm
n[gIaOZmfKgj_MT00<GIaOT00<GiaMW5nLGIaOW5fLGiaMW5nLGIaOW5f@00aMT00<HJcS[66/HjaQ[>
>/HJaS[66P00cQW>>/hIcS[>6Lhj0036NkiKaW^nF`00_U_6NkiKaWbnFlIk_U_6O;iKaW/00;Hl[Q`3
00004JhL[Sb^7000[Qb^?:hL[S`00:GlYMb]o:GLYObUg:glYM`00`00012Ug:Gl002Uo:GLYObUg:Gl
YMbUo:GLYObUg:GlYM`0017oo`00Fooo00<00?oo00009Ooo0`002?oo01H009glYOfMo:GmWObUoIgl
YOfMo:GmWObUo@00SKj5WHfnQIf=_XFMSKj5W@L0000AEAeM?UdNGCh003Bn=5dd_CAM=;h005CnC=eD
oTcME?i<g@0800005XfmSIf=_HfLSKd00;Gk[IZenjfK]O^]V[Gk[I^enjfJ]O^]VkGk[IX00;gj0P00
03?5n[giaOZmnLGj_OW5n[giaOZmnLGj_OW5nP00aSX00<gjaOW=nLGicO[5nLgiaOW=n/GicOW5n@00
aOS=n@00cS[6>LhjaSW>>/HicS[6>@00cSW>N/HicW[>>LijaSW>NP00aW/00P0000bnNlIl_W_6O;ik
aWbnNlIl_W_6O;ikaW`200004Zhl]Sf^?:hm[Sbf?@00[Sf^?;Hm[Sb^?@00[OfUo:glYOb]o@800006
YOb]o:Gl[ObUo0000jGl00F]o:GlYObUo:gl00>Uo003[O`00000013oo`00Fooo0P008ooo0`003?oo
014009gLWOfMg9gmWMbMoIgLWOfMg9gmWMbMo@00SKf=WHfm00@00007SIf=_HfM001M7UdnGAh01`00
00@dWCBm=9dd_@80000PC=eDoTcME?i<gECnC=d008fMSKf=WHfmSIf=_HfMSKf=WHfm002enjgK[O^]
fkGk[M^]njgK]O^]fjgk[M^en`800011_MW5n[gI_OZmfLGj_MVmn[gIaOZmfKgj_MW5n[gI_OX00<Gi
aMW5nLGIaOW5fLGiaMW5nLGIaOW5f@00aMW=nLgIcOT00<HjaQ[>>/HJaS[66P00cQW>>/hIcS[>6Lhj
cQW>>/hIcSX00<Il_U_6NkiKaWbnFlIk_U_6O;iKaW^nF`0200004Kjl002^?:hL[Sb^7:hl[Qb^?000
[Sb^7:hl[Q`00:GLYO`00`0001BUo:GLYObUg:GlYMbUo:GL002Ug:GlYMbUo:GLYObUg:GlYMbUo:GL
0P004?oo0016ool00`00ooooo`02ool00`00ooooo`050002ool00`00ooooo`03ool00`00ooooo`0O
ool3000@ool03000WObUoIglYOfMo:GmWObUoIglYOfMo0@0000AUOf=WIGnSIfEoHfMUOj=W@00GAeU
OUdNIGiM7FEnGAiUOP0400008CAM=;hdG@00C=eDoTcME?i<gECnC=d008fLSKf=WHfmSIb=_HfMSKf=
W8fm002enjfJ]O^]VkGk[IZenjfK]O^]VP0200004;Gk[IX00;giaOZmnLGj_OW5n[giaOZmnLGj_OW5
n[gi0P0002o5nP00cOW5nLgjaOW=nLGicO[5nLgiaOT00<GhcOW5n<giaOS=n@00cS[6>LhjaST00<hi
cW[6>LijcSW>N/HicW[>>Lij003FNP00aWbnNlIl_W_6O;ikaWbnNlIl0080000@_[c6_;jla[`00:hm
[Sbf?Jhl[Sf^?;Hm002^?Jhl]Sd300003JglYOb]o:Gl[ObUo:glYOb]o:Gl[ObUo00000>Uo003[ObU
o:Gl00@00003ool00?oo00ooo`00AOoo00<00?oo00002?oo00L00?ooooooo`00ool00004ool00`00
ooooo`0Lool3000Dool02000WMbMoIgLWOfMg9gmWM`300006IgLYOd008fmSIf=_HfMSKf=WHfmSIf=
_HfM001M7UdnGAiU?UdNGCiM7VDn000TGAaM00D0000JC=eDoTcME?i<gECnC=d008fMSKf=WHfmSIf=
_HfMSKf=W@00[M^enjgK[O^]fkGk[M^]n`80000N[I^]^jfK[K^]V`00_MW5n[gI_OZmfLGj_MVmn[gI
aOZmf@00_MW5nKgI0035fLGiaMW5nLGIaOW5fLGi0P0003;5fLgicMW=nLGIcOW=fLgi0036>/HJ003>
6LhjcQW>>/hIcS[>6LhjcQW>>P00eW[>FLij0036O;iKaW^nFlIl_U_6N`00_[bnW;jl_Ybn_;jL_[`0
0:hl[Qb^?:hL[Sb^7:hl0`0001:^?:GL002Ug:GlYMbUo:GLYObUg:GlYMbUo:GLYO`00:GlYM`40005
ool00`00ooooo`0>ool004Goo`03003oo`0000Soo`03003ooooo00?oo`03003ooooo00;oo`03003o
oooo01[oo`8001Soo`03002Mo:Gm00@0000JWObUoIglYOfMo:Gm002EoXfMUOf=WIGnSIfEoHfMUOj=
W@00GAeUOUdNIGiM7FEnGAiUOP80000495`TOAaL97d300005UCnC=eDoTcME?h008fmSIb=_HfMSKf=
W8fmSIf=_HfL002]VkGk[IZenjfK0P0004:enjfJ]O^]V[Gk[IZen`00aOZmnLGj_OW5n[giaOZmnLGj
_OT00;fIaOZmVLGi_IT00<GicOW5nLgjaOW=n@00cOW5n<giaOS=nLGhcOW5n<giaOP00<Hi003>>Lij
aSW>N/hicW[6>LijcSW>NP00eW[>NMIjcWWFNP00aWbnNlIl_W/200003<Jl_[c6_;jla[bn_<Jl_[c6
_000[Sf^?0D0000AYOb^?:Gl[Sd00:glYOb]o:Gl[ObUo:glYOb]o:Gl[ObUo003000:ool00`00oooo
o`0=ool004Goo`03003oo`0000Soo`04003oooooool20005ool00`00ooooo`0Gool3000Kool20000
9ZGlWMbUoIgLYObMg:GmWMbUo9gLYOd008fmSIf=_HfMSKf=WHfmSIf=_HfM001M7UdnGAiU?UdNGCiM
7VDnGAh001aM95dLG2AM75d400004ECnC=eDoP00SKf=WHfmSIf=_HfMSKf=WHfmSId00:gK]O/00P00
01:]Vjfk[I^]^jfK[K^]Vjfk[I^]^`00_OZmfLGj_MVmn[gIaOX20000;[gIaOVmfLGi_MW5nKgI0035
fLGiaMW5n@00cOW5fLgicMW=nLGIcOW=fLgiaMW=nLgI003>6LhjcQW>>/hIcS[>6LhjcQW>>P00eW[>
FLijcUWFN/iIcWX00<Il0P0000^nW;jl_Ybn_;jL_[bnW;jl_Ybn_;jL00<0000CYMb^?:GL[SbUg000
YMb^?:GL[S`00:GlYMbUo:GLYObUg:GlYM`00`003Ooo00<00?ooool03Ooo0015ool00`00ool00008
ool01@00oooooooo00001Ooo0P005_oo0`007ooo01H009glYOfMo:GmWObUoIglYOfMo:GmWObUo@00
UOj=WIGmSIfEoXfMUOf=W@h0000797dLG2Am95`003BM?;h01@0000J=_HfLSKf=WHfmSI`60000CkGk
[IZenjfJ]O^]V[Gk[IZenjfJ]O^]V[Gk0035n[giaOZmnLGj0035nKfIaOZmVLGi_IW5n[fIaOVmV@00
aOW=n@00cOW5n<giaOS=nLGhcOW5n<giaOS=nLGh003=n000aSW>N/hicW[6>LijcSW>NP00eW[>NMIj
cWWFN/iieW[>NMIj0036_;jla[bn_<Jl_[c6_;jla[bn_<Jl0080000D][bn_@00[SbUo:hmYOb^?:Gl
002Uo:hlYOb^?@00[ObUo:glYOb]o080013oo`03003ooooo00goo`00A_oo00<00?ooool01_oo0P00
0ooo0`000ooo00<00?ooool04_oo0`008ooo014009gLYObMg:GmWMbUo9gLYOfMg:GlWMbUo@00SKf=
WHfm00@0000=UIfEoIFM001UGVenIEi]OVENKGiUGVenIEh00`0000TLG2AM75d003BM=;ddWCbm=9d0
1`0005>5GHEmQEf5OHEM002]Vjfk[I^]^jfK[K^]Vjfk[I^]^jfK[K^]Vjfk002mn[gIaOX00<Gi_MW5
nKgIaOVmfLGi_MW5nKgIaOT00<Gi003=nLGIcOW=fLgiaMW=nLgIcOW5fLgicMT00<gHcOS=f000cQW>
>/hIcS[>6Lhj003FN/iIcW[>FMIjcUW>N/iIeWX00=Jj002n_;jL_[bnW;jl_Ybn_;jL0080000C][ff
WKjm]Y`00:GL[SbUg:hlYMb^?000[SbUg:hlYM`00:GLYO`00`004_oo00<00?ooool03Ooo001Jool0
0`00ooooo`0?ool3000Wool200002JGmWObUoIglYOfMo:GmWObUo@05000059GmUIbMoIFMUOfEW9gm
UId006EMKGiUGVenIEe]OVENKGiUG@0051`300008bAL000dWCbn=9dl_CBM?;h008FmOEf5_XEMQKem
GHFnQEf5_GeM002]V[Gk[IZenjfJ]O^]V[Gk[IZenjfJ]O^]VP00_OT00P0001_5nKfIaOZmVLGi_IW5
n[fIaOVmVLGj_IW5n@00cOW5n<giaOS=nLGhcOW5n<giaOS=nLGh00000lgh01_=nLgh0036>LijcSW>
NP00eW[>NMIjcWWFN/iieW[>NMIj003F^]Jig[X00<Jl_[c6_;jla[`00P0001:f_;jm][bn_KJl_[ff
_000YOb^?:Gl[SfUo:hl002^?JGl[S`3000Eool00`00ooooo`0=ool005[oo`8000goo`<002coo`04
002Uo9gLYOd500003ZGlYMbUo000UOfEWIGmUIfEoIFMUOfEWIGmUId2000026enIEi]OVENKGiUGVen
IEh200000a@L31`0000200007SBM=;ddWCbm=9dd_@00QGf5GHEmQEf5OHEMQGf5GHEmQEd00:fK[K^]
Vjfk[I^]^jfK[K^]Vjfk[I^]^`80000i_MW5nKgIaOVmfLGi_MW5nKgIaOVmfLGi_MW5n@00aKT00<gi
cMW=nLGIcOW=fLgiaMW=nLgI003=f<ghcMS=n<gHcOP00<hjcQW>>P00eW[>FLijcUWFN/iIcW[>FMIj
003F^]JJe[[FVMJj002n_;jL0080000A_[ffW;Jm]Yfn_KJL][ffWKjm]Y`00:GL[SbUg:hlYMb^?003
000Hool00`00ooooo`0=ool005[oo`03003ooooo00Woo`<0033oo`<0000SYObMo:GmWObUo9glYOfM
o:Gl002MoIFMUOfEW9gmUIfEoIFLWOfEWIGm001]OVENKGiUGFenIEi]OVEMKGh001`l51`L?0030000
6Cbn=9dl_CBM?;h008FmOEf5_XEMQKemGHFnQEf5_@00]O^]V[Gk[IZenjfJ]O^]V[Gk00<0000M[K^]
VP00_IW5n[fIaOVmVLGj_IW5nKfIaOZmVLGi0035^KfHaKT00<giaOS=nLGhcOW5n<giaOP00003cOP0
6LgicOS=n<ghcOT00<ij003FN/iieW[>NMIjcWWFN/iieWX00=Jje[WN^]Jie[[F^Mjj0080000?][bn
_KJl_[ff_;jm][bn_KJl_[ff_;jm002^?JGl00@00003ool00?oo01Soo`03003ooooo00goo`00F_oo
00<00?ooool01ooo0P00=?oo00`00:GlYMbUo:GLYObUg:GlYMbUo:GLYO`2000029FMUOfEWIGmUIfE
oIFMUOd>00000``L51`<7004000053bm=9dd_@00QGf5GHEmQEf5OHEMQGf5GHEm002]^jfK[K^]Vjfk
[I/20000BZfk[I^]^jfK[K^]V`00_MW5nKgIaOVmfLGi_MW5nKgIaOT00<Fi_IW5^LFI0035fLgicMW=
nLGIcOW=fLgi003=n<gHcOS=f<ghcMS=n<gHcOP00=IjcUW>N/iIeW[>FLijcUWFNP00e[[FV]JjeYWF
^]JJe[X00=mj002n_KJL][ffWKjm]Ybf_KJM_[ffW;Jm]Yd30005ool00`00ooooo`0Gool00`00oooo
o`0=ool005Woo`03003ooooo00Goo`<003Ooo`0A002UoIglYObMo:GmWObUo9glYOfMo:GlWO`009FM
UOfEW00400003IgmWIbMo@00MKieGWFnMEee_WENMKieGGFn00@0000451`L?0004o`5000038FmOEf5
_XEMQKemGHFnQEf5_@00]O^]VP<0000Q[IZ]^jfJ[K^]VZfk[IZ]^`00aOVmVLGj_IW5nKfIaOZmVLGi
0035^KfHaKVmV<Fi_IP00<GhcOW5n<giaOS=n@0000;=n005cOW=n<ghcOS=n@02cOP05P00eOP00=Ij
cWWFN/iieW[>NMIj003F^]Jig[[F^MJje[WN^P00gg_GN]mk0P0000Nf_;jm][bn_KJl_[ff_0030009
ool00`00ooooo`0Gool00`00ooooo`0<ool005Woo`8000?oo`<003_oo`80000:YMbUo:GLYObUg:Gl
YMbUo:GLYO`400005IgLWOfMgIgmWMbMoIgMWOd007EnMEieOWENMGieGWEnMEieOP002o`3f`050000
0`_L4o`;g00=00004jfK[K^]Vjfk[I^]^jfK[K^]Vjfk[I^]^`00aOVmfLGi_MW5nKgI0080000ZaKVm
VLFiaIW5^KfIaKW5V@00aMW=nLgIcOT00<ghcMS=n<gHcOS=f<ghcMS=n000eOS=elgh003FN/iIcW[>
FMIj003F^]JJe[[FVMJjeY[F^P000]mj00OONmmjgg[ONP00]Ybf_@04000=ool00`00ooooo`0Fool0
0`00ooooo`0<ool005Woo`03003oo`000080043oo`07002Mo:GlWObUoIglYO`00`000ZGl00/009fL
WOfEW9gmWIbMoIFLWOfMW9gm00800008MEie_WEMMKieGWFnMEee_P8000042m/D?0_K53`20000<@_K
4o`;fa?l001eOVdMMGie7GEnKAeeOWDMMGh00:fk[IZ]^jfJ[K^]VZfk[IZ]^jfJ[K^]VZfk0035nKfI
aOZmV@00_IS5^KfHaKVmV<Fi_IS5^KfHaKVmV000aOS=n@0000;=n005cOW=n<ghcOS=n@02cOP06`00
eOS=mmGhcOOEn000eW[>NMIj003F^]Jig[[F^MJje[WN^P00gg_GN]mkgg[ONmMjgg_ONP02000Aool0
0`00ooooo`0Fool00`00ooooo`0<ool005Woo`8004Coo`03002Ug:Gl00<0000RYObUg:GlYMbUo:GL
002MgIgmWMbMoIgMWOfMg9gmWMfMoIgL001eGWEnMEieOWENMGieGWEnMEh000?K2o`3g0_l0m/20000
BQ?l2m`Co000MGieGGEmMEeeOWEMMGeeGGEn002]^jfK[K^]Vjfk[I^]^jfK[K^]Vjfk[I^]^`00aOVm
f@00aIW5^KfIaKW5VLFi_IW5^LFIaKVmVLFi003=n@00cOS=f<ghcMS=n<gHcOS=f<ghcMP00<gGcOS=
emGhcMO=n000eWX00=JjeY[F^]JIe[[FV]Jj0002ggX01mmkgg[ON]mjgg_ONP0001Coo`03003ooooo
01Goo`03003ooooo00coo`00F_oo00<00?ooool0@ooo0P000ZGl00FUoJGlYObUo:Gm00>Uo00;002M
W9gmUIbMoIfLWOfEW9gmWIbMo@0=000011@l2m/D?0_K0`0002/;fa?l001eOVdMMGie7GEnKAeeOWDM
002]VZfk[IZ]^jfJ[K^]VZfk[IZ]^jfJ[K^]VP00_IT00;fHaKVmV<Fi_IS5^KfHaKVmV<Fi_IS5^KfH
aKT00002cOP01LgicOS=n<ghcOT00lgh01T00<ggeOS=mmGhcOOEn<ggeOP00=Jje[WN^]Jie[[F^Mjj
003ONmMjgg_ON]mkeg[ON`02000Fool00`00ooooo`0Dool00`00ooooo`0<ool005_oo`8004Coo`0C
002Ug:GlYMbUo:GLYObUg:GlYMbUo:GL002MgIgmWMbMoIgMWOd00`0000bUoIgL0025WHFnQIf5_XFM
QKj5WHFnQId4000010_l0m/000;I0P0001LCo000MGieGGEmMEeeOWEMMGeeG@00[I^]^jfK[K^]Vjfk
[I^]^jfK[K^]Vjfk0080000[aIW5^KfIaKW5VLFi_IW5^LFIaKVmVLFiaIW5^@00aKP00<ghcMS=n<gH
cOS=f<ghcMP00<gGcOS=emGhcMO=n<gGeOP00=Gg003F^]JIe[[FV]Jj00000]mj00KONmmjgg[ON]mk
000Iool00`00ooooo`0Cool00`00ooooo`0<ool005goo`03003ooooo04;oo`05002Uo:GlYObUo@03
YO`01jGmYObUo:Gl002MW9gm00<0000@YOfMo:GmWObUoIgl0025WHFnOIf5_XFMQKimWHFnQId20000
0a@l0000000200000`;H0cT0000200004GEnKAeeOWDMMGi]7GEnMAd00:fJ[K^]VZfk[IZ]^jfJ[K/0
0`0000j]^jFJ002mV<Fi_IS5^KfHaKVmV<Fi_IS5^KfH0P0000?5^;fH00000lgh01k=nLghcOS=n000
cOOEn<ggeOS=mmGhcOOEn<gg003Em]Gg003F^]Jig[X00=mkeg[ONmmjgg_GN]mk000Jool00`00oooo
o`0Cool00`00ooooo`0<ool005koo`03003ooooo04;oo`0;002Ug:GlYMbUo:GLYObUg:GlYMbUo003
00002ZGmWMbUo9gLYOfMg:GlWMbUoIgL0P0000f5_XFMQKj5WHFnQIf5_XFMQKh001@L31`D70020003
0]T4000037EmMEeeOWEMMGeeG@00[I^]^jfK[K^]V`80000^[K^]VZfk[I^]^`00aKW5VLFi_IW5^LFI
aKVmVLFiaIT00<FHaKS5V<FhaIP00<gHcOS=f<ghcMP00<gGcOS=emGhcMO=n<gGeOS=e`00eMOEmmGG
eOL00=Jj0002ggX01]mkgg[ON]mjgg/001coo`03003ooooo01;oo`03003ooooo00coo`00Gooo00<0
0?ooool0@Ooo00<00:GmYO`00ZGl00>UoJGlYO`00`000ZGl01<009glYOfMo:GmWObUoIglYOfMo:Gm
WObUo@00QKimWHFnQIf5_P0600000a@L53`<6`0200001@<i0]P3>@00G?h01@0000AeOP00[K^]VP<0
000JYIZ]^jFJ[K^UVZfkYIZ]^`00aKVmV<Fi_IS5^KfHaKVmV000aIS5^;fHaKW5V<Fh_IP000?=n00A
003=mmGhcOOEn<ggeOS=mmGhcOL00=GfeOOEm]GgeOKEm`0200001MMjgg_ON]mkegX00P007_oo00<0
0?ooool04_oo00<00?ooool02ooo001Pool20012ool00`00YObUg00400004ZGlYMbUo:GLYObUg000
WMbUoIgLYObMg:GmWMbUo9gLYOfMg0H00005UKfEWIFmUIfE_@04000010`L51`000000P;I00H005cn
E=eDoUCMG?h40000<jfJ[K^]Vjfk[IZ]^jfK[K^]VZfk[I^]^`00aKW5VLFi_IW5^LFI0035V<FhaIS5
^<FHaKS5V<FhaIP00<gHcOP00<ghcMOEn<gGcOS=emGhcMO=n000eOOEemGgeMOEmmGG003MeP020002
ggX00`00ooooo`0Oool00`00ooooo`0Aool00`00ooooo`0;ool006;oo`03003ooooo043oo`8000>U
o005[ObUo:GlYOb]o003YO`200001ZGmWObUoIglYOfMo0<0000?WObUo@00UOf=WIGmSIfEoHfMUOf=
WIGmSId002aM00D0000m0]P3>@00G?iDgEcnE=eLoUCMG?h00:fkYIZ]^jFJ[K^UVZfkYIZ]^jFJ[K^U
VP00_IS5^KfHaKVmV000aIS5^;fHaKW5V<Fh_IS5^LFHaKP00<gi003En<ggeOS=mmGhcOOEn<ggeOP0
0=GgeOKEmmGfeOOEmP00gOD00mgf0P008_oo00<00?ooool04Ooo00<00?ooool02ooo001Sool00`00
ooooo`10ool04@00YObUg:GlYMbUo:GLYObUg:GlYMbUo:GLYO`00:GmWM`00`00016Ug:GlYMbUo:GL
YO`009FmUIfE_IFMUKfEWIFmUIfE_IFM00800003;;d/GBbm00@0000HE=eLoUCME?iDgEcnE=eDoP00
[K^]VZfk[I^]^jfJ[K^]Vjfk[IZ]^jfK002mVLFi0P0002G5V<FhaIS5^<FHaKS5V<FhaIS5^<FHaKP0
0<ghcMOEn<gGcOS=emGhcMO=n000eOOEemGgeMOEmmGGeOL00=gfgMKMm]gFgOH0000Sool00`00oooo
o`0@ool00`00ooooo`0;ool006Coo`03003ooooo043oo`03002]o:Gl00:Uo005[ObUo:GlYOb]o003
YO`300001YglYOfUo:GlWObUo@:Uo00=WObUo@00UOf=WIGmSIfEoHfMUOf=WIGmSId0100000<d_BaM
00000P0003MDgEcnE=eLoUCMG?iDg@00YIZ]^jFJ[K^UVZfkYIZ]^jFJ[K^UVZfk0035^@00aKW5V<Fh
_IS5^LFHaKRmV<FiaIS5^;fHaKT00<Eh003En<ggeOS=mmGhcOOEn<gg003Em]GgeOKEmmGfeOL00003
gOH00mgegOH0000Uool00`00ooooo`0?ool00`00ooooo`0;ool006Goo`80047oo`800007YMbUo:GL
YObUg:GlYM`00`0001FUg:Gl002Uo:GLYObUg:GlYMbUo:GLYObUg000UIfE_IFMUKfEWIFmUId00`00
00BMg9gl001M?PL0000BG?iDgECnE=eLoUCM002]Vjfk[IZ]^jfK[K^]VZfk[I^]^jfJ0P0002O5^<FH
aKS5V<FhaIS5^<FHaKS5V<FhaIS5^000aGO5E`00cMO=n<gGeOS=elghcML00=GGeOOEemGgeMOEmmGG
003Me]gfgMKMm]gF00009Ooo00<00?ooool03ooo00<00?ooool02ooo001Wool00`00ooooo`10ool0
0`00YObUo00400000jGl[ObUo002YO`01Jgl002Uo9glYOd00ZGl00RMo:GmYObUo9gl002=WIGm1000
00^MW:GmWIbUoIfLYOd005dnGAeU?UdN00H0000=G?iDgEcnE=d00:FJ[K^UVZfkYIZ]^jFJ[K/00P00
02:UFZfk0035^;fHaKW5V<Fh_IS5^LFHaKRmV<Fi0035N<EGaGS5E`00cOOEn<ggeOS=m`00eOKEmmGf
eOOEm]GgeOH000;MmP04gOGMm]gf000Wool00`00ooooo`0>ool00`00ooooo`0;ool006Soo`03003o
oooo043oo`80000EYObUg:GlYMbUo:GLYObUg:GlYMbUo000YObUg:GlYMbUo:GLYObUg:Gl00<0000A
WOfMg9glWMbMoIgLWObMg9gmWMbMo000GCiM7UdnGAiM?P02000031@L91`00000E=eLoUCM002]Vjfk
[IZ]^`<0000ZYG^UFjEkYEX00<FHaKS5V<FhaIS5^<FHaKS5V<Fh0035MlEGaGS5ElEgaEL00<gGcOS=
emGh003EmmGGeOOEemGgeMOEm`00gOKMe]gfgMKMmP00:?oo00<00?ooool03Ooo00<00?ooool02ooo
001Yool00`00ooooo`10ool01@00YObUo:Gl[O`00jGl00F]o:GlYObUo00000:Uo004WObUoJGlYO`3
0002YO`04`00WIbUoIfLYOfMW:GmWIbUoIfLYOfMW:Gm001M?UdMICiM7Udn00<0000393dL700000<0
000/[K^UVP00002]^jEJ[K^UFZfkYEZ]^jEJ0035V<Fh_IS5^LFHaKRmV<Fi0035N<EGaGS5ElEhaEO5
N000eOS=mmGh003EmmGfeOOEm]GgeOKEm`00gOKMm@?MmP03gOD00?oo02Soo`03003ooooo00goo`03
003ooooo00[oo`00J_oo0P00@Ooo00l00:GLYObUg:GlYMbUo:GLYObUg:GlYM`00:GLYO`00`0001:U
o:GLYObUg:GlYM`009gLWOfMg9glWMbMoIgLWObMg9gmWM`6000028fmSId0000091`D72@L51`30000
;ZEKYG^UFZEkYE^UNjEJYG^UFjEk0035^<FHaKS5V<FhaIS5^000aGO5ElEhaEO5MlEGaGS5ElEg003E
n000eOOEemGgeMOEmmGGeOOEe`00gMKMm]gFgOKMeP00:_oo00<00?ooool03Ooo00<00?ooool02_oo
001/ool00`00ooooo`0oool20002YO`01ZglYObUo:Gl[ObUo0@000:Uo005[ObUo:GlYOb]o003YO`2
00001ZGmWIbUoIfLYOfMW0<000:Uo00g002=_HFMSKj=WHfmQIf=_P0093dL72@m71`T?@00[K^UFZfk
YEZ]^jEJ[K^UFZfkYEZ]^`00aKW5V<Fh_IS5^@00aGS5ElEhaEO5N<EGaGS5ElEhaEL00<gg003Em]Gg
eOKEmmGfeOOEmP00gOD00mgf00?MmMgf0000:ooo00<00?ooool03?oo00<00?ooool02_oo001]ool0
0`00ooooo`10ool01000YObUg:Gl100001>Ug:GlYM`00:GLYObUg:GlYMbUo:GLYObUg:GlYMbUo000
WOfMg00300003ZGLYObUg:GlYMbUo000SKf=WHfmSIf=_HfMSKd20000<Q@L91`D7000YEZUNjEKYG^U
FZEkYE^UNjEJYG^UF`00aIS5^<FHaKP00<EgaEO5N<EGaGO5ElEhaEO5MlEGaGS5E`00eMOEmmGGeOOE
emGgeMOEm`00gOKMe]gfgMKMm]gF000/ool00`00ooooo`0;ool00`00ooooo`0:ool006koo`03003o
oooo043oo`<00005[ObUo:GlYOb]o003YO`01@00YObUo:Gl[O`00jGl00B]o:GlYObUo0<000ZUo008
002=_HFMSKj=WHfmQIf=_P<0000X93dL7000YEZ]^jEJ[K^UFZfkYEZ]^jEJ[K^UFP00_IS5^@00aGS5
ElEhaEO5N<EGaGS5ElEhaEO5N<EG002m5P00eOKEmmGfeOOEm]Gg0003gOH01=gegOKMmP00;Ooo00<0
0?ooool02ooo00<00?ooool02_oo001_ool20011ool02`00YObUg:GlYMbUo:GLYObUg:GlYM`00P00
00JUo:GLYObUg:GlYM`300004ZGLYO`00:GlYMbUo:GLYObUg:GlYMbUo:GLYO`008fmSIf=_@L0000^
91`D7000YEZUNjEKYG^UFZEkYE^UNjEJYG/00<Fh0035MlEGaGS5ElEgaEO5N<EGaGO5ElEhaEL00<DF
aCH00=GgeMOEmmGGeOOEe`00gMKMm]gFgOKMe]gf000^ool00`00ooooo`0:ool00`00ooooo`0:ool0
077oo`03003ooooo03ooo`04002Uo:Gl[O`3YO`01ZglYObUo:Gl[O`000:Uo0<00003YOb]o:Gl00:U
o003[O`00:Gl00VUo0@000Koo`<0000:71`00:EJ[K^UFZfkYEZ]^jEJ[K/300005lEhaEO5N<EGaGS5
ElEhaEO5N<EGaGS5ElEh0035=lDFaCL00=GgeOKEmmGf00000]gf00GMmMgfgOKMmP00033oo`03003o
oooo00Woo`03003ooooo00[oo`00L_oo00<00?ooool0?ooo00X00:GlYMbUo:GLYObUg:GlYMbUo0@0
000AYMbUo:GLYObUg:GlYMbUo:GLYO`00:GlYMbUo:GLYObUg003000;ool01`000MD00000YG^UFZEk
00D0000QWG^MFYek0035N<EGaGO5ElEhaEO5MlEGaGS5ElEg0035=/DFaCK55/Df003EmmGGeOL00=gf
gMKMm]gFgOKMeP00037oo`03003ooooo00Soo`03003ooooo00[oo`00Looo00<00?ooool0?ooo00@0
0:GlYOb]o0D000:Uo005[O`00:GlYOb]o003YO`01ZglYObUo:Gl[O`000:Uo0<000ooo`030001e@7F
00<0000PYG^M6ZEkWAZUNidJYG^M6P00aEO5N<EGaGS5ElEhaEO5N<EGaGP00<DgaAK5=kdFaCO55P00
eOKEm`00gOKMm@?MmP03gOGMmP00037oo`03003ooooo00Woo`03003ooooo00Woo`00M?oo00<00?oo
ool0?ooo0`0001BUo:GLYObUg:GlYMbUo:GLYO`00:GlYMbUo:GLYObUg:GlYMbUo:GL0`004ooo02X0
007E0MD009ekWEZMNieKWG^MFYekWE^MNieJ0035ElEhaEO5MlEGaGS5ElEg0035=/DFaCK55/DfaAK5
=/DF003Ee`00gMKMm]gFgOKMe]gf000cool00`00ooooo`08ool00`00ooooo`09ool007Goo`80043o
o`04002Uo:Gl[O`3YO`01ZglYObUo:Gl[O`000:Uo004[ObUo:GlYO`3000Gool07`000MD009dJYG^M
6ZEkWAZUNidJYG^M6ZEk0035N<EGaGS5ElEhaEO5N<EG00355/Dg_AK5=lDFaCNm5/Dg00800005gOGM
m]gfgOKMm@02gOH00`00ooooo`0bool00`00ooooo`07ool00`00ooooo`09ool007Ooo`03003ooooo
03koo`0?002Uo:GLYObUg:GlYMbUo:GLYObUg:Gl002Uo:GL00<001_oo`0X0001e@00WE^MNieJWG^M
FiekWEZMNieKWG/00<EgaEO5N<EGaGO5E`00aAK5=/DFaCK55/DfaAK5=/DFaCH00=gfgMKMm]gFgOKM
e]gf000dool00`00ooooo`07ool00`00ooooo`09ool007Soo`03003ooooo03koo`800003YOb]o:Gl
00:Uo003[ObUo:Gl00@001ooo`0R0001e@00WAZUNidJYG^M6ZEkWAZUNidJYG/00<EhaEO5N<EG0035
5/Dg_AK5=lDFaCNm5/DgaAK5=`00a?D00=gfgOD3gOH00`00ooooo`0dool00`00ooooo`06ool00`00
ooooo`09ool007Woo`03003ooooo03ooo`04002Ug:GlYM`4000Tool200008iekWE^MNieJWG^MFiek
WEZMNieK0035ElEgaEL00<DFaCK55/DfaAK5=/DFaCK55/DfaAH00;bD003Me]gfgMKMm]gF0000=ooo
00<00?ooool01Ooo00<00?ooool02Ooo001jool20010ool3000Yool200007JEkWAZUNidJYG^M6ZEk
WAZUNidJ0035ElEh0035=kdFaCO55/Dg_AK5=lDFaCNm5P00_9C4mKbD00000]gf00?Mm@00ool0>?oo
00<00?ooool01?oo00<00?ooool02Ooo001lool00`00ooooo`0mool00`00ooooo`0Zool08P00WEZM
NieKWG^MFYekWE^MNieJWG/00<Eh0035=/DFaCK55/DfaAK5=/DFaCK55P00_9C4mKbEa?FlU000gMKM
mP00>Ooo00<00?ooool01?oo00<00?ooool02Ooo001mool00`00ooooo`0lool00`00ooooo`0[ool<
00005LDg_AK5=lDFaCNm5/DgaAK5=kdFaCL00<Ce_9C4mKbDa?FlU000gOH0000jool00`00ooooo`04
ool00`00ooooo`08ool007koo`03003ooooo03_oo`03003ooooo02coo`0M002=6hdkSA^E>hdKSC^=
6iDkSA/00<DFaCK55/DfaAK5=/DFaCK55/Df0034mKbEa?FlU<Ce_9G4m@02000lool00`00ooooo`03
ool00`00ooooo`08ool007ooo`8003_oo`03003ooooo02goo`0N002<fYDkS=^E>hcJUC^<fiDkS=X0
0<DFaCNm5/DgaAK5=kdFaCO55P00_9C4mKbDa?FlU<Ce_9C4m@00?Ooo00<00?ooool00_oo00<00?oo
ool02?oo0021ool00`00ooooo`0hool00`00ooooo`0]ool07P00UC^=6hdkSA^E>hdKSC^=6iDk0035
=/DFaCK55/DfaAK5=/DF002lULCe_9C4mKbEa?FlU<Ce_9D003goo`03003ooooo00;oo`03003ooooo
00Soo`00P_oo00<00?ooool0=ooo00<00?ooool0;_oo01`009DkS=ZE>hcKUC^<fYDkS=^E>`00aCO5
5/Dg_AK5=lDF002lU<Ce_9C4mKbDa?FlU<Ce_9@003ooo`05003oooooool0000:ool008?oo`03003o
oooo03Koo`03003ooooo02ooo`0K002E>hdKSC^=6iDkSA^=>hdK00355/DfaAK5=/DFaCH00<Ce_9C4
mKbEa?FlU<Ce_9G4m@00043oo`04003ooooo000:ool008Coo`8003Koo`03003ooooo033oo`0J002E
>hcJUC^<fiDkS=ZE>hcK002m5/DgaAK5=`00a?FlU<Ce_9C4mKbDa?FlU<Ce_9@0043oo`04003ooooo
000:ool008Koo`03003ooooo03?oo`03003ooooo033oo`0I002=6iDkSA^=>hdKUC^=6hdk0035=/DF
aCH00<Ce_9C4mKbEa?FlU<Ce_9G4mKbD0000@_oo00<00?oo00002_oo0027ool00`00ooooo`0bool0
0`00ooooo`0aool200005YDkS=ZE>hcKUC^<fYDk0035=kdF002lU<Ce_9C4mKbDa?FlU<Ce_9C4m@00
@ooo00<00?oo00002Ooo0028ool00`00ooooo`0aool00`00ooooo`0bool400004hdkSA^E>hdK0035
5P00_9C4mKbEa?FlU<Ce_9G4mKbDa?FlU@0004Coo`8000Woo`00ROoo0P00<?oo00<00?ooool0<ooo
00@005AmC5aDO@@0000>S=X00000a?FlU<Ce_9C4mKbDa?FlU<Ce_9@004Goo`8000Woo`00Rooo00<0
0?ooool0;Ooo00<00?ooool0=?oo00L005ALC5aDG4aLE5a<G00200003<Ce_9G4mKbDa?FlULCe_9C4
mKbEa?D004Goo`8000Woo`00S?oo00<00?ooool0;?oo00<00?ooool0=Ooo01@005AmC5aDODaLE7e<
G000_9C4mKbDa?FlU<Ce_9C4mKbDa?FlU000@Ooo10002ooo002=ool00`00ooooo`0[ool00`00oooo
o`0fool04P00E5a<G5ALC5aDG4aL002lU<Ce_9G4mKbDa?FlULCe_9@003koo`@000ooo`00S_oo0P00
:ooo00<00?ooool0=_oo018004aLE7e<G5AmC5aDO@00a?FlU<Ce_9C4mKbDa?FlU<Ce000jool4000C
ool0093oo`03003ooooo02Soo`03003ooooo03Ooo`0A001<G5ALC5aDG4aL002lULCe_9C4mKbEa?Fl
U<Ce_9D0000fool4000Gool0097oo`03003ooooo02Ooo`03003ooooo03Soo`0?001<G5AmC5aDODaL
002lU<Ce_9C4mKbDa?FlU00003?oo`@001_oo`00T_oo00<00?ooool09_oo00<00?ooool0>?oo00l0
05ALC5aDG4aLE5`00<Ce_9G4mKbDa?FlULCe0000;ooo10007ooo002Cool2000Vool00`00ooooo`0i
ool03P00E7e<G5AmC5`00;bDa?FlU<Ce_9C4mKbD000[ool4000Sool009Goo`03003ooooo02?oo`03
003ooooo03[oo`0=001DG4aLE5a<G000_9C4mKbEa?FlU<Ce0000:?oo0`009ooo002Fool00`00oooo
o`0Rool00`00ooooo`0kool02`00E7e<G5Am0034mKbDa?FlU<Ce00009Ooo1000:_oo002Gool00`00
ooooo`0Qool00`00ooooo`0kool02`00C5aDG4aL002lULCe_9C4mKbE00008Ooo1000;_oo002Hool2
000Qool00`00ooooo`0lool02P00C5aDO@00a?FlU<Ce_9C4m@007Ooo1000<_oo002Jool00`00oooo
o`0Nool00`00ooooo`0mool02000C5aDG000a?FlULCe000Jool4000fool009_oo`03003ooooo01go
o`03003ooooo03koo`07001<G000_9C4mKbD00005_oo1000>_oo002Lool00`00ooooo`0Lool00`00
ooooo`0nool01`00E5`00<Ce_9C4m@0001;oo`@003koo`00WOoo0P007?oo00<00?ooool0?ooo00D0
05Am0034m@00013oo`<004;oo`00Wooo00<00?ooool06Ooo00<00?ooool0@?oo0P0000>lU@00ool0
2ooo1000AOoo002Pool00`00ooooo`0Hool00`00ooooo`11ool00`00a?D00008ool40019ool00:7o
o`03003ooooo01Ooo`03003ooooo047oo`8000Goo`@004goo`00X_oo00<00?ooool05_oo00<00?oo
ool0@_oo00<00?oo00000`00DOoo002Sool2000Fool00`00ooooo`10ool4001Eool00:Goo`03003o
oooo01?oo`03003ooooo03coo`@005Woo`00Y_oo00<00?ooool04_oo00<00?ooool0>?oo1000GOoo
002Wool00`00ooooo`0Aool00`00ooooo`0eool3001Qool00:Soo`80017oo`03003ooooo037oo`@0
06Coo`00Z_oo00<00?ooool03Ooo00<00?ooool0;_oo1000J?oo002[ool00`00ooooo`0<ool00`00
ooooo`0Zool4001/ool00:coo`03003ooooo00_oo`03003ooooo02Koo`@0073oo`00[Ooo0P002ooo
00<00?ooool08_oo1000M?oo002_ool00`00ooooo`08ool00`00ooooo`0Nool4001hool00;3oo`03
003ooooo00Ooo`03003ooooo01_oo`<007coo`00/Ooo00<00?ooool01_oo00<00?ooool05ooo1000
Oooo002bool20006ool00`00ooooo`0Cool40023ool00;Coo`03003ooooo00?oo`03003ooooo00oo
o`@008Ooo`00]Ooo00<00?ooool00_oo00<00?ooool02ooo1000Rooo002fool01@00oooooooo0000
2Ooo1000Sooo002gool200000ooo003oo`04ool4002Cool00;Woo`800003ool00000008009Ooo`00
^_oo0P00Vooo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003o
oomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSo
o`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003o
oomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSo
o`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003o
oomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSo
o`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo003ooomHool00?oooeSoo`00ooooF?oo0000
\
\>"],
  ImageRangeCache->{{{0, 342.188}, {308.312, 0}} -> {-0.34822, -0.164271, \
0.00389779, 0.00389779}}]
}, Open  ]],

Cell[TextData[{
  "Here is the analytical expression for the rho of the put option ",
  StyleBox["xyzft", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.35"],

Cell[CellGroupData[{

Cell["Rho[xyzft, settlement, r]", "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(\(-\(\(20\ \((1 + 
                Erf[\(\(-\(2\/\(5\ \@3\)\)\) + \@3\/20\)\/\@2])\)\)\/\(3\ E\^\
\(1/25\)\)\)\)\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["This is a numerical approximation. ", "MathCaption",
  CellTags->"0.36"],

Cell[CellGroupData[{

Cell["N[%]", "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(\(-5.67015597470215304`\)\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell[TextData[{
  "We define the rho of the option ",
  StyleBox["abcft", "MB"],
  " as a function of two variables, ",
  StyleBox["x", "MB"],
  " and ",
  StyleBox["t", "MB"],
  ", the price of the underlying asset and the time to maturity, \
respectively. "
}], "MathCaption",
  CellTags->"0.37"],

Cell["\<\
optionrho[x_, t_] = Rho[abcft,
   ToCalendar[ToJulian[settlement] + Floor[t]], r] /.
   Price[ABC] -> x;\
\>", "Input",
  CellLabel->"In[32]:="],

Cell["\<\
This illustrates how the graph of the option rho changes as the \
time to maturity varies. \
\>", "MathCaption",
  CellTags->"0.38"],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Table[optionrho[x, j],
   {j, 0, 120, 10}]], {x, 25, 45},
   PlotLabel ->
      \"    Call Option Rho\\nfor Different Maturities\",
   FrameLabel -> {\"Stock Price\", \"\"}];\
\>", "Input",
  CellLabel->"In[33]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.16667 0.0476191 0.0147151 0.0581978 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -35 -24 ]
[.5 -0.0125 35 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13111 -6 -4.5 ]
[-0.0125 .13111 0 4.5 ]
[-0.0125 .24751 -6 -4.5 ]
[-0.0125 .24751 0 4.5 ]
[-0.0125 .3639 -6 -4.5 ]
[-0.0125 .3639 0 4.5 ]
[-0.0125 .4803 -6 -4.5 ]
[-0.0125 .4803 0 4.5 ]
[-0.0125 .59669 -12 -4.5 ]
[-0.0125 .59669 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74 0 ]
[.5 .63053 74 31 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(25)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(30)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(35)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(40)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(45)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -96 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13111 m
.00625 .13111 L
s
[(2)] -0.0125 .13111 1 0 Mshowa
0 .24751 m
.00625 .24751 L
s
[(4)] -0.0125 .24751 1 0 Mshowa
0 .3639 m
.00625 .3639 L
s
[(6)] -0.0125 .3639 1 0 Mshowa
0 .4803 m
.00625 .4803 L
s
[(8)] -0.0125 .4803 1 0 Mshowa
0 .59669 m
.00625 .59669 L
s
[(10)] -0.0125 .59669 1 0 Mshowa
.125 Mabswid
0 .04381 m
.00375 .04381 L
s
0 .07291 m
.00375 .07291 L
s
0 .10201 m
.00375 .10201 L
s
0 .16021 m
.00375 .16021 L
s
0 .18931 m
.00375 .18931 L
s
0 .21841 m
.00375 .21841 L
s
0 .27661 m
.00375 .27661 L
s
0 .3057 m
.00375 .3057 L
s
0 .3348 m
.00375 .3348 L
s
0 .393 m
.00375 .393 L
s
0 .4221 m
.00375 .4221 L
s
0 .4512 m
.00375 .4512 L
s
0 .5094 m
.00375 .5094 L
s
0 .5385 m
.00375 .5385 L
s
0 .56759 m
.00375 .56759 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13111 m
1 .13111 L
s
.99375 .24751 m
1 .24751 L
s
.99375 .3639 m
1 .3639 L
s
.99375 .4803 m
1 .4803 L
s
.99375 .59669 m
1 .59669 L
s
.125 Mabswid
.99625 .04381 m
1 .04381 L
s
.99625 .07291 m
1 .07291 L
s
.99625 .10201 m
1 .10201 L
s
.99625 .16021 m
1 .16021 L
s
.99625 .18931 m
1 .18931 L
s
.99625 .21841 m
1 .21841 L
s
.99625 .27661 m
1 .27661 L
s
.99625 .3057 m
1 .3057 L
s
.99625 .3348 m
1 .3348 L
s
.99625 .393 m
1 .393 L
s
.99625 .4221 m
1 .4221 L
s
.99625 .4512 m
1 .4512 L
s
.99625 .5094 m
1 .5094 L
s
.99625 .5385 m
1 .5385 L
s
.99625 .56759 m
1 .56759 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Call) show
117.000000 15.000000 moveto
(Option) show
159.000000 15.000000 moveto
(Rho) show
63.000000 31.000000 moveto
(for) show
87.000000 31.000000 moveto
(Different) show
147.000000 31.000000 moveto
(Maturities) show
207.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.02381 .01836 m
.04262 .01944 L
.06244 .02085 L
.08426 .02278 L
.10458 .02499 L
.14264 .0304 L
.18163 .03801 L
.22307 .04882 L
.263 .06228 L
.30142 .07832 L
.34228 .09887 L
.38164 .12208 L
.41947 .14745 L
.45976 .17747 L
.49853 .20892 L
.53975 .24457 L
.57946 .28047 L
.61766 .31586 L
.6583 .35382 L
.69743 .39005 L
.73901 .42764 L
.77908 .46246 L
.81763 .49429 L
.85863 .52604 L
.89812 .55434 L
.93609 .57933 L
.97619 .60332 L
s
.02381 .01702 m
.04262 .01778 L
.06244 .01878 L
.08255 .02006 L
.10458 .02183 L
.12579 .02395 L
.14509 .02629 L
.18408 .03243 L
.22401 .04104 L
.26243 .05191 L
.30329 .06663 L
.34264 .08408 L
.38048 .104 L
.42077 .12852 L
.45954 .15516 L
.50076 .18636 L
.54047 .21872 L
.57866 .25145 L
.61931 .28736 L
.65844 .32235 L
.70002 .3593 L
.74009 .39408 L
.77864 .42628 L
.81964 .45875 L
.85913 .48797 L
.8971 .51396 L
.93752 .53923 L
.97619 .56104 L
s
.02381 .01607 m
.04262 .01656 L
.06244 .01723 L
.08255 .01811 L
.10458 .01935 L
.12415 .02075 L
.14509 .0226 L
.16496 .02477 L
.18653 .02762 L
.22646 .03454 L
.26733 .04421 L
.30668 .05637 L
.34452 .07099 L
.3848 .08986 L
.42358 .11125 L
.4648 .13731 L
.50451 .16532 L
.5427 .1945 L
.58335 .22741 L
.62248 .26027 L
.66406 .29572 L
.70413 .3297 L
.74268 .36166 L
.78368 .39431 L
.82317 .42401 L
.86114 .45064 L
.90156 .47671 L
.94047 .49944 L
.97619 .51825 L
s
.02381 .01543 m
.04262 .01572 L
.06244 .01613 L
.08255 .01669 L
.10458 .0175 L
.12415 .01844 L
.14509 .01973 L
.16496 .02126 L
.18653 .02334 L
.22646 .02855 L
.2463 .03191 L
.26733 .03612 L
.30517 .04556 L
.34545 .05854 L
.38422 .07414 L
.42545 .09417 L
.46516 .11674 L
.50335 .14126 L
.544 .16995 L
.58313 .19955 L
.62471 .23245 L
.66477 .26483 L
.70333 .29594 L
.74433 .32832 L
.78382 .35824 L
.82179 .38542 L
.86221 .41228 L
.90112 .4359 L
.94248 .45846 L
.97619 .47489 L
s
.02381 .01504 m
.04262 .0152 L
.06244 .01542 L
.08255 .01574 L
.10458 .01622 L
.12415 .0168 L
.14509 .01762 L
.16639 .0187 L
.18653 .02003 L
.22495 .02353 L
.24479 .02596 L
.26581 .02908 L
.30365 .0363 L
.34394 .04663 L
.38271 .05947 L
.42393 .07648 L
.46364 .09617 L
.50184 .11801 L
.54248 .14404 L
.58161 .17131 L
.62319 .20197 L
.66326 .23241 L
.70181 .26182 L
.74281 .29253 L
.7823 .32091 L
.82027 .34664 L
.8607 .37198 L
.8996 .39412 L
.94097 .4151 L
.97619 .43087 L
s
.02381 .01484 m
.03279 .01487 L
.04262 .01491 L
.06244 .01501 L
.07298 .01509 L
.08426 .01518 L
.10458 .01542 L
.12589 .01576 L
.14603 .01621 L
.166 .01681 L
.18444 .01754 L
.20316 .01848 L
.22379 .01981 L
.2432 .02139 L
.26408 .0235 L
.28379 .02595 L
.3053 .0292 L
.34501 .03703 L
.38566 .04788 L
.42479 .06133 L
.46637 .07903 L
.50643 .09933 L
.54499 .12162 L
.58599 .14779 L
.62548 .17476 L
.66345 .20165 L
.70387 .23054 L
.74278 .25791 L
.78414 .2858 L
.82399 .31096 L
.86232 .33318 L
.9031 .35444 L
.94237 .37247 L
.97619 .38608 L
s
.02381 .01475 m
.03279 .01476 L
.04262 .01477 L
.05288 .01479 L
.06244 .01481 L
.0828 .01487 L
.09421 .01492 L
.10458 .01498 L
.12373 .01511 L
.13453 .01521 L
.14451 .01533 L
.16324 .0156 L
.18386 .01601 L
.20327 .01655 L
.22415 .01732 L
.24528 .01836 L
.26537 .01965 L
.30357 .02312 L
.32324 .02555 L
.34421 .0287 L
.38579 .03695 L
.42586 .04778 L
.46441 .06116 L
.50541 .07864 L
.5449 .0985 L
.58287 .12003 L
.6233 .14499 L
.66221 .17029 L
.70357 .19769 L
.74341 .22375 L
.78174 .24783 L
.82252 .27175 L
.86179 .29271 L
.89954 .31069 L
.93974 .32739 L
.97619 .34036 L
s
.02381 .01472 m
.03279 .01472 L
.04262 .01473 L
.05288 .01473 L
.06244 .01474 L
.0731 .01474 L
.0828 .01475 L
.094 .01477 L
.10458 .01478 L
.11428 .0148 L
.12455 .01483 L
.14299 .0149 L
.1524 .01494 L
.16253 .015 L
.18083 .01515 L
.19093 .01525 L
.20196 .01539 L
.22205 .01573 L
.24173 .01619 L
.2627 .01687 L
.28411 .01781 L
.30428 .01899 L
.32436 .02051 L
.34283 .02226 L
.36325 .02467 L
.38232 .02741 L
.42029 .03455 L
.4592 .04449 L
.50056 .05827 L
.54041 .0747 L
.57874 .09321 L
.61952 .11532 L
.65878 .13825 L
.69653 .16105 L
.73674 .18527 L
.77543 .20775 L
.81656 .23005 L
.85619 .24944 L
.8943 .26587 L
.93486 .28085 L
.9739 .29286 L
.97619 .29349 L
s
.02381 .01472 m
.03279 .01472 L
.04262 .01472 L
.04758 .01472 L
.05288 .01472 L
.06244 .01472 L
.06788 .01472 L
.07379 .01472 L
.08451 .01472 L
.09494 .01472 L
.10458 .01473 L
.11425 .01473 L
.12331 .01473 L
.13324 .01474 L
.14393 .01475 L
.15404 .01476 L
.16506 .01478 L
.17548 .0148 L
.18515 .01483 L
.19572 .01486 L
.20568 .0149 L
.22428 .01501 L
.23405 .01509 L
.24436 .01519 L
.26284 .01543 L
.27231 .01558 L
.28247 .01578 L
.30081 .01625 L
.32205 .017 L
.34217 .01797 L
.36208 .01924 L
.3805 .02075 L
.40075 .02285 L
.41976 .0253 L
.45751 .03179 L
.4962 .04102 L
.53734 .05397 L
.57697 .06948 L
.61507 .08689 L
.65564 .10747 L
.69468 .12843 L
.73618 .15092 L
.77616 .17181 L
.81463 .19044 L
.85555 .2081 L
.89495 .2227 L
.93284 .23441 L
.97318 .24448 L
.97619 .24514 L
s
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.04262 .01472 L
.04795 .01472 L
.053 .01472 L
.06244 .01472 L
.06754 .01472 L
.07295 .01472 L
.08265 .01472 L
.08804 .01472 L
.09308 .01472 L
.09858 .01472 L
.10458 .01472 L
.10996 .01472 L
.11496 .01472 L
.12013 .01472 L
.12483 .01472 L
.13379 .01472 L
.14335 .01472 L
.14823 .01472 L
.15338 .01472 L
.1626 .01472 L
.17252 .01472 L
.18342 .01473 L
.19362 .01473 L
.20293 .01474 L
.21367 .01474 L
.22384 .01476 L
.2335 .01477 L
.24375 .01479 L
.25251 .01481 L
.26217 .01484 L
.27226 .01488 L
.28152 .01493 L
.29168 .01499 L
.30238 .01508 L
.31192 .01517 L
.32212 .0153 L
.34048 .0156 L
.35073 .01582 L
.36183 .01612 L
.38198 .01682 L
.40186 .01778 L
.4229 .01916 L
.44247 .02087 L
.46079 .02289 L
.49961 .02881 L
.52079 .03312 L
Mistroke
.54089 .03798 L
.57913 .04934 L
.61983 .06432 L
.65901 .08104 L
.70065 .10031 L
.74077 .11921 L
.77937 .13668 L
.82042 .15356 L
.85996 .16758 L
.89799 .17874 L
.93846 .18812 L
.97619 .19476 L
Mfstroke
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.0402 .01472 L
.04262 .01472 L
.0475 .01472 L
.05026 .01472 L
.05281 .01472 L
.05749 .01472 L
.06244 .01472 L
.06743 .01472 L
.0728 .01472 L
.07786 .01472 L
.0825 .01472 L
.08791 .01472 L
.09097 .01472 L
.09382 .01472 L
.09903 .01472 L
.10458 .01472 L
.10994 .01472 L
.11487 .01472 L
.12028 .01472 L
.12599 .01472 L
.13096 .01472 L
.13561 .01472 L
.1407 .01472 L
.14616 .01472 L
.15145 .01472 L
.15634 .01472 L
.1617 .01472 L
.1674 .01472 L
.17233 .01472 L
.17697 .01472 L
.18205 .01472 L
.18752 .01472 L
.19248 .01472 L
.19709 .01472 L
.20216 .01472 L
.20756 .01472 L
.21325 .01472 L
.21862 .01472 L
.2234 .01472 L
.22866 .01472 L
.23838 .01472 L
.2437 .01472 L
.24868 .01472 L
.25757 .01472 L
.26257 .01472 L
.26713 .01472 L
Mistroke
.277 .01472 L
.28615 .01473 L
.2962 .01474 L
.30689 .01474 L
.3172 .01476 L
.32834 .01478 L
.33886 .0148 L
.34852 .01483 L
.35829 .01487 L
.36739 .01492 L
.37737 .01499 L
.38806 .01509 L
.39826 .01521 L
.40934 .01538 L
.41892 .01556 L
.42948 .0158 L
.44929 .01643 L
.46014 .01689 L
.47031 .0174 L
.49053 .01872 L
.50905 .02035 L
.52801 .02249 L
.54873 .02548 L
.58934 .03354 L
.62844 .04417 L
.66999 .05816 L
.71002 .0733 L
.74854 .08822 L
.78951 .10314 L
.82897 .11562 L
.86691 .12536 L
.9073 .13321 L
.92725 .1362 L
.94617 .13855 L
.97619 .14144 L
Mfstroke
.02381 .01472 m
.04262 .01472 L
.0522 .01472 L
.05746 .01472 L
.06005 .01472 L
.06119 .01472 L
.06244 .01472 L
.06371 .01472 L
.06441 .01472 L
.06506 .01472 L
.0679 .01472 L
.06912 .01472 L
.07029 .01472 L
.07093 .01472 L
.07163 .01472 L
.07286 .01472 L
.07413 .01472 L
.07529 .01472 L
.07593 .01472 L
.07663 .01472 L
.07788 .01472 L
.07907 .01472 L
.08032 .01472 L
.08138 .01472 L
.08255 .01472 L
.08326 .01472 L
.08403 .01472 L
.08476 .01472 L
.08543 .01472 L
.0867 .01472 L
.08805 .01472 L
.09085 .01472 L
.09245 .01472 L
.09395 .01472 L
.09644 .01472 L
.09906 .01472 L
.10044 .01472 L
.10194 .01472 L
.10458 .01472 L
.10712 .01472 L
.10986 .01472 L
.11246 .01472 L
.11485 .01472 L
.11701 .01472 L
.11939 .01472 L
.12187 .01472 L
.12419 .01472 L
.1269 .01472 L
.12947 .01472 L
.13178 .01472 L
Mistroke
.13429 .01472 L
.13702 .01472 L
.13992 .01472 L
.14266 .01472 L
.14514 .01472 L
.14747 .01472 L
.15003 .01472 L
.1527 .01472 L
.15519 .01472 L
.15753 .01472 L
.15965 .01472 L
.16197 .01472 L
.16443 .01472 L
.16709 .01472 L
.16956 .01472 L
.17221 .01472 L
.17513 .01472 L
.17765 .01472 L
.18036 .01472 L
.18292 .01472 L
.18526 .01472 L
.19001 .01472 L
.19267 .01472 L
.19509 .01472 L
.19735 .01472 L
.19979 .01472 L
.20422 .01472 L
.20672 .01472 L
.20946 .01472 L
.21233 .01472 L
.21501 .01472 L
.2198 .01472 L
.22248 .01472 L
.22494 .01472 L
.22973 .01472 L
.23216 .01472 L
.23483 .01472 L
.23711 .01472 L
.23956 .01472 L
.244 .01472 L
.24651 .01472 L
.24927 .01472 L
.25195 .01472 L
.25482 .01472 L
.25751 .01472 L
.25996 .01472 L
.26475 .01472 L
.26959 .01472 L
.27203 .01472 L
.27471 .01472 L
Mistroke
.27946 .01472 L
.28391 .01472 L
.28914 .01472 L
.29393 .01472 L
.29945 .01472 L
.3047 .01472 L
.30973 .01472 L
.31429 .01472 L
.31956 .01472 L
.32452 .01472 L
.32912 .01472 L
.33336 .01472 L
.338 .01472 L
.34291 .01472 L
.34788 .01472 L
.3524 .01472 L
.35762 .01472 L
.36256 .01472 L
.36713 .01472 L
.37135 .01472 L
.3809 .01472 L
.38554 .01472 L
.39054 .01472 L
.39958 .01472 L
.40482 .01472 L
.41034 .01473 L
.4155 .01473 L
.42019 .01473 L
.42974 .01474 L
.43499 .01475 L
.43995 .01476 L
.44876 .01478 L
.45832 .01481 L
.46779 .01485 L
.47821 .01491 L
.48909 .015 L
.49926 .01511 L
.50967 .01527 L
.51956 .01546 L
.52843 .01569 L
.5381 .01599 L
.55783 .01687 L
.56885 .01753 L
.57882 .01827 L
.59812 .0201 L
.61896 .02276 L
.63895 .02604 L
.66003 .03028 L
.69808 .03964 L
.73857 .05091 L
Mistroke
.77755 .06136 L
.81899 .07051 L
.83974 .07408 L
.8589 .07675 L
.87754 .07882 L
.89731 .0805 L
.91683 .08174 L
.93513 .08258 L
.9455 .08295 L
.95537 .08324 L
.97389 .08365 L
.97619 .0837 L
Mfstroke
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.34309 .01472 L
.3815 .01472 L
.42237 .01472 L
.46172 .01472 L
.48147 .01472 L
.49012 .01472 L
.49468 .01472 L
.49955 .01472 L
.50095 .01472 L
.50226 .01472 L
.50344 .01472 L
.50471 .01472 L
.50592 .01472 L
.50721 .01472 L
.5095 .01472 L
.51063 .01472 L
.51183 .01472 L
.51297 .01472 L
.51401 .01472 L
.51523 .01472 L
.51587 .01472 L
.51655 .01472 L
.5178 .01472 L
.51896 .01472 L
.52025 .01472 L
.52142 .01472 L
.52272 .01472 L
.52337 .01472 L
.52408 .01472 L
.52528 .01472 L
.52657 .01472 L
.52778 .01472 L
.52888 .01472 L
.52957 .01472 L
.53029 .01472 L
.53159 .01472 L
.53231 .01472 L
.53298 .01472 L
.53377 .01472 L
.53452 .01472 L
.53586 .01472 L
.53708 .01472 L
Mistroke
.5384 .01472 L
.53915 .01472 L
.53984 .01472 L
.54113 .01472 L
.54249 .01472 L
.54366 .01472 L
.54493 .01472 L
.54631 .01472 L
.54708 .01472 L
.54778 .01472 L
.54914 .01472 L
.55043 .01472 L
.55164 .01472 L
.55292 .01472 L
.55401 .01472 L
.55521 .01472 L
.5565 .01472 L
.55789 .01472 L
.5592 .01472 L
.5604 .01472 L
.56149 .01472 L
.56265 .01472 L
.56375 .01472 L
.56474 .01472 L
.56591 .01472 L
.56718 .01472 L
.56838 .01472 L
.56948 .01472 L
.57062 .01472 L
.57169 .01472 L
.57286 .01472 L
.57412 .01472 L
.57543 .01472 L
.57668 .01472 L
.5778 .01472 L
.57902 .01472 L
.58023 .01472 L
.58135 .01472 L
.58257 .01472 L
.58386 .01472 L
.58603 .01472 L
.58726 .01472 L
.58841 .01472 L
.58975 .01472 L
.59103 .01472 L
.59341 .01472 L
.59475 .01472 L
.59598 .01472 L
.59734 .01472 L
.59877 .01472 L
Mistroke
.60126 .01472 L
.60266 .01472 L
.60393 .01472 L
.60512 .01472 L
.60641 .01472 L
.60877 .01472 L
.61022 .01472 L
.61153 .01472 L
.61295 .01472 L
.61447 .01472 L
.6159 .01472 L
.6172 .01472 L
.61852 .01472 L
.61977 .01472 L
.62223 .01472 L
.62448 .01472 L
.62689 .01472 L
.62952 .01472 L
.63181 .01472 L
.63424 .01472 L
.63632 .01472 L
.63861 .01472 L
.64129 .01472 L
.64374 .01472 L
.64644 .01472 L
.64927 .01472 L
.65175 .01473 L
.65405 .01473 L
.65658 .01473 L
.65928 .01474 L
.66187 .01475 L
.66461 .01476 L
.66953 .01478 L
.67227 .0148 L
.67482 .01482 L
.67781 .01485 L
.68064 .01488 L
.68572 .01496 L
.69036 .01506 L
.69535 .0152 L
.7008 .01539 L
.71115 .01589 L
.72052 .01651 L
.74151 .01822 L
.7517 .01904 L
.76244 .01977 L
.77161 .02025 L
.77681 .02045 L
.78165 .02061 L
.78667 .02074 L
Mistroke
.79142 .02083 L
.79568 .0209 L
.80031 .02095 L
.80535 .02099 L
.80789 .02101 L
.81069 .02102 L
.81307 .02103 L
.81564 .02104 L
.82028 .02105 L
.82281 .02106 L
.82551 .02106 L
.82785 .02106 L
.83037 .02107 L
.83335 .02107 L
.83616 .02107 L
.83889 .02107 L
.8414 .02107 L
.84381 .02107 L
.84605 .02107 L
.84852 .02107 L
.85117 .02107 L
.85394 .02107 L
.85656 .02107 L
.85892 .02107 L
.86149 .02107 L
.86382 .02107 L
.86633 .02107 L
.8687 .02107 L
.87088 .02107 L
.87329 .02107 L
.87593 .02107 L
.87726 .02107 L
.87869 .02107 L
.88125 .02107 L
.88266 .02107 L
.88397 .02107 L
.88537 .02107 L
.88691 .02107 L
.88951 .02107 L
.89093 .02107 L
.89226 .02107 L
.89355 .02107 L
.89477 .02107 L
.89708 .02107 L
.89836 .02107 L
.89955 .02107 L
.90087 .02107 L
.90226 .02107 L
.90352 .02107 L
.90491 .02107 L
Mistroke
.90735 .02107 L
.90872 .02107 L
.91019 .02107 L
.91285 .02107 L
.91413 .02107 L
.91552 .02107 L
.91675 .02107 L
.91806 .02107 L
.91923 .02107 L
.92053 .02107 L
.92281 .02107 L
.92399 .02107 L
.92522 .02107 L
.92744 .02107 L
.92867 .02107 L
.92982 .02107 L
.93115 .02107 L
.93242 .02107 L
.93351 .02107 L
.9347 .02107 L
.93678 .02107 L
.93795 .02107 L
.9392 .02107 L
.94143 .02107 L
.94254 .02107 L
.94375 .02107 L
.94482 .02107 L
.94596 .02107 L
.94698 .02107 L
.9481 .02107 L
.95009 .02107 L
.9513 .02107 L
.9524 .02107 L
.95361 .02107 L
.95489 .02107 L
.95593 .02107 L
.95704 .02107 L
.95826 .02107 L
.9594 .02107 L
.96045 .02107 L
.96156 .02107 L
.96279 .02107 L
.96392 .02107 L
.96595 .02107 L
.96711 .02107 L
.96819 .02107 L
.96922 .02107 L
.9702 .02107 L
.97204 .02107 L
.97307 .02107 L
Mistroke
.97403 .02107 L
.97619 .02107 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[33]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo003ooolX
ool00?ooobSoo`00oooo:?oo003ooolXool007Woo`<000?oo`8000?oo`8000;oo`<00004ool00000
ool2000;ool30003ool30002ool30002ool30003ool2001cool007Woo`03003oo`0000;oo`06003o
oooo003oo`000_oo00<00?oo00001?oo00<00?oo00003Ooo00<00?ooool00ooo00<00?ooool00_oo
00D00?ooooooo`0000Coo`03003ooooo07?oo`00Nooo00@00?ooool000Coo`06003ooooo003oo`00
1?oo0`003Ooo0`000ooo00<00?ooool00_oo00D00?ooooooo`0000Coo`<007?oo`00N_oo00<00?oo
ool010000ooo0P000_oo0`000_oo00@00?oo000000coo`05003ooooo003oo`0400000ooo00000003
ool30002ool3001cool007Woo`03003oo`0000;oo`03003ooooo00coo`03003ooooo00goo`04003o
oooo0026ool007Woo`<0013oo`8000koo`@000Soo`03003ooooo07coo`00oooo:?oo003ooolXool0
0?ooobSoo`00oooo:?oo003ooolXool003Soo`<000?oo`03003ooooo02Goo`8000Coo`03003ooooo
02Koo`8000Coo`03003ooooo02Ooo`<000;oo`03003ooooo02Ooo`<000;oo`03003ooooo02_oo`00
>?oo00<00?ooool00_oo00<00?oo0000:?oo00H00?ooool00?oo000Yool01P00ooooo`00ool002Wo
o`06003ooooo003oo`00:Ooo00H00?ooool00?oo000/ool003Woo`03003ooooo00?oo`03003ooooo
02Goo`07003oooooool00?oo0000:?oo00<00?ooool00ooo00<00?ooool09Ooo100000Coo`00ool0
02Ooo`@000?oo`03003ooooo02[oo`00>Ooo00@00?ooooooo`8002Woo`06003ooooo003oo`00:Ooo
00<00?ooool00P00:?oo00<00?oo00000_oo00<00?oo00009ooo00<00?oo00000_oo0P00;Ooo000h
ool00`00ool00002ool00`00ooooo`0Vool00`00ool00002ool00`00ool0000Wool00`00ool00002
ool00`00ooooo`0Xool20002ool00`00ool0000Xool20002ool00`00ooooo`0/ool003Woo`04003o
ooooool3000Wool00`00ooooo`02ool00`00ooooo`0Wool01000oooooooo0`00:Ooo00D00?oooooo
o`0002[oo`03003ooooo00<002coo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo000gooo6
000Zool0037oo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00Koo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00;oo`03003ooooo02Soo`00
<?oo00<00?oo00001?oo00<00?ooool00_oo00<00?ooool0:ooo00<00?ooool0;?oo00<00?ooool0
;?oo00<00?ooool0;?oo00<00?ooool00_oo00<00?ooool0:?oo000`ool00`00ool00004ool20003
oon8000gool2000Zool0033oo`03003oo`0000Coo`03003ooooo00;oof4000Koo``001Gooc@000Co
o`03003ooooo02Soo`00<?oo00<00?oo00001?oo00<00?ooool02ooo>`001?oo20001?oo1P001ooo
20002_oo2000AOoo00<00?ooool0:?oo000aool00`00ooooo`03ool00`00ooooo`0Eool80003ool;
0004ool60002ool40004ool40003ool60006ool40006ool5000:ool4000>ool40011ool00`00oooo
o`0Xool003Ooo`03003ooooo01_oo`X00003ool0000000`00003ool0000000P000Coo`@000Goo`H0
00Coo`D000Koo`@000[oo`@000koo`@003goo`03003ooooo02Soo`00=ooo00<00?ooool07ooo1000
0_oo1P0000?oo`0000000P001?oo10000ooo0P000_oo10001?oo10001ooo10001Ooo1P001?oo1000
2_oo10003_oo0`00>_oo00<00?ooool0:?oo000gool2000Tool40004ool20003ool40004ool30002
ool30003ool40004ool40007ool30008ool20006ool4000:ool4000=ool4000eool2000Zool003Oo
o`03003ooooo02Ooo`@000;oo`<000Coo`@000?oo`8000?oo`<000Coo`@000Coo`@000Koo`8000So
o`<000Ooo`@000[oo`8000ooo`@003;oo`03003ooooo02Soo`00=ooo00<00?ooool0:ooo0P000ooo
0`001Ooo0`000_oo0`000ooo10001?oo10001?oo10001?oo0`002?oo0`002?oo0P002_oo0`004?oo
1000;_oo00<00?ooool0:?oo000gool00`00ooooo`0]ool30003ool40004ool20003ool30004ool3
0005ool30005ool20005ool30008ool20008ool3000:ool3000Aool4000Zool00`00ooooo`0Xool0
03Ooo`03003ooooo033oo`<000Coo`<000?oo`<000?oo`8000Goo`8000Koo`8000Goo`8000Koo`80
00Soo`<000Soo`<000[oo`8001?oo`@002Koo`03003ooooo02Soo`00=ooo00<00?ooool0<ooo0P00
1Ooo0P001?oo0P000ooo0`001?oo0`001Ooo0P001Ooo0P001_oo0`002?oo0`002?oo0P002_oo0`00
5?oo10008_oo00<00?ooool0:?oo000gool2000fool20005ool20004ool20004ool20005ool20005
ool20005ool20007ool20009ool20008ool3000:ool3000Eool8000Iool2000Zool003Ooo`03003o
oooo03Ooo`8000Goo`8000Coo`8000Coo`8000Goo`8000Goo`8000Goo`8000Ooo`8000Woo`8000Wo
o`8000_oo`8001_oo`/000ooo`03003ooooo02Soo`00=ooo00<00?ooool0>Ooo0P001Ooo00<00?oo
ool00ooo0P001?oo0P001Ooo0P001Ooo0P001Ooo0P001ooo0P002Ooo0P002Ooo0P002ooo0P009?oo
2`001?oo00<00?ooool0:?oo000gool00`00ooooo`0kool20004ool20005ool20004ool20005ool2
0005ool20005ool20007ool20009ool20009ool2000;ool3000`ool00`00ooooo`0Xool003Ooo`03
003ooooo03goo`8000Coo`8000Goo`8000Coo`8000Goo`8000Goo`8000Goo`8000Ooo`8000Woo`80
00Woo`8000coo`8002koo`03003ooooo02Soo`00=ooo0P00@?oo0P001?oo0P001Ooo0P001?oo0P00
1Ooo0P001Ooo0P001Ooo0P001ooo0P002Ooo0P002Ooo0P003?oo0`00:_oo0P00:_oo000gool00`00
ooooo`11ool20004ool20005ool20004ool20005ool00`00ooooo`04ool20005ool20007ool20009
ool20009ool2000=ool3000Xool00`00ooooo`0Xool003Ooo`03003ooooo04?oo`8000Coo`8000Go
o`03003ooooo00?oo`8000Coo`8000Koo`8000Goo`8000Ooo`8000Woo`8000Woo`8000koo`@002Co
o`03003ooooo02Soo`00=ooo00<00?ooool0AOoo0P001?oo00<00?ooool00ooo0P001Ooo00<00?oo
ool00ooo0P001_oo0P001Ooo0P001ooo0P002Ooo00<00?ooool02?oo0P004?oo10008?oo00<00?oo
ool0:?oo000`ool30004ool00`00ooooo`17ool20003ool20005ool00`00ooooo`03ool20005ool0
0`00ooooo`05ool00`00ooooo`04ool20007ool20008ool2000:ool3000Aool4000Lool00`00oooo
o`0Xool0033oo`03003ooooo00Coo`03003ooooo04Woo`8000?oo`8000Coo`8000Goo`03003ooooo
00?oo`8000Koo`8000Koo`8000Ooo`03003ooooo00Ooo`8000_oo`8001?oo`@001Soo`03003ooooo
02Soo`00<Ooo00<00?ooool00ooo0P00C?oo00<00?ooool00_oo00<00?ooool00ooo0P001?oo0P00
1Ooo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01Ooo0P002Ooo00<00?ooool02_oo0P00
5Ooo10004ooo0P00:_oo000aool00`00ooooo`03ool00`00ooooo`1<ool20003ool20005ool00`00
ooooo`03ool20004ool20006ool20006ool20007ool20008ool2000<ool2000Gool7000=ool00`00
ooooo`0Xool0033oo`03003oo`0000Coo`03003ooooo04koo`8000?oo`03003ooooo00?oo`03003o
oooo00Coo`03003ooooo00?oo`8000Koo`8000Koo`8000Ooo`03003ooooo00Ooo`8000coo`8001co
o`T000Coo`03003ooooo02Soo`00<Ooo00<00?ooool00ooo00<00?ooool0D?oo00D00?ooooooo`00
00Goo`8000Goo`03003ooooo00Coo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo00Goo`80
00Woo`8000coo`8002Ooo`03003ooooo02Soo`00=ooo00<00?ooool0DOoo00@00?ooooooo`8000Go
o`03003ooooo00?oo`8000Goo`8000Koo`03003ooooo00Goo`8000Ooo`8000Woo`8000coo`8002Go
o`03003ooooo02Soo`00=ooo00<00?ooool0D_oo00<00?ooool00_oo00<00?ooool00ooo00<00?oo
ool01?oo00<00?ooool01?oo00<00?ooool01?oo0P001ooo00<00?ooool01_oo0P002Ooo0P003?oo
0`008_oo00<00?ooool0:?oo000gool2001Dool20003ool20004ool20005ool00`00ooooo`04ool0
0`00ooooo`05ool00`00ooooo`05ool00`00ooooo`07ool00`00ooooo`08ool2000=ool4000Mool2
000Zool003Ooo`03003ooooo05Goo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00?oo`80
00Goo`8000Koo`03003ooooo00Goo`8000Soo`8000[oo`8000ooo`@001[oo`03003ooooo02Soo`00
=ooo00<00?ooool0E_oo00<00?ooool00_oo0P001?oo00<00?ooool01?oo00<00?ooool01?oo00<0
0?ooool01?oo0P001ooo00<00?ooool01ooo00<00?ooool02Ooo0P004Ooo0P006?oo00<00?ooool0
:?oo000gool00`00ooooo`1Gool00`00ooooo`03ool00`00ooooo`02ool20005ool00`00ooooo`04
ool20006ool00`00ooooo`05ool20008ool2000;ool2000Aool3000Eool00`00ooooo`0Xool003Oo
o`03003ooooo05Soo`03003ooooo00?oo`8000Coo`03003ooooo00?oo`8000Koo`03003ooooo00Co
o`8000Ooo`03003ooooo00Ooo`8000_oo`8001;oo`D0013oo`03003ooooo02Soo`00=ooo00<00?oo
ool0FOoo0P001Ooo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool01?oo0P001_oo00<00?oo
ool01Ooo0P002Ooo00<00?ooool02_oo0P005Ooo1P002_oo00<00?ooool0:?oo000gool2001Lool0
0`00ooooo`03ool00`00ooooo`02ool20005ool00`00ooooo`05ool00`00ooooo`04ool20007ool2
0008ool2000<ool2000Iool40005ool2000Zool003Ooo`03003ooooo05coo`03003ooooo00?oo`03
003ooooo00?oo`03003ooooo00?oo`8000Koo`8000Koo`8000Ooo`03003ooooo00Ooo`8000coo`80
01_oo`8000Coo`03003ooooo02Soo`00=ooo00<00?ooool0GOoo0P001?oo0P001?oo00<00?ooool0
1?oo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01Ooo0P002Ooo0P003?oo0`007_oo00<0
0?ooool0:?oo000gool00`00ooooo`1Oool00`00ooooo`03ool00`00ooooo`02ool20005ool00`00
ooooo`05ool00`00ooooo`05ool00`00ooooo`06ool00`00ooooo`08ool2000=ool3000Kool00`00
ooooo`0Xool003Ooo`03003ooooo063oo`03003ooooo00?oo`03003ooooo00?oo`03003ooooo00?o
o`8000Koo`8000Koo`8000Ooo`8000[oo`8000koo`8001Woo`03003ooooo02Soo`00=ooo0P00H_oo
00<00?ooool00ooo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool01Ooo00<00?ooool01Ooo
00<00?ooool01_oo0P002_oo00<00?ooool03Ooo0`005Ooo0P00:_oo000gool00`00ooooo`1Rool0
0`00ooooo`03ool00`00ooooo`03ool20005ool00`00ooooo`05ool00`00ooooo`05ool00`00oooo
o`07ool00`00ooooo`08ool2000@ool3000Cool00`00ooooo`0Xool003Ooo`03003ooooo06?oo`80
00Coo`03003ooooo00Coo`03003ooooo00?oo`8000Koo`8000Koo`8000Soo`8000[oo`80017oo`@0
00ooo`03003ooooo02Soo`00=ooo00<00?ooool0IOoo00<00?ooool00_oo00<00?ooool01?oo00<0
0?ooool01?oo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01ooo00<00?ooool02Ooo0P00
4ooo10002ooo00<00?ooool0:?oo000aool30003ool00`00ooooo`1Vool00`00ooooo`02ool20005
ool00`00ooooo`04ool00`00ooooo`05ool00`00ooooo`05ool20008ool2000;ool2000Eool40007
ool00`00ooooo`0Xool003;oo`03003ooooo00;oo`03003ooooo06Ooo`03003ooooo00?oo`03003o
oooo00?oo`03003ooooo00Coo`8000Koo`03003ooooo00Koo`03003ooooo00Ooo`8000_oo`8001Oo
o`<000Coo`03003ooooo02Soo`00<?oo10000ooo0P00JOoo00<00?ooool00ooo00<00?ooool00ooo
00<00?ooool01Ooo00<00?ooool01?oo0P001ooo00<00?ooool02?oo00<00?ooool02_oo0P005ooo
00@00?ooooooo`8002[oo`00<?oo00<00?oo00001?oo00<00?ooool0JOoo00<00?ooool00ooo00<0
0?ooool00ooo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01Ooo0P002Ooo0P003?oo0P00
6_oo00<00?ooool0:?oo000aool20004ool00`00ooooo`1Zool00`00ooooo`03ool00`00ooooo`03
ool00`00ooooo`05ool20006ool00`00ooooo`06ool00`00ooooo`08ool00`00ooooo`0;ool2000H
ool00`00ooooo`0Xool003;oo`03003ooooo00;oo`03003ooooo06_oo`03003ooooo00?oo`03003o
oooo00?oo`03003ooooo00Koo`03003ooooo00Coo`03003ooooo00Koo`03003ooooo00Soo`8000go
o`8001Koo`03003ooooo02Soo`00=ooo00<00?ooool0K?oo00<00?ooool00ooo00<00?ooool00ooo
00<00?ooool01_oo00<00?ooool01?oo00<00?ooool01_oo0P002_oo0P003Ooo0`004ooo00<00?oo
ool0:?oo000gool00`00ooooo`1]ool00`00ooooo`03ool20004ool20007ool00`00ooooo`04ool2
0008ool00`00ooooo`09ool00`00ooooo`0=ool2000Aool00`00ooooo`0Xool003Ooo`8006ooo`03
003ooooo00Coo`03003ooooo00?oo`03003ooooo00Goo`03003ooooo00Goo`03003ooooo00Koo`03
003ooooo00Woo`8000ooo`<000goo`8002[oo`00=ooo00<00?ooool0Kooo00<00?ooool01?oo00<0
0?ooool00ooo00<00?ooool01Ooo00<00?ooool01Ooo00<00?ooool01_oo0P002ooo0P004?oo0`00
2ooo00<00?ooool0:?oo000gool00`00ooooo`1`ool00`00ooooo`04ool00`00ooooo`03ool20006
ool00`00ooooo`05ool20008ool00`00ooooo`0:ool2000Aool40007ool00`00ooooo`0Xool003Oo
o`03003ooooo077oo`03003ooooo00Coo`03003ooooo00Coo`03003ooooo00Coo`03003ooooo00Ko
o`03003ooooo00Koo`8000coo`8001?oo`<000Coo`03003ooooo02Soo`00=ooo00<00?ooool0L_oo
00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool01_oo00<00?ooool01ooo
00<00?ooool02ooo0P006?oo00<00?ooool0:?oo000gool00`00ooooo`1cool20005ool00`00oooo
o`04ool00`00ooooo`04ool00`00ooooo`06ool20008ool2000=ool2000Fool00`00ooooo`0Xool0
03Ooo`8007Koo`03003ooooo00?oo`8000Goo`8000Goo`8000Soo`03003ooooo00Ooo`8000goo`80
01?oo`8002[oo`00=ooo00<00?ooool0M_oo00<00?ooool01?oo00<00?ooool01?oo00<00?ooool0
1?oo00<00?ooool01_oo00<00?ooool02?oo00<00?ooool03?oo0P004_oo00<00?ooool0:?oo000g
ool00`00ooooo`1gool00`00ooooo`04ool00`00ooooo`04ool00`00ooooo`04ool00`00ooooo`06
ool20009ool2000>ool2000@ool00`00ooooo`0Xool003Ooo`03003ooooo07Soo`03003ooooo00Co
o`03003ooooo00Coo`8000Goo`8000Soo`03003ooooo00Soo`8000koo`<000goo`03003ooooo02So
o`00=ooo00<00?ooool0NOoo00<00?ooool01?oo00<00?ooool01Ooo00<00?ooool01?oo00<00?oo
ool01_oo0P002_oo0P003ooo0`002_oo00<00?ooool0:?oo000gool2001kool00`00ooooo`04ool0
0`00ooooo`05ool00`00ooooo`04ool00`00ooooo`07ool00`00ooooo`09ool2000@ool40005ool2
000Zool003Ooo`03003ooooo07_oo`8000Goo`03003ooooo00Goo`03003ooooo00Coo`8000Soo`03
003ooooo00[oo`8001;oo`8000Coo`03003ooooo02Soo`00=ooo00<00?ooool0OOoo00<00?ooool0
0ooo0P001_oo00<00?ooool01Ooo00<00?ooool01_oo0P003?oo0P005_oo00<00?ooool0:?oo000g
ool00`00ooooo`1nool00`00ooooo`04ool00`00ooooo`04ool00`00ooooo`05ool00`00ooooo`07
ool00`00ooooo`0;ool2000Dool00`00ooooo`0Xool0033oo`8000Goo`03003ooooo07ooo`03003o
oooo00Coo`03003ooooo00Coo`03003ooooo00Goo`8000Soo`8000goo`8001;oo`03003ooooo02So
o`00<?oo00<00?oo00001?oo00<00?ooool0P?oo00<00?ooool01?oo00<00?ooool01?oo00<00?oo
ool01_oo00<00?ooool01ooo00<00?ooool03?oo0P004?oo00<00?ooool0:?oo000`ool00`00ool0
0004ool20022ool00`00ooooo`04ool00`00ooooo`04ool00`00ooooo`06ool20008ool2000>ool2
000=ool2000Zool0033oo`8000Goo`03003ooooo08;oo`03003ooooo00Coo`03003ooooo00Coo`03
003ooooo00Ooo`03003ooooo00Ooo`8000koo`8000coo`03003ooooo02Soo`00<?oo00<00?ooool0
1?oo00<00?ooool0Pooo00<00?ooool01?oo00<00?ooool01?oo0P002?oo0P002Ooo00<00?ooool0
3Ooo0P002_oo00<00?ooool0:?oo000aool20004ool00`00ooooo`24ool00`00ooooo`04ool20006
ool00`00ooooo`07ool20008ool2000?ool40006ool00`00ooooo`0Xool003Ooo`03003ooooo08Go
o`03003ooooo00Goo`03003ooooo00Coo`03003ooooo00Soo`03003ooooo00Ooo`80017oo`8000Co
o`03003ooooo02Soo`00=ooo00<00?ooool0Q_oo00<00?ooool01Ooo00<00?ooool01?oo0P002Ooo
00<00?ooool02?oo0P005Ooo00<00?ooool0:?oo000gool20028ool00`00ooooo`05ool00`00oooo
o`05ool00`00ooooo`07ool2000:ool2000Bool2000Zool003Ooo`03003ooooo08Soo`03003ooooo
00Goo`03003ooooo00Goo`03003ooooo00Soo`03003ooooo00Woo`80017oo`03003ooooo02Soo`00
=ooo00<00?ooool0ROoo00<00?ooool01Ooo00<00?ooool01Ooo0P002Ooo00<00?ooool02_oo0P00
3ooo00<00?ooool0:?oo000gool00`00ooooo`2:ool00`00ooooo`05ool20007ool00`00ooooo`07
ool2000<ool2000=ool00`00ooooo`0Xool003Ooo`03003ooooo08_oo`03003ooooo00Koo`03003o
oooo00Goo`03003ooooo00Soo`03003ooooo00_oo`<000[oo`03003ooooo02Soo`00=ooo0P00SOoo
00<00?ooool01_oo00<00?ooool01Ooo0P002Ooo0P003_oo0P001ooo0P00:_oo000gool00`00oooo
o`2=ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`08ool2000>ool20006ool00`00oooo
o`0Xool003Ooo`03003ooooo08koo`03003ooooo00Koo`03003ooooo00Koo`8000[oo`8000koo`80
00Coo`03003ooooo02Soo`00=ooo00<00?ooool0Sooo00<00?ooool01_oo00<00?ooool01ooo00<0
0?ooool02Ooo00<00?ooool04Ooo00<00?ooool0:?oo000gool00`00ooooo`2@ool20007ool00`00
ooooo`07ool00`00ooooo`09ool2000Aool00`00ooooo`0Xool003Ooo`03003ooooo09;oo`03003o
oooo00Goo`8000Soo`8000_oo`03003ooooo00koo`03003ooooo02Soo`00=ooo0P00U?oo00<00?oo
ool01_oo00<00?ooool01ooo00<00?ooool02Ooo0P003Ooo0P00:_oo000gool00`00ooooo`2Dool2
0007ool00`00ooooo`07ool2000;ool2000<ool00`00ooooo`0Xool003Ooo`03003ooooo09Koo`03
003ooooo00Goo`03003ooooo00Soo`03003ooooo00[oo`8000[oo`03003ooooo02Soo`00=ooo00<0
0?ooool0Uooo00<00?ooool01Ooo0P002Ooo0P003?oo0P002?oo00<00?ooool0:?oo000aool00`00
ooooo`03ool00`00ooooo`2Hool00`00ooooo`06ool00`00ooooo`08ool2000<ool20006ool00`00
ooooo`0Xool0033oo`03003oo`0000Coo`03003ooooo09Woo`03003ooooo00Koo`8000[oo`03003o
oooo00_oo`8000Coo`03003ooooo02Soo`00<?oo00<00?oo00001?oo0P00Vooo0P002?oo0P002Ooo
0P004?oo0P00:_oo000aool00`00ooooo`03ool00`00ooooo`2Lool00`00ooooo`07ool00`00oooo
o`08ool00`00ooooo`0>ool00`00ooooo`0Xool0033oo`03003oo`0000Coo`03003ooooo09goo`03
003ooooo00Ooo`03003ooooo00Soo`8000koo`03003ooooo02Soo`00<Ooo00<00?ooool00ooo00<0
0?ooool0W_oo00<00?ooool01ooo0P002_oo0P003?oo00<00?ooool0:?oo000gool00`00ooooo`2O
ool00`00ooooo`08ool00`00ooooo`09ool2000:ool00`00ooooo`0Xool003Ooo`03003ooooo0:3o
o`8000Woo`03003ooooo00[oo`8000Soo`03003ooooo02Soo`00=ooo0P00Xooo00<00?ooool01ooo
0P003?oo0P001Ooo0P00:_oo000gool00`00ooooo`2Sool00`00ooooo`08ool00`00ooooo`0;ool2
0004ool00`00ooooo`0Xool003Ooo`03003ooooo0:Coo`8000Woo`80017oo`03003ooooo02Soo`00
=ooo00<00?ooool0Y_oo00<00?ooool02?oo00<00?ooool03_oo00<00?ooool0:?oo000gool00`00
ooooo`2Wool20009ool2000>ool00`00ooooo`0Xool003Ooo`800:[oo`03003ooooo00Soo`8000_o
o`8002[oo`00=ooo00<00?ooool0Z_oo0P002_oo00<00?ooool02Ooo00<00?ooool0:?oo000gool0
0`00ooooo`2/ool20009ool20009ool00`00ooooo`0Xool003Ooo`03003ooooo0:koo`03003ooooo
00Soo`8000Ooo`03003ooooo02Soo`00=ooo00<00?ooool0[ooo0P002_oo0P001Ooo00<00?ooool0
:?oo000gool00`00ooooo`2aool00`00ooooo`09ool00`00ooooo`02ool00`00ooooo`0Xool003Oo
o`800;?oo`03003ooooo00coo`8002[oo`00=ooo00<00?ooool0/ooo0P003Ooo00<00?ooool0:?oo
000gool00`00ooooo`2eool00`00ooooo`0:ool00`00ooooo`0Xool003Ooo`03003ooooo0;Koo`80
00[oo`03003ooooo02Soo`00:_oo1@000_oo00<00?ooool00ooo00<00?ooool0^?oo00<00?ooool0
1ooo00<00?ooool0:?oo000/ool01`00oooooooo003oo`0000Coo`03003ooooo0;Woo`8000Ooo`03
003ooooo02Soo`00;?oo00L00?ooooooo`00ool00004ool2002lool20004ool2000Zool002coo`07
003oooooool00?oo00001?oo00<00?ooool0_Ooo00<00?ooool00_oo00<00?ooool0:?oo000/ool0
1`00oooooooo003oo`0000Coo`03003ooooo0<;oo`03003ooooo02Soo`00:ooo0P001?oo00<00?oo
ool00ooo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01ooo00<00?oo
ool01_oo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo00<00?oo
ool01_oo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo00<00?oo
ool01ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo00<00?oo
ool01ooo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool0:?oo000gooo6000Zool00?ooobSo
o`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool005;oo`<000?oo`8000;oo`<0
00[oo`@000;oo`<000;oo`<000;oo`<000?oo`8000;oo`<000?oo`800003ool0000000;oo`03003o
oooo0080013oo`800004ool00000ool40002ool20003ool300001?oo000000000_oo0`000ooo0P00
0_oo0`000ooo0P000_oo0P00D_oo001Cool01@00oooooooo00000_oo00@00?ooool000coo`04003o
oooo0002ool00`00ooooo`02ool00`00ooooo`02ool01@00oooooooo00001Ooo00D00?ooooooo`00
00Coo`06003ooooo003oo`000_oo00<00?ooool03Ooo00H00?ooooooo`00ool30002ool01P00oooo
o`00ool000;oo`04003ooooo0004ool01@00oooooooo00000_oo00@00?ooool000?oo`03003ooooo
00Coo`03003ooooo04ooo`00Dooo00D00?ooooooo`0000;oo`04003ooooo000<ool01000ooooo`00
0_oo00<00?ooool00_oo00<00?ooool00_oo00@00?ooooooo`<000?oo`04003oooooool30002ool0
1P00ooooo`00ool001;oo`05003oo`00ool00003ool01000ooooo`001?oo00@00?ooool000;oo`03
003ooooo00;oo`05003oooooool00005ool01000oooooooo0`000ooo00<00?ooool0D?oo001Bool3
0003ool20002ool4000:ool01@00ooooo`00ool00P000ooo0`000_oo0`000_oo0`000_oo100000Go
o`0000000?oo00@00003ool000000080013oo`800003ool0000000;oo`800003ool0000000800004
ool00000ool200000ooo0000000200000ooo00000002ool40002ool20003ool30003ool2001Aool0
05?oo`03003ooooo01Coo`04003ooooo0007ool00`00ooooo`02ool00`00ooooo`0Eool00`00oooo
o`0@ool200000ooo00000006ool00`00ooooo`0Aool00`00ooooo`1Pool005Coo`03003ooooo01;o
o`@000?oo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo02Ooo`800003ool0000001Koo`03
003ooooo00Ooo`03003ooooo05[oo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolX
ool00?ooobSoo`00oooo:?oo003ooolXool008coo`<009Soo`00SOoo00<00?ooool0Uooo001[ool2
0002ool400001?oo000000000_oo0`003Ooo0P000_oo0`000ooo0P000_oo0`000ooo0P0000?oo`00
00000_oo00<00?ooool02_oo0`0000?oo`0000000P0000Coo`00ooooo`8006Soo`00J_oo00<00?oo
ool00_oo0`000ooo00<00?ooool00_oo00<00?ooool02ooo00H00?ooool00?oo0002ool00`00ool0
0002ool01000ooooo`000ooo00H00?ooool00?oo0002ool00`00ooooo`0;ool01P00ooooo`00ool0
00;oo`03003oo`0000;oo`03003ooooo06Goo`00J_oo00<00?ooool01?oo00D00?ooooooo`0000Co
o`03003ooooo00_oo`06003ooooo003oo`000_oo00<00?oo00001Ooo00D00?ooooooo`0000;oo`03
003oo`0000;oo`03003ooooo00_oo`<000;oo`06003ooooo003oo`000_oo00<00?ooool0IOoo001Z
ool00`00ooooo`03ool20003ool00`00ooooo`02ool00`00ooooo`0;ool00`00ooooo`0500000ooo
000000020002ool20004ool200000ooo00000002000>ool01@00ooooo`00ool00`000ooo0P00J?oo
001Zool00`00ool00008ool00`00ooooo`02ool00`00ooooo`0;ool01000ooooo`001_oo00<00?oo
ool07Ooo00H00?ooool00?oo001_ool006[oo`<000Ooo`8000?oo`8000koo`8000goo`03003ooooo
01Koo`@00003ool0000006ooo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool0
0001\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {18.5922, -2.5619, \
0.106644, 0.0872589}}]
}, Open  ]],

Cell["Here is the equivalent three\[Hyphen]dimensional graph. ", "MathCaption",
  CellTags->"0.39"],

Cell[CellGroupData[{

Cell["\<\
Plot3D[optionrho[x, t], {x, 25, 55}, {t, 0, 110},
   AxesLabel->{\"Stock Price\", \"Time\", \"Option \\nRho\"}];\
\>", "Input",
  CellLabel->"In[34]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -11.1734 -9 ]
[.3345 .12542 .8266 0 ]
[.56094 .0364 -10.3394 -9 ]
[.56094 .0364 1.66057 0 ]
[.29165 .07573 -65.1782 -15 ]
[.29165 .07573 4.82182 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.77605 .1102 0 -6.14908 ]
[.77605 .1102 12 2.85092 ]
[.84375 .21386 0 -6.04972 ]
[.84375 .21386 12 2.95028 ]
[.9051 .30781 0 -5.96165 ]
[.9051 .30781 12 3.03835 ]
[.96095 .39335 0 -5.88306 ]
[.96095 .39335 18 3.11694 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 28 4.94788 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01039 .35115 -6 -2.81514 ]
[.01039 .35115 0 6.18486 ]
[-0.00413 .44213 -12 -2.89259 ]
[-0.00413 .44213 0 6.10741 ]
[-0.05457 .39542 -46 -9.75946 ]
[-0.05457 .39542 0 21.2405 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.76373 .11471 m
.75757 .11697 L
s
[(25)] .77605 .1102 -1 .36646 Mshowa
.83134 .21814 m
.82514 .22027 L
s
[(50)] .84375 .21386 -1 .34438 Mshowa
.89262 .31187 m
.88638 .3139 L
s
[(75)] .9051 .30781 -1 .32481 Mshowa
.94841 .39721 m
.94213 .39913 L
s
[(100)] .96095 .39335 -1 .30735 Mshowa
.125 Mabswid
.70438 .02393 m
.70071 .02535 L
s
.71969 .04735 m
.71602 .04876 L
s
.73468 .07028 m
.731 .07167 L
s
.74936 .09273 m
.74567 .0941 L
s
.7778 .13624 m
.7741 .13758 L
s
.7916 .15734 m
.78789 .15866 L
s
.80511 .17801 m
.8014 .17932 L
s
.81836 .19827 m
.81464 .19957 L
s
.84407 .23761 m
.84035 .23888 L
s
.85656 .25671 m
.85283 .25797 L
s
.86881 .27545 m
.86507 .27669 L
s
.88083 .29383 m
.87709 .29506 L
s
.90419 .32957 m
.90044 .33077 L
s
.91555 .34695 m
.9118 .34814 L
s
.9267 .364 m
.92295 .36518 L
s
.93765 .38075 m
.93389 .38192 L
s
.95897 .41336 m
.9552 .41451 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02267 .34655 m
.02882 .34424 L
s
[(5)] .01039 .35115 1 -0.37441 Mshowa
.00823 .43772 m
.01441 .43551 L
s
[(10)] -0.00413 .44213 1 -0.3572 Mshowa
.125 Mabswid
.03366 .2772 m
.03733 .27578 L
s
.03096 .29425 m
.03464 .29284 L
s
.02823 .31149 m
.03191 .31009 L
s
.02547 .32892 m
.02915 .32753 L
s
.01985 .36437 m
.02354 .363 L
s
.01699 .3824 m
.02069 .38104 L
s
.0141 .40063 m
.0178 .39928 L
s
.01118 .41907 m
.01489 .41773 L
s
.00524 .45659 m
.00895 .45527 L
s
.00221 .47567 m
.00593 .47437 L
s
gsave
-0.05457 .39542 -107 -13.7595 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Option) show
63.000000 31.000000 moveto
(Rho) show
81.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.38313 .58323 .40512 .60371 .44189 .59268 .42021 .57192 Metetra
.664 .741 .908 r
.42021 .57192 .44189 .59268 .47916 .5815 .45781 .56045 Metetra
.663 .741 .908 r
.45781 .56045 .47916 .5815 .51695 .57017 .49594 .54883 Metetra
.662 .741 .909 r
.49594 .54883 .51695 .57017 .55526 .55868 .53461 .53722 Metetra
.648 .738 .915 r
.53461 .53722 .55526 .55868 .59412 .54732 .57385 .52684 Metetra
.599 .734 .939 r
.57385 .52684 .59412 .54732 .63362 .53811 .6138 .52035 Metetra
.523 .737 .972 r
.6138 .52035 .63362 .53811 .67392 .533 .65462 .51781 Metetra
.51 .765 .988 r
.65462 .51781 .67392 .533 .71495 .52727 .69625 .51441 Metetra
.559 .816 .994 r
.69625 .51441 .71495 .52727 .75645 .51739 .73844 .50669 Metetra
.589 .857 .994 r
.73844 .50669 .75645 .51739 .79845 .50534 .78114 .49558 Metetra
.597 .874 .993 r
.78114 .49558 .79845 .50534 .84105 .49274 .82441 .48301 Metetra
.599 .878 .992 r
.82441 .48301 .84105 .49274 .88428 .47992 .86831 .46993 Metetra
.599 .879 .992 r
.86831 .46993 .88428 .47992 .92815 .46691 .91287 .45661 Metetra
.599 .879 .992 r
.91287 .45661 .92815 .46691 .97269 .4537 .95812 .44308 Metetra
.664 .741 .908 r
.36056 .56222 .38313 .58323 .42021 .57192 .39797 .55062 Metetra
.664 .741 .908 r
.39797 .55062 .42021 .57192 .45781 .56045 .4359 .53885 Metetra
.663 .741 .908 r
.4359 .53885 .45781 .56045 .49594 .54883 .47437 .527 Metetra
.656 .74 .912 r
.47437 .527 .49594 .54883 .53461 .53722 .5134 .51566 Metetra
.627 .736 .926 r
.5134 .51566 .53461 .53722 .57385 .52684 .55302 .50683 Metetra
.558 .73 .955 r
.55302 .50683 .57385 .52684 .6138 .52035 .59341 .50275 Metetra
.477 .725 .979 r
.59341 .50275 .6138 .52035 .65462 .51781 .63472 .50221 Metetra
.471 .748 .99 r
.63472 .50221 .65462 .51781 .69625 .51441 .6769 .50061 Metetra
.528 .797 .995 r
.6769 .50061 .69625 .51441 .73844 .50669 .71975 .49472 Metetra
.574 .841 .995 r
.71975 .49472 .73844 .50669 .78114 .49558 .76315 .48481 Metetra
.593 .865 .994 r
.76315 .48481 .78114 .49558 .82441 .48301 .80713 .47262 Metetra
.598 .875 .993 r
.80713 .47262 .82441 .48301 .86831 .46993 .85173 .45944 Metetra
.599 .878 .992 r
.85173 .45944 .86831 .46993 .91287 .45661 .897 .44584 Metetra
.6 .879 .992 r
.897 .44584 .91287 .45661 .95812 .44308 .94299 .43198 Metetra
.664 .741 .908 r
.33741 .54067 .36056 .56222 .39797 .55062 .37515 .52876 Metetra
.663 .741 .908 r
.37515 .52876 .39797 .55062 .4359 .53885 .41342 .51671 Metetra
.66 .741 .909 r
.41342 .51671 .4359 .53885 .47437 .527 .45223 .50477 Metetra
.646 .739 .917 r
.45223 .50477 .47437 .527 .5134 .51566 .4916 .4941 Metetra
.602 .733 .937 r
.4916 .4941 .5134 .51566 .55302 .50683 .5316 .48701 Metetra
.516 .721 .966 r
.5316 .48701 .55302 .50683 .59341 .50275 .5724 .48501 Metetra
.435 .71 .981 r
.5724 .48501 .59341 .50275 .63472 .50221 .61417 .48615 Metetra
.436 .732 .989 r
.61417 .48615 .63472 .50221 .6769 .50061 .65688 .48606 Metetra
.497 .781 .995 r
.65688 .48606 .6769 .50061 .71975 .49472 .70036 .48173 Metetra
.554 .826 .996 r
.70036 .48173 .71975 .49472 .76315 .48481 .74447 .47304 Metetra
.584 .855 .995 r
.74447 .47304 .76315 .48481 .80713 .47262 .78917 .46144 Metetra
.596 .87 .993 r
.78917 .46144 .80713 .47262 .85173 .45944 .8345 .44834 Metetra
.599 .876 .993 r
.8345 .44834 .85173 .45944 .897 .44584 .88052 .43454 Metetra
.6 .878 .992 r
.88052 .43454 .897 .44584 .94299 .43198 .92726 .42036 Metetra
.663 .741 .908 r
.31365 .51855 .33741 .54067 .37515 .52876 .35172 .50633 Metetra
.662 .741 .908 r
.35172 .50633 .37515 .52876 .41342 .51671 .39032 .49403 Metetra
.656 .74 .912 r
.39032 .49403 .41342 .51671 .45223 .50477 .42948 .48221 Metetra
.632 .737 .923 r
.42948 .48221 .45223 .50477 .4916 .4941 .46919 .47247 Metetra
.573 .728 .948 r
.46919 .47247 .4916 .4941 .5316 .48701 .50955 .46714 Metetra
.475 .709 .972 r
.50955 .46714 .5316 .48701 .5724 .48501 .55074 .46699 Metetra
.396 .694 .98 r
.55074 .46699 .5724 .48501 .61417 .48615 .59295 .46959 Metetra
.403 .716 .987 r
.59295 .46959 .61417 .48615 .65688 .48606 .63617 .47083 Metetra
.469 .766 .995 r
.63617 .47083 .65688 .48606 .70036 .48173 .68026 .46787 Metetra
.533 .813 .997 r
.68026 .46787 .70036 .48173 .74447 .47304 .72506 .46034 Metetra
.573 .845 .996 r
.72506 .46034 .74447 .47304 .78917 .46144 .77049 .44943 Metetra
.591 .863 .994 r
.77049 .44943 .78917 .46144 .8345 .44834 .81659 .43655 Metetra
.598 .872 .993 r
.81659 .43655 .8345 .44834 .88052 .43454 .86337 .42264 Metetra
.601 .876 .992 r
.86337 .42264 .88052 .43454 .92726 .42036 .9109 .40818 Metetra
.663 .741 .908 r
.28926 .49583 .31365 .51855 .35172 .50633 .32765 .48331 Metetra
.661 .741 .909 r
.32765 .48331 .35172 .50633 .39032 .49403 .3666 .47084 Metetra
.65 .739 .915 r
.3666 .47084 .39032 .49403 .42948 .48221 .40609 .45933 Metetra
.615 .734 .931 r
.40609 .45933 .42948 .48221 .46919 .47247 .44613 .45072 Metetra
.541 .721 .957 r
.44613 .45072 .46919 .47247 .50955 .46714 .48682 .44709 Metetra
.434 .695 .974 r
.48682 .44709 .50955 .46714 .55074 .46699 .52839 .44859 Metetra
.359 .677 .977 r
.52839 .44859 .55074 .46699 .59295 .46959 .57102 .45251 Metetra
.372 .701 .984 r
.57102 .45251 .59295 .46959 .63617 .47083 .61474 .45494 Metetra
.442 .751 .994 r
.61474 .45494 .63617 .47083 .68026 .46787 .65942 .45319 Metetra
.512 .8 .998 r
.65942 .45319 .68026 .46787 .72506 .46034 .7049 .44674 Metetra
.56 .835 .997 r
.7049 .44674 .72506 .46034 .77049 .44943 .75108 .43657 Metetra
.585 .857 .995 r
.75108 .43657 .77049 .44943 .81659 .43655 .79795 .424 Metetra
.596 .868 .993 r
.79795 .424 .81659 .43655 .86337 .42264 .84553 .41006 Metetra
.6 .874 .993 r
.84553 .41006 .86337 .42264 .9109 .40818 .89387 .39537 Metetra
.663 .741 .908 r
.2642 .47251 .28926 .49583 .32765 .48331 .30293 .45969 Metetra
.658 .74 .911 r
.30293 .45969 .32765 .48331 .3666 .47084 .34221 .44716 Metetra
.641 .738 .919 r
.34221 .44716 .3666 .47084 .40609 .45933 .38202 .43613 Metetra
.595 .731 .939 r
.38202 .43613 .40609 .45933 .44613 .45072 .42237 .42875 Metetra
.508 .712 .963 r
.42237 .42875 .44613 .45072 .48682 .44709 .46339 .42675 Metetra
.394 .679 .974 r
.46339 .42675 .48682 .44709 .52839 .44859 .50531 .42975 Metetra
.324 .66 .973 r
.50531 .42975 .52839 .44859 .57102 .45251 .54834 .43487 Metetra
.343 .685 .98 r
.54834 .43487 .57102 .45251 .61474 .45494 .59255 .43838 Metetra
.416 .738 .992 r
.59255 .43838 .61474 .45494 .65942 .45319 .6378 .43773 Metetra
.492 .788 .998 r
.6378 .43773 .65942 .45319 .7049 .44674 .68396 .43229 Metetra
.545 .826 .998 r
.68396 .43229 .7049 .44674 .75108 .43657 .73088 .42285 Metetra
.576 .85 .996 r
.73088 .42285 .75108 .43657 .79795 .424 .77854 .41065 Metetra
.592 .864 .994 r
.77854 .41065 .79795 .424 .84553 .41006 .82695 .39676 Metetra
.599 .871 .993 r
.82695 .39676 .84553 .41006 .89387 .39537 .87613 .38189 Metetra
.662 .741 .909 r
.23846 .44855 .2642 .47251 .30293 .45969 .27752 .43548 Metetra
.654 .74 .913 r
.27752 .43548 .30293 .45969 .34221 .44716 .31713 .42298 Metetra
.63 .736 .924 r
.31713 .42298 .34221 .44716 .38202 .43613 .35725 .41259 Metetra
.573 .726 .946 r
.35725 .41259 .38202 .43613 .42237 .42875 .39789 .40648 Metetra
.473 .7 .968 r
.39789 .40648 .42237 .42875 .46339 .42675 .4392 .40603 Metetra
.355 .662 .972 r
.4392 .40603 .46339 .42675 .50531 .42975 .48146 .41042 Metetra
.291 .643 .967 r
.48146 .41042 .50531 .42975 .54834 .43487 .52489 .41664 Metetra
.315 .67 .975 r
.52489 .41664 .54834 .43487 .59255 .43838 .56956 .42115 Metetra
.391 .724 .989 r
.56956 .42115 .59255 .43838 .6378 .43773 .61538 .4215 Metetra
.472 .777 .997 r
.61538 .4215 .6378 .43773 .68396 .43229 .6622 .41699 Metetra
.531 .817 .998 r
.6622 .41699 .68396 .43229 .73088 .42285 .70987 .40826 Metetra
.567 .843 .996 r
.70987 .40826 .73088 .42285 .77854 .41065 .75834 .39646 Metetra
.587 .859 .995 r
.75834 .39646 .77854 .41065 .82695 .39676 .80759 .38267 Metetra
.597 .868 .993 r
.80759 .38267 .82695 .39676 .87613 .38189 .85764 .36767 Metetra
.66 .741 .909 r
.21199 .42394 .23846 .44855 .27752 .43548 .25139 .41063 Metetra
.65 .739 .915 r
.25139 .41063 .27752 .43548 .31713 .42298 .29132 .39821 Metetra
.619 .734 .928 r
.29132 .39821 .31713 .42298 .35725 .41259 .33173 .38842 Metetra
.553 .719 .95 r
.33173 .38842 .35725 .41259 .39789 .40648 .37265 .3834 Metetra
.445 .686 .968 r
.37265 .3834 .39789 .40648 .4392 .40603 .41425 .38419 Metetra
.331 .644 .967 r
.41425 .38419 .4392 .40603 .48146 .41042 .45682 .38966 Metetra
.278 .628 .962 r
.45682 .38966 .48146 .41042 .52489 .41664 .50061 .39676 Metetra
.308 .656 .971 r
.50061 .39676 .52489 .41664 .56956 .42115 .54573 .40204 Metetra
.387 .709 .986 r
.54573 .40204 .56956 .42115 .61538 .4215 .59209 .40315 Metetra
.469 .761 .994 r
.59209 .40315 .61538 .4215 .6622 .41699 .63954 .39936 Metetra
.532 .8 .995 r
.63954 .39936 .6622 .41699 .70987 .40826 .68793 .39118 Metetra
.572 .826 .993 r
.68793 .39118 .70987 .40826 .75834 .39646 .73717 .37968 Metetra
.595 .842 .991 r
.73717 .37968 .75834 .39646 .80759 .38267 .78725 .36595 Metetra
.607 .852 .99 r
.78725 .36595 .80759 .38267 .85764 .36767 .83816 .35079 Metetra
.658 .74 .91 r
.18478 .39866 .21199 .42394 .25139 .41063 .2245 .38517 Metetra
.643 .738 .918 r
.2245 .38517 .25139 .41063 .29132 .39821 .26474 .37299 Metetra
.604 .731 .935 r
.26474 .37299 .29132 .39821 .33173 .38842 .30542 .36403 Metetra
.526 .713 .958 r
.30542 .36403 .33173 .38842 .37265 .3834 .34659 .3603 Metetra
.405 .674 .97 r
.34659 .3603 .37265 .3834 .41425 .38419 .38844 .36248 Metetra
.285 .628 .962 r
.38844 .36248 .41425 .38419 .45682 .38966 .43131 .36915 Metetra
.234 .611 .954 r
.43131 .36915 .45682 .38966 .50061 .39676 .47547 .37722 Metetra
.267 .643 .965 r
.47547 .37722 .50061 .39676 .54573 .40204 .52103 .38338 Metetra
.349 .7 .983 r
.52103 .38338 .54573 .40204 .59209 .40315 .56793 .38535 Metetra
.436 .756 .995 r
.56793 .38535 .59209 .40315 .63954 .39936 .61603 .38236 Metetra
.504 .8 .999 r
.61603 .38236 .63954 .39936 .68793 .39118 .66517 .37484 Metetra
.549 .83 .998 r
.66517 .37484 .68793 .39118 .73717 .37968 .71524 .36375 Metetra
.576 .849 .996 r
.71524 .36375 .73717 .37968 .78725 .36595 .7662 .35017 Metetra
.591 .861 .994 r
.7662 .35017 .78725 .36595 .83816 .35079 .81804 .33493 Metetra
.656 .74 .912 r
.15678 .37268 .18478 .39866 .2245 .38517 .19682 .35909 Metetra
.635 .737 .921 r
.19682 .35909 .2245 .38517 .26474 .37299 .23735 .34724 Metetra
.588 .728 .94 r
.23735 .34724 .26474 .37299 .30542 .36403 .27828 .33917 Metetra
.497 .704 .962 r
.27828 .33917 .30542 .36403 .34659 .3603 .31967 .33671 Metetra
.368 .658 .969 r
.31967 .33671 .34659 .3603 .38844 .36248 .36176 .34021 Metetra
.249 .609 .955 r
.36176 .34021 .38844 .36248 .43131 .36915 .40491 .348 Metetra
.205 .594 .946 r
.40491 .348 .43131 .36915 .47547 .37722 .44941 .35698 Metetra
.243 .628 .959 r
.44941 .35698 .47547 .37722 .52103 .38338 .4954 .36395 Metetra
.327 .687 .98 r
.4954 .36395 .52103 .38338 .56793 .38535 .54284 .36672 Metetra
.417 .746 .994 r
.54284 .36672 .56793 .38535 .61603 .38236 .59159 .36449 Metetra
.489 .791 .998 r
.59159 .36449 .61603 .38236 .66517 .37484 .64147 .35758 Metetra
.538 .823 .998 r
.64147 .35758 .66517 .37484 .71524 .36375 .69237 .3469 Metetra
.569 .844 .996 r
.69237 .3469 .71524 .36375 .7662 .35017 .74422 .33347 Metetra
.587 .857 .995 r
.74422 .33347 .7662 .35017 .81804 .33493 .79701 .31817 Metetra
.652 .739 .914 r
.12796 .346 .15678 .37268 .19682 .35909 .16831 .33236 Metetra
.626 .735 .925 r
.16831 .33236 .19682 .35909 .23735 .34724 .20911 .32092 Metetra
.57 .723 .946 r
.20911 .32092 .23735 .34724 .27828 .33917 .25026 .31378 Metetra
.468 .694 .966 r
.25026 .31378 .27828 .33917 .31967 .33671 .29185 .31256 Metetra
.331 .641 .965 r
.29185 .31256 .31967 .33671 .36176 .34021 .33415 .31731 Metetra
.215 .589 .946 r
.33415 .31731 .36176 .34021 .40491 .348 .37755 .32615 Metetra
.177 .578 .937 r
.37755 .32615 .40491 .348 .44941 .35698 .42238 .33599 Metetra
.219 .614 .952 r
.42238 .33599 .44941 .35698 .4954 .36395 .46878 .34372 Metetra
.306 .675 .975 r
.46878 .34372 .4954 .36395 .54284 .36672 .51675 .34723 Metetra
.399 .735 .992 r
.51675 .34723 .54284 .36672 .59159 .36449 .56613 .3457 Metetra
.474 .783 .998 r
.56613 .3457 .59159 .36449 .64147 .35758 .61676 .33937 Metetra
.528 .816 .999 r
.61676 .33937 .64147 .35758 .69237 .3469 .6685 .32908 Metetra
.562 .838 .997 r
.6685 .32908 .69237 .3469 .74422 .33347 .72127 .31582 Metetra
.582 .853 .995 r
.72127 .31582 .74422 .33347 .79701 .31817 .77503 .30045 Metetra
.647 .739 .916 r
.09827 .31858 .12796 .346 .16831 .33236 .13893 .30495 Metetra
.616 .733 .93 r
.13893 .30495 .16831 .33236 .20911 .32092 .17997 .294 Metetra
.55 .718 .951 r
.17997 .294 .20911 .32092 .25026 .31378 .22131 .28781 Metetra
.436 .682 .967 r
.22131 .28781 .25026 .31378 .29185 .31256 .26308 .2878 Metetra
.293 .623 .96 r
.26308 .2878 .29185 .31256 .33415 .31731 .30557 .29373 Metetra
.181 .57 .936 r
.30557 .29373 .33415 .31731 .37755 .32615 .3492 .30356 Metetra
.15 .561 .928 r
.3492 .30356 .37755 .32615 .42238 .33599 .39432 .3142 Metetra
.196 .6 .945 r
.39432 .3142 .42238 .33599 .46878 .34372 .44113 .32266 Metetra
.286 .663 .971 r
.44113 .32266 .46878 .34372 .51675 .34723 .48961 .32686 Metetra
.381 .725 .989 r
.48961 .32686 .51675 .34723 .56613 .3457 .53962 .32597 Metetra
.46 .774 .997 r
.53962 .32597 .56613 .3457 .61676 .33937 .591 .32018 Metetra
.517 .809 .999 r
.591 .32018 .61676 .33937 .6685 .32908 .64358 .31025 Metetra
.554 .833 .997 r
.64358 .31025 .6685 .32908 .72127 .31582 .69728 .29715 Metetra
.577 .849 .996 r
.69728 .29715 .72127 .31582 .77503 .30045 .75203 .28173 Metetra
.642 .738 .918 r
.06769 .2904 .09827 .31858 .13893 .30495 .10863 .27684 Metetra
.604 .73 .934 r
.10863 .27684 .13893 .30495 .17997 .294 .14989 .26643 Metetra
.528 .711 .955 r
.14989 .26643 .17997 .294 .22131 .28781 .1914 .26121 Metetra
.404 .668 .968 r
.1914 .26121 .22131 .28781 .26308 .2878 .2333 .26238 Metetra
.256 .604 .953 r
.2333 .26238 .26308 .2878 .30557 .29373 .27595 .26942 Metetra
.149 .551 .926 r
.27595 .26942 .30557 .29373 .3492 .30356 .31978 .28018 Metetra
.124 .545 .919 r
.31978 .28018 .3492 .30356 .39432 .3142 .36519 .29158 Metetra
.175 .586 .938 r
.36519 .29158 .39432 .3142 .44113 .32266 .41238 .30071 Metetra
.267 .651 .966 r
.41238 .30071 .44113 .32266 .48961 .32686 .46135 .30555 Metetra
.364 .715 .987 r
.46135 .30555 .48961 .32686 .53962 .32597 .51199 .30526 Metetra
.446 .766 .997 r
.51199 .30526 .53962 .32597 .591 .32018 .56411 .29997 Metetra
.506 .803 .999 r
.56411 .29997 .591 .32018 .64358 .31025 .61754 .29038 Metetra
.546 .828 .998 r
.61754 .29038 .64358 .31025 .69728 .29715 .67218 .27741 Metetra
.572 .845 .996 r
.67218 .27741 .69728 .29715 .75203 .28173 .72796 .26194 Metetra
.637 .737 .921 r
.03617 .26138 .06769 .2904 .10863 .27684 .07738 .24787 Metetra
.593 .727 .937 r
.07738 .24787 .10863 .27684 .14989 .26643 .11884 .23792 Metetra
.509 .703 .958 r
.11884 .23792 .14989 .26643 .1914 .26121 .16051 .23349 Metetra
.378 .654 .965 r
.16051 .23349 .1914 .26121 .2333 .26238 .20254 .23559 Metetra
.233 .586 .946 r
.20254 .23559 .2333 .26238 .27595 .26942 .24531 .24351 Metetra
.134 .535 .919 r
.24531 .24351 .27595 .26942 .31978 .28018 .28932 .25498 Metetra
.117 .533 .915 r
.28932 .25498 .31978 .28018 .36519 .29158 .33497 .26696 Metetra
.173 .575 .936 r
.33497 .26696 .36519 .29158 .41238 .30071 .38251 .27659 Metetra
.266 .64 .964 r
.38251 .27659 .41238 .30071 .46135 .30555 .43195 .28189 Metetra
.364 .703 .984 r
.43195 .28189 .46135 .30555 .51199 .30526 .48318 .28202 Metetra
.447 .753 .994 r
.48318 .28202 .51199 .30526 .56411 .29997 .53602 .27706 Metetra
.508 .789 .996 r
.53602 .27706 .56411 .29997 .61754 .29038 .59028 .26766 Metetra
.549 .814 .995 r
.59028 .26766 .61754 .29038 .67218 .27741 .64584 .25472 Metetra
.577 .831 .993 r
.64584 .25472 .67218 .27741 .72796 .26194 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[34]:=",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jA000`40n007h00Ooooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00
oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00
oooo8Ooo003ooolQool00=Goo`03003ooooo04Soo`00e?oo00<00?oo0000BOoo003Dool00`00ool0
0019ool00=Coo`03003oo`0004Woo`00e?oo00<00?oo0000BOoo002^ool00`00ooooo`02ool00`00
ooooo`0Iool20004ool00`00ooooo`18ool00:goo`03003oo`0000;oo`03003oo`0001Soo`D004ko
o`00[ooo00H00?ooool00?oo000Eool30003ool2001>ool00:goo`8000?oo`03003oo`0001?oo`80
0003ool00?oo00?oo`03003oo`0004goo`00[Ooo00<00?ooool00_oo00<00?oo00004?oo0`002?oo
00@00?ooool004coo`00[Ooo0`000ooo00<00?ooool03Ooo0P002ooo00<00?ooool00P00Booo0030
ool3000=ool00`00ooooo`02001;ool003_oo`<000?oo`8000?oo`8000;oo`<00004ool00000ool2
000;ool30003ool30002ool30002ool30003ool20017ool300000ooo003oo`0=ool00`00ooooo`02
ool00`00ooooo`18ool003_oo`03003oo`0000;oo`06003ooooo003oo`000_oo00<00?oo00001?oo
00<00?oo00003Ooo00<00?ooool00ooo00<00?ooool00_oo00D00?ooooooo`0000Coo`03003ooooo
04Goo`8001?oo`03003ooooo00;oo`03003ooooo04Soo`00?Ooo00@00?ooool000Coo`06003ooooo
003oo`001?oo0`003Ooo0`000ooo00<00?ooool00_oo00D00?ooooooo`0000Coo`<004;oo`<001Ko
o`03003ooooo00;oo`03003ooooo04Ooo`00??oo00<00?ooool010000ooo0P000_oo0`000_oo00@0
0?oo000000coo`05003ooooo003oo`0400000ooo00000003ool30002ool30010ool2000Iool00`00
ooooo`03ool00`00ooooo`16ool003_oo`03003oo`0000;oo`03003ooooo00coo`03003ooooo00go
o`04003ooooo001@ool300000ooo003oo`0Hool00`00ooooo`02ool20018ool003_oo`<0013oo`80
00koo`@000Soo`03003ooooo04Coo`8000Coo`03003ooooo01Ooo`03003ooooo00Coo`03003ooooo
04Goo`00[_oo0`008?oo00<00?ooool01Ooo00<00?ooool0A?oo002/ool2000Sool00`00ooooo`05
ool00`00ooooo`14ool00:Woo`@002Coo`03003ooooo00Koo`03003ooooo04?oo`00Yooo0P00:?oo
00<00?ooool01Ooo00<00?oo0000A?oo002Tool3000Zool00`00ooooo`07ool00`00ooooo`12ool0
0:;oo`8002goo`03003ooooo00Soo`03003ooooo047oo`00Wooo1000;_oo00<00?ooool02Ooo00<0
0?ooool0@?oo001kool30002ool00`00ooooo`0Jool2000bool00`00ooooo`09ool00`00ooooo`04
ool30003ool00`00ooooo`0cool007coo`06003ooooo003oo`006?oo0`00=?oo00<00?ooool02Ooo
0P001Ooo00<00?ooool00_oo00<00?oo0000=?oo001jool400001?oo003oo`005Ooo0`00=ooo00<0
0?ooool02ooo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool0<_oo001jool00`00ool00002
ool00`00ool0000Cool200000ooo003oo`0gool00`00ooooo`0;ool00`00ooooo`03ool01000oooo
oooo0P00=Ooo001kool20002ool00`00ool0000@ool3000lool00`00ooooo`0<ool01`00oooooooo
003oo`0000;oo`03003ooooo03Coo`00O?oo00D00?ooooooo`0000ooo`8003ooo`03003ooooo00co
o`8000?oo`04003oooooool3000dool008goo`<0047oo`03003ooooo00_oo`<003koo`00Rooo0P00
0_oo00<00?ooool0@?oo00<00?ooool03Ooo00<00?ooool0>ooo0028ool30017ool00`00ooooo`0=
ool00`00ooooo`0kool008Koo`8004[oo`03003ooooo00koo`03003ooooo03[oo`00Pooo0`00C?oo
00<00?ooool03_oo0P00>ooo0021ool20002ool00`00ooooo`1:ool00`00ooooo`0?ool00`00oooo
o`0iool007koo`<0057oo`03003ooooo013oo`03003ooooo03Soo`00Nooo0`00E?oo00<00?ooool0
4Ooo00<00?ooool0=ooo001iool4001Eool00`00ooooo`0Aool00`00ooooo`0gool007Koo`<005Wo
o`03003ooooo017oo`8003Soo`00M?oo0P00G?oo00<00?ooool04ooo00<00?ooool0=Ooo001aool3
001Nool00`00ooooo`0Cool00`00ooooo`0eool004coo`8000Coo`03003ooooo01[oo`800003ool0
0?oo05koo`03003ooooo01Coo`03003ooooo03Coo`00C_oo00H00?ooool00?oo000Hool3001Sool0
0`00ooooo`0Dool2000eool004goo`07003oooooool00?oo00005_oo0P00I_oo00<00?ooool05Ooo
00<00?ooool0<ooo001>ool01P00ooooo`00ool001?oo`<006Soo`03003ooooo01Koo`03003ooooo
03;oo`00C?oo00<00?oo00000_oo00<00?oo00004Ooo0P00Jooo00<00?ooool05ooo00<00?ooool0
5ooo0`000_oo0`0000Koo`00ool00?oo0002ool20008ool004goo`03003ooooo00;oo`03003ooooo
00goo`<006goo`03003ooooo01Ooo`8000Koo`03003ooooo00;oo`03003ooooo00_oo`03003ooooo
00;oo`0:003ooooo003oo`00ool00?oo000:ool0063oo`80073oo`03003ooooo01Ooo`8000Goo`03
003oo`0000;oo`03003oo`0000coo`03003ooooo00;oo`09003ooooo003oo`00ool00?oo00<000So
o`00GOoo1000L_oo00<00?ooool06?oo00<00?ooool01?oo00H00?ooool00?oo000<ool01000oooo
oooo0P000_oo0P0000Coo`00ooooo`<000Soo`00Fooo0P00M_oo00<00?ooool06?oo00<00?ooool0
0_oo0P000ooo00<00?oo00002_oo00D00?oo003oo`0001Koo`00F?oo0`00N?oo00<00?ooool06Ooo
00D00?ooooooo`0000Coo`03003oo`0000[oo`D000;oo`03003ooooo017oo`00E_oo0P00Nooo00<0
0?ooool06?oo0`000_oo0`000ooo00<00?ooool09?oo001Cool30002ool00`00ooooo`1hool00`00
ooooo`0Jool00`00ooooo`0]ool0053oo`<0083oo`03003ooooo01_oo`03003ooooo02coo`00C_oo
0P002Ooo2@00LOoo00<00?ooool07?oo00<00?ooool0:ooo001;ool300000ooo003oo`0800002Gfn
OIem_WfNOKh005dnGAiM?P09001Wool2000Mool2000]ool004Woo`8000;oo`@0000JUIfEoHfL001m
GHFnOEf5_WeMQKimGHFnOEf5_P00GCiM7UdnGAeM?UdNGCh003bn=9dl_PH005koo`<00003U[l00000
01koo`03003ooooo02[oo`00A_oo1`0002>EoIFMUOfEWIGmUIfEoIFM001mWWfnOIem_WfNOKimWGfn
OIim_P00GCiM7UdnGAiM?UdNGCh003Bm=9dl_CBM=;ddWCbm00@005Soo`<00003U[n>Whjo00800003
SYl00?oo01goo`03003ooooo02Woo`00A?oo1@0000fMo:Gm002EoHfLUOfEWIGmSIbEoIFMUOf=W002
00004HFnOEf5_WeMQKimGHFnOEf5_P00GCiM7UdnGAeM?UdNGCh00P0000TdWCbn=9dl_SBM?;h002@m
71`01000DOoo0`0000>F_hjnU[l00`0000BF_hjn002>_P8001coo`03003ooooo02Woo`00@_oo1000
02bMg9glWMbUoIgLWO`009GmUIfEoIFMUOfEWIGmUIfEoIFMUOd007fnOIem_WfNOKimWGfnOIim_P00
GCiM7UdnGAiM?UdNGCiM7P00=9dl_CBM=;ddWCbm0P0000@D71`M51`L70<004_oo`<00003U[n>Whjo
00<0000:S[n>WiJoSYn>_`00U[n>Whjo000Lool00`00ooooo`0Xool0047oo`80000LWObUoIglYOfM
o:GmWObUoIglYOd009GmSIbEoIFMUOf=W9GmUIfEoHfLUOd008FnOEf5_WeMQKh900004UdnGAiM?UdM
000dWCbn=9dl_SBM?;hdW@0071`T?A`L93dL70@004Coo`@00003SWn6OP0000<0000<U[n>_YJoS[jF
_hjnU[n>_YJo002F_hjn0P006_oo00<00?oo0000:Ooo0012ool05`00YOfMg9glWMbUoIgLWObMg:Gm
WMbMo000UOfEWIGmUIfEoIFMUOfEWIGmUId01P0000V5_XFMQKj5WHFn001UOVENIGh02P0000`dWCbm
=9d001@L71dD71`L51`000`L71`4000lool4000018IOSWn6Ghio100000^>WiJoSYn>_hjOU[n>Whjo
SYnF_hjO00<00003SYn>_`0001_oo`03003ooooo02Ooo`00??oo00<00?ooool00_oo01D00?oo002U
oIglYOfMo:GmWObUoIglYOfMo:Gm002EoHfLUOfEWIGmSI`00`0001VEW9gm0025_WfMQKj5WHFnOIf5
_XFMQKh006EnIAiUOUdMIGiU7VEnGAd003bM??hlW@0700000a`L93dL7002000011`m51`L?A@L1000
<ooo1@0000J>OhInSWn6OXioQWh2000018ioQWj>OhIn0P0000JF_hjnU[n>_YJoS[h300001hjnU[l0
09JoS[jF_`0001_oo`03003ooooo02Koo`00>ooo00<00?oo00000ooo0P00013oo`00YOfMg9glWMbU
oIgLWObMg:GmWMbMo000UOfEW@<0000@UIfEoIFMUOfEWIGm0025_XFMQKj5WHFnQIf5_XFMQKh20000
4FENIGiUGVEnIEiUOVEN000dWCcn=9dloCBM??hdW@0075d0100000TL7@0071`D71`L31`L7000;;d0
1@00:?oo1P0000Qn?ghOOSl008ioQUn>OhIO0`0000^6GhioQUn>OhIOSWn6Ghio002F_hjO00<0000;
SYn>_hjOS[n>W`00SYn>_hjOS[l0000Kool00`00ooooo`0Uool003_oo`03003oo`0000?oo`0?003o
ooooool00:GmWObUoIglYOfMo:GmWObUoIgl00<0000:UIbMoIFMWOfEW9gmUIfMoIFLWOd200004GfM
QKj5WHFnOIf5_XFMQKimW@00IAiUOUdMIGiU7VEnGAd00P0000/loSbMA?hlWCcn?9d001aL97dLG2Am
00@0000:51`L?A@L73d002bm95`/_BAM;;d8000Gool900002WhnQWmn?XIoOSj6OghnQWmn?XIo1000
00^6OXioQWj>OhInSWn6OXioQWj>OhIn00<0000?S[jF_hjnU[n>_YJoS[jF_hjn002>_YJoS[jF_`00
01Woo`8002Ooo`00>ooo00<00?oo00000ooo00<00?ooool00_oo00L00:GmWMbMo9gLYOfMg0030000
:IgLYO`009GmUIfEoIFMUOfEWIGmUIfEoIFMUOfEW@00QIf5_XFMQKj5WHFnQIf5_XFM001UGVEnIEiU
OVENIGiUGVEn000loSBM??ddWCcn=9d00P0000DTGAaL95dLGBAM00@0000:31`L7000000LWBbm79d/
_AbM;;d200000cDNAChe7P0G00004FGOKOmUgfgoIMm]o`00OSmn7ghoOQmn?ghOOSmn7ghoOQl01@00
00R6GhioQUn>OhIOSWn6Ghio10000166WhJo002>_hjOS[n>WhjoSYn>_hjOS[n>W`00SYn>_hjO0080
01[oo`03003ooooo02Coo`00>ooo00<00?oo00000ooo00<00?ooool00ooo00<00:GmWO`00`0001VM
o:GmWObUoIglYOd009gmUIbMoIFMWOfEW9gmUIfMoIFLWOfEW@00OIf5_XFMQKimW@0B000033cn?9e4
oP0097dLG2Am75`TO@0077dL70D0000K95`/_BAM;;dTG2bm95d003cMAChlgDDn?=e5?ScMACh005fo
EEiM_eENGKmEGUfoEEiM_eEN0080000BMOm]oWGoKOieofgnMOm]oWGoKOieo`00QWmn?XIoOSj6Oghn
0`0000Un?XIoOSj6Oghn0026OXioQWh0100000N>_hIoS[n6OhjoQWn>_`02000028jnU[n>_YJoS[jF
_hjnU[l400000hjnU_l0000Jool00`00ooooo`0Sool003coo`03003ooooo00;oo`03003ooooo00Co
o`80000:WMbUo9gLYOfMg:GlWMbUoIgLYO`200002YFMUOfEWIGmUIfEoIFMUOfEWIGm1P0001:5WHfm
QIf=_XFM001UGVenIEi]OVENKGiUGVen001<oScMA?h6000011aL95dLGBAM0P0000@DG1aM55`LG0@0
000V79d/_AbM;;dLW@00=Ai5?SDNAChe7TDn=Ai5?P00GKiMWUfoEIiM_UfNGKmEWUfnGIiM_`00KOmU
gfgoIMm]ofGOKOmUgfgoIMm]o`80000;OQl00000001n7ghoOQmn?ghOOSmn7`0500004HJOS[n6WhJo
QYn>_hJOQ[n6WhjoQYn6_hJO002>WhjoSYl0100000NF_`00S[n>WiJoSYn>_`02000Hool00`00oooo
o`05ool00`00ooooo`02ool00`00ooooo`0Fool0043oo`03003ooooo00Koo`0D002UoIglYOfMo:Gm
WObUoIglYOfMo:GmWO`009FLWOfEWIgmUIbMo@<0000MWOfEW000QIf=_XFMSKj5WHfnQIf=_XFM001]
GVenIEe]OVeNKGiUGFen001<oTCMC?i4gDcnA=e<oP0400002AaL97dLG00071`LOA@L77dL700:0000
1dDn?=e5?ScMAChlgDDn0080000EEEiM_eENGKmEGUfoEEiM_eENGKl007GoKOieofgnMOm]oWGoKOie
ofgn00<00004OSj6OghnQWl600004WioQWmnO`00QWn>_hIoS[n6OhjoQWn>_hIoS[n6OhjoQWn>_`@0
000>S[jFohjnU_n>_YKo002FohjnU_n>_YKoS[h001Koo`03003oo`0000Koo`07003oooooool00?oo
00005ooo0010ool00`00ooooo`07ool04000YOfMg:GlWMbUoIgLYObMg:GmWMbUo9gL002EWIGm0`00
02:MoIgMWOfEgIgmWMd008FMSKf5WHfnQIf=_HFMSKj5W@00IEi]OVENKGiUGVenIEi]OP00C?hlgDCn
?=i<oScMA?h0008/G@D0000<55`LGAAL75`DG1aM000/_AbM;;dLWBbm1`0000m5?SDNAChe7P00GIiM
_eFNGKiMWUfoEIiM_UfNGKl00P0000EUgfgoIMm]ofGO00X0000:OWmnGgioOUmnOgiOOWmnGgioOUl2
000028JoQYn>_hJOQ[n6WhjoQYl400004HjoSYl008jOS[n>WiJoSYn>_hjOU[l008joSYnF_hjOS[l0
0P006?oo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool05Ooo0010ool00`00ooooo`08ool2
00002YglYOfMo:GmWObUoIglYOfMo:Gm0`0002FMoIFLWOfEW9gmUIbMoIFLWOfEW000QIf=_XFMSKj5
WHfnQIf=_XFM001]GVenIEe]OVeNKGiUGFen001<oTCMC?i4gDcnA=e<oP02000012AL;;dTGBbm1000
010D71am71`LO@00;;dTWBbm99d/_BBM;;d004Dn?Ai5?QL00006MSm^?gHoKSmf?fho0P000Wio00F6
OgioOWmnOhIo00=nO`07QWmnOgio002>_hIoS[l0100000N6_hjoQ[n>_hJoS[n6_`02000029KoS[jF
ohjnU_n>_P00S[h400000iKoS[h0000Gool00`00ooooo`04ool00`00ooooo`02000Hool0043oo`03
003ooooo00[oo`07002Mg:GlWMbUoIgLYO`00`0002^Uo:GL002EgIgmWMfMoIGMWOfMgIgmUMfMoIgM
0025WHfmQIf=_XFMSKf5WHfnQId006ENKGiUGVenIEi]OVENKGh004cn?=e4oScNC?hlgDCn?=h00005
;5d900003abM;;dLWBbm79d/_@00AChe7TDn=Ai5?SDNAChe7P02000025foEIiM_efNGKmEWUfoGIh4
00005fhoIQm^?fHOKSmV7fhoIQm^?fHOKSl007ioOUmnOgiOOWmnGgioOUmnOgiOOWl01@00016>_hJO
S[n>WhjoQYn>_hjOS[n6WhjoSYn>_`00S[n>WiJo00@00007SYnFohjOU_n>WiKoSYl00P005_oo00L0
0?ooooooo`00ool00002ool00`00ooooo`0Gool0043oo`03003ooooo00_oo`03002Mo:Gm00<0000H
YOfMo:GmWObUoIgl002EW9gmUIbMoIFLWOfEW9gmUIbMoIFL0025WHfnQIf=_XFM4P00011<oTCMC?i4
g@0095`/_BAM;;dTG2bm000TOAaL97dLG0D0000499d/_BBM;;d200003CdNAChm7DDn?Ai5?SdMACh0
05foEIiM_eFN00<0000@EIiM_eFNGKl007HoKSmf?fhoMSm^?gHoKSmf?fhoMSl200000gioQWmnO`06
00000hIoOWn6O`0200003HJoS[n6_hjoQ[n>_hJoS[n6_hjoQ[n>_hJo00@0000>U_n>_YKoS[h008jn
U_n>_YKoS[jFohjnU_l001?oo`800004ool00?ooool30002ool3000Gool0043oo`03003ooooo00co
o`80000EYObUg:GlWMbUo:GLYObMg:GlYM`009GMWOfMgIgmUMfMoIgMWOfEgIgm00H0000BSIf=_HfM
SKf=W@00MEieOWENMGieGWEnMEieOP00ECi=7UDn2P000RaM0P0000LLG2AM75dTGAaL000/W@050000
31bM000e7TDn=Ai5?SDNAChe7TDn001M_`800008GIiM_eFNGKmMWUfoEIiM_`800006IQm^?fHOKSmV
7fho200001AnGhIoOUn6OgiOQWmnGhIoOUn6OgiO002>WhjoQYn>_hjOS[n6Whjo1000016>Whjo002F
ohjOU_n>WiKoSYl008jOU_n>WiKoSYnFohjO008001Goo`03003ooooo01ooo`00?ooo00<00?ooool0
3_oo01<009glYOfMo:GmWObUoIglYOfMo:GmWO`009FLWOfEW9gmUIbMo@0300008YgmWO`008fMUOj=
WHgnSIfEoXfMSOj=W@00MEie_VeMMKieGWFnKEee_P00ECi=7EDnCAiE?TdMECi=7P00;9dd_SBM1P00
00XTOAaL97dLG000;9ddoBbM=?h/W@P00003ACh0000000800006EIiM_eFNGKmEWUfo2`0001Af?fho
MSm^?gHoKSl007ioQWmnOhIoOWn6OgioQWmnOhIoOWn6Ogio0P0000>>_hJo00000`000hjo00B6_hjo
S[n>_`800008S[jFohjnU_l009KoS[jFo`@00003S[jFo`0001Goo`03003ooooo01koo`00?ooo0P00
4?oo00l009gLYObUg:GlWMbUo:GLYObMg:GlYM`009GMWOd00`00012MoIgLWOfMg9gmWM`008fMSKf=
WHfmSIf=_HfMSKf=W@800007MGieGWEnMEieOWENMGh00P0000m=7UDnCAiE?TdNECi=7P00=9dd_CBM
=;ddWCBm=9d0100000XTGAaL000002bm;9d/_BbM;;d/W@800003ACh0000000/0000BGKmMWefoGIiM
_efO001V7gHoMQmf?fHOMSmf7gHoIQmf?gHO0P0000^6OgiOQWmnGhIoOUn6OgiOQWmnGhIo00@0000A
SYn>_hjOS[n>WhjoSYn>_hjOS[n>WhjoSYl008jOU_n>W`040007U_l2000Cool00`00ooooo`0Nool0
03ooo`03003ooooo013oo`0;002Mo:GmWObUoIglYOfMo:GmWObUo@0300009YgmWObMoIglWOfMo9gm
WObMoIgl002=WIGnSIf=oXfMUOj=WHgnSIfEoP00MKi]GGFnMEie_VeMMKieGP00CAeE?TdNECi=7EDn
CAh200002CBn=9dd_RbM=;hdW@0095`/_@0500001CCm;9ddoRbM=?d00`0000Q5OTDNCGi57TEnAAi=
OTDN0P0001aUoefNGOmMWVGoGIiMoefNIOmMWP00KSmf?fhoMSm^?gHoKSmf?fhoMSm^?gHo0026Ogio
QWmnO`H00006QWmnOhIo002>_hJo0hjo00F6_hjoS[n>_hJo00>>_`@0000<S[jFo`00U_n>_YKoS[jF
ohjnU_n>_YKo0P004ooo00<00?ooool07Ooo000oool00`00ooooo`0Aool01`00WMbUo:GLYObMg:Gl
00<0000GYObUg000WMbMoIgLWOfMg9gmWMbMoIgLWOfMg000SIf=_HfMSKf=WHfmSIf=_@0@00002ddN
ECi=7UDn000d_CBM=;ddWCBm=9d00P0000@/_BbM;;dLW@H00003;;d/WBbm0080000N?Ai5?SdNAChm
7TDn?Ai5?P00GKmMWefoGIiM_efOGKmMWUfoGIl006HOMSmf7gHoIQmf?gHOMSmV7gHo1P0000Z6GhIo
QUn6OhIOQWn6GhIoQUn6O`800007SYn>_hjOS[n>WhjoSYl0100000>>_hjO000019Ko00<009KoU_l0
0iKo0`000YKo00<00?ooool04Ooo00<00?ooool07?oo000oool2000Cool00`00WObUo@0300005ZGm
WObUo9glYOfMo000WObMoIglWOfMo9gmWObMoIglWOfMo000SIfEoXfM1000012EoHfMUOd007fnMIem
_WfMOKieWGfnOId005DNGCiE7PX00007=;hdWCBn000/_BAM;;d0100000<dgCCn00002P0000==OTDN
AGh00P0000eMWUgoGIiUoefNGOmMWVGoGIh006hoMSm^?`0600000ghoMSmf?`020002QWl01GioQWn6
OhIoOWl00hIo00InOhIoQWl008JoS[l400001hjnS[n>_YJoS[j>_hjn00800006U_n>_P00S[jFohjn
0P0000JFohknU_nFoYKoS_h2000Aool00`00ooooo`0Lool003koo`8001Goo`80000:YObUg:GlYMbU
o:GLYObUg:GlYM`200002IgmWMbMoIgLWOfMg9gmWMbMo@0400007YFMUOfEWIGmUIfEoIFMUOd007fn
OIim_WfNOKimWWfnOIh005dNGCiM7UdnGAiM?UdNGCh003cn==dloPL0000A;;dLWBbm;9d003CM=?dd
gCCn==ddoCCM001=GTenCEi=OP0B00005gHOMSmf7gHoMQmf?gHOMSmf7gHoMQl008IOQWn6GhIoQUn6
OhIOQWn6GhIoQUl0100000j>_hjOS[n>WhjoSYn>_hjOS[n>WhjoSYn>_`000YKo0`002YKo00<00?oo
ool03_oo0P007Ooo000iool00`00ooooo`02ool00`00ooooo`0Eool05000WObUoIglYObMo:GmWObU
o9glYOfMo:Gl002MoIglWOfMo9gmWO`200005ZGmWO`008fMUOf=WIGmSIfEoHfMUOf=WIGm001m_WFM
OKimWGfnMIem_WfM0P0000MM?UDNGCiE7UdnEAiM?P0200000cbM??h0000200000ccn000d_P070000
6SCn==ddoSCM=?hdg@00AEi=OdENCGi5GTeoAEi=OTEN001MoVGoGOiUoegnIOmMoVGoGOh200001Gho
MSmf?gHoOSl00gHo00An?gHoMSmf?`800003QWmnOhIo00H0000AQWn>_hIo002>_YJoS[j>_hjnU[n>
_XjoS[jF_hjnS[n>_P0300003Hkn002FoYKoS_jFoiKnU_n>oYKoU_jFohkn0080017oo`03003ooooo
01[oo`00>?oo00<00?oo00000ooo00<00?ooool05_oo01000:GLYObUg:GlYMbUo:GLYObUg:GlYMbU
o000WOfMg0<0000RWMbMoIgLWObMg000UIfEoIFMUOfEWIGmUIfEoIFMUOd007fnOIim_WfNOKimWWfn
OIim_P00GCiM7UdnGAiM?UdNGCh300002ccn==dloSCM??h003Bm;9dd_BbM=;d01@0000@doSCM=?dd
g@800008CGi=GTenCEi=OTeNCGi=GP80000EIOmUgVGoIMmUofGNIOmUgfGo001f?gHOMSmf7gHoMQmf
?gHOMSmf7gHo00D0000:Q[n6GhJoQUn6_hIOQ[n6GhJoQUl200001hjoSYn>_hjOS[n>Whjo00@00006
SYn>_`00002Fo`001YKo100000>FWYKo00004?oo00<00?ooool06_oo000jool01@00oooooooo0000
6Ooo0P0000ZUoIglYObMo:GmWObUo9glYOfMo0<0000JWObUoIglYOfMo:GmWObUoIgl002=WIGmSIfE
oHfMUOf=WIGmSIfEo@00OKieWGfnOIem_Q000004=9dloSbM??h2000022bM=;h/WCBn;9dd_P00??h5
00005CCn001=OdENCGi5GTeoAEi=OTENCGl006GoGOiUoegnIOmMoVGoGOiUo`020003MSl6000057io
MSmnO`00Q[n6OhjoQWn6_hIoS[n6OhJoQWn>_hIoQ[l009JoS[h4000029KoS[jFohjnU_n>_YKoS[h2
00000iKoU_h00003000029koU[jNoiJnW_nF_Yko000@ool00`00ooooo`0Iool003Soo`8000Coo`80
01[oo`07002Uo:GLYObUg:GlYM`00`0001JUg:Gl002Mo9gLWOfMg9glWMbMoIgLWObMg000UIfEoIFM
UOfEWIGmUIfEo@L00005QKj5WHFnQIj5_P03000026EnIEiUOVENIGiUGP00?=h500003SCM000/WCBm
;9dd_BbM=;d003cn==hloSCM??hJ00002WHOOWmn7gioMQmnOghOOWmf7gio0P0000Z6GhJoQUn6_hIO
Q[n6GhJoQUn6_`@0000=SYnF_hjOS[n>WiJoSYn>_hjOU[n>WhjoSYl00`0000fFWikoUYjFoiJOW_nF
WYKoUYnNoiJNU_l0000>ool3000Jool003Soo`03003ooooo00?oo`03003ooooo01[oo`03002UoIgl
00<000:Uo00CWObUoJGlYO`00:GmWObUoIglYOfMo:GmWObUoIgl002=WIGmSId0100000ZMoIFLWOd0
08FnOIf5_WfMQKimW@@0000>IGiUGVEnGEiUOVENIGiMGP00A=e4oTCMA?i4g@D00004;9dd_RbM=;h2
000043CM??hdgCcn==dloP00EGm=GUEoCEiEOdeNEGm=GUEo0P0001]UoVgoIOi]ofGnKOmUoVgoIOh0
07HoOWmf?gioMSmnOgHoOWmf?gioMSmnOgHo0026OhjoQWl01P0000>>_hJoS[l00P0000R>_YKoS[jF
ohjnU_n>_YKo100000nF_YJo002NoiJnW_nF_YkoU[jNoiJnW_nF_YkoU[h00P003ooo00<00?ooool0
6?oo0002ool300000ooo0000000200001?oo003ooooo0P00:?oo0`000_oo00<00?ooool07?oo0P00
00ZUg:GlYMbUo:GLYObUg:GlYMbUo0800008WMbMoIgLWObMg9gmWMbMo0@0000;UMfEoIGMUOfEgIGm
UMfEo@00QKj5W@03000018FMQKj5WXFn0P0000MUGVEnIEiUOVENIGiUGP02000024Cn?=i4oScNA?hl
gP00==d5000022bM000dgScn==dloSCN??h200004deNEGi=GTenCEiEOTeNCGi=GP00IMmUofGOIOmU
gfGoIMmUofGO0080000:OWmf7gioOQmnOgHOOWmn7gioMQl500002hJOS[n6WhjoQYn>_hJOS[n6Whjo
QYl00P0000>F_hjO00000`0000JF_iJOU[nFWYJoUYl200001iKoUYnNoiJNU_nFWiko00@000:Fo`03
003ooooo00goo`03003ooooo00?oo`D000;oo`03003ooooo00;oo`03003ooooo00Goo`000ooo00H0
0?ooool00?oo0002ool00`00ool00002ool00`00ooooo`0Zool00`00ooooo`0Mool01P00YOfUo:Gl
WObUo@:Uo009WObUoJGlYObMo000WObUoIgl00@0000<YOfMo000UIbMoIFMWOfEW9gmUIfMoIFL0`00
01UmWHFnOIf5_WfMQKimWHFnOId006ENIGiMGVEnIEiUOUeNIGh004CnA=e4oTCMA?i4g@02000013cn
==dloSCM1`0000ddgCcn==d004eNEGm=GUEoCEiEOdeNEGm=GP0200003FgoIOi]ofGnKOmUoVgoIOi]
o`00OWmf?gio00H0000AOWn6Ogio0026_hjoQ[n>_hJoS[n6_hjoQ[n>_hJoS[n6_`0300002iJnU[nF
_YJoU[jF_iJnU[nF_YJoU[h00P0000>NoiJn00000`0000NFoiKnU_nFoYKoU_jFo`02000>ool00`00
ooooo`04ool01`00oooooooo003oo`0000;oo`03003oo`0000Koo`000ooo0`000_oo00H00?ooool0
0?oo0002ool00`00ooooo`0Zool2000Oool03000YObUg:GlYMbUo:GLYObUg:GlYMbUo0@0000=WMbU
o9gLYOfMg:GlWM`009GMUOfEgIGmUMd00`0000VEgIGmUMd008FMQKj5WXFnQId04P0000i4oScNA?h0
03cn==ddoSCM??hdg@00=Ai5?SDN700000YnOgiOOWmnGgioOUmnOgiOOWmnG`800007S[n6WhjoQYn>
_hJOS[l0100000n>Whjo002F_iJNU[nFWiJoUYjF_iJOU[nFWYJoUYl00`0039Ko0P003?oo0P001_oo
00L00?ooooooo`00ool00002ool00`00ool00006ool000?oo`05003ooooo003oo`030003ool2000]
ool00`00ooooo`0Oool20002YO`019glYOfUo:Gl0`000ZGl00X009glYOfMo:GmWObUoIglYOfMo0D0
0005UIbMoIFMWOfEW00700004XFMSKj5WHfnQId006eNKGi]GGEnKEi]OVeMMGh005DnCAeE?PL00004
??hdgCcn==d200001TDn?Ae5?SdNAChm7@80000DEKmEGUfoEEiE_eENGKmEGUFo001^?fgnKSmUoVho
KOi^?fGnKSl0009nO`05QWmnOgioOWn6O`03OWl01XIoOWmnO`00S[n6_`@0000?U[n>OYJoSWjF_hin
U[l009JoU[jF_iJnU[nF_YJo00@0000;S[h00000U_nFoYKoU_jFoiKnU_nFoP0400000ikoU_h0000=
ool00`00ooooo`03ool01`00oooooooo003oo`0000;oo`03003oo`0000Koo`000ooo00H00?ooool0
0?oo000dool00`00ooooo`0Qool00`00YMbUo00300003ZGlYMbUo:GLYObUg000WMbUoIgLYObMg:Gm
WM`400000iGmUMfEo@04000089gLWOfMg@00QIf=_HfMSKj5WHfmSIf=_XFM001UGVenIEi]OVENKGiU
GVen001E?TdNECi=7UDnCAiE?P00A?h500004cCn0015?SDNAChe7TDn=Ai5?P00EKmEWUFnEIiE_eFN
EKiEWUFo00800008IMm]ofGOKOmUgfgoIMm]o`80000:OUmnOgiOOWmnGgioOUmnOgiOOWl400003hjO
S[n>WhjoSYn>_hjOS[n>WhjoSYn>_`00U[nFWP040005U_l01000U_l000000YKo10001iKo0P003?oo
00<00?ooool00_oo00L00?ooooooo`00ool00002ool00`00ool00006ool000;oo`@00003ool00000
03Coo`03003ooooo02;oo`8000ZUo004002Mo:GmWO`300000iglYOfMo00400004YgmUIbMoIFLWOfE
W9gmUI`008FMSKj5WHfnQIf=_XFMSKj5W@800007KGi]GGEnKEi]OVeMMGh00P0000a=7EDnCAiE?TdM
ECh004Cn?=e4oTCMA?h700000dDn?Ae5?P0200005eENGKmEGUFoEEiM_eENEKmEGP00KOi^?fGnKSm]
oVhoIOi^?fgn001nOhIoOWl01P0000>6OhInQWl00P0000Z>OYJoSWjF_hinU[n>OYJoSWjF_`@0000<
S[jFohjnU_n>_YKoS[jFohjnU_l009Ko0`0000bFoiKnW_nFoYKoU_jNoiKnU_nFoYkoU_h2000:ool2
0003ool20004ool00`00ooooo`02ool00`00ooooo`05ool003coo`8002Goo`0;002Ug:GlYMbUo:GL
YObUg:GlYMbUo00400000igLYObMg00300003JGLYO`009gmWMfMoIgLWOfMgIgmWMbMoIgM0080000I
SKf=WHfnQIf=_HfMSKj5WHfm001]OVENKGiUGVenIEi]OVEN001=7UDnCAiE?TdNECh00P0000XlgTCn
?=i4oScNA?h004dnCAi=?Q`0000;QUn6OhIOQWn6GhIoQUn6OhIOQWn6G`0200000hjoSYn>_`050000
0hjoSYn>_`020008U_l30002U_l20008U_l30002U_l2000:ool00`00ooooo`0Cool003coo`03003o
oooo02Goo`03002Uo:Gl00FUo0@00003YOfMo0000080000HWObUoIglYOfMo:Gm002MoIFLWOfEW9gm
UIbMoIFLWOfEW9gm002=_XFMSKj5WHfn4P0000Y=7EDnCAh003cMA?i4gDCn?=e4oP80000KAAi=?TDN
CCi57TdnAAh005fNIKmMWVFoGIiU_efNIKmMWP00MOif?gGnMSmeoWHoMOif?gGn0080000;QWn6OXIo
QWj6OhInQWn6OXIoQWj6O`0500002YJoS[j>_hjnU[n>_XjoS[jF_hjn0P0000>Fohjn00000`0000NF
ohknU_l009KoS_jFo`0200000iKnW_l0000300001iKnU_nFoYkoU_jFoiKn008000Woo`03003ooooo
01;oo`00??oo00<00?ooool09_oo00@00:GLYObUg0<00003YMbUo:GL00<0000EYMbUo:GLYObUg:Gl
YMbUo:GLYO`009gmWMfMoIgLWOfMgIgmWMbMoIgM00H0000BSKf=WHfmSIf=_@00MKieWWFnMIie_WFN
MKieWP00EAiE?UDN2@0000/lgTCn?=h004dNCCi=7TdnCAi=?TdN00800008GKmMWVFoGIiM_efNIKmM
WP800009MSmeggHoMMmf?gGOMSmeggHo00800003QUn6OhIO00H0000@QWn6GhIo002>_hjOS[n>Whjo
SYn>_hjOS[n>WhjoSYl30007U_l00`00U_nFo`02U_l30008U_l300000iKnU_l00008ool00`00oooo
o`0Bool003coo`03003ooooo02Ooo`<000BUo08000:Uo00C002UoIglYOfMo:GmWObUoIglYOfMo:Gm
002MoIFLWOfEW9gmUI`00`00026Mo9gm002EoXfMUOj=WIGnSIfEoXfMUOh007FnMEem_WENMKieGGfn
MEh005DNGGiE7UenEAiMOUDN00157DdnAAh02@0001E57TdnAAi=?P00IKmMWVFoGIiU_efNIKmMWVFo
001f?gGnMSmeoWHoMOh01`00019nOhJoQWn6_gioQ[n6OhJoOWn6_`00S[n>_YJoS[j>_hjnU[l40000
2hjnU_l009KoU_jFohknU_nFoYKoS_h0100000VFoiKn002FoYkoU_jFoiKnW_l00P0000NFoYkoU_jF
oiKnW_l00007ool2000Cool003coo`8002Koo`@00003YMbUo0000080000DYObUg:GlYMbUo000YObU
g:GlYMbUo:GLYObUg:GlYMbUo000WOfMg@<0000QWMbMoIgLWOfMg9gm002=_HfMSKf=WHfmSIf=_HfM
SKd007FnMIie_WFNMKieWWFnMIh005DNECiE7UDnEAiE?UDN0080000:AChm7TDn?Ai5?SdN001=GTen
CEhE00005GHOMSmf7gHoMQl008IOQWn6GhIoQUn6OhIOQWn6GhIoQUn6O`00S[n>W`0400001hjoSYnF
_hjOS[n>WiJo008000:Fo`@00003U_l009Ko00BFo`03002FoiKo00<000>Fo`05U_jFoiKoU_nFoP02
0008ool00`00ooooo`0@ool003_oo`03003ooooo02?oo`<000Coo`8000VUo0800008WObUoIglYOfM
o:GmWObUo@@0000]WObMoIglYOfMo9gmWObUoIglWOd009GnSIfEoXfMUOj=WIGnSIfEoP00MKieGGfn
MEie_WEMOKieGP00EAiMOUDNGGiE7UenEAiMOP00CCi57TdnAAe=?TDN0080000BCGm=7TenCAi=OddN
CGh006GoGIiUoefNIOmMWVGoGIiUo`002WHo0P0000V6_gioQ[n6OhJoOWn6_hIoQ[l0100000b>_YKo
S[jFohjnU_n>_YKoS[jFohjnU_l300002iKoU_jFoiKnU_l009KoU_jFoiKnU_l00`0000RNoiKnU_nF
oYkoU_jFoiKn0`0000>FoYko00001ooo00<00?ooool04?oo000kool00`00ooooo`0Pool30008ool0
4000YMbUo:GLYObUg:GlYMbUo:GLYObUg000YMbUo:GL100001NUo:GLYO`009gmWMbMoIgLWOfMg9gm
WMbMoIgL002=WHfmSIf=_HfMSKf=WHfm01T0000;AChm7TDn001=OTeNCGi=GTenCEi=OP02000025fO
IKmMWVFoGImU_efNIKl200003WHOMSmf7gHoMQmf?gHOMSmf7gHo0026OhIOQWl500000hjoQYn6_`02
000028jOS[n>WiJoSYn>_hjOU[l300000iKoS_l00006U_l00`00U_l000020002U_l20003U_l40000
1YKnU_nFoiKoU_jFo`8000Goo`80017oo`00>ooo00<00?oo00007Ooo0`003?oo00<00:GlYO`02:Gl
100000JMo:GmYObUo9glYOd2YO`03`00YOfMo9gmWObUoIglWOfMo:GmWO`008fMUOj=W@0400006IGm
UIfEo@00QKimWHFnOIf5_WfMQKimW@00GEiUOeeNIGiMGVEoGEiUOP00ECm=7UDn00T0000?CGm=7Ten
CAh005fNIOmMWVGoGIiUoefNIOmMWP0000If?`L0000:S[n6OhjoQWn>_hIoS[n6OhjoQWl200000iKo
S[h0000300001YKoS[jFohjnU_n>_P800003U_nFoP0000<00007W_nFoYKoU_jNoiKnU_l00`0000^F
oiKnW_nFoYKoU_jNoiKnU_nFoYko00H00003ool00?oo013oo`001ooo0`00<Ooo0P006ooo0`004?oo
0P0000JUo:GLYObUg:GlYM`200005ZGlYM`00:GLYObUg:GlYMbUo:GLYObUg:Gl002MoIgLWOfMg9gm
WMbMoIgL1@00016EgIGmUMfEoIGMUOfEgIGm001m_WfNOKimWWfnOIim_WfN00800007IGiMGVEnGEiU
OUeNIGh00P0000Y=7TdnCAi=?TdNCCh005EnEEiEOQD00005OSmn7ghoMQmn?`0200002XJOQ[n6Whjo
QYn6_hJOS[n6WhJo10000YKo00F>oiKoU_nFohko00>Fo`@000BFo`04002FoiKoU_l30002U_l01000
U_nFoiKn0iKo00>FoYKo00000P000YKo0P000ooo00<00?ooool03ooo0008ool00`00ooooo`0Tool5
0002ool00`00ooooo`02ool00`00ooooo`0Gool3000Eool00`00YObUo00300000jGl[ObUo002YO`0
1@00YObUo9glYOd00ZGl00RMo:GmYObUo000YOfMo9gm100002RMo:GmWO`009FMUOfEWIGmUIfEoIFM
UOfEWIGm0025_WfMQKimWHFnOIf5_WfMQKh006EoGEiUOUeNIGmMGVEnGEh004dNECi=7UDoCAiE?P80
000AEEiEOdeNEGmEGUEoCEh006GnKOmUoVgoIOi]ofGnKOmUoP0200002WioMSmnOgHoOWmf?gioMSmn
OgHo0P0000>>_hIoS[l01@000hjo0P0000B>_YKoS[jFo`D00003U_n>oYKo00800003U_jNoiKn00@0
0006U_nFoYkoU_jFoiKn0P0000>FoiKn00000`0000JO?iKnUcnFoYloU_h20002ool00`00ooooo`0?
ool000Coo`8000;oo`<000?oo`8000;oo`<000?oo`800003ool0000000;oo`03003ooooo00ooo`07
003oooooool00?oo00000ooo00<00?ooool05?oo0`006Ooo0P0001>Ug:GlYMbUo:GLYObUg:GlYM`0
0:GLYObUg:GlYMbUo:GLYObUg00400006JGmWMbUo9gLYOfMg:GlWM`009GMUOfEgIGmUMfEoIGMUOfE
gIGm001m_WfNOKimWWfn0180000;CAi=?TdN001EGUEnEEiEOUENEGiEGP0200002FGoIMiUofGOIOmU
gVGoIMmUo`0200001WhOOSmf7ghoOQmn?`L0000:S[n>WhjoSYn>_hjOS[n>WhjoSYl4000:U_l30000
0iKo002Fo`08U_l300001IKnU_nFoiKoU_h00YKo0`000YKo0`004Ooo0003ool01P00ooooo`00ool0
00;oo`03003oo`0000;oo`04003ooooo0003ool01P00ooooo`00ool000;oo`03003ooooo00ooo`07
003oooooool00?oo00000_oo00<00?ooool04_oo0`007Ooo00@00:GlYOb]o0>Uo005[ObUo:GlYO`0
0002YO`019glYOfUo:Gl0P000ZGl01@00:GmWObUoIglYOfMo:GmWObUoIgl002EWIGmUIfEoIFMUOfE
WIGm1`0001:=_XFMSKj5WHfn001]_feNKKiUGVfoKEi]_VEN001EGUeoEEh900002eENEGm=GUEo001]
ofGnKOmUoVgoIOh02P0000J6OgioQWmnOhIo0003S[l01HJoS[n>_hjoQ[l00`0000^>_YJo002Fohkn
U_nFoYKoS_jFoiKn00<0000;U_jFo`00W_nFoP00U_jNoiKnU_nFoP0300001YKnW_l00000U_jO?`@0
0006U_jG?iKnWcnFoYLo0`004?oo0003ool01P00ooooo`00ool000;oo`03003oo`0000Goo`05003o
ooooool00002ool00`00ool00002ool00`00ooooo`0?ool01`00oooooooo003oo`0000;oo`80013o
o`<0027oo`0>002Uo:GLYObUg:GlYMbUo:GLYObUg000YMbUo0<0000DYObUg:GlYMbUo000YObMg:Gm
WMbUo9gLYOfMg:GlWM`009GMUOfEg@@0000=WOfEgIgm0025_XFMQKj5WHFnQIf5_XFMQKh00P0000MU
GVenIEi]OVENKGiUGP0200002UenEEiEOUENGGiEGP00GIiM_efN2`00011UgfgoIMm]ofGO001nGhIo
OUmnOgiOQWmnGgioOUn6O`800003SYn>_`0000<00006SYn>_hjOS[n>Whjo0P000YKo10001YKo0P00
00>Fo`0000000`0000JFoYKoU_nFoiKnU_l30003U_l019KnU_nFoiKo0`000_oo00<00?ooool03_oo
0003ool00`00ooooo`0500000ooo000000020002ool20004ool200000ooo00000002000Bool01`00
oooooooo003oo`0000;oo`03003ooooo00coo`<002Goo`04002Uo:Gl[O`3YO`00jglYObUo0030002
YO`01JGmYObUo:GlYOd00ZGl0P0000RMo:GmWObUoIglYOfMo:Gm100002>EW9gmUIbMoIFLWOfEW9gm
002=_XFMSKj5WHfnQIf=_XFMSKj5W@00KEi]_VENKKm]GVfnIEi]_`00GGmEGUeoEEiMOeEN00800007
GKmEGUfoGEiM_eENGKl00P0001=]oWGoKOi]ofgnMOm]oVgoKOh007ioQWmnOhIoOWn6OgioQWmnO`04
00002iJoS[jF_hjnU[n>_YJoS[jF_hjnU[l00`0000^FoiKnU_nFoYKoU_jFoiKnU_nFoYKo00<00007
U_nFoYkoU_jFoiKnW_l00`0000NO?iKn000009loU_jG?`030005ool00`00ooooo`0>ool000?oo`04
003ooooo0006ool00`00ooooo`0Pool20004ool01@00oooooooo00003?oo0P00:?oo00L00:GLYObU
g:GlYMbUo00300004ZGlYM`00:GLYObUg:GlYMbUo:GLYObUg:GlYM`009gLYOfMg0@0000FYObUg000
UMfMoIgMWOfEgIgmWMfMoIGMWOd008FnQIf5_XFMQKj5WHFnQId@000035enEEiEOP00GKmMWUfnGIiM
_efNGKiMWP80000<KOmUgfgoIMm]ofGOKOmUg`00OUn6OgiO1@0000b6GhIoQUl008jOS[n>WhjoSYn>
_hjOS[l300000iKoUYl00008U_l30002U_l200000iKoU_h000030003U_l019KnU_nFoiKo0`002?oo
00<00?ooool03_oo0004ool2000=ool00`00ooooo`0Tool00`00ooooo`07ool3000[ool00`00YObU
o0030002YO`01JglYObUo:Gl00000jGl00FUoJGlYObUo:Gm00:Uo0@0000FWObUoIglYOfMo:GmWO`0
09FLWOfEW9gmUIbMoIFLWOfEW9gm002=_XFMSKh4000048fMUOj=W@00MIie_WFNOKieWWFnMIim_P00
IKmMGVFo6P002HIo0P0000>F_hjn00000`0000JFohjnU_n>_YKoS[h200000iKoU_h0000300001YKo
U_jNoiKnU_nFoP<00008U_jO?iKnUcnFoYloU_jG?`<000_oo`03003ooooo00koo`00>_oo0P001Ooo
0`00;ooo0P00016Uo:GLYObUg:GlYMbUo:GLYObUg000YMbUo:GLYObUg:Gl00<0000EYObUg000YMbU
o:GLYObUg:GlYMbUo:GL002EgIgmWMfMoIGMWOfMgIgm00D0000ASOf=WHgmSIf=oHfMSOf=W@00MIie
_WFNMKieWWFnMIie_P0200006EeNIGiUGVEnGEiUOP00IKmUWVFoIIiU_fFNIKmUWVFo001f?gHOMSmf
7gHoMQmf?gHO00800009QWn6GhIoQUn6OhIOQWn6GhIo00@0000:SYnFoiJOU_n>WiKoUYnFohjOU_l4
0007U_l300001IKnU_l00000U_h00YKo10003_oo00<00?ooool03_oo000iool00`00ooooo`02ool3
000cool01@00YObUo:Gl[O`00jGl00F]o:GlYObUo00000:Uo0<000:Uo00B[ObUo:GlYO`009glYOfM
o:GmWObUoIglYOfMo000UIbMoIFL100001nMoIglYOd009GnSIfEoXfMUOj=WIGnSIfEoXfM001eWWFn
MIim_WFNMKieWWfnMIh005eNIKmMGVFoGEiU_`02000025fNIKmUWVFoGIiU_fFNIKl2000027HnMSmf
?WHoMSif?gHnMSl20003QWl400000hjoQWj>_`02000018jnU_n>_YKo1@0000>FoiKnU_l00P0000>F
oYKoU_h00`0000NFoYkoU_jFoiKn002FoP03000Bool00`00ooooo`0>ool003Woo`03003oo`000080
03Ooo`0;002Ug:GlYMbUo:GLYObUg:GlYMbUo00300004jGlYMbUo:GLYObUg:GlYMbUo:GL002Ug:Gl
YMbUo:GLYObUg:Gl00@00008WMbMoIgLWOfMg9gmWMbMo@80000?SIf=oHfMSOf=WHgmSIf=oHfM001e
WWFnMIie_WFN00T00009GEiUOVEN001UWVFoIIiU_fFN01400008SYn>_hJOS[n>WhjoQYn>_`D000ZF
o`<00005U_jFoiKoU_nFoP02U_l3000Eool00`00ooooo`0>ool003Woo`8003_oo`8000:Uo004[ObU
o:GlYO`20002YO`01@00YObUo:Gl[O`00jGl00R]o:GlYObUo000WObUoIgl100001BUoJGl002Mo:Gm
WObMoIglYOfMo9gmWObUoIgl002=WIGnSIfEoXfM2@0000UmWXFnOIf5_WfN001UWVfoKIh02@0000mU
WVgoKIi]ofFN001n?WhoMSin?ghnOSmf?WhoOSh00P0000B>_hInS[n6OP@0000<U[n>_YJo002FoiKn
U_n>oYKoU_jFohkn0`0000NFoYKo000009KnW_nFoP030003ool00`00ooooo`0Cool00`00ooooo`0=
ool003[oo`03003ooooo03_oo`03002Uo:GL00<0000@YMbUo:GLYObUg000YMbUo:GLYObUg:GlYMbU
o:GLYO`400004ZGLYObUg:GlYMbUo:GL002Mg9gmWMbMoIgLWOfMg9gmWMbMo@H0000QUMfEoIGMUOfE
g@00OIj5_WfNQKimWXFnOIj5_WfN001UWVfnIIi]_fFNKKiUWP00IMi]ofGOKOmUgVgoIMm]ofGN0080
0008OSmn7ghoOQmn?ghOOSmn7`D00008SYn>_hjOS[n>WhjoSYn>_`8000:Fo`@000NFo`<000Koo`03
003ooooo01?oo`03003ooooo00goo`00>ooo0P00??oo0P0000>Uo:glYO`00ZGl00F]o:GlYObUo000
00>Uo003[ObUo:Gl00<000:Uo005002Uo:GlWObUo@02YO`02YglYOfUo000WObUoIglWOfMo:Gm0`00
01jUoIgl002EW9gmUIfMoIFLWOfEWIgmUI`007fNQKimWHFnOIj5_WfMQKimWP00IIi]_ffNKKmUWVfo
KIh200003FgoKIi]ofFNKOm]WVgoIIi]o`00OSmf?Who00@0000=QWj6Ogin002>_YJoS[jF_hjnU[n>
_YJoS[h0100000RFoiKnU_nFoYKoU_jFoiKn0`002_oo00<00?ooool04_oo00<00?ooool03Ooo000m
ool00`00ooooo`0jool03P00YObUg:GlYMbUo:GLYObUg:GlYM`00:GLYO`300004jGlYMbUo:GLYObU
g000YMbUo:GLYObUg:GlYMbUo:GL002Mg9gm00<0000FYObUg:GlWMbUo:GL002EgIGmUMfEoIGMUOfE
gIGmUMd007fNQKimWXFnOIhJ000028IoQUn6OhIOQWn6GhIoQUl200000hjoSYn>_`040003U_l20003
U_l4000>ool00`00ooooo`0Aool00`00ooooo`0=ool003koo`03003ooooo03[oo`04002Uo:Gl[O`3
YO`00jglYObUo0030002YO`01JglYObUo:Gl[O`00jGl00D00:GlYObMo:Gm00:Uo003WObUo@000080
000CYOfMo:GmWObUoIglYOfMo:GmWO`009FLWOfEWIgmUIbMoIFMWOd01P0000j5WHgnQIf=oXFM001e
WWgoMIimogFNOOmeWWgo0P00019eoWGoMOieogGnMOmeoWGo0026OginQWn6OXIoOWj6OhInQWl50000
29KoS[jFohjnU_n>_YKoS[h4000Cool00`00ooooo`0@ool00`00ooooo`0=ool003ooo`03003ooooo
03[oo`07002Uo:GLYObUg:GlYM`00P0001:Uo:GL002Ug:GlYMbUo:GLYObUg:GlYMbUo:GL002Ug:Gl
YM`400004ZGlYM`009gLYObUg:GlWMbUo:GLYObMg:GlYM`009GMUOfEg@@0000<WOfMg000SIf=oXfM
SOj=WHgnSIf=oXfM0P0000Qe_WFNMKieWWFnMIie_WFN0P0000MeogGNMOmeggGoMMieo`0200000hIO
QWn6G`0400000hioSUn>O`020004U_l4000Gool00`00ooooo`0@ool00`00ooooo`0=ool0043oo`80
03_oo`03002Uo:Gl00<00003YOb]o:Gl00:Uo005002Uo:GlYOb]o003YO`00jglYObUo0040007YO`2
00002:GmWObUoIglYOfMo:GmWO`500001iglWOfMo9gmWObMoIgl0080000?SOj5WHgnQIf=oXFMSOj5
WHgn001mogFNOOmeWWgo01000009SWj>OhInSWn>OXioQWj>Ohin00@001coo`03003ooooo00ooo`03
003ooooo00goo`00@_oo00<00?ooool0>Ooo0P0000VUg:GlYMbUo:GLYObUg:GlYM`00P0000JUo:GL
YObUg:GlYM`200004JGlYM`00:GLYObUg:GlYMbUo:GLYObUg:Gl002Uo:GLYO`0100001BUg:GlYM`0
09gLWOfMgIgmWMbMoIgMWOfMg9gm002=oXfMSOj=WHgn2@0001J5oXGNQOimgXGn001n?ghNOSmn7Who
OQin?ghN002>GhioSUn>OhiOSWn>G`<0027oo`03003ooooo00koo`03003ooooo00goo`00@ooo00<0
0?ooool0>Ooo00@00:GlYOb]o0>Uo006[ObUo:GlYOb]o0000ZGl0`0000>Uo:glYO`00ZGl00<00:Gl
YO`01jGl100000>Uo9glYOd00ZGl00fMo:GmYO`009glWOfMo9gmWObMoIglWOfMo006000069GmUIfM
oIFMUOd008GnOOj5oWgnQOimoXGnOOj5oP00QSmmoXHoOOj6?ggnQSmmoP800003SWn>OP00008002Go
o`03003ooooo00koo`03003ooooo00coo`00A?oo00<00?ooool0>Ooo0P0000RUg:GlYMbUo:GLYObU
g:Gl1000012Ug:GlYMbUo:GLYObUg:GlYM`00:GLYObUg:GlYMbUo080000CYMbUo000YObUg:GlYMbU
o:GLYObUg:Gl002MoIgLWOfMgIgmWM`00`0001bMg:Gl002EoIGMUOfEgIGmUMfEoIGMUOd008GnQMj5
oWgNQOj5gXGnOMj5oP00OSmn7WhoOQin?`H002Soo`03003ooooo00koo`03003ooooo00coo`00AOoo
0P00>ooo00@00:Gl[ObUo0@000:Uo005[O`00:GlYOb]o003YO`01JglYObUo:Gl00000ZGl0`000ZGl
00F]o:GlYO`00:Gm00:Uo009WObUoJGlYObMo:Gm002MoIgl00<0000FWObUoIglYOfMo:Gm002EoIFM
WOfEWIGmUIfMoIFMUOd008GnOOj5oWgnQOh9000_ool00`00ooooo`0=ool00`00ooooo`0<ool004Oo
o`03003ooooo03Woo`<0000BYMbUo:GLYObUg:GlYMbUo000YObUg:GlYMbUo:GLYObUg:Gl0`0001:U
o:GLYObUg:GlYMbUo:GLYO`00:GlYMbUo:GLYObUg:GlYM`300004YgLYObUg:GlWMbUo:GLYObMg000
UMfEoIGMUOfEgIGmUMfEo@L003Woo`03003ooooo00coo`03003ooooo00coo`00B?oo00<00?ooool0
>Ooo00<00:Gl[O`00jGl00J]o:GlYObUo:gl0002YO`01:glYObUo:Gl0P000ZGl00D00:GlYObUo:gl
00>Uo005[ObUo:Gl002Uo@02YO`400004JGl[O`00:GmWObUoIglYOfMo:GmWObUoIgl002EWIGmUId0
1000@?oo00<00?ooool03?oo00<00?ooool03?oo0019ool00`00ooooo`0iool03P00YMbUo:GLYObU
g:GlYMbUo:GLYO`00:GlYM`300003jGLYObUg:GlYM`00:GLYObUg:GlYMbUo:GLYObUg00400001jGl
YMbUo:GLYObUg:Gl00800008WMbUo:GLYObMg:GlYMbUo0@004Goo`03003ooooo00_oo`03003ooooo
00coo`00B_oo00<00?ooool0>Ooo00<00:Gl[O`00jGl00>]o:GlYO`0100000>Uo:glYO`00ZGl00F]
o:GlYObUo00000>Uo003[ObUo:Gl008000:Uo003002]o:Gl00:Uo00:[ObUo:GlYOb]o:Gl002Mo:Gm
WO`4001:ool00`00ooooo`0:ool00`00ooooo`0<ool004_oo`8003[oo`04002Ug:GlYM`400004JGl
YMbUo000YObUg:GlYMbUo:GLYObUg:GlYM`00:GLYO`00`0000nUo:GLYObUg:Gl002Uo:GLYObUg:Gl
YMbUo:GLYO`01000Cooo00<00?ooool02Ooo00<00?ooool03?oo001=ool00`00ooooo`0hool30003
YO`01ZglYObUo:Gl[O`000:Uo006[ObUo:GlYOb]o:Gl10000ZGl00F]o:GlYObUo:gl00:Uo003002]
o:Gl00:Uo004[ObUo000001Cool00`00ooooo`0:ool00`00ooooo`0;ool004koo`03003ooooo03So
o`0?002Ug:GlYMbUo:GLYObUg:GlYMbUo000YObUg:Gl00@0000AYMbUo:GL002Ug:GlYMbUo:GLYObU
g:GlYMbUo000YObUg003001Fool00`00ooooo`09ool00`00ooooo`0;ool004ooo`03003ooooo03So
o`03002Uo:gl00>Uo004[ObUo:GlYO`400001JglYObUo:Gl[O`00jGl00D00:GlYObUo:gl00>Uo003
[O`00000008005[oo`03003ooooo00Soo`03003ooooo00_oo`00D?oo0P00>Ooo00L00:GLYObUg:Gl
YMbUo00200004JGLYO`00:GlYMbUo:GLYObUg:GlYMbUo:GL002Ug:GlYM`01000Gooo00<00?ooool0
1ooo00<00?ooool02ooo001Bool00`00ooooo`0gool00`00YOb]o00300001ZglYObUo:Gl[O`000:U
o005[ObUo:GlYOb]o002YO`4001Sool00`00ooooo`07ool00`00ooooo`0;ool005?oo`03003ooooo
03Ooo`80000@YObUg:GlYMbUo:GLYObUg:Gl002Uo:GLYObUg:GlYM`2001Xool00`00ooooo`06ool0
0`00ooooo`0;ool005Coo`03003ooooo03Ooo`03002Uo:gl00>Uo006[ObUo:GlYOb]o0000ZGl0`00
Jooo00<00?ooool01Ooo00<00?ooool02ooo001Eool2000hool200002:GlYMbUo:GLYObUg:GlYM`3
001_ool00`00ooooo`04ool00`00ooooo`0;ool005Ooo`03003ooooo03Ooo`04002]o:GlYO`4001b
ool00`00ooooo`05ool00`00ooooo`0:ool005Soo`03003ooooo03Ooo`<007Ooo`03003ooooo00Co
o`03003ooooo00[oo`00FOoo00<00?ooool0=_oo00<00?ooool0N?oo00<00?ooool00ooo00<00?oo
ool02_oo001Jool2000fool00`00ooooo`1hool00`00ooooo`03ool00`00ooooo`0:ool005coo`03
003ooooo03?oo`03003ooooo07Woo`03003ooooo00;oo`03003ooooo00[oo`00GOoo00<00?ooool0
<_oo00<00?ooool0N_oo00D00?ooooooo`0000coo`00G_oo00<00?ooool0<Ooo00<00?ooool0Nooo
00@00?ooool000coo`00Gooo0P00<Ooo00<00?ooool0Nooo00@00?ooool000coo`00HOoo00<00?oo
ool0;_oo00<00?ooool0O?oo00@00?ooool000_oo`00H_oo00<00?ooool0;Ooo00<00?ooool0OOoo
00<00?oo00002ooo001Sool00`00ooooo`0/ool00`00ooooo`1nool2000;ool006Coo`03003ooooo
02_oo`03003ooooo07koo`8000_oo`00IOoo0P00:ooo00<00?ooool0O_oo0P002ooo001Wool00`00
ooooo`0Xool00`00ooooo`1jool4000=ool006Soo`03003ooooo02Ooo`03003ooooo07Koo`@0017o
o`00JOoo00<00?ooool09_oo00<00?ooool0L_oo10005Ooo001Zool2000Vool00`00ooooo`1_ool3
000Iool006coo`03003ooooo02?oo`03003ooooo06_oo`@001coo`00KOoo00<00?ooool08_oo00<0
0?ooool0Iooo10008?oo001^ool00`00ooooo`0Qool00`00ooooo`1Sool4000Tool006ooo`80027o
o`03003ooooo063oo`<002Soo`00LOoo00<00?ooool07_oo00<00?ooool0G?oo1000:ooo001bool0
0`00ooooo`0Mool00`00ooooo`1Hool4000_ool007?oo`03003ooooo01coo`03003ooooo05Coo`@0
03?oo`00M?oo0P006ooo00<00?ooool0D_oo0`00=ooo001fool00`00ooooo`0Hool00`00ooooo`1>
ool4000jool007Ooo`03003ooooo01Ooo`03003ooooo04[oo`@003koo`00N?oo00<00?ooool05_oo
00<00?ooool0A_oo1000@_oo001iool2000Fool00`00ooooo`13ool30016ool007_oo`03003ooooo
01?oo`03003ooooo03ooo`@004Woo`00O?oo00<00?ooool04_oo00<00?ooool0>ooo1000COoo001m
ool00`00ooooo`0Aool00`00ooooo`0hool3001Aool007koo`80017oo`03003ooooo03Coo`@005Co
o`00P?oo00<00?ooool03_oo00<00?ooool0<?oo1000F?oo0021ool00`00ooooo`0=ool00`00oooo
o`0/ool4001Lool008;oo`03003ooooo00coo`03003ooooo02Woo`<0063oo`00Pooo00<00?ooool0
2ooo00<00?ooool09Ooo1000Hooo0024ool2000;ool00`00ooooo`0Qool4001Wool008Koo`03003o
oooo00Soo`03003ooooo01goo`@006_oo`00Qooo00<00?ooool01ooo00<00?ooool06_oo0`00Kooo
0028ool00`00ooooo`06ool00`00ooooo`0Fool4001bool008Woo`8000Koo`03003ooooo01;oo`@0
07Koo`00Rooo00<00?ooool00ooo00<00?ooool03_oo1000N_oo002<ool00`00ooooo`02ool00`00
ooooo`0;ool3001nool008goo`05003oooooool00009ool40021ool008koo`800003ool00?oo00Co
o`@008Goo`00T?oo0P0000?oo`0000000P00ROoo002Aool2002=ool00?ooob7oo`00oooo8Ooo003o
oolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7o
o`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003o
oolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.252196, -0.0709221, \
0.00435235, 0.00435235}}]
}, Open  ]],

Cell[TextData[{
  "Here is the analytical expression for the lambda of the put option ",
  StyleBox["xyzft", "MB"],
  ". Kappa, vega, and epsilon are sometimes used instead of lambda. "
}], "MathCaption",
  CellTags->"0.40"],

Cell[CellGroupData[{

Cell["Lambda[xyzft, settlement, r]", "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(20\ E\^\(\(-\(1\/2\)\)\ \((2\/\(5\ \@3\) + \@3\/20)\)\^2\)\ \
\@\(6\/\[Pi]\)\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell["This is a numerical approximation. ", "MathCaption",
  CellTags->"0.41"],

Cell[CellGroupData[{

Cell["N[%]", "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(26.2805835528340248`\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[TextData[{
  "We define the lambda of the option ",
  StyleBox["abcft", "MB"],
  " as a function of two variables, ",
  StyleBox["x", "MB"],
  " and ",
  StyleBox["t", "MB"],
  ", the price of the underlying asset and the time to maturity, \
respectively. "
}], "MathCaption",
  CellTags->"0.42"],

Cell["\<\
optionlambda[x_, t_] = Lambda[abcft,
   ToCalendar[ToJulian[settlement] + Floor[t]], r]  /.
   Price[ABC] -> x;\
\>", "Input",
  CellLabel->"In[37]:="],

Cell["\<\
This illustrates how the graph of the option lambda changes as the \
time to maturity varies. \
\>", "MathCaption",
  CellTags->"0.43"],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Table[optionlambda[x, t],
   {t, 0, 110, 10}]], {x, 25, 45},
   PlotLabel ->
      \"    Call Option Lambda\\nfor Different maturities\",
   FrameLabel -> {\"Stock Price\", \"\"}];\
\>", "Input",
  CellLabel->"In[38]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.16667 0.0476191 0.0147151 0.00641765 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -35 -24 ]
[.5 -0.0125 35 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14307 -12 -4.5 ]
[-0.0125 .14307 0 4.5 ]
[-0.0125 .27142 -12 -4.5 ]
[-0.0125 .27142 0 4.5 ]
[-0.0125 .39977 -12 -4.5 ]
[-0.0125 .39977 0 4.5 ]
[-0.0125 .52813 -12 -4.5 ]
[-0.0125 .52813 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74 0 ]
[.5 .63053 74 31 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(25)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(30)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(35)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(40)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(45)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -96 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14307 m
.00625 .14307 L
s
[(20)] -0.0125 .14307 1 0 Mshowa
0 .27142 m
.00625 .27142 L
s
[(40)] -0.0125 .27142 1 0 Mshowa
0 .39977 m
.00625 .39977 L
s
[(60)] -0.0125 .39977 1 0 Mshowa
0 .52813 m
.00625 .52813 L
s
[(80)] -0.0125 .52813 1 0 Mshowa
.125 Mabswid
0 .0468 m
.00375 .0468 L
s
0 .07889 m
.00375 .07889 L
s
0 .11098 m
.00375 .11098 L
s
0 .17516 m
.00375 .17516 L
s
0 .20724 m
.00375 .20724 L
s
0 .23933 m
.00375 .23933 L
s
0 .30351 m
.00375 .30351 L
s
0 .3356 m
.00375 .3356 L
s
0 .36769 m
.00375 .36769 L
s
0 .43186 m
.00375 .43186 L
s
0 .46395 m
.00375 .46395 L
s
0 .49604 m
.00375 .49604 L
s
0 .56022 m
.00375 .56022 L
s
0 .5923 m
.00375 .5923 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14307 m
1 .14307 L
s
.99375 .27142 m
1 .27142 L
s
.99375 .39977 m
1 .39977 L
s
.99375 .52813 m
1 .52813 L
s
.125 Mabswid
.99625 .0468 m
1 .0468 L
s
.99625 .07889 m
1 .07889 L
s
.99625 .11098 m
1 .11098 L
s
.99625 .17516 m
1 .17516 L
s
.99625 .20724 m
1 .20724 L
s
.99625 .23933 m
1 .23933 L
s
.99625 .30351 m
1 .30351 L
s
.99625 .3356 m
1 .3356 L
s
.99625 .36769 m
1 .36769 L
s
.99625 .43186 m
1 .43186 L
s
.99625 .46395 m
1 .46395 L
s
.99625 .49604 m
1 .49604 L
s
.99625 .56022 m
1 .56022 L
s
.99625 .5923 m
1 .5923 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Call) show
117.000000 15.000000 moveto
(Option) show
159.000000 15.000000 moveto
(Lambda) show
63.000000 31.000000 moveto
(for) show
87.000000 31.000000 moveto
(Different) show
147.000000 31.000000 moveto
(maturities) show
207.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.02381 .02084 m
.06244 .02442 L
.10458 .02992 L
.14415 .03685 L
.18221 .04525 L
.22272 .05609 L
.26171 .06824 L
.30316 .0827 L
.34309 .09768 L
.3815 .11253 L
.42237 .12818 L
.46172 .14246 L
.49955 .15492 L
.53984 .16628 L
.57861 .17497 L
.59832 .17846 L
.61984 .18151 L
.6298 .18266 L
.64043 .18368 L
.65038 .18447 L
.65954 .18504 L
.66445 .18528 L
.66983 .18551 L
.67524 .18568 L
.6782 .18575 L
.68096 .18581 L
.68357 .18585 L
.68486 .18586 L
.68605 .18588 L
.6871 .18588 L
.68827 .18589 L
.68944 .1859 L
.69069 .1859 L
.69135 .1859 L
.69204 .1859 L
.69328 .1859 L
.69397 .18589 L
.69461 .18589 L
.69607 .18588 L
.69735 .18587 L
.69852 .18586 L
.70113 .18582 L
.70344 .18578 L
.70597 .18573 L
.71111 .18558 L
.72031 .18522 L
.73106 .18462 L
.74111 .18391 L
.7614 .18202 L
.77993 .17979 L
Mistroke
.81969 .17355 L
.85794 .16597 L
.89864 .15659 L
.93782 .14664 L
.97619 .13636 L
Mfstroke
.02381 .01931 m
.04262 .02063 L
.06244 .02232 L
.10458 .02716 L
.14264 .03322 L
.18314 .04167 L
.22214 .05186 L
.26358 .06485 L
.30351 .07923 L
.34193 .09439 L
.38279 .11135 L
.42214 .12781 L
.45998 .14308 L
.50027 .15802 L
.53904 .1705 L
.58026 .18117 L
.60086 .18536 L
.61997 .18852 L
.63846 .19091 L
.64872 .19194 L
.65817 .19271 L
.66845 .19334 L
.67386 .19359 L
.67958 .1938 L
.68198 .19386 L
.68455 .19392 L
.68698 .19397 L
.68919 .194 L
.69054 .19401 L
.69179 .19402 L
.69244 .19402 L
.69316 .19403 L
.69391 .19403 L
.69461 .19403 L
.6959 .19403 L
.69708 .19403 L
.69838 .19402 L
.69903 .19402 L
.69975 .19401 L
.70228 .19398 L
.70371 .19396 L
.70503 .19394 L
.71002 .19383 L
.71456 .19368 L
.71936 .19349 L
.72933 .19295 L
.74031 .19216 L
.75976 .19026 L
.78065 .18755 L
.82192 .18035 L
Mistroke
.86169 .1715 L
.89993 .16164 L
.94063 .15014 L
.97619 .1396 L
Mfstroke
.02381 .01795 m
.04262 .019 L
.06244 .02037 L
.08426 .02227 L
.10458 .02446 L
.14264 .02981 L
.18163 .03726 L
.22307 .0476 L
.263 .05999 L
.30142 .07403 L
.34228 .09087 L
.38164 .10835 L
.41947 .12565 L
.45976 .14377 L
.49853 .16009 L
.53975 .17537 L
.57946 .18736 L
.61766 .19591 L
.63733 .19906 L
.64825 .20044 L
.6583 .20147 L
.66859 .20229 L
.674 .20262 L
.67971 .2029 L
.68469 .20309 L
.68707 .20316 L
.68933 .20321 L
.69061 .20324 L
.69199 .20326 L
.69315 .20328 L
.69442 .20329 L
.6958 .2033 L
.69655 .20331 L
.69726 .20331 L
.69852 .20332 L
.69923 .20332 L
.69988 .20332 L
.70116 .20331 L
.70237 .2033 L
.70345 .2033 L
.70462 .20328 L
.70726 .20324 L
.70969 .20319 L
.71412 .20307 L
.71881 .2029 L
.72867 .20238 L
.73951 .20158 L
.75896 .19957 L
.77985 .19662 L
.82112 .18867 L
Mistroke
.86089 .1788 L
.89913 .16777 L
.93983 .15492 L
.97619 .14291 L
Mfstroke
.02381 .01682 m
.04262 .01758 L
.06244 .01863 L
.08255 .01999 L
.10458 .02189 L
.12579 .0242 L
.14509 .02677 L
.18408 .03352 L
.22401 .04289 L
.26243 .05445 L
.30329 .06947 L
.34264 .08632 L
.38048 .10423 L
.42077 .12434 L
.45954 .1438 L
.50076 .1635 L
.54047 .18046 L
.57866 .19407 L
.59998 .20028 L
.61931 .20496 L
.63946 .20882 L
.65844 .2115 L
.6682 .2125 L
.67354 .21295 L
.67852 .2133 L
.68312 .21356 L
.68732 .21375 L
.69199 .21391 L
.69456 .21397 L
.69573 .214 L
.69699 .21402 L
.69822 .21403 L
.69936 .21405 L
.70044 .21405 L
.70158 .21406 L
.70283 .21406 L
.704 .21406 L
.70528 .21405 L
.70599 .21405 L
.70664 .21404 L
.70796 .21403 L
.70917 .21401 L
.71192 .21396 L
.71434 .2139 L
.7169 .21381 L
.72143 .21363 L
.72567 .21341 L
.73532 .21275 L
.74573 .21179 L
.75561 .21065 L
Mistroke
.77414 .20793 L
.81239 .20015 L
.85309 .18917 L
.89227 .17663 L
.9339 .16191 L
.97402 .14704 L
.97619 .14623 L
Mfstroke
.02381 .01593 m
.04262 .01644 L
.06244 .01717 L
.08255 .01815 L
.10458 .01958 L
.12415 .02123 L
.14509 .02346 L
.16496 .02609 L
.18653 .0296 L
.22646 .03815 L
.26733 .04999 L
.30668 .06451 L
.34452 .08124 L
.3848 .10155 L
.42358 .12275 L
.4648 .14589 L
.50451 .16749 L
.5427 .18641 L
.58335 .20338 L
.62248 .21573 L
.64389 .2206 L
.6537 .22236 L
.66406 .2239 L
.67363 .22502 L
.6787 .2255 L
.68414 .22592 L
.68913 .22623 L
.69369 .22644 L
.69588 .22652 L
.69827 .22659 L
.69936 .22662 L
.70052 .22664 L
.7016 .22666 L
.70261 .22668 L
.70375 .22669 L
.70499 .2267 L
.7062 .2267 L
.7075 .2267 L
.70871 .2267 L
.70985 .22669 L
.71087 .22668 L
.71198 .22666 L
.71453 .22661 L
.71724 .22654 L
.72208 .22635 L
.72658 .22611 L
.73079 .22584 L
.74036 .22503 L
.75077 .22385 L
.76065 .22246 L
Mistroke
.77918 .21918 L
.81743 .20987 L
.85813 .19688 L
.89731 .18221 L
.93894 .16519 L
.97619 .14944 L
Mfstroke
.02381 .01531 m
.04262 .01561 L
.06244 .01605 L
.08255 .01668 L
.10458 .01764 L
.12415 .0188 L
.14509 .02045 L
.16639 .02264 L
.18653 .02528 L
.22495 .03217 L
.24479 .03683 L
.26581 .0427 L
.30365 .05582 L
.34394 .07347 L
.38271 .09379 L
.42393 .1182 L
.46364 .14323 L
.50184 .1673 L
.54248 .19127 L
.58161 .2112 L
.60159 .21976 L
.62319 .22757 L
.64406 .23357 L
.65399 .23587 L
.66326 .23768 L
.67311 .23925 L
.68208 .24037 L
.68686 .24083 L
.69206 .24124 L
.69491 .24143 L
.69755 .24157 L
.70026 .24169 L
.70275 .24177 L
.705 .24183 L
.70614 .24185 L
.70738 .24186 L
.70863 .24188 L
.70933 .24188 L
.70997 .24188 L
.7112 .24188 L
.71237 .24188 L
.71347 .24187 L
.71463 .24185 L
.71562 .24184 L
.71671 .24181 L
.71914 .24175 L
.72141 .24167 L
.7266 .24141 L
.73134 .2411 L
.74201 .2401 L
Mistroke
.75188 .23882 L
.76104 .23735 L
.78177 .23305 L
.82096 .22161 L
.86259 .20568 L
.90271 .1878 L
.94131 .16932 L
.97619 .15229 L
Mfstroke
.02381 .01494 m
.03279 .015 L
.04262 .01508 L
.06244 .0153 L
.07298 .01546 L
.08426 .01567 L
.10458 .01619 L
.1148 .01653 L
.12589 .01697 L
.14603 .018 L
.16586 .01939 L
.18689 .02136 L
.20643 .02376 L
.22473 .02658 L
.2635 .03482 L
.28463 .04082 L
.30472 .04761 L
.34292 .06368 L
.38356 .08534 L
.42269 .11012 L
.46427 .13944 L
.50434 .16878 L
.54289 .196 L
.58389 .22166 L
.60432 .23252 L
.62338 .24123 L
.64288 .24858 L
.66135 .25398 L
.6711 .25619 L
.68171 .25809 L
.68638 .25876 L
.69134 .25936 L
.69569 .25978 L
.70026 .26013 L
.7026 .26028 L
.70515 .2604 L
.70747 .26049 L
.70851 .26052 L
.70963 .26055 L
.71095 .26057 L
.71219 .26059 L
.7134 .2606 L
.71452 .2606 L
.71572 .2606 L
.71641 .26059 L
.71705 .26059 L
.71834 .26057 L
.71973 .26054 L
.72208 .26047 L
.72463 .26036 L
Mistroke
.72928 .2601 L
.73381 .25974 L
.73801 .25933 L
.74861 .25796 L
.75857 .25623 L
.77719 .25193 L
.79731 .24583 L
.8158 .23903 L
.85534 .22135 L
.89336 .20145 L
.93384 .1786 L
.9728 .15628 L
.97619 .15436 L
Mfstroke
.02381 .01477 m
.03279 .01479 L
.04262 .01482 L
.05288 .01486 L
.06244 .0149 L
.0731 .01496 L
.0828 .01503 L
.094 .01514 L
.10458 .01527 L
.11428 .01542 L
.12455 .01561 L
.14299 .01608 L
.1524 .01639 L
.16253 .01679 L
.18083 .01774 L
.20196 .01925 L
.22205 .02124 L
.24186 .02386 L
.26025 .02699 L
.29938 .03645 L
.32079 .04354 L
.34096 .05162 L
.37951 .07113 L
.42051 .09772 L
.46 .12821 L
.49797 .16044 L
.5384 .19536 L
.5773 .22674 L
.61867 .25459 L
.63936 .26553 L
.65851 .27357 L
.6771 .27931 L
.68648 .28142 L
.69153 .28232 L
.69684 .28311 L
.70166 .28367 L
.70421 .28391 L
.70693 .28412 L
.70944 .28428 L
.71173 .28438 L
.71283 .28442 L
.71402 .28446 L
.71515 .28448 L
.71619 .2845 L
.71739 .28451 L
.71868 .28451 L
.7199 .28451 L
.72101 .28449 L
.72231 .28446 L
.72373 .28442 L
Mistroke
.72632 .28432 L
.72901 .28417 L
.73188 .28396 L
.73704 .28346 L
.74242 .28278 L
.74736 .28201 L
.7585 .27977 L
.77868 .27403 L
.79754 .26687 L
.81822 .25729 L
.85869 .23434 L
.89765 .2088 L
.93907 .18015 L
.97619 .15477 L
Mfstroke
.02381 .01472 m
.03279 .01473 L
.04262 .01473 L
.05288 .01474 L
.06244 .01475 L
.0731 .01476 L
.0828 .01478 L
.094 .01481 L
.10458 .01484 L
.11428 .01489 L
.12455 .01495 L
.13333 .01501 L
.14299 .01511 L
.15313 .01523 L
.1624 .01537 L
.17311 .01558 L
.18328 .01584 L
.19287 .01613 L
.20309 .01652 L
.22147 .01745 L
.23176 .01813 L
.24289 .01903 L
.26306 .02117 L
.283 .02408 L
.30406 .02825 L
.3237 .03337 L
.34203 .03939 L
.38094 .05687 L
.40218 .06939 L
.4223 .0833 L
.46063 .11505 L
.50141 .15505 L
.54068 .19672 L
.57843 .23599 L
.61863 .2726 L
.63711 .28644 L
.65732 .29888 L
.67736 .30811 L
.68829 .31175 L
.69846 .31423 L
.70351 .31514 L
.70617 .31553 L
.70898 .31588 L
.71144 .31613 L
.71415 .31634 L
.71534 .31641 L
.71661 .31648 L
.71773 .31653 L
.71892 .31657 L
.72015 .31659 L
Mistroke
.7213 .31661 L
.722 .31661 L
.72267 .31661 L
.7239 .3166 L
.72509 .31657 L
.72617 .31654 L
.72737 .3165 L
.72863 .31644 L
.73082 .3163 L
.73286 .31613 L
.73751 .31563 L
.74253 .31489 L
.74798 .31386 L
.7579 .3114 L
.76755 .30829 L
.77647 .30482 L
.81578 .28353 L
.85359 .25593 L
.89384 .22213 L
.93258 .18832 L
.97377 .15372 L
.97619 .15178 L
Mfstroke
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03793 .01472 L
.04262 .01472 L
.0522 .01472 L
.05746 .01472 L
.06244 .01472 L
.06754 .01472 L
.07295 .01472 L
.08265 .01472 L
.08804 .01472 L
.09308 .01472 L
.09858 .01472 L
.10458 .01473 L
.10996 .01473 L
.11496 .01473 L
.12483 .01474 L
.13379 .01475 L
.14335 .01476 L
.15364 .01479 L
.15943 .0148 L
.16476 .01482 L
.17457 .01486 L
.18493 .01492 L
.19441 .01499 L
.20457 .0151 L
.21416 .01523 L
.22291 .01538 L
.23282 .0156 L
.24199 .01585 L
.25206 .01621 L
.26275 .0167 L
.27212 .01723 L
.28222 .01794 L
.3005 .01966 L
.31007 .02085 L
.32054 .02241 L
.34164 .02657 L
.36125 .03194 L
.3822 .03967 L
.40355 .05004 L
.4237 .06249 L
.46217 .09412 L
.50309 .13904 L
.54249 .19075 L
.58038 .24344 L
.62072 .29566 L
.63929 .31622 L
.65954 .33501 L
Mistroke
.67053 .34338 L
.68071 .34988 L
.69038 .35488 L
.70082 .35896 L
.70634 .36055 L
.71141 .36167 L
.71392 .36211 L
.71626 .36243 L
.7187 .3627 L
.71999 .36281 L
.72138 .36291 L
.72263 .36297 L
.72378 .36301 L
.72504 .36304 L
.72568 .36305 L
.72639 .36305 L
.72756 .36303 L
.72883 .363 L
.73003 .36294 L
.73112 .36288 L
.73319 .36272 L
.73545 .36248 L
.74 .36181 L
.7453 .36071 L
.7503 .35936 L
.75965 .35604 L
.76971 .35135 L
.78061 .34506 L
.82158 .31181 L
.86104 .26985 L
.89898 .22568 L
.93937 .17955 L
.97619 .14149 L
Mfstroke
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.04262 .01472 L
.04518 .01472 L
.04795 .01472 L
.053 .01472 L
.05791 .01472 L
.06244 .01472 L
.06747 .01472 L
.07218 .01472 L
.07734 .01472 L
.0829 .01472 L
.08567 .01472 L
.0887 .01472 L
.09422 .01472 L
.09959 .01472 L
.10458 .01472 L
.10966 .01472 L
.11515 .01472 L
.12033 .01472 L
.1251 .01472 L
.12942 .01472 L
.13415 .01472 L
.13909 .01472 L
.14371 .01472 L
.14872 .01472 L
.15416 .01472 L
.1593 .01472 L
.16406 .01472 L
.17306 .01472 L
.1776 .01472 L
.18262 .01472 L
.18753 .01472 L
.19271 .01472 L
.20196 .01473 L
.20712 .01473 L
.21193 .01474 L
.21715 .01474 L
.22282 .01475 L
.2283 .01476 L
.23334 .01477 L
.23807 .01478 L
.24328 .0148 L
.25231 .01484 L
.26187 .01489 L
.27203 .01498 L
.28131 .01508 L
.29203 .01525 L
Mistroke
.30221 .01548 L
.31182 .01576 L
.32205 .01617 L
.33171 .01668 L
.34045 .01726 L
.3505 .01813 L
.35974 .01913 L
.36987 .02053 L
.38057 .02239 L
.39007 .02445 L
.40025 .02715 L
.41859 .0336 L
.43987 .0442 L
.46001 .05806 L
.47996 .0761 L
.49839 .09698 L
.53771 .15527 L
.57551 .22594 L
.61577 .3071 L
.65451 .37676 L
.67458 .40477 L
.6848 .41615 L
.6957 .42591 L
.70104 .42975 L
.70607 .43279 L
.71097 .4352 L
.71548 .43693 L
.71977 .43814 L
.72193 .43859 L
.7243 .43896 L
.72555 .4391 L
.72669 .4392 L
.728 .43928 L
.72924 .43932 L
.73039 .43932 L
.73145 .4393 L
.73262 .43924 L
.73386 .43914 L
.73499 .43903 L
.73623 .43887 L
.73874 .43844 L
.74105 .43791 L
.74321 .43732 L
.74809 .4356 L
.7533 .43319 L
.76287 .42729 L
.77158 .42035 L
.79074 .40027 L
.81153 .37228 L
.85241 .30529 L
Mistroke
.89178 .2365 L
.92964 .17558 L
.96995 .12207 L
.97619 .115 L
Mfstroke
.02381 .01472 m
.02605 .01472 L
.02846 .01472 L
.03072 .01472 L
.03279 .01472 L
.03521 .01472 L
.03784 .01472 L
.04032 .01472 L
.04262 .01472 L
.04498 .01472 L
.0472 .01472 L
.04963 .01472 L
.05224 .01472 L
.05355 .01472 L
.05497 .01472 L
.05757 .01472 L
.0601 .01472 L
.06244 .01472 L
.06509 .01472 L
.06658 .01472 L
.06795 .01472 L
.07048 .01472 L
.07314 .01472 L
.07553 .01472 L
.07776 .01472 L
.08021 .01472 L
.08284 .01472 L
.08564 .01472 L
.08722 .01472 L
.08868 .01472 L
.09136 .01472 L
.09421 .01472 L
.09675 .01472 L
.09914 .01472 L
.10176 .01472 L
.10458 .01472 L
.10698 .01472 L
.10954 .01472 L
.11195 .01472 L
.11415 .01472 L
.11673 .01472 L
.11954 .01472 L
.12218 .01472 L
.12462 .01472 L
.12714 .01472 L
.1295 .01472 L
.13209 .01472 L
.13487 .01472 L
.13778 .01472 L
.14054 .01472 L
Mistroke
.14302 .01472 L
.14572 .01472 L
.14828 .01472 L
.15105 .01472 L
.15366 .01472 L
.15606 .01472 L
.16062 .01472 L
.16292 .01472 L
.16543 .01472 L
.16818 .01472 L
.17068 .01472 L
.17356 .01472 L
.17629 .01472 L
.17881 .01472 L
.18114 .01472 L
.1837 .01472 L
.18642 .01472 L
.18881 .01472 L
.19132 .01472 L
.19581 .01472 L
.19832 .01472 L
.20065 .01472 L
.20336 .01472 L
.20593 .01472 L
.20816 .01472 L
.21057 .01472 L
.21478 .01472 L
.21717 .01472 L
.21969 .01472 L
.22422 .01472 L
.22676 .01472 L
.22917 .01472 L
.23368 .01472 L
.23621 .01472 L
.23854 .01472 L
.24127 .01472 L
.24383 .01472 L
.24805 .01472 L
.25272 .01472 L
.25726 .01472 L
.26216 .01472 L
.26711 .01472 L
.27172 .01472 L
.27677 .01472 L
.2796 .01472 L
.28218 .01472 L
.28738 .01472 L
.29031 .01472 L
.29302 .01472 L
.298 .01472 L
Mistroke
.30327 .01472 L
.30819 .01472 L
.31269 .01472 L
.31788 .01472 L
.32282 .01473 L
.32736 .01473 L
.33157 .01473 L
.3362 .01474 L
.34112 .01474 L
.34649 .01475 L
.35142 .01477 L
.35683 .01479 L
.36255 .01481 L
.36753 .01484 L
.37217 .01487 L
.37727 .01492 L
.38272 .01498 L
.38802 .01506 L
.39291 .01514 L
.39817 .01526 L
.40398 .01543 L
.41374 .01581 L
.41909 .01609 L
.42411 .01641 L
.43395 .01724 L
.43889 .01778 L
.4443 .01849 L
.45389 .02011 L
.46281 .02213 L
.47335 .02532 L
.48329 .02936 L
.49221 .03403 L
.50188 .04042 L
.52177 .05901 L
.53179 .07173 L
.54282 .08873 L
.56228 .12731 L
.58318 .1816 L
.62447 .32232 L
.66425 .46994 L
.68434 .53231 L
.69308 .55442 L
.70252 .57409 L
.70782 .58305 L
.71269 .58989 L
.71734 .59514 L
.72225 .59928 L
.72475 .60084 L
.72613 .60154 L
.72743 .60209 L
Mistroke
.72864 .60252 L
.72996 .60287 L
.73116 .60311 L
.73226 .60325 L
.73357 .60332 L
.7348 .60329 L
.7355 .60323 L
.73614 .60316 L
.73688 .60304 L
.73759 .60289 L
.73899 .60251 L
.74029 .60206 L
.74324 .60066 L
.74588 .59897 L
.74831 .59707 L
.7538 .59153 L
.76375 .57732 L
.77279 .56012 L
.78235 .53801 L
.82031 .42281 L
.86073 .28656 L
.89962 .17618 L
.92085 .13017 L
.94097 .09608 L
.95926 .07238 L
.97619 .05574 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo003ooolX
ool00?ooobSoo`00oooo:?oo003ooolXool007Woo`<000?oo`8000?oo`8000;oo`<00004ool00000
ool2000;ool30003ool30002ool30002ool30003ool2001cool007Woo`03003oo`0000;oo`06003o
oooo003oo`000_oo00<00?oo00001?oo00<00?oo00003Ooo00<00?ooool00ooo00<00?ooool00_oo
00D00?ooooooo`0000Coo`03003ooooo07?oo`00Nooo00@00?ooool000Coo`06003ooooo003oo`00
1?oo0`003Ooo0`000ooo00<00?ooool00_oo00D00?ooooooo`0000Coo`<007?oo`00N_oo00<00?oo
ool010000ooo0P000_oo0`000_oo00@00?oo000000coo`05003ooooo003oo`0400000ooo00000003
ool30002ool3001cool007Woo`03003oo`0000;oo`03003ooooo00coo`03003ooooo00goo`04003o
oooo0026ool007Woo`<0013oo`8000koo`@000Soo`03003ooooo07coo`00oooo:?oo003ooolXool0
0?ooobSoo`00oooo:?oo003ooolXool003Soo`<000?oo`03003ooooo02Goo`8000Coo`03003ooooo
02Koo`8000Coo`03003ooooo02Ooo`<000;oo`03003ooooo02Ooo`<000;oo`03003ooooo02_oo`00
>?oo00<00?ooool00_oo00<00?oo0000:?oo00H00?ooool00?oo000Yool01P00ooooo`00ool002Wo
o`06003ooooo003oo`00:Ooo00H00?ooool00?oo000/ool003Woo`03003ooooo00?oo`03003ooooo
02Goo`07003oooooool00?oo0000:?oo00<00?ooool00ooo00<00?ooool09Ooo100000Coo`00ool0
02Ooo`@000?oo`03003ooooo02[oo`00>Ooo00@00?ooooooo`8002Woo`06003ooooo003oo`00:Ooo
00<00?ooool00P00:?oo00<00?oo00000_oo00<00?oo00009ooo00<00?oo00000_oo0P00;Ooo000h
ool00`00ool00002ool00`00ooooo`0Vool00`00ool00002ool00`00ool0000Wool00`00ool00002
ool00`00ooooo`0Xool20002ool00`00ool0000Xool20002ool00`00ooooo`0/ool003Woo`04003o
ooooool3000Wool00`00ooooo`02ool00`00ooooo`0Wool01000oooooooo0`00:Ooo00D00?oooooo
o`0002[oo`03003ooooo00<002coo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo000gooo6
000Zool0037oo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00Koo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03
003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00;oo`03003ooooo02Soo`00
<?oo00<00?oo00001?oo00<00?ooool00_oo00<00?ooool0:ooo00<00?ooool0;?oo00<00?ooool0
;?oo00<00?ooool0;?oo00<00?ooool00_oo00<00?ooool0:?oo000`ool00`00ool00004ool20003
oom=001bool2000Zool0033oo`03003oo`0000Coo`03003ooooo00;oodD000Soo`P006_oo`03003o
oooo02Soo`00<?oo00<00?oo00001?oo00<00?ooool01_oo<@001?oo0`002Ooo10003?oo1000Iooo
00<00?ooool0:?oo000aool00`00ooooo`03ool00`00ooooo`0=ool@0003ool=0002ool30005ool4
0003ool40009ool3000=ool2001Uool00`00ooooo`0Xool003Ooo`03003ooooo01?ooa000003ool0
000000D000;oo`T000Goo`@000?oo`@000Soo`<000coo`8006?oo`03003ooooo02Soo`00=ooo00<0
0?ooool05ooo400000?oo`0000001@001?oo1`001Ooo0P001Ooo0`002?oo0P003?oo0P00HOoo00<0
0?ooool0:?oo000gool00`00ooooo`0Mool>00000ooo000000050003ool20002ool30004ool20006
ool20008ool2000<ool00`00ooooo`1Nool00`00ooooo`0Xool003Ooo`8002Coo``00003ool00000
00D00004ool000000002ool20004ool20006ool20008ool00`00ooooo`0:ool00`00ooooo`1Lool2
000Zool003Ooo`03003ooooo02Ooo``00004ool00000ool300000ooo00000002ool30003ool20006
ool00`00ooooo`06ool00`00ooooo`0:ool00`00ooooo`1Gool00`00ooooo`02ool00`00ooooo`0X
ool003Ooo`03003ooooo02_oo`X00003ool0000000;oo`800003ool0000000?oo`8000?oo`8000Go
o`8000Ooo`03003ooooo00[oo`03003ooooo05Goo`03003ooooo00?oo`03003ooooo02Soo`00=ooo
00<00?ooool0;Ooo3P0000Coo`00003oo`8000?oo`<000;oo`8000Goo`03003ooooo00Goo`03003o
oooo00[oo`03003ooooo05?oo`03003ooooo00Coo`03003ooooo02Soo`00=ooo00<00?ooool0;ooo
0`0000?oo`0000000P0000?oo`0000000`0000Coo`00003oo`8000Coo`8000;oo`8000Coo`03003o
oooo00Goo`8000_oo`03003ooooo05;oo`03003ooooo00Coo`03003ooooo02Soo`00=ooo00<00?oo
ool0<_oo200000?oo`0000001@0000?oo`0000001?oo00D00?ooooooo`0000Coo`8000Ooo`03003o
oooo00Woo`03003ooooo053oo`03003ooooo00Goo`03003ooooo02Soo`00=ooo0P00=_oo1`0000Co
o`00003oo`@00003ool0000000?oo`8000;oo`8000Coo`03003ooooo00Goo`03003ooooo00Soo`03
003ooooo04ooo`03003ooooo00Goo`8002[oo`00=ooo00<00?ooool0>?oo2@0000?oo`0000000P00
00?oo`0000000ooo00D00?ooooooo`0000Coo`03003ooooo00Goo`03003ooooo00Soo`03003ooooo
04goo`03003ooooo00Ooo`03003ooooo02Soo`00=ooo00<00?ooool0>ooo200000?oo`0000000P00
00?oo`0000000_oo00D00?ooooooo`0000Coo`8000Koo`03003ooooo00Ooo`03003ooooo04coo`03
003ooooo00Soo`03003ooooo02Soo`00=ooo00<00?ooool0?Ooo200000Coo`00000000;oo`03003o
oooo008000;oo`8000Coo`03003ooooo00Coo`03003ooooo00Ooo`03003ooooo04[oo`03003ooooo
00Woo`03003ooooo02Soo`00=ooo00<00?ooool0?ooo200000Goo`0000000?oo008000;oo`05003o
ooooool00004ool00`00ooooo`04ool00`00ooooo`06ool00`00ooooo`19ool00`00ooooo`0:ool0
0`00ooooo`0Xool003Ooo`03003ooooo04;oo`L00003ool0000000;oo`800003ool00?oo00;oo`03
003ooooo00;oo`03003ooooo00?oo`03003ooooo00Ooo`03003ooooo04Soo`03003ooooo00[oo`03
003ooooo02Soo`00=ooo0P00Aooo1@0000?oo`0000000_oo00<00?oo00000ooo0P000ooo00<00?oo
ool00ooo00<00?ooool01_oo00<00?ooool0Aooo00<00?ooool02_oo0P00:_oo000gool00`00oooo
o`19ool700000ooo003oo`020003ool01@00oooooooo00001Ooo00<00?ooool01_oo00<00?ooool0
A_oo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool0:?oo000gool00`00ooooo`1;ool60000
1Ooo00000?oo00000ooo00@00?ooool000Goo`03003ooooo00Koo`03003ooooo04Goo`03003ooooo
00Koo`03003ooooo00?oo`03003ooooo02Soo`00=ooo00<00?ooool0COoo1P0000Coo`00ool000?o
o`04003ooooo0005ool00`00ooooo`06ool00`00ooooo`14ool00`00ooooo`05ool00`00ooooo`04
ool00`00ooooo`0Xool003Ooo`03003ooooo04ooo`D00004ool00?oo0003ool01000ooooo`001Ooo
00<00?ooool01Ooo00<00?ooool0@ooo00<00?ooool01_oo00<00?ooool01?oo00<00?ooool0:?oo
000[ool30003ool00`00ooooo`03ool00`00ooooo`1Bool70003ool01000ooooo`001?oo00<00?oo
ool01_oo00<00?ooool0@_oo00<00?ooool01Ooo00@00?oo000000Coo`03003ooooo02Soo`00:ooo
00<00?ooool00_oo00<00?oo00001?oo00<00?ooool0E?oo1`000_oo00@00?ooool000Coo`03003o
oooo00Goo`03003ooooo047oo`03003ooooo00Coo`H000Coo`03003ooooo02Soo`00;?oo00L00?oo
ooooo`00ool00004ool2001Gool60002ool01000ooooo`001?oo00<00?ooool01?oo00<00?ooool0
@Ooo00@00?ooooooo`T000?oo`8002[oo`00;?oo00L00?ooooooo`00ool00004ool00`00ooooo`1I
ool500001Ooo003ooooo00000ooo00<00?ooool01Ooo00<00?ooool0?ooo3P001?oo00<00?ooool0
:?oo000[ool00`00ool00002ool00`00ool00004ool00`00ooooo`1Kool600000ooo003oo`03ool0
0`00ooooo`04ool00`00ooooo`0loolA0004ool00`00ooooo`0Xool002coo`03003ooooo00;oo`03
003ooooo00?oo`03003ooooo05goo`P000?oo`03003ooooo00Coo`03003ooooo03Ooo`h00003ool0
000000<000Goo`03003ooooo02Soo`00=ooo00<00?ooool0G_oo2`001_oo00<00?ooool0<ooo3000
00Coo`00003oo`L000Koo`03003ooooo02Soo`00=ooo00<00?ooool0H?oo3@000_oo00<00?ooool0
;ooo100000Coo`00000000;oo`800003ool0000000800003ool0000000800003ool0000000Soo`03
003ooooo02Soo`00=ooo0P00H_oo50009_oo1P0000?oo`0000000P000_oo0`0000Goo`0000000?oo
00D00004ool000000008ool2000Zool003Ooo`03003ooooo06?oo`h000Coo`D001Soo`T00003ool0
000000@00003ool0000000<000;oo`800005ool00000003oo`0300001?oo000000002_oo00<00?oo
ool0:?oo000gool00`00ooooo`1Tool70002ool<00000ooo0000000F0004ool600000ooo00000004
0004ool300001Ooo00000000ool00P000_oo0`003?oo00<00?ooool0:?oo000gool00`00ooooo`1V
ool300000ooo000000020003ool40004ool;0006ool<0003ool40007ool300001?oo000000000_oo
0P000_oo10003Ooo00<00?ooool0:?oo000gool00`00ooooo`1Wool;0003ool4000:ool7000;ool4
0007ool400001?oo000000000ooo0`0000?oo`0000000`003_oo00<00?ooool0:?oo000gool00`00
ooooo`1Xool50002ool60004oolL0005ool60003ool20004ool200000ooo00000005000?ool00`00
ooooo`0Xool003Ooo`8006[oo`H000;oo`<00003ool0000000H001Ooo`H000Koo`<000?oo`<000;o
o`800003ool00?oo00<000koo`8002[oo`00=ooo00<00?ooool0J_oo100000Koo`00ooooo`00ool2
0007oolG0007ool50004ool20003ool500001?oo000000004?oo00<00?ooool0:?oo000gool00`00
ooooo`1[ool80003ool4000Kool60006ool30003ool20002ool00`00ooooo`03000Aool00`00oooo
o`0Xool003Ooo`03003ooooo06coo`<00003ool00?oo00@000Coo`L0013oo`@000Woo`<000?oo`<0
00;oo`<00004ool00?oo000Bool00`00ooooo`0Xool003Ooo`03003ooooo06goo`<00004ool00000
0002ool40007ool@0009ool40004ool20003ool200001_oo003oo`00ool001?oo`03003ooooo02So
o`00=ooo00<00?ooool0K_oo100000?oo`0000001Ooo0`006Ooo10001_oo0P001?oo00@00?oooooo
o`800003ool0000001?oo`03003ooooo02Soo`00=ooo0P00Kooo0P000_oo0P0000?oo`0000001_oo
1@003ooo1@002?oo0P001?oo0P001?oo00@00?oo000001?oo`8002[oo`00=ooo00<00?ooool0Kooo
0P000_oo0P000_oo0`002?oo3`002ooo0P001Ooo00<00?ooool00_oo0P0000?oo`0000005Ooo00<0
0?ooool0:?oo000gool00`00ooooo`1`ool20002ool30003ool3000Lool30005ool20004ool01P00
ool00000ool001Goo`03003ooooo02Soo`00=ooo00<00?ooool0L?oo0`0000Goo`00ooooo`0000Go
o`<001Goo`@000Koo`8000Goo`06003ooooo003oo`005_oo00<00?ooool0:?oo000gool00`00oooo
o`1aool01000ool000000ooo00<00?ooool01Ooo1`001_oo20002Ooo00<00?ooool01?oo00@00?oo
ool000;oo`03003ooooo01Coo`03003ooooo02Soo`00;?oo0`000_oo00<00?ooool00ooo00<00?oo
ool0L_oo00@00?ooool000?oo`8000coo`L000koo`8000Goo`8000;oo`800003ool00?oo01Koo`03
003ooooo02Soo`00;Ooo00H00?ooool00?oo0004ool00`00ooooo`1bool200000ooo00000004ool2
000Lool30006ool01000oooooooo0P0000?oo`00ool05ooo00<00?ooool0:?oo000[ool400001?oo
003oo`001?oo0P00M?oo00D00?oo003oo`0000Goo`@001Coo`@000Soo`09003oooooool00?oo003o
o`0001Ooo`8002[oo`00:ooo00<00?oo00000_oo00<00?oo00001?oo00<00?ooool0Looo0`000_oo
00<00?ooool01_oo0P003ooo0`002_oo0P000ooo00<00?ooool00P006Ooo00<00?ooool0:?oo000/
ool20002ool00`00ool00004ool00`00ooooo`1dool30002ool00`00ooooo`07ool?000<ool00`00
ooooo`03ool01000ool000006_oo00<00?ooool0:?oo000]ool01@00oooooooo00001Ooo00<00?oo
ool0M?oo00<00?oo00000ooo00<00?ooool07ooo0P001Ooo00<00?ooool00P006_oo00<00?ooool0
:?oo000gool00`00ooooo`1eool20004ool2000Mool20006ool01@00oooooooo00006ooo00<00?oo
ool0:?oo000gool00`00ooooo`1eool00`00ool00005ool2000Iool20007ool01000oooooooo0P00
6ooo00<00?ooool0:?oo000gool2001gool30006ool2000Eool20009ool01@00oooooooo00006ooo
0P00:_oo000gool00`00ooooo`1fool200000ooo003oo`06ool2000Aool2000:ool01000oooooooo
0P007?oo00<00?ooool0:?oo000gool00`00ooooo`1gool01000ooooo`002?oo1P001Ooo1P002ooo
00<00?ooool00_oo0P007?oo00<00?ooool0:?oo000gool00`00ooooo`1gool20002ool00`00oooo
o`0;ool5000@ool00`00ooooo`02ool2000Mool00`00ooooo`0Xool003Ooo`03003ooooo07Soo`05
003oooooool0000Oool20005ool2000Mool00`00ooooo`0Xool003Ooo`03003ooooo07Soo`03003o
oooo00;oo`8001coo`03003ooooo00Coo`03003oo`0001goo`03003ooooo02Soo`00=ooo0P00N_oo
00<00?ooool00ooo00<00?ooool06?oo00<00?ooool01Ooo0P007Ooo0P00:_oo000gool00`00oooo
o`1iool00`00ooooo`04ool00`00ooooo`0Eool20007ool00`00ool0000Nool00`00ooooo`0Xool0
03Ooo`03003ooooo07Woo`8000Koo`03003ooooo01?oo`03003ooooo00Koo`04003ooooo000Nool0
0`00ooooo`0Xool003Ooo`03003ooooo07Woo`03003oo`0000Koo`80017oo`8000Woo`03003oo`00
01ooo`03003ooooo02Soo`00=ooo00<00?ooool0N_oo0P002?oo0P003?oo0`002_oo00@00?ooool0
01ooo`03003ooooo02Soo`00=ooo00<00?ooool0N_oo00<00?oo00002Ooo0`001ooo0P003Ooo00@0
0?ooool001ooo`03003ooooo02Soo`00=ooo00<00?ooool0N_oo00<00?oo00003?oo1`003_oo00D0
0?ooooooo`0001ooo`03003ooooo02Soo`00=ooo0P00Nooo00@00?ooool0023oo`04003ooooo000O
ool2000Zool003Ooo`03003ooooo07_oo`03003oo`0001ooo`05003oooooool0000Pool00`00oooo
o`0Xool003Ooo`03003ooooo07_oo`04003ooooo000Mool00`00ooooo`02ool00`00ooooo`0Nool0
0`00ooooo`0Xool003Ooo`03003ooooo07_oo`05003oooooool0000Kool00`00ooooo`02ool00`00
ooooo`0Oool00`00ooooo`0Xool002_oo`8000Coo`03003ooooo00?oo`03003ooooo07coo`05003o
ooooool0000Jool00`00ooooo`02ool00`00ooooo`0Oool00`00ooooo`0Xool002_oo`03003oo`00
00;oo`03003oo`0000Coo`03003ooooo07coo`05003oooooool0000Iool00`00ooooo`03ool00`00
ooooo`0Oool00`00ooooo`0Xool002_oo`03003oo`0000;oo`03003oo`0000Coo`8007goo`03003o
oooo00;oo`03003ooooo01Goo`03003ooooo00?oo`03003ooooo01ooo`8002[oo`00:ooo0P000ooo
00<00?oo00001?oo00<00?ooool0O?oo00<00?ooool00ooo00<00?ooool04ooo00<00?ooool01?oo
00<00?ooool08?oo00<00?ooool0:?oo000[ool00`00ooooo`02ool00`00ool00004ool00`00oooo
o`1mool00`00ooooo`03ool00`00ooooo`0Aool00`00ooooo`05ool00`00ooooo`0Pool00`00oooo
o`0Xool002coo`8000?oo`03003ooooo00?oo`03003ooooo07goo`03003ooooo00Coo`03003ooooo
00ooo`03003ooooo00Koo`03003ooooo023oo`03003ooooo02Soo`00=ooo00<00?ooool0OOoo00<0
0?ooool01Ooo00<00?ooool03Ooo00<00?ooool01_oo00<00?ooool08Ooo00<00?ooool0:?oo000g
ool00`00ooooo`1nool00`00ooooo`05ool00`00ooooo`0:ool20009ool00`00ooooo`0Qool00`00
ooooo`0Xool003Ooo`8007ooo`03003ooooo00Koo`03003ooooo00Soo`03003ooooo00Woo`03003o
oooo023oo`8002[oo`00=ooo00<00?ooool0O_oo00<00?ooool01ooo0`001?oo0`002ooo00<00?oo
ool08_oo00<00?ooool0:?oo000gool00`00ooooo`1nool00`00ooooo`0:ool5000=ool00`00oooo
o`0Rool00`00ooooo`0Xool003Ooo`03003ooooo07ooo`03003ooooo01_oo`03003ooooo02;oo`03
003ooooo02Soo`00=ooo00<00?ooool0Oooo00<00?ooool06_oo00<00?ooool08ooo00<00?ooool0
:?oo000gool00`00ooooo`1oool00`00ooooo`0Jool00`00ooooo`0Sool00`00ooooo`0Xool003Oo
o`03003ooooo07ooo`03003ooooo01[oo`03003ooooo02?oo`03003ooooo02Soo`00=ooo0P00POoo
00<00?ooool06?oo00<00?ooool08ooo0P00:_oo000gool00`00ooooo`20ool00`00ooooo`0Hool0
0`00ooooo`0Tool00`00ooooo`0Xool003Ooo`03003ooooo083oo`03003ooooo01Soo`03003ooooo
02Coo`03003ooooo02Soo`00=ooo00<00?ooool0POoo00<00?ooool05_oo00<00?ooool09Ooo00<0
0?ooool0:?oo000gool00`00ooooo`21ool00`00ooooo`0Fool00`00ooooo`0Uool00`00ooooo`0X
ool003Ooo`03003ooooo087oo`03003ooooo01Koo`03003ooooo02Goo`03003ooooo02Soo`00=ooo
0P00Pooo00<00?ooool05Ooo00<00?ooool09?oo0P00:_oo000gool00`00ooooo`22ool00`00oooo
o`0Dool00`00ooooo`0Vool00`00ooooo`0Xool003Ooo`03003ooooo08;oo`03003ooooo01Coo`03
003ooooo02Koo`03003ooooo02Soo`00=ooo00<00?ooool0Pooo00<00?ooool04ooo00<00?ooool0
9_oo00<00?ooool0:?oo000/ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`23ool00`00
ooooo`0Bool00`00ooooo`0Wool00`00ooooo`0Xool002_oo`03003oo`0000;oo`03003oo`0000Co
o`03003ooooo08?oo`03003ooooo01;oo`03003ooooo02Ooo`03003ooooo02Soo`00:ooo00<00?oo
00000_oo00<00?oo00001?oo0P00QOoo00<00?ooool04Ooo00<00?ooool09_oo0P00:_oo000/ool0
1`00oooooooo003oo`0000Coo`03003ooooo08Coo`03003ooooo013oo`03003ooooo02Soo`03003o
oooo02Soo`00:ooo00<00?oo00000_oo00<00?oo00001?oo00<00?ooool0Q?oo00<00?ooool04?oo
00<00?ooool0:?oo00<00?ooool0:?oo000/ool00`00ooooo`02ool00`00ooooo`03ool00`00oooo
o`24ool00`00ooooo`0@ool00`00ooooo`0Xool00`00ooooo`0Xool003Ooo`03003ooooo08Goo`03
003ooooo00koo`03003ooooo02Woo`03003ooooo02Soo`00=ooo00<00?ooool0QOoo00<00?ooool0
3_oo00<00?ooool0:Ooo00<00?ooool0:?oo000gool00`00ooooo`25ool00`00ooooo`0=ool00`00
ooooo`0Zool00`00ooooo`0Xool003Ooo`8008Ooo`03003ooooo00coo`03003ooooo02Woo`8002[o
o`00=ooo00<00?ooool0Q_oo00<00?ooool02ooo00<00?ooool0:ooo00<00?ooool0:?oo000gool0
0`00ooooo`27ool00`00ooooo`0:ool00`00ooooo`0[ool00`00ooooo`0Xool003Ooo`03003ooooo
08Soo`03003ooooo00Soo`03003ooooo02coo`03003ooooo02Soo`00=ooo00<00?ooool0R?oo00<0
0?ooool01ooo00<00?ooool0;Ooo00<00?ooool0:?oo000gool00`00ooooo`29ool00`00ooooo`06
ool00`00ooooo`0]ool00`00ooooo`0Xool003Ooo`8008_oo`03003ooooo00Coo`03003ooooo02go
o`8002[oo`00=ooo00<00?ooool0R_oo0P001?oo00<00?ooool0;ooo00<00?ooool0:?oo000gool0
0`00ooooo`2<ool4000bool00`00ooooo`0Xool003Ooo`03003ooooo0<;oo`03003ooooo02Soo`00
=ooo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool0
1_oo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool0
1_oo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool0
1ooo00<00?ooool01_oo00<00?ooool01ooo00<00?ooool01_oo00<00?ooool01_oo00<00?ooool0
1ooo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool0:?oo000gooo6000Zool00?ooobSoo`00
oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool005;oo`<000?oo`8000;oo`<000[o
o`@000;oo`<000;oo`<000;oo`<000?oo`8000;oo`<000?oo`800003ool0000000;oo`03003ooooo
0080013oo`06003oo`00ool00?oo10000_oo0P000ooo0`0000Coo`00000000;oo`<000?oo`8000;o
o`<000?oo`8000;oo`8005;oo`00Dooo00D00?ooooooo`0000;oo`04003ooooo000<ool01000oooo
o`000_oo00<00?ooool00_oo00<00?ooool00_oo00D00?ooooooo`0000Goo`05003oooooool00004
ool01P00ooooo`00ool000;oo`03003ooooo00goo`06003oo`00ool00?oo0`000_oo00H00?ooool0
0?oo0002ool01000ooooo`001?oo00D00?ooooooo`0000;oo`04003ooooo0003ool00`00ooooo`04
ool00`00ooooo`1?ool005?oo`05003oooooool00002ool01000ooooo`003?oo00@00?ooool000;o
o`03003ooooo00;oo`03003ooooo00;oo`04003oooooool30003ool01000oooooooo0`000_oo00H0
0?ooool00?oo000Bool01@00ool00?oo00000ooo00@00?ooool000Coo`04003ooooo0002ool00`00
ooooo`02ool01@00oooooooo00001Ooo00@00?ooooooo`<000?oo`03003ooooo053oo`00D_oo0`00
0ooo0P000_oo10002_oo00D00?ooool00?oo008000?oo`<000;oo`<000;oo`<000;oo`@00005ool0
0000003oo`0400000ooo00000002000@ool200000ooo003oo`02ool200000ooo0000000200001?oo
00000?oo0P0000?oo`0000000P0000?oo`0000000_oo10000_oo0P000ooo0`000ooo0P00DOoo001C
ool00`00ooooo`0Dool01000ooooo`001ooo00<00?ooool00_oo00<00?ooool05Ooo00<00?ooool0
6ooo00<00?ooool04Ooo00<00?ooool0H?oo001Dool00`00ooooo`0Bool40003ool00`00ooooo`03
ool00`00ooooo`02ool00`00ooooo`12ool00`00ooooo`07ool00`00ooooo`1Jool00?ooobSoo`00
oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo002<ool3
002Hool008goo`03003ooooo09Ooo`00Jooo0P000_oo100000Coo`00000000;oo`<000goo`8000;o
o`<000?oo`8000;oo`<000?oo`800003ool0000000;oo`03003ooooo00[oo`D00003ool0000000<0
0003ool00?oo00D000?oo`<00003ool00000008005Soo`00J_oo00<00?ooool00_oo0`000ooo00<0
0?ooool00_oo00<00?ooool02ooo00H00?ooool00?oo0002ool00`00ool00002ool01000ooooo`00
0ooo00H00?ooool00?oo0002ool00`00ooooo`0;ool01@00ooooo`00ool00`0000Soo`00ool00?oo
003oo`000_oo00<00?oo00000_oo00<00?oo00000P00FOoo001Zool00`00ooooo`04ool01@00oooo
oooo00001?oo00<00?ooool02ooo00H00?ooool00?oo0002ool00`00ool00005ool01@00oooooooo
00000_oo00<00?oo00000_oo00<00?ooool02ooo00<00?ooool01?oo00T00?oo003oo`00ool00?oo
00000_oo00<00?oo00000_oo00D00?ooooooo`0005Woo`00J_oo00<00?ooool00ooo0P000ooo00<0
0?ooool00_oo00<00?ooool02ooo00<00?ooool01@0000?oo`0000000P000_oo0P001?oo0P0000?o
o`0000000P003_oo00<00?ooool00ooo0P0000Goo`00003oo`0000;oo`<000?oo`<000;oo`8005Wo
o`00J_oo00<00?oo00002?oo00<00?ooool00_oo00<00?ooool02ooo00@00?ooool000Koo`03003o
oooo01goo`03003ooooo00coo`03003ooooo00Goo`03003ooooo05_oo`00J_oo0`001ooo0P000ooo
0P003_oo0P003Ooo00<00?ooool05_oo0`003?oo0P001_oo0P00GOoo003ooolXool00?ooobSoo`00
oooo:?oo003ooolXool00?ooobSoo`00\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {18.5922, -23.2323, \
0.106644, 0.791298}}]
}, Open  ]],

Cell["Here is the equivalent three\[Hyphen]dimensional graph. ", "MathCaption",
  CellTags->"0.44"],

Cell[CellGroupData[{

Cell["\<\
Plot3D[optionlambda[x, t], {x, 25, 55}, {t, 0, 110},
   AxesLabel->{\"Stock Price\", \"Time\", \"Option  \\nLambda\"}];\
\>", \
"Input",
  CellLabel->"In[39]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -11.1734 -9 ]
[.3345 .12542 .8266 0 ]
[.56094 .0364 -10.3394 -9 ]
[.56094 .0364 1.66057 0 ]
[.29165 .07573 -65.1782 -15 ]
[.29165 .07573 4.82182 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.77605 .1102 0 -6.14908 ]
[.77605 .1102 12 2.85092 ]
[.84375 .21386 0 -6.04972 ]
[.84375 .21386 12 2.95028 ]
[.9051 .30781 0 -5.96165 ]
[.9051 .30781 12 3.03835 ]
[.96095 .39335 0 -5.88306 ]
[.96095 .39335 18 3.11694 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 28 4.94788 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01677 .31114 -12 -2.78123 ]
[.01677 .31114 0 6.21877 ]
[.0092 .35857 -12 -2.82145 ]
[.0092 .35857 0 6.17855 ]
[.0014 .40747 -12 -2.86303 ]
[.0014 .40747 0 6.13697 ]
[-0.00665 .45789 -12 -2.90605 ]
[-0.00665 .45789 0 6.09395 ]
[-0.05457 .39542 -52 -9.75946 ]
[-0.05457 .39542 0 21.2405 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.76373 .11471 m
.75757 .11697 L
s
[(25)] .77605 .1102 -1 .36646 Mshowa
.83134 .21814 m
.82514 .22027 L
s
[(50)] .84375 .21386 -1 .34438 Mshowa
.89262 .31187 m
.88638 .3139 L
s
[(75)] .9051 .30781 -1 .32481 Mshowa
.94841 .39721 m
.94213 .39913 L
s
[(100)] .96095 .39335 -1 .30735 Mshowa
.125 Mabswid
.70438 .02393 m
.70071 .02535 L
s
.71969 .04735 m
.71602 .04876 L
s
.73468 .07028 m
.731 .07167 L
s
.74936 .09273 m
.74567 .0941 L
s
.7778 .13624 m
.7741 .13758 L
s
.7916 .15734 m
.78789 .15866 L
s
.80511 .17801 m
.8014 .17932 L
s
.81836 .19827 m
.81464 .19957 L
s
.84407 .23761 m
.84035 .23888 L
s
.85656 .25671 m
.85283 .25797 L
s
.86881 .27545 m
.86507 .27669 L
s
.88083 .29383 m
.87709 .29506 L
s
.90419 .32957 m
.90044 .33077 L
s
.91555 .34695 m
.9118 .34814 L
s
.9267 .364 m
.92295 .36518 L
s
.93765 .38075 m
.93389 .38192 L
s
.95897 .41336 m
.9552 .41451 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02903 .30646 m
.03516 .30412 L
s
[(20)] .01677 .31114 1 -0.38195 Mshowa
.0215 .35399 m
.02764 .3517 L
s
[(40)] .0092 .35857 1 -0.37301 Mshowa
.01373 .40298 m
.0199 .40074 L
s
[(60)] .0014 .40747 1 -0.36377 Mshowa
.00572 .45351 m
.01191 .45132 L
s
[(80)] -0.00665 .45789 1 -0.35421 Mshowa
.125 Mabswid
.03453 .27174 m
.0382 .27031 L
s
.03271 .28323 m
.03638 .28181 L
s
.03087 .2948 m
.03455 .29339 L
s
.02717 .31821 m
.03085 .31681 L
s
.02529 .33005 m
.02897 .32866 L
s
.0234 .34197 m
.02709 .34059 L
s
.01958 .3661 m
.02327 .36473 L
s
.01764 .3783 m
.02134 .37694 L
s
.01569 .39059 m
.01939 .38924 L
s
.01175 .41547 m
.01545 .41413 L
s
.00976 .42805 m
.01346 .42672 L
s
.00775 .44073 m
.01146 .43941 L
s
.00368 .46639 m
.0074 .46509 L
s
.00162 .47938 m
.00534 .47808 L
s
gsave
-0.05457 .39542 -113 -13.7595 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Option) show
63.000000 31.000000 moveto
(Lambda) show
99.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.38313 .58323 .40512 .60371 .44189 .59268 .42021 .57192 Metetra
.663 .741 .908 r
.42021 .57192 .44189 .59268 .47916 .5815 .45781 .56045 Metetra
.66 .74 .909 r
.45781 .56045 .47916 .5815 .51695 .57017 .49593 .54917 Metetra
.595 .723 .933 r
.49593 .54917 .51695 .57017 .55527 .55944 .53462 .54344 Metetra
0 .284 .729 r
.53462 .54344 .55527 .55944 .59453 .56701 .57443 .5668 Metetra
.832 .38 .148 r
.57443 .5668 .59453 .56701 .63743 .65591 .6167 .62948 Metetra
.024 .367 .837 r
.6167 .62948 .63743 .65591 .68272 .73097 .66003 .65696 Metetra
.746 .594 .687 r
.66003 .65696 .68272 .73097 .7207 .62866 .70059 .5989 Metetra
.879 .747 .711 r
.70059 .5989 .7207 .62866 .75702 .52559 .7394 .52167 Metetra
.898 .952 .829 r
.7394 .52167 .75702 .52559 .79711 .48907 .77955 .47501 Metetra
.752 .866 .932 r
.77955 .47501 .79711 .48907 .83923 .47365 .82158 .45182 Metetra
.681 .768 .917 r
.82158 .45182 .83923 .47365 .88217 .4606 .86483 .4366 Metetra
.666 .745 .909 r
.86483 .4366 .88217 .4606 .92578 .44752 .90888 .42288 Metetra
.664 .742 .908 r
.90888 .42288 .92578 .44752 .97003 .43424 .95362 .4092 Metetra
.664 .741 .908 r
.36056 .56222 .38313 .58323 .42021 .57192 .39797 .55062 Metetra
.663 .741 .908 r
.39797 .55062 .42021 .57192 .45781 .56045 .4359 .53895 Metetra
.645 .737 .916 r
.4359 .53895 .45781 .56045 .49593 .54917 .47435 .52881 Metetra
.492 .695 .959 r
.47435 .52881 .49593 .54917 .53462 .54344 .51335 .52912 Metetra
0 .172 .601 r
.51335 .52912 .53462 .54344 .57443 .5668 .55343 .55548 Metetra
.685 .146 0 r
.55343 .55548 .57443 .5668 .6167 .62948 .59537 .59779 Metetra
.419 .567 .895 r
.59537 .59779 .6167 .62948 .66003 .65696 .63821 .60804 Metetra
.755 .647 .742 r
.63821 .60804 .66003 .65696 .70059 .5989 .67989 .56595 Metetra
.843 .732 .742 r
.67989 .56595 .70059 .5989 .7394 .52167 .7204 .50571 Metetra
.869 .849 .821 r
.7204 .50571 .7394 .52167 .77955 .47501 .76133 .45953 Metetra
.786 .86 .905 r
.76133 .45953 .77955 .47501 .82158 .45182 .80359 .43128 Metetra
.705 .795 .92 r
.80359 .43128 .82158 .45182 .86483 .4366 .84709 .41282 Metetra
.674 .756 .913 r
.84709 .41282 .86483 .4366 .90888 .42288 .89153 .39778 Metetra
.666 .744 .909 r
.89153 .39778 .90888 .42288 .95362 .4092 .93676 .38349 Metetra
.663 .741 .908 r
.33741 .54067 .36056 .56222 .39797 .55062 .37514 .52878 Metetra
.659 .74 .91 r
.37514 .52878 .39797 .55062 .4359 .53895 .4134 .51717 Metetra
.62 .732 .927 r
.4134 .51717 .4359 .53895 .47435 .52881 .45214 .50898 Metetra
.391 .661 .966 r
.45214 .50898 .47435 .52881 .51335 .52912 .49141 .51343 Metetra
0 .244 .679 r
.49141 .51343 .51335 .52912 .55343 .55548 .53171 .53768 Metetra
0 .201 .662 r
.53171 .53768 .55343 .55548 .59537 .59779 .57357 .56635 Metetra
.519 .625 .896 r
.57357 .56635 .59537 .59779 .63821 .60804 .61638 .56815 Metetra
.751 .679 .781 r
.61638 .56815 .63821 .60804 .67989 .56595 .65878 .53378 Metetra
.822 .736 .77 r
.65878 .53378 .67989 .56595 .7204 .50571 .70049 .48408 Metetra
.84 .808 .819 r
.70049 .48408 .7204 .50571 .76133 .45953 .74232 .44083 Metetra
.792 .834 .884 r
.74232 .44083 .76133 .45953 .80359 .43128 .78505 .41034 Metetra
.725 .803 .913 r
.78505 .41034 .80359 .43128 .84709 .41282 .8289 .38913 Metetra
.685 .768 .914 r
.8289 .38913 .84709 .41282 .89153 .39778 .87373 .37238 Metetra
.67 .75 .911 r
.87373 .37238 .89153 .39778 .93676 .38349 .91942 .35719 Metetra
.663 .741 .908 r
.31365 .51855 .33741 .54067 .37514 .52878 .35171 .50643 Metetra
.652 .739 .913 r
.35171 .50643 .37514 .52878 .4134 .51717 .39028 .4952 Metetra
.589 .726 .938 r
.39028 .4952 .4134 .51717 .45214 .50898 .42928 .48906 Metetra
.329 .635 .963 r
.42928 .48906 .45214 .50898 .49141 .51343 .4688 .49564 Metetra
0 .359 .792 r
.4688 .49564 .49141 .51343 .53171 .53768 .50932 .51626 Metetra
.029 .439 .87 r
.50932 .51626 .53171 .53768 .57357 .56635 .55128 .53557 Metetra
.566 .657 .897 r
.55128 .53557 .57357 .56635 .61638 .56815 .59425 .53243 Metetra
.744 .699 .808 r
.59425 .53243 .61638 .56815 .65878 .53378 .63724 .5024 Metetra
.805 .741 .792 r
.63724 .5024 .65878 .53378 .70049 .48408 .67987 .45954 Metetra
.819 .789 .824 r
.67987 .45954 .70049 .48408 .74232 .44083 .72256 .41936 Metetra
.788 .814 .873 r
.72256 .41936 .74232 .44083 .78505 .41034 .7659 .38819 Metetra
.735 .8 .904 r
.7659 .38819 .78505 .41034 .8289 .38913 .81018 .36502 Metetra
.695 .774 .912 r
.81018 .36502 .8289 .38913 .87373 .37238 .85544 .3466 Metetra
.675 .755 .911 r
.85544 .3466 .87373 .37238 .91942 .35719 .9016 .33032 Metetra
.661 .741 .909 r
.28926 .49585 .31365 .51855 .35171 .50643 .32764 .48358 Metetra
.642 .737 .918 r
.32764 .48358 .35171 .50643 .39028 .4952 .3665 .47297 Metetra
.559 .719 .947 r
.3665 .47297 .39028 .4952 .42928 .48906 .40576 .46858 Metetra
.306 .623 .96 r
.40576 .46858 .42928 .48906 .4688 .49564 .44553 .47585 Metetra
.026 .459 .875 r
.44553 .47585 .4688 .49564 .50932 .51626 .48629 .49263 Metetra
.236 .554 .932 r
.48629 .49263 .50932 .51626 .55128 .53557 .52845 .50522 Metetra
.594 .677 .899 r
.52845 .50522 .55128 .53557 .59425 .53243 .57167 .49885 Metetra
.737 .712 .828 r
.57167 .49885 .59425 .53243 .63724 .5024 .61519 .47146 Metetra
.791 .745 .81 r
.61519 .47146 .63724 .5024 .67987 .45954 .6586 .43325 Metetra
.803 .78 .831 r
.6586 .43325 .67987 .45954 .72256 .41936 .70209 .39572 Metetra
.781 .8 .868 r
.70209 .39572 .72256 .41936 .7659 .38819 .74608 .3646 Metetra
.74 .795 .897 r
.74608 .3646 .7659 .38819 .81018 .36502 .79089 .34014 Metetra
.703 .777 .909 r
.79089 .34014 .81018 .36502 .85544 .3466 .83662 .32027 Metetra
.681 .76 .911 r
.83662 .32027 .85544 .3466 .9016 .33032 .88326 .30285 Metetra
.658 .74 .911 r
.2642 .47256 .28926 .49585 .32764 .48358 .30289 .46025 Metetra
.63 .735 .923 r
.30289 .46025 .32764 .48358 .3665 .47297 .34203 .45036 Metetra
.534 .712 .953 r
.34203 .45036 .3665 .47297 .40576 .46858 .38154 .44725 Metetra
.311 .623 .959 r
.38154 .44725 .40576 .46858 .44553 .47585 .42157 .45429 Metetra
.156 .532 .921 r
.42157 .45429 .44553 .47585 .48629 .49263 .46262 .46748 Metetra
.355 .612 .947 r
.46262 .46748 .48629 .49263 .52845 .50522 .50504 .47504 Metetra
.611 .691 .9 r
.50504 .47504 .52845 .50522 .57167 .49885 .54857 .46637 Metetra
.73 .721 .842 r
.54857 .46637 .57167 .49885 .61519 .47146 .59259 .44067 Metetra
.778 .748 .825 r
.59259 .44067 .61519 .47146 .6586 .43325 .6367 .40572 Metetra
.79 .774 .839 r
.6367 .40572 .6586 .43325 .70209 .39572 .68093 .37035 Metetra
.774 .791 .867 r
.68093 .37035 .70209 .39572 .74608 .3646 .7256 .33958 Metetra
.741 .79 .892 r
.7256 .33958 .74608 .3646 .79089 .34014 .77098 .31428 Metetra
.709 .777 .905 r
.77098 .31428 .79089 .34014 .83662 .32027 .81723 .29322 Metetra
.686 .762 .909 r
.81723 .29322 .83662 .32027 .88326 .30285 .86438 .2747 Metetra
.654 .74 .913 r
.23845 .44867 .2642 .47256 .30289 .46025 .27745 .43641 Metetra
.618 .733 .928 r
.27745 .43641 .30289 .46025 .34203 .45036 .31686 .42722 Metetra
.515 .705 .957 r
.31686 .42722 .34203 .45036 .38154 .44725 .35661 .42494 Metetra
.33 .63 .96 r
.35661 .42494 .38154 .44725 .42157 .45429 .39691 .43121 Metetra
.254 .582 .944 r
.39691 .43121 .42157 .45429 .46262 .46748 .43827 .44115 Metetra
.428 .645 .949 r
.43827 .44115 .46262 .46748 .50504 .47504 .481 .4448 Metetra
.624 .702 .901 r
.481 .4448 .50504 .47504 .54857 .46637 .52489 .43437 Metetra
.724 .727 .853 r
.52489 .43437 .54857 .46637 .59259 .44067 .5694 .40979 Metetra
.768 .75 .836 r
.5694 .40979 .59259 .44067 .6367 .40572 .61415 .37717 Metetra
.779 .771 .845 r
.61415 .37717 .6367 .40572 .68093 .37035 .65909 .34353 Metetra
.767 .784 .867 r
.65909 .34353 .68093 .37035 .7256 .33958 .70443 .3132 Metetra
.741 .785 .889 r
.70443 .3132 .7256 .33958 .77098 .31428 .75042 .28735 Metetra
.712 .776 .902 r
.75042 .28735 .77098 .31428 .81723 .29322 .79723 .26529 Metetra
.69 .764 .908 r
.79723 .26529 .81723 .29322 .86438 .2747 .84492 .24575 Metetra
.65 .739 .915 r
.21197 .42415 .23845 .44867 .27745 .43641 .25128 .41194 Metetra
.608 .73 .932 r
.25128 .41194 .27745 .43641 .31686 .42722 .29096 .40325 Metetra
.505 .7 .957 r
.29096 .40325 .31686 .42722 .35661 .42494 .33096 .40132 Metetra
.356 .637 .96 r
.33096 .40132 .35661 .42494 .39691 .43121 .37155 .40662 Metetra
.322 .612 .953 r
.37155 .40662 .39691 .43121 .43827 .44115 .41322 .41397 Metetra
.471 .665 .947 r
.41322 .41397 .43827 .44115 .481 .4448 .45628 .41479 Metetra
.631 .712 .905 r
.45628 .41479 .481 .4448 .52489 .43437 .50056 .40307 Metetra
.721 .736 .864 r
.50056 .40307 .52489 .43437 .5694 .40979 .54558 .37906 Metetra
.761 .754 .847 r
.54558 .37906 .5694 .40979 .61415 .37717 .59094 .34789 Metetra
.771 .77 .852 r
.59094 .34789 .61415 .37717 .65909 .34353 .63655 .31539 Metetra
.761 .779 .868 r
.63655 .31539 .65909 .34353 .70443 .3132 .68256 .28536 Metetra
.739 .78 .886 r
.68256 .28536 .70443 .3132 .75042 .28735 .72918 .2591 Metetra
.714 .773 .899 r
.72918 .2591 .75042 .28735 .79723 .26529 .77657 .23625 Metetra
.693 .763 .905 r
.77657 .23625 .79723 .26529 .84492 .24575 .82484 .21581 Metetra
.644 .738 .917 r
.18474 .399 .21197 .42415 .25128 .41194 .22434 .38693 Metetra
.597 .728 .936 r
.22434 .38693 .25128 .41194 .29096 .40325 .26427 .37874 Metetra
.496 .698 .959 r
.26427 .37874 .29096 .40325 .33096 .40132 .30453 .37696 Metetra
.378 .647 .962 r
.30453 .37696 .33096 .40132 .37155 .40662 .34543 .38101 Metetra
.376 .637 .957 r
.34543 .38101 .37155 .40662 .41322 .41397 .38745 .38573 Metetra
.508 .679 .943 r
.38745 .38573 .41322 .41397 .45628 .41479 .43088 .3839 Metetra
.638 .715 .903 r
.43088 .3839 .45628 .41479 .50056 .40307 .47556 .37096 Metetra
.715 .735 .867 r
.47556 .37096 .50056 .40307 .54558 .37906 .52107 .34743 Metetra
.751 .752 .852 r
.52107 .34743 .54558 .37906 .59094 .34789 .56702 .31754 Metetra
.762 .767 .856 r
.56702 .31754 .59094 .34789 .63655 .31539 .6133 .28613 Metetra
.755 .776 .87 r
.6133 .28613 .63655 .31539 .68256 .28536 .65998 .25648 Metetra
.737 .778 .886 r
.65998 .25648 .68256 .28536 .72918 .2591 .70724 .22991 Metetra
.715 .773 .898 r
.70724 .22991 .72918 .2591 .77657 .23625 .75526 .20633 Metetra
.696 .764 .905 r
.75526 .20633 .77657 .23625 .82484 .21581 .80412 .18502 Metetra
.638 .737 .92 r
.15672 .37319 .18474 .399 .22434 .38693 .1966 .36126 Metetra
.587 .725 .939 r
.1966 .36126 .22434 .38693 .26427 .37874 .23679 .35343 Metetra
.492 .696 .959 r
.23679 .35343 .26427 .37874 .30453 .37696 .27731 .35152 Metetra
.403 .657 .962 r
.27731 .35152 .30453 .37696 .34543 .38101 .31853 .35424 Metetra
.42 .656 .957 r
.31853 .35424 .34543 .38101 .38745 .38573 .36092 .3566 Metetra
.534 .69 .939 r
.36092 .3566 .38745 .38573 .43088 .3839 .40474 .35253 Metetra
.644 .719 .903 r
.40474 .35253 .43088 .3839 .47556 .37096 .44984 .33852 Metetra
.711 .738 .872 r
.44984 .33852 .47556 .37096 .52107 .34743 .49585 .31526 Metetra
.744 .752 .859 r
.49585 .31526 .52107 .34743 .56702 .31754 .54239 .2863 Metetra
.755 .765 .861 r
.54239 .2863 .56702 .31754 .6133 .28613 .58931 .25571 Metetra
.75 .773 .872 r
.58931 .25571 .6133 .28613 .65998 .25648 .63666 .22636 Metetra
.734 .775 .886 r
.63666 .22636 .65998 .25648 .70724 .22991 .68458 .19954 Metetra
.715 .771 .897 r
.68458 .19954 .70724 .22991 .75526 .20633 .73323 .17532 Metetra
.697 .764 .903 r
.73323 .17532 .75526 .20633 .80412 .18502 .78272 .15319 Metetra
.633 .736 .922 r
.12787 .34668 .15672 .37319 .1966 .36126 .16803 .33488 Metetra
.579 .723 .941 r
.16803 .33488 .1966 .36126 .23679 .35343 .20847 .32726 Metetra
.493 .695 .959 r
.20847 .32726 .23679 .35343 .27731 .35152 .24927 .32501 Metetra
.426 .665 .961 r
.24927 .32501 .27731 .35152 .31853 .35424 .29082 .32636 Metetra
.454 .669 .955 r
.29082 .32636 .31853 .35424 .36092 .3566 .33359 .32659 Metetra
.554 .698 .936 r
.33359 .32659 .36092 .3566 .40474 .35253 .37781 .32058 Metetra
.648 .723 .904 r
.37781 .32058 .40474 .35253 .44984 .33852 .42336 .30561 Metetra
.707 .74 .877 r
.42336 .30561 .44984 .33852 .49585 .31526 .46987 .28245 Metetra
.738 .753 .864 r
.46987 .28245 .49585 .31526 .54239 .2863 .51699 .25415 Metetra
.748 .764 .865 r
.51699 .25415 .54239 .2863 .58931 .25571 .56455 .22417 Metetra
.744 .771 .874 r
.56455 .22417 .58931 .25571 .63666 .22636 .61257 .19503 Metetra
.731 .772 .886 r
.61257 .19503 .63666 .22636 .68458 .19954 .66116 .16796 Metetra
.715 .769 .896 r
.66116 .16796 .68458 .19954 .73323 .17532 .71046 .14316 Metetra
.698 .764 .902 r
.71046 .14316 .73323 .17532 .78272 .15319 .7606 .12025 Metetra
.627 .735 .925 r
.09816 .31943 .12787 .34668 .16803 .33488 .13859 .30772 Metetra
.572 .721 .943 r
.13859 .30772 .16803 .33488 .20847 .32726 .17928 .30017 Metetra
.495 .695 .958 r
.17928 .30017 .20847 .32726 .24927 .32501 .22038 .29743 Metetra
.447 .673 .96 r
.22038 .29743 .24927 .32501 .29082 .32636 .26227 .29739 Metetra
.481 .68 .953 r
.26227 .29739 .29082 .32636 .33359 .32659 .30543 .29568 Metetra
.569 .705 .933 r
.30543 .29568 .33359 .32659 .37781 .32058 .35007 .28795 Metetra
.651 .726 .904 r
.35007 .28795 .37781 .32058 .42336 .30561 .39608 .2721 Metetra
.704 .741 .88 r
.39608 .2721 .42336 .30561 .46987 .28245 .44309 .24891 Metetra
.732 .753 .869 r
.44309 .24891 .46987 .28245 .51699 .25415 .49079 .22105 Metetra
.743 .762 .869 r
.49079 .22105 .51699 .25415 .56455 .22417 .53899 .1915 Metetra
.74 .769 .876 r
.53899 .1915 .56455 .22417 .61257 .19503 .58768 .16248 Metetra
.729 .77 .886 r
.58768 .16248 .61257 .19503 .66116 .16796 .63695 .13515 Metetra
.714 .768 .895 r
.63695 .13515 .66116 .16796 .71046 .14316 .68692 .10979 Metetra
.699 .763 .901 r
.68692 .10979 .71046 .14316 .7606 .12025 .73772 .08615 Metetra
.622 .733 .927 r
.06754 .29141 .09816 .31943 .13859 .30772 .10824 .27973 Metetra
.567 .719 .944 r
.10824 .27973 .13859 .30772 .17928 .30017 .14919 .27212 Metetra
.5 .696 .957 r
.14919 .27212 .17928 .30017 .22038 .29743 .19058 .26875 Metetra
.466 .68 .958 r
.19058 .26875 .22038 .29743 .26227 .29739 .23283 .26734 Metetra
.503 .688 .95 r
.23283 .26734 .26227 .29739 .30543 .29568 .2764 .26385 Metetra
.582 .71 .931 r
.2764 .26385 .30543 .29568 .35007 .28795 .32147 .25457 Metetra
.654 .729 .904 r
.32147 .25457 .35007 .28795 .39608 .2721 .36794 .23787 Metetra
.701 .742 .883 r
.36794 .23787 .39608 .2721 .44309 .24891 .41548 .21456 Metetra
.728 .753 .873 r
.41548 .21456 .44309 .24891 .49079 .22105 .46376 .18696 Metetra
.737 .762 .872 r
.46376 .18696 .49079 .22105 .53899 .1915 .5126 .15768 Metetra
.735 .767 .878 r
.5126 .15768 .53899 .1915 .58768 .16248 .56196 .12869 Metetra
.726 .768 .887 r
.56196 .12869 .58768 .16248 .63695 .13515 .61191 .10109 Metetra
.713 .767 .895 r
.61191 .10109 .63695 .13515 .68692 .10979 .66257 .07518 Metetra
.699 .762 .901 r
.66257 .07518 .68692 .10979 .73772 .08615 .71406 .05081 Metetra
.617 .732 .928 r
.03599 .2625 .06754 .29141 .10824 .27973 .07696 .25075 Metetra
.564 .717 .944 r
.07696 .25075 .10824 .27973 .14919 .27212 .11818 .24293 Metetra
.505 .696 .955 r
.11818 .24293 .14919 .27212 .19058 .26875 .15987 .23888 Metetra
.482 .684 .956 r
.15987 .23888 .19058 .26875 .23283 .26734 .20247 .23621 Metetra
.519 .694 .948 r
.20247 .23621 .23283 .26734 .2764 .26385 .24643 .23121 Metetra
.591 .715 .93 r
.24643 .23121 .2764 .26385 .32147 .25457 .29195 .22062 Metetra
.656 .733 .906 r
.29195 .22062 .32147 .25457 .36794 .23787 .3389 .20313 Metetra
.7 .745 .887 r
.3389 .20313 .36794 .23787 .41548 .21456 .38697 .17955 Metetra
.724 .755 .877 r
.38697 .17955 .41548 .21456 .46376 .18696 .43584 .15198 Metetra
.734 .762 .875 r
.43584 .15198 .46376 .18696 .5126 .15768 .48532 .12274 Metetra
.732 .766 .88 r
.48532 .12274 .5126 .15768 .56196 .12869 .53536 .09363 Metetra
.724 .767 .887 r
.53536 .09363 .56196 .12869 .61191 .10109 .58601 .06566 Metetra
.712 .765 .894 r
.58601 .06566 .61191 .10109 .66257 .07518 .63737 .03918 Metetra
.699 .761 .9 r
.63737 .03918 .66257 .07518 .71406 .05081 .68955 .01409 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[39]:=",
  ImageSize->{289, 234.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004Q0000jQ000`40n007h00Ooooo8_oo003ooolR
ool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00
oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolR
ool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00
oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003Gool00`00ooooo`17ool00=Koo`03003oo`00
04Soo`00e_oo00<00?oo0000B?oo003Fool00`00ool00018ool00=Koo`03003oo`0004Soo`00eooo
00<00?ooool0Aooo002`ool00`00ooooo`02ool00`00ooooo`0Iool2001>ool00:ooo`03003oo`00
00;oo`03003oo`0001Soo`800003ool0000004goo`00/Ooo00H00?ooool00?oo000Eool30003ool2
001=ool00:ooo`8000?oo`03003oo`0001;oo`<000;oo`04003oooooool3001<ool00:ooo`03003o
oooo00;oo`03003oo`00013oo`8000Ooo`<00003[S`0000004_oo`00[ooo0`000ooo00<00?ooool0
3?oo0`001ooo0P0000Bf?:gk002]n`<004[oo`00?ooo0`000ooo0P000ooo0P000_oo0`0000Coo`00
003oo`8000_oo`<000?oo`<000;oo`<000;oo`<000?oo`8004Soo`8000Ooo`<00007[Mb^?:gL[S`0
0:hl[M`00P00B_oo000oool00`00ool00002ool01P00ooooo`00ool000;oo`03003oo`0000Coo`03
003oo`0000goo`03003ooooo00?oo`03003ooooo00;oo`05003oooooool00004ool00`00ooooo`15
ool300000ooo003oo`04ool200002jgk]Sb]nkHl[O^f?:gk002]nkHl[O/00P00BOoo0011ool01000
ooooo`001?oo00H00?ooool00?oo0004ool3000=ool30003ool00`00ooooo`02ool01@00oooooooo
00001?oo0`00@ooo0P002?oo0P0000f^?:gL[Sb]g:hl[Mb^?:gL[S`00:hl[Mb^?0020019ool0043o
o`03003ooooo00@000?oo`8000;oo`<000;oo`04003oo`00000<ool01@00ooooo`00ool0100000?o
o`0000000ooo0`000_oo0`00@?oo0`002?oo0P00012]n`00[O^f?:gk]Sb]nkHl[O^f?:gk]S`00;Hl
[O^f?08004Soo`00?ooo00<00?oo00000_oo00<00?ooool03?oo00<00?ooool03Ooo00@00?ooool0
053oo`<000Woo`80000B]Sbf6kHl]Q/00:gL[Sb]g:hl[Mb^?:gL[Sb]g000[Mb^?:gL0`00Aooo000o
ool3000@ool2000>ool40008ool00`00ooooo`14ool20003ool00`00ooooo`04ool200005:gk]Sb]
nkHl[O^f?000]Sb]nkHl[O^f?:gk]Sb]nkHl002f?:gk]S`30017ool00;;oo`<000[oo`80000D]Sbf
6kHl]Q^f?;HK]Sbf6kHl002^?:gL[Sb]g:hl[Mb^?:gL002]g0800004[Sb^70000016ool00;3oo`80
00_oo`80000D[O^f?:gk]Sb]nkHl[O^f?:gk]Sb]nkHl002f?:gk]Sb]nkHl[O^f?0800004[O^f?:gk
]S`20016ool00:goo`<000coo`0E002f?;HK]Sbf6kHl]Q^f?;HK]Sbf6kHl]Q^f?;HK]S`00:hl[Mb^
?:gL00<00006[Qb^?:hL[Sb^7:hl0P00AOoo002[ool2000=ool200004khl002f?:gk]Sb]nkHl[O^f
?:gk]Sb]nkHl[O^f?:gk002]nkHl0080000:[O^f?000]Sb]nkHl[O^f?:gk]S`20014ool00:Soo`<0
00goo`80000B]Q^f?;HK]S/00;Hl]Q^f?;HK]Sbf6kHl]Q^f?;HK]Sbf6kHl0`0000j^?:hL[Sb^7000
[Qb^?:hL[Sb^7:hl[Qb^?000A?oo002Uool3000?ool04`00]Sbf>khl]S^f?;Hk_S`00;Hl[O^f?:gk
]Sb]nkHl[O^f?:gk0080000@]Sb^>`00[O^f?:gk]S`00;Hl[O^f?:gk]Sb]nkHl[O/20013ool00:?o
o`<000ooo`80000A]S^f6kHl]Q^f>kHK]Sbf6`00]Q^f?;HK]Sbf6kHl]Q^f?00200004[HK]Sbf7;Hl
002^?:hL[Sb^7000[Qb^?:hL[Sb^7:hl[Qb^?0<004;oo`00Oooo0`000_oo00<00?ooool06Ooo0`00
4?oo0P00016f>kHl]S^n?;Hk]Sbf>khl]S^f?;Hk002]nkHl[O^f?:gk0080000B]Sb^>kHl[S^f?:hk
]S`00;Hl[O^f?000]Sb]nkHl[O^f?:gk0P0000>f?:gk00001ooo0`000ooo00<00?ooool0<_oo0020
ool01P00ooooo`00ool001Soo`8001;oo`0B002f?;HK]S^f6kHl]Q^f>kHK]Sbf6kHk]Q^f?;HK002f
6kHl0P0001:f7;Hl]Q^f?;HL]Sbf6kHl]Qbf?000[Sb^7000[Qb^?:hL[S`200001:hL[Sb^7:hl0P00
1_oo00<00?ooool00_oo00<00?oo0000<ooo001nool400001?oo003oo`005Ooo0`004_oo0P00012n
?000]Sbf>khl]S^f?;Hk_Sbf>kHl]S^n?;Hk]Sbf>`80000B]Sb^>kHl[S^f?:hk]Sb^>kHl[S^f?:hk
]S`00;Hl002f?:gk0P0000Nf?:gk]Sb]nkHl[O^f?0020006ool00`00ooooo`03ool00`00ooooo`0a
ool007koo`03003oo`0000;oo`03003oo`0001?oo`800003ool00?oo013oo`80000@]Q^n>kHK002f
6kHl]Q^f>kHK]Sbf6kHk]Q^f?;HK]S/200004KHK002f7;Hl]Q^f?;HL]Sbf6kHl]Qbf?;HK]Sbf7000
[Q`00`0000^^7:hl[Qb^?:hL[Sb^7:hl[Qb^?00000Koo`04003oooooool2000dool007ooo`8000;o
o`03003oo`00013oo`<001?oo`80000@_S^f>khl]S^n>kHk002f>kHl]S^n?;Hk]Sbf>khl]S/20000
4[hl]S^f?000]Sb^>kHl[S^f?:hk]Sb^>kHl[S^f?:hk]Sb^>`80000>]Sb]nkHl[O^f?:gk]Sb]nkHl
[O^f?:gk]S`000Coo`03003oo`0000;oo`03003ooooo03?oo`00P?oo00D00?ooooooo`0000koo`<0
01Coo`80000@]Q^f>kHK_S^f6kHk]Q^n>kHK002f6kHl]Q^f>kHK]S`200004[HK]Sbf6kHk]Q^f?000
]Sbf7;Hl]Q^f?;HL]Sbf6kHl]Qbf?080000?]Q`00:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL0080
00Coo`04003oooooool3000cool0097oo`8001Goo`80000@_Sbf>khk]S^n?;Hk_S^f>khl]S^n>kHk
002f>kHl]S/200004[Hl]S^n?;Hk]Sbf>khl]S^f?000]Sb^>kHl[S^f?:hk]Sb^>`80000A]Sb^>kHl
002f?:gk]Sb]nkHl[O^f?:gk]Sb]nkHl[O^f?002000nool008koo`<00003ool00?oo01?oo`0A002f
6khk]Q^f>kHK_S^f6kHk]Q^n>kHK]S^f6khk002f>`0200004[HK]S^f6kHl]Q^f>kHK]Sbf6kHk]Q/0
0;HK]Sbf7;Hl]Q^f?080000A]Q^f?;HL]Sbf6kHl002^?:hL[Sb^7:hl[Qb^?:hL[Sb^700200000jhl
[Q`0000mool008coo`8001Ooo`80000S]OX00;Hk_S^f>khl]S^n>kHk_Sbf>khk]S^n?;Hk_S/00;hl
]S^f?;Hk_Sbf>kHl]S^n?;Hk]Sbf>khl]S/00:hk]Sb^>`0200002;Hl[S^f?:hk]Sb^>kHl[S/20000
1kHl[O^f?:gk]Sb]nkHl00800004[O^f?:gk]S`2000lool008Woo`<001Ooo`80000@]S^f6khk]Q/0
0;HK_S^f6kHk]Q^n>kHK]S^f6khk]Q/200004Khk002f>kHK]Sbf6kHk]Q^f?;HK]S^f6kHl]Q^f>`00
]S`00P00016f7;Hl]Q^f?;HL]Sbf6kHl]Qbf?000]S`00:hl[Qb^?:hL00800008[Sb^7:hl[Qb^?:hL
[S`003coo`00Qooo0P006?oo0P00012enkhk]OZn>kGk_S^enP00]S^n>kHk_Sbf>khk]S^n?080000T
]S^n>kHk_S/00;hl]S^f?;Hk_Sbf>kHl]S^n?;Hk]Sbf>khl002f?:hk]Sb^>kHl[S^f?:hk]Sb^>kHl
[S/00:hk002]nkHl0P0000V]nkHl[O^f?:gk]Sb]nkHl[O/00P00>ooo0024ool30002ool00`00oooo
o`0Cool200009;hk]Q^f>kHK_S^f6kHk]Q^n>`00]S^f6khk]Q^f>kHK_S/00;hk]Q^n>kHK_S^f6khk
002f>kHK]Sbf6kHk]Q^f?;HK]S^f6`80000@]S/00;Hl]Q^f?;HL]Sbf6kHl]Qbf?;HK]S`00;Hl]Q/2
00003:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^708003[oo`00POoo0`006Ooo0P00016en[hk]O^n>kGj
_S^enkhk]OZn>kGk_S/00;hl]S^n>kHk0080000A_S^f>khk]S^n>kHk_S^f>`00]S^n?;Hk]Sbf>khl
]S^f?00200003kHk_Sbf>`00[S^f?:hk]Sb^>kHl[S^f?:hk]Sb^>`0300003Zhk002]nkHl[O^f?:gk
]Sb]nkHl[O^f?:gk]S`2000jool007ooo`8001_oo`0B002f>kHK_S^f6kHk]Q^n>kHK]S^f6khk]Q^f
>kHK_S/00;Hk0P00016f6khk]Q^n>kHK_S^f6khk]Q^n>kHK002f6kHk]Q^f?;HK0080000@]S^f6kHk
]Q^f>kHK002f7;Hl]Q^f?;HL]Sbf6kHl]Q`200004KHl]Qbf?000[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^
?:hL[S`00P00>Ooo001lool300000ooo003oo`0Hool200008kHk002n>kGk_S^en[hk]O^n>kGj_S^e
nkhk]OZn>kGk_S/00;hk]S^n>kHk_S^f>khk]S^n>kHk_S^f>khk]S/00;Hk_S`00P00012f>khl]S^n
?;Hk_Sbf>khl]S/00:hk]Sb^>kHl[S^f?080000B]S/00:hk]Sbf>kHl002f?:gk]Sb]nkHl[O^f?:gk
]Sb]nkHl0P0000?oo`00ool0=ooo001jool2000Lool200004KGK]O^efkGk002f>kHK_S^f6kHk]Q^n
>kHK]S^f6khk]Q/00P00012n>`00_S^f6khk]Q^n>kHK_S^f6khk]Q^n>kHK_S^f6`80000@]S^f6kHk
]Q^f>kHK]S^f6kHk]Q^f>kHK002f7;Hl]Q/200004[Hl]Q^f?000]Sbf6kHl]Qbf?000[Sb^7:hl[Qb^
?:hL[Sb^70800004[Sb^7000000hool007Ooo`<001goo`0T002n>kGk]S^enkhk]O/00;Gj_S^enkhk
]OZn>kGk_S^en[hk]O/00;Gj_S^en`00]S^n>kHk_S^f>khk]S^n>kHk_S^f>khk0P00012f>`00]S^n
?;Hk_Sbf>khl]S^n?;Hk_Sbf>khl002f?080000A[S^f?;Hk]Sb^>`00]S^f?:hk]Sbf>kHl002f?:gk
]Sb]n`0300001Jgk]Sb]o;Hl[O/00P00=ooo001Aool20004ool00`00ooooo`0Kool3000Mool20000
4KGk]M^enkGK]O^efkGk]M/00;HK]S^f6khk]Q^f>kHK_S/00P0003Bf6khk]Q^n>kHK002f6khk]Q^n
>kHK_S^f6khk]Q^n>`00_S^f6khk002f>kHK]S^f6kHk]Q^f>kHK]S^f6kHk]Q^f>`00]Sbf7;Hl]Q^f
?;HL]S`00;Hl]Qbf?;HK]Sbf7000[Qb^?080000:[Qb^?:hL[Sb^7:hl[Qb^?:hL000gool005?oo`06
003ooooo003oo`006Ooo0`007_oo0P00016enkhk]O^f>kGk_S^enkHk]O^n>kGk002en[hk]O^n>kGj
0080000@_S^en[hk]O^n>kGj_S^en`00]S^n>kHk_S^f>khk]S/200004;hk]S^n>kHk_S/00;hl]S^n
?;Hk_Sbf>khl]S^n?;Hk0P0000nn?000]Sbf>kHl[S^f?;Hk002^>kHl]S^f?:hk]S`00`0000^f?:gl
]Sb]nkHl[Obf?:gk]Sb]o;Hl008003Koo`00D_oo00L00?ooooooo`00ool0000Fool3000Pool09000
]O^efkGk]M^enkGK]O^efkGk]M^enkGK]O^ef`00]Q^f>kHK002f6khk]Q^n>kHK_S^f6khk]Q^n>`00
_S^f6khk]Q^n>`80000@_Q^n>kHK_S^n6khk]Q^n>`00]S^f6kHk]Q^f>kHK]S/200003kHK]S^f6khk
002f?;HL]Sbf6kHl002f?;HK]Sbf700200003kHl]Q`00:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^?002
000eool005?oo`06003ooooo003oo`005?oo0P008Ooo0P00016eo000_S^enkHk]O^n>kGk]S^enkhk
]O^f>kGk_S/00;hk0080000Q]O^n>kGj_S^enkhk]OZn>kGk_S^en[hk002n>kHk_S/00;hk]S^n>kHk
_S^f>khk]S^n>kHk_S/00;hl]S^n?;Hk0080000?_Sbf>khl]S^n?;Hk_S`00;Hl]S^f?:hk002f>kHl
0080000C]S^f?:hk]S`00;Hl[O^f?:gl]Sb]nkHl[Obf?:gk]Sb]o;Hl0000=Ooo001Aool00`00ool0
0002ool00`00ool0000Aool300000ooo003oo`0Nool200008jgK[O^]fkGl002enkGK]O^efkGk]M^e
nkGK]O^efkGk]M^en`00_S^f6khk]Q^n>kHK_S^f6khk]Q^n>kHK_S^f6`00]Q/00P0000nn>khK_S^f
6khk_Q^n>kHK_S^n6khk]Q/00;HK]S/00P0000jf6khk]Q^f>kHK_S^f6kHk]Q/00;HK]Sbf7;Hl0`00
01:f?;HK]Sbf7;Hl]Q^f?000[Sb^7:hl[Qb^?:hL[Sb^7:hl[Q`200000jhl003oo`0Iool30002ool3
00001_oo003oo`00ool000;oo`8000Soo`00D_oo00<00?ooool00_oo00<00?ooool03_oo0P008_oo
0P0001:eo:gk]Ob]nkGl[O/00;Gk_S^enkHk]O^n>kGk]S^enkhk]O/200008;gk002n>kGj_S^enkhk
]OZn>kGk_S^en[hk]O^n>kGj002f>khk]S^n>kHk_S^f>khk]S^n>kHk_S^f>khk]S/200003khl]S^n
?;Hk_Sbf>khl]S^n?;Hk_Sbf>`00[S^f?00200004Zhk]Sbf>kHl[S^f?;Hk]Sb^>kHl002f?:gk]Sb]
o;Hl[O^f?0800003[O^f?:gl008000Soo`03003ooooo00;oo`03003ooooo00[oo`03003ooooo00;o
o`0:003ooooo003oo`00ool00?oo000:ool006Goo`<002;oo`80000B[M^eo:gK[O^]fkGl[M^]njgK
002efkGk]M^enkGK]O^efkGk0P00012efkGk]M^en`00_S^f6khk]Q^n>kHK_S^f6khk]Q^n>`80000>
_Q/00;hK_S^f6khk_Q^n>kHK_S^n6khk]Q^n>`80000?_Q/00;HK_S^f6kHk]Q^n>kHK]S^f6khk]Q^f
>kHK0080000B]S`00;Hl]Q^f?;HL]Sbf6kHl]Qbf?;HK]S`00:hl[Qb^?:hL0P0000J^?:hL[Sb^7:hl
[Q`20006ool00`00ool00002ool00`00ool0000;ool00`00ooooo`02ool02@00ooooo`00ool00?oo
003oo`030008ool006?oo`<0027oo`<0000T]Ob]nkGl[O^eo:gk]Ob]nkGl[O^eo:gk002enkhk]O^f
>kGk_S/00;gk]OZmnkGk_O^en[gk002n>kGj_S^enkhk]OZn>kGk0P0001nn>kGj_S^enP00]S^n>kHk
_S^f>khk]S^n>kHk_S/00;hk]S^n>`00_Sbf>khl]S^n?;Hk_Sbf>khl]S^n?00200004[Hk002^>`00
]S^f?:hk]Sbf>kHl[S^f?;Hk]Sb^>`00[Obf?0800008[Obf?:gk]Sb]o;Hl[O^f?08000Soo`06003o
oooo003oo`002ooo00@00?ooooooo`8000;oo`800004ool00?ooool30008ool0063oo`<002;oo`80
000DYObUg000[M^eo:gK[O^]fkGl[M^]njgK]Ob]fjgk[M/00;GK]O^ef`80000`]O^efkGk]M^enkGK
]O^ef`00]Q^n>kHK_S^f6khk]Q/00;hK_S^n6khk_Q^n>khK002n6khk]Q^n>khK_S^f6khk002n>khK
_S^n6khk002f>kHK_S^f6kHk]Q^n>kHK0P00016n>kHK]S/00;Hl]Q/00;HL]Sbf6kHl]Qbf?;HK]Sbf
7;Hl00<0000;[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^?0020005ool20003ool00`00ool00009ool01@00
ool00?oo00005_oo001Mool3000Rool3000059fKYObUW:GlWI/00:gk]Ob]nkGl[O^eo:gk]Ob]nkGl
[O^eo000]S/200004;Gk_O^en[gk]O^mnkGj_O^enkgk]OX00;Gk_S^en[hk0P0000nen[hk]OZn>kGj
_S^en[hk002n>kHk_S^f>khk]S/00P00022n>kHk_S^f>[hk]S^n>`00_Sbf>khl]S^n?;Hk002f>khl
]S^n?;Hk_S`00;Hl002f?;Hk]Sb^>kHl]S^f?:hk0P0000jf?:hk002]o;Hl[O^f?:gl]Sb]nkHl[Obf
?:gk0P001Ooo00<00?ooool00_oo00<00?oo00002Ooo1@000_oo00<00?ooool04Ooo001Kool2000S
ool200009jGLYObUg:GlYMbUo:GLYO`00:gk[M^eo:gK[O^]fkGl[M^]njgK]Ob]fjgk002enkGK]O^e
fkGk]M^enkGK]O^efkGk]M^enkGK002f6`0200007khk_Q^n>khK_S^n6khk_Q^n>khK_S/00;hk_Q^n
>kHK002n6khk_Q^n>khK_S^n6khk_Q^n>`00]S^f6khk00800008]Q^n>kHK]S^f6khk]Q^f>`800006
]Q^f?;HL]Sbf6kHl0P00012f6kHl]Qbf?000[Sb^7:hl[Qb^?:hL[Sb^7:hl[Qb^?0@000?oo`<000?o
o`03003ooooo02?oo`00F?oo0`000_oo00<00?ooool07?oo100001JUo:FLYObMVjGlYIbUo9fKYObU
W:Gl002eo:gk]Ob]nkGl[O^eo:gk]Ob]n`80000Q]O`00;gk]OZmnkGk_O^en[gk]O^mnkGj_O^enkgk
]OX00;Gj_S^en[hk]OZn>kGj_S^en[hk]OZn>kGj_S/00;hk0080000=]SZn>kHk_S^f>[hk]S^n>kHj
_S^f>`00]S/00P00012n?;Hk_Sbf>khl]S^n?;Hk_Sbf>khl002f?:hk]Sbf>`80000@]Sbf>kHl[S^f
?;Hk]S`00;Hl[Obf?:gk]Sb]o;Hl[O/200001:hl[O/00000;ooo001Fool2000Oool5000069FMUKfE
W@00YMbUo:GLYObUg:GlYMbUo:GLYObUg:Gl002]njgK]Ob]fjgk[M^eo080000@[M^enjgK[O/00;Gk
]M^enkGK]O^efkGk]M^enkGK]O/20000<;GK002n6khk_Q^n>khK_S^n6khk_Q^n>khK_S^n6khk002n
>khK_S^n6khk_Q^n>khK_S^n6khk_Q^n>khK002f6kHk]Q^n>kHK]S^f6khk]Q^f>kHK_S^f6`00]Qbf
?080000?]Qbf?;HK]Sbf7;Hl]Q^f?;HL]S`00:hl[Qb^?:hL00<00006[Qb^?:hL[Sb^7000;ooo001C
ool3000Jool700006iFLUKf=W9FmUIbE_HfLUKfEW000WI^Uo:FLYObMVjGlYIbUo9fKYObUW:Gl002e
o:gk]Ob]n`0200004;Gl[O^eo:gk]Ob]nkGl002mnkGj_O^enkgk]OZmnkGk0P00012mnkGj_O^enP00
]OZn>kGj_S^en[hk]OZn>kGj_S^enP80000=_S/00;hk]S^n>kHj_S^f>khk]SZn>kHk_S/00P0000jn
>`00]S^n?;Hk_Sbf>khl]S^n?;Hk_Sbf>khl0`0000nf?:hk]Sbf>kHl[S^f?;Hk]Sb^>kHl]S/00:gk
]S`00P0000Z]nkHl[Ob^?:gk]Sb]o:hl[O/002koo`00DOoo0P0000?oo`00ool04?oo2P00021mGHEm
OEf5OGeM002EWIFmUIfE_IFMUKfEWIFmUIfE_IFM002Ug:GlYMbUo:GLYObUg:GlYMbUo:GL002]fjgk
0P0002:]fjgk[M^enjgK[O^]fkGk[M/00;GK]O^efkGk]M^enkGK002efkgk]M^enkGK_O^ef`00_Q^n
>khK_S^n6khk_Q^n>`80000=_QZn>khK_S/00;hk_Q^n>khK_S^n6khk_Q/00P0000nn>khK_S/00;hk
]Q^f>kHK_S^f6kHk]Q^n>kHK]S/00P0000nf6`00]Qbf?;HK]Sbf7;Hl]Q^f?;HL]Sbf6kHl]Q`00P00
00^^?:hL[Sb^7:hl[Qb^?:hL[Sb^7:hl008002goo`00C_oo0`003?oo2@0002MmOWEMOGieGGen0025
_WeMQKimGHFnOEf5_WeMQKimG@00SIbE_IFLUKf=W9FmUIbE_HfLUKd00:GlWI^Uo:FLYObMVjGlYIbU
o9fKYO`00`00016eo:gk]Ob]nkGl[O^eo:gk]Ob]nkGl[O/00;Gk_O^en[gk0080000Q]OZmnkGj_O^e
n[gk]OZmn`00_S^en[hk]OZn>kGj_S/00;hk_OZn>kGj_S^mn[hk002n>kHk_S^f>[hk]S/00;Hj00>n
>`0;]SZn>`00_Sbf>khl]S^n?;Hk_Sbf>`0200003khl002n?;Hk002f>kHl[S^f?;Hk]Sb^>kHl]S^f
?00200003Zhk002]nkHl[Ob^?:gk]Sb]o:hl[O^f?:gl[S`2000/ool004_oo`<000Ooo`P0000]OKim
GGfnOEem_P00OGieGGEnMEemOWEMMGieGGen0025OGeMQGemGHEmOEf5OGeMQGemG@00UIfE_IFMUKfE
WIFmUIfE_IFMUKd00:GlYMbUo:GLYObUg:Gl00<0000BYObUW000[M^]njgK]O^]fjgk[M^enjgK[O^]
fkGk[M/00;GK0P00012enkGK_O^efkGk]M^mnkGK]O^efkgk002n>khK_S^n6`80000=_S^n6[hk_Q^n
>khJ_S^n6`00_Q^n>khK_S/00P0001:n6khk_Q^n>khK_S^n6khk002n>kHK]S^f6khk]Q/00;HK_S/2
00002kHK_S^f6`00]Qbf?;HK]Sbf7;Hl]Q/00P00012f?;HL]Sbf7000[Qb^?:hL[Sb^7:hl[Qb^?:hL
[Sb^708002coo`00BOoo10000_oo1P00036=WHfnSIf=_@00QKimGGfnOEf5_WeMOKimGHFn001mOWEM
OGieGGenMEemOWEMOGh008FnOEf5_WeMQKimGHFnOEf5_P00UKf=W9FmUIbE_HfLUKfEW9FmSIbE_@00
YObMV`0400009JGlYIbUo9fKYObUW000[O^eo:gk]Ob]nkGl[O^eo:gk]Ob]nkGl[O/00;Gj_O^en[gk
]OZmnkGj_O^en[gk]OZmnkGj_O/00;hk0080000=]OZn>kgj_S^en[hk_OZn>kGj_S^mnP00]SX00P00
00>n>kHj_S/00[hk00Zf>[hk_S^n>kHj_S/00;hl]S^n?0D0000;_Sbf>`00]S^n?000]Sbf>kHl[S^f
?00200004:hk]Sb^>kHl[S^f?:hk002]nkHl[Ob^?:gk]Sb]o:hl0P0000>]o:hl0000:ooo0017ool2
0003ool300005IgmWMd008fMSKf=WHfmSIf=_HfMSKd007fnOEem_WeMOKimGGfnOEem_P02000077EM
MGieGGenMEeeOWEMOGh008EmOEf5OGeMQGemGHEmOEf5O@00UKfEWIFmUIfE_IFMUKfEWIFm100001JU
W:GlYIbUo:FLYObUW:GlYIbUo:FL002]fjgk[M^enjgK[O^]fkGk[M^]n`80000_[M/00;GK_O^efkGk
]M^mnkGK]O^efkgk]M^enkGK_O/00;hk_Q^n>khJ_S^n6khk_QZn>khK_S^n6[hk_Q/00;hK_S^n6khk
_Q^n>khK_S^n6khk_Q^n>khK002f6`0400003;hk]Q^n>kHK_S/00;hk]Q^n>`00]Sbf7080000?]Sbf
7;Hl]Qbf?;HL]Sbf7;Hl002^?:hL[Sb^7:hl00<00005[Sb^7:hl[Q`0000[ool004Ooo`D0000?WOfE
W9gmUIbMoIFL002=WHfnSIf=_HfMSKj=WHfm0080000POEem_WeMQKimGGfnOEf5_WeM001eGGenMEem
OWEMOGieGGen0025_WeMQKimGHFnOEf5_WeMQKh009FmSIbE_@D0000HUKf=W9Fm002Uo9fKYObUW:Gl
WI^Uo:FLYObMVjGl002eo:gk]Ob]nkGl[O^eo:gk0P00012eo:gk]O^]n`00]OZmnkGj_O^en[gk]OZm
nkGj_O^enP80000=_O/00;hk_OZn>kGj_S^mn[hk]OZn>kgj_S/00P0000>mnP00]SX00khk00Ff>[hk
_S^n>kHj00>n>`<0000=_Sbf>khl]S^n?;Hk_Sbf>khl002n?;Hk_S`00P0000n^>kHl[S^f?:hk]Sb^
>kHl[S^f?:hk]S`00:hl[O/00P0000V^?:gl[Sb]o:hl[Ob^?:gl0000:_oo0017ool20000;IgmWMfM
oIGLWOfMgIgmUMbMoIgM002=WHfmSIf=_HfMSKf=WHfmSId007eMOKimGGfnOEem_WeMOKimG@00MEee
OWEMOGieGGEnMEemOP00QGemGHEmOEf5O@0700006iFmSIfE_HfMUKf=WIFmSIfE_@00YObUW:GlYIbU
o:FLYObUW:GlYIbUo000]O^]fjgk[M^en`0200004:gK]O^]fkGk[M^enjgK002efkgk]M^enkGK_O^e
fkGk0P0001fef[gk]M/00;hJ_S^n6khk_QZn>khK_S^n6[hk002n>khJ_S/00;hk_Q^n>khK_S^n6khk
_Q^n>khK00<0000<_Q/00;HK_S^f6khk]Q^n>kHK_S^f6khk0`0000nn>`00]Sbf7;Hl]Qbf?;HL]Sbf
7;Hl]Qbf?;HL]S`00P0000b^7:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL000Yool0047oo`03003ooooo00?o
o`80000KUIbMoIFLWOfEW9gmUIbMoIFLWOd008fmSIf=_XfMSKf=WHfnSIf=_HfM001mGGfnOEf5_WeM
0180000POGimGGenOEemOP00UKf=W9FmSIbE_HfLUKf=W9FmSIbE_@00YObMVjGlYIbUo9fKYObUW:Gl
WI^Uo000]Ob]n`80000Z]O^]nkGl[O^enjgk]Ob]nkGk002mnkGj_O^en[gk]OZmn`00_O^en[gk]OZm
nkGj002en[hk_OZn>kGj_S^mn[hk0036>kgj_S^mn/Hk002n>kHj0khk00>f>P0000000P0000g6>khj
_S^n>P00]S^n?;Hk_Sbf>khl]S^n?00300003[hl]S^n?000]Sb^>kHl[S^f?:hk]Sb^>kHl[S/20000
3[Hl002^?:gl[Sb]o:hl[Ob^?:gl[Sb]o:hl000Yool0043oo`03003oo`0000?oo`80000Eool009GL
WOfMgIgmUMbMoIgMWOfEg9gm002=_HfMSKf=WHfmSIf=_HfM00L0000_OEem_WeMOKimG@00MEeeOWEN
MGieGGEnMEieOP00OGemGGenOEemOGeMOGimGGem002E_HfMUKf=WIFmSIfE_HfMUKf=W@00YIbUo:FL
YObUW:GlYIbUo:FLYObUW00300004JgK]O^]fkGk[M^enjgK]O^]fkGk[M^en`00]O^efkgk]M/00P00
00jmnkGJ_O^efkgk]MZmnkGK002n6[hk_Q^n>khJ0P0000Zn>khJ_S^n6[hk_QZn>`00_S^n6`<0000P
_Q/00;hK_S^n6khk_Q^n>khK002f6khk]Q^n>kHK_S/00;hk_Q/00;HK_S^n6khk002f?;HL]Sbf7;Hl
]Qbf?080000?]Qbf?;HL002^7:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL008002Soo`00@?oo00<00?oo0000
0ooo00@00?ooooooo`80000=WOfEW9gmUIbMoIFLWOfEW9gm002=_HfMSKh0100003>=WHfmSId007eM
OKieGGfnOEem_WEMOKimG@00KEeeOWEMMGi]GGEnMEeeOP00OGimGGenOEemOWeMOGimGGen002E_HfL
UKf=W9FmSIbE_HfLUKf=W000YIbUo9fKYObUW:GlWI/00`0001:MVjGl002enjgk]Ob]nkGk[O^eo:gk
]O^]nkGl[O^en`00_O/200006KGj_O^en[gk]OZmnkGj_O^en[gk]OX00;Gj_S^mnP00_O[6>kgj_S^m
n/Hk_OZn>kgj00<0000A]SZn>`00002n>/Hk_SZn>khjaS^n>[hk002n?;Hk_Sbf>`0200003[hl]S^n
?;Hk002f>khl]S/00:hk]Sb^>kHl[S/200003kHl[S^f?:hk]Sb^>`00[Ob^?:gl[Sb]o:hl[Ob^?002
00000jGl0000000Wool0043oo`03003oo`0000?oo`8000Coo`09002MoIgMWOfEg9gmWMfMoIGL00@0
000cSKf=WHfmSIf=_HfMSKf=W@00OEem_WeMOKimGGfnOEem_WeM001eGGEnMEieOWEMMGieGWEn001m
OGeMOGimGGemOEemOWeM002=WIFmSIfE_HfMUKf=WIFmSIfE_HfM002UW:Gl00@0000TYIbU_:FLYKbU
W:Fl002enjgK]O^]fkGk[M^enjgK]O^]fkGk[M^en`00_O^efkgk]MZmnkGK_O^ef[gk]M^mnkGJ_O/0
0;hk0P0000Nn6[hk_QZn>khJ_S^n6P0300000khJ002n6`0200003Khk_Q^n>khK_S^n6khk_Q^n>khK
_S/00;hk0080000>]Q^n>khK_S^f6khk_Q/00;HK_S^n6`00]Qbf?080000>]Qbf?;HL]Sbf7;Hl]Qbf
?;HL002^7:hl[Qb^?0<00005[Sb^7:hl[Q`0000Wool0043oo`03003oo`0000?oo`03003ooooo00Co
o`04002MoIFLWOd40000<iFLWOd008fmSIfE_XfMSKf=WIFnSIf=_HfM001mGGfnMEem_WeMOKieGGfn
OEd006eMMGieGGEnKEeeOWEMMGh007enOEemOWeMOGimGGenOEd008fLUKf=W9FmSIbE_HfLUKf=W004
00005ZGlWI^Uo9fLYObMVjGlWIbUo9fKYO`00;Gk[O^eo:gk]O^]nkGl[O^enjgk0P0001Jen`00_O^e
n[gk]OZmnkGj_O^en[gk]OZmnkGj_O/00;hk_O[6>kgj_S^mnP<0000S_O[6>kgj_S^mnP00_SZn>khj
aS^n>[hk_S[6>khj_S^n>/Hk_SZn>`00_Sbf>khl]S^n?;Hk_Sbf>khl]S/00;Hk_Sbf>`0200003[Hl
[S^f?:hk]Sb^>kHl[S^f?:hk]S`00:hl[O`200002Jhl[Ob^?:Gl[Sb]o:hlYO`0000Vool0047oo`03
003ooooo00;oo`8000Koo`<0000bWOfMg9gmWMfMoIgLWOd008fmSIf=_HfMSKf=WHfmSIf=_HfM001m
GGfnOEem_WeMOKimGGfnOEd007EMMGieGWEnMEeeOWENMGh007emOEemOWeMOGemGGenOEd008fMUKf=
W@D0000HSIf=_HfM002UW:FlYIbU_:FLYKbUW:FlYIbU_:FL002]fkGk[M^enjgK]O^]fkGk0P0000n]
fkGk[M/00;GJ_O^efkgk]MZmnkGK_O^ef[gk]M/00P0000BmnP00_S^n6P<00006_QZn>khJ_S^n6[hk
0P0000fn6P00_Q^n>khK_S^n6khk_Q^n>khK_S^n6`0200003Khk002n>khK_S^f6khk_Q^n>kHK_S/0
0;hk0080000>_Q/00;HL]Sbf7;Hl]Qbf?;HL]Sbf7;Hl]Qbf?080000:[Qb^?:hL[Sb^7:hl[Qb^?:hL
[S`20007ool00`00ooooo`02ool00`00ooooo`0Fool004Koo`03003ooooo00Koo`0:002MoIfLWOfE
W9gmWIbMoIFLWOd200003hfMUKj=WHfmSIfE_XfMSKf=W@00OEem_WEMOKimG@0I00006hfLUKf=W8fm
SIbE_HfLSKf=W000WIbUo9fKYObMW:GlWI^Uo9fLYObMV`00[O^enjgk]Ob]n`0200003kGk[O^enjgk
]O^]n`00]OZmnkGj_O^en[gk]OZmn`0200000kGj_O^enP0300005[gjaS^mn[hk_O[6>kgj_S/00<Hk
_S[6>khj002n>[hk_S[6>khj_S^n>/Hk0P0000fn>/Hk_S[6>`00_Sbf>khl]S^n?;Hk_Sbf>`020000
3[hl]S^n?000]Sb^>kHl[S^f?:hk]Sb^>kHl[S/200003[Hl002^?:gl[SbUo:hl[Ob^?:Gl[Sb]o:hl
0007ool01`00oooooooo003oo`0001Ooo`00AOoo00<00?ooool02?oo01@009gmWMfMoIgLWOfMgIgm
WMbMoIgM002=WHfmSIf=_HfMSKf=WHfm1P00039mGWenOEemOWeN001UGFenIEi]OVEMKGiUGVen001e
OGEMOGieGGEmMEemOWEM002=WHfmSIf=_HfMSKf=WHfmSIf=_HfM002UW:FlYIbU_:FLYKbUW:FlYIbU
_:FL002]fkGk0P0001>]fkGk[M^enjgK]O^]fkGk[M/00;GJ_O^efkgk]MZmn`00_O^mfP030000=[gJ
002n6[hk_QZn>khJ_S^n6[hk0036>khJ_SZn6/Hk_QX00;hK_S^n6khk_Q^n>`00_S^n6khk_Q^n>khK
_S/00;hk_Q^n>kHK_S^n6`00]Q^n>`00_Sbf6khk002f?;HL]Sbf7;Hl]Qbf?080000?[Qbf?;HL002^
7:hl[Qb^?:hL[Sb^7:hl[Qb^?:hL008000Koo`03003ooooo00?oo`03003ooooo01Goo`00AOoo0`00
2Ooo00l009gmWIbMoIFLWOfMW9gmUIbMoIfL002=WIFnSId0100003FE_HfM001eGGfnMEem_WEMOKie
GGfnMEd006eMMGi]GGEnKEeeOVeMMGh007enMEemOWEMOGieGGenMEd008fLSKf=W9FmSIb=_HfLUKf=
W8fm002Uo9fLYObMVjGlWIbUo9fKYObMW:Gl00<0000@]O^]nkGk[O^enjgk]O^]nkGk[O^enjgk002e
n[gk]OX200003[gk00000;Gj_O^en[gk]OX00;gj_S^mn/Hk_OX200003<Hk_S[6>khjaS^n>/Hk0036
>khj_S^n>P80000=aS^n>/Hk_S[6>khjaS^n>P00]S^n?;Hk_S`00P0000ff>khl]S^n?000_Sbf>khl
002f?:hk]Sb^>`0200003kHl[Sbf?:hk]Sb^?000YOb^?:gl[SbUo:hl[Ob^?00200000jGl00000006
ool00`00ooooo`02000Hool004Goo`03003ooooo00[oo`09002MoIgMWOfMg9gmWMfMoIgL00D0000f
SIf=_HfMSKf=WHfmSId007eNOGimGGenOEimOWeMOGimGP00IEe]OVENKGiUGFenIEi]OP00MGeeGGen
MEeeOGEMOGieG@00SIf=_HfMSKf=WHfmSIf=_HfMSKd00:FlYIbU_:FLYKbUW:Fl0`00016U_9fL002]
fkGk[M^enjgK]O^]fkGk[M^enjgK]O/00;gk00D0000I_OZmf[gk_MZmn[gJ_O^mfP00_QZn>khJ002n
6/Hk_QZn>[hJaS^n6[hj_Q[6>`00_S/00P0000fn6khk_Q^n>khK_S^n6khk_Q^n>khK002f6`020000
3Khl]Q^n>khK_Sbf6`00_Q^n?;HK002f7;Hl0080000>]Qbf?:hL]Sbf7;Hl[Qbf?;HL002^7:hl[Qb^
?0<00004[Sb]g:hl[M`20003ool00`00ool00002ool00`00ooooo`0Gool003[oo`<000?oo`03003o
oooo00;oo`8000coo`04002MoIfLWOd400003IglWOfMo000SIfE_XfMUKf=WIFnSIfE_HfM0080000X
OKieGGfnMEem_WEMOKieG@00KEeeOVeMMGi]GGEnKEd007EMOGieGGenMEemOWEMOGh009FmSIb=_HfL
UKf=W8fmSIbE_HfLSKd00:GlWI`400004jGlWI^Uo9fLYO`00;Gk[O^enjgk]O^]nkGk[O^enjgk]O^]
nkGk00<0000=_O^en[gk]OZmnkGj_O^en[gk]OZmn`00aS/00P0002Vn>/Hk_S[6>khjaS^n>/Hk_S[6
>khjaS/00<Hk_S[6>khjaS^n>/Hk_S[6>khjaS^n>/Hk_SX00;Hk_Sbf>khl]S^n?;Hk_Sbf>`00]S^n
?;Hk0080000>]Sb^>kHl[Sbf?:hk]Sb^?;Hl[S^f?000[SbUo0800009[SbUo:hmYOb^?:Gl[SfUo000
00?oo`<000;oo`<001Ooo`00>_oo00<00?ooool00_oo00<00?oo00000ooo00<00?ooool03?oo0`00
03NMoIgLWOfMg9gmWMbMoIgL002=WHfmSIf=_HfMSKf=WHfmSIf=_@00OGimGGenOEimOWeMOGimGP00
IEe]OVENKGiUGFenIEh007EMMGeeGGenMEeeOGEMOGh008fmSIf=_HfMSKf=WHfmSIf=_@0400005:FL
YKbMW:FlYIbU_9fLYKbUW:Fl002enjgK]O^]fkGk[M^enjgK]O/300007;Gk002mnkgJ_OZmf[gk_MZm
n[gJ_O^mf[gj_MZmn`00_SZn6/Hk_QZn>[hJaS^n6[hj_Q[6>khJ0P0000g6>P00_S^n6khk_Q^n>khK
_S^n6khk_Q^n>`0200002khK002f6khk_Q^n?;HK_S^n6khl]Q/00`0000ff6`00]Qbf?:hL]Sbf7;Hl
[Qbf?;HL]Sb^700300002ZgL[Sb]g:hl[Mb^?:gL[Sb]g:hl0P008Ooo000kool01`00oooooooo003o
o`0000?oo`03003ooooo00goo`0;002MoIglWOfMo9gmWObMoIglWOfMo00200003iFnSIfE_HfMUKj=
WIFmSIfE_P00OKieGGfnMEem_P08000046eMMGi]G@00MEemOWEMOGieGGenMEemOP00UKf=W8fm1@00
01F=_HEMSKd00:GlWIbUo9fKYObMW:GlWI^Uo9fLYO`00;Gk[O^enjgk]O/0100000n]nkGk[OZen`00
_O^en[gk]OZmnkGj_O^en[gk]OX00P0001Zmn`00aS^n>/Hk_S[6>khjaS^n>/Hk_SX00;hjaS^n>/Hk
0036>khjaS^n>/Hk_S[6>khj0P0000c6>khjaS^n>P00]S^n?;Hk_Sbf>khl]S/300003;Hk_Wbf>`00
[Sbf?:hk]Sb^?;Hl[S^f?080000?[Sbf?000[SbUo:hmYOb^?:Gl[SfUo:hlYOb^?@00027oo`00>ooo
00L00?ooooooo`00ool00002ool2000@ool04P00WOfMg9gmWMbMoIgLWOfMg9gmWMbMo@00SKf=WHfm
SIf=_@T00008OGimGGenOEh006DNKGiU7Q00000GSKf5GHfmSEf=_HEMSKf=GHfm002U_:FLYKbMW:Fl
YIbU_9fLYKbUW:Fl002en`050000>KGk]M^enkGK]O^efkGk002mnkgJ_OZmf[gk_MZmn[gJ002mf[gj
_MZmnP00_SZn6/Hk_QZn>[hJaS^n6P00aQ[6>[hJaS[66/Hj002n>khK_S^n6khk_Q/00;hJaS^n6lHk
_Q[6>`00_Sbf6khk_Q^n?00200003;hK_W`00;il_Q^nO000]Sbf7;Hl[Qbf?0<0000@[Sb^7;Hl[Q`0
0:gL[Sb]g:hl[Mb^?:gL[Sb]g:hl[M`2000Pool003[oo`03003oo`0000;oo`03003oo`0000;oo`03
003ooooo013oo`0;002MoIglWOfMo9gmWObMoIglWOfMo0060000=IGmSIfEoHfMUOd007fnMEem_WEM
OKieGGfnMEd006DMKGiU7FenIAe]OVDM001]7GEnKAeeOVdMMGi]7GEn002=_HEMSKf5G8fmQEf=_HEL
SKf5GHfm002Uo9fLYObMVjGlWIbUo9fKYO`00`0001>en`00002]n[Gk[O^enjgj]O^]nkGk[OX00;Gj
_O^en[gk]OZmn`0200003;gj_O^mn[gk_OZmn`00aS^n>/Hk_S[6>`80000<_S[6>khjaS^n>/Hk_SX0
0;hjaS^n>/Hk0P0000^n>/Hk_S[6>khjaS^n>/Hk002n?;Hk0080000<_Wbf>kil]S^nO000_Wbf>kil
002f?:hl0P00016f?:hl]Sb^?;Hl[Sbf?:hl002Uo:hlYOb^?JGl[SbUo:hm00800003YO`0000001oo
o`00>ooo00<00?ooool00_oo00D00?ooooooo`0001?oo`07002MoIgLWOfMg9gmWM`00`0003RMg9gm
002E_HfMUKf=WIFmSIfE_HfMUKd007enOEemOWeNOGimGGenOEh006DNKGiU7VenIAi]OVDN001UGGEn
IEeeOVEMMGiUGGEn002=_HeMSKf5GHfmSEf=_HEMSKf=G@00WIbU_:FLYKbMW:Fl0`00032U_0000000
0;Gk]M^enkGK]O^efkGk]M^enkGK]O^ef`00_MZmnkgJ_OX00;gj_MZmn[gJ_OZmf[gj_MX00;hJ_SZn
6/Hk0036>/HJaSZn6/HjaQ[6>[hJaS[66P00_Q/200002lHk_Q[6>khKaS^n6/Hk_Q_6>khJaS/00P00
00bf6kil_Q^nO;HK_Wbn6kil002nO;hK_W`200004:hL]Sb^7:hl[Qbf?:hL[Sb^7;Hl[Q`00:gL[Sb]
g:hl0`0000F]o:GL[ObUg00001ooo`00A?oo0P004ooo00<009gmWO`00`00012Mo:GmWObUoIglYOd0
09GmSIfEoHfMUOf=WIGmSIfEo@80000?MEem_WEMOKieGGfnMEd006DMKGiU7FenIAe]OVDM0080000E
MGi]7GEnKAeeOVdMMGh008fmQEf=_HELSKf5GHfmQEb=_HEM002MVjGl00<0000FYO`00000002U_9fL
002]n[Gk[O^enjgj]O^]nkGk[OZenjgk]O^]nP00]OX200003;gk_OZmnkgj_O^mn[gk_OZmnkgj002n
>P80000VaS^n>/Hk_S[6>khjaS^n>/Hk_S[6>khj002n>/Hk_S[6>khjaS^n>/Hk_S[6>khjaS/00<Ik
002nO;Hk_Wbf>kil]S^nO;Hk002f>`80000@_W`00;Hl[Sbf?:hl]Sb^?;Hl[Sbf?:hl]S`00:hmYO`2
00002JhmYOb^?:Gl[SfUo:hlYO`0000Nool004Coo`03003ooooo01?oo`80000iWMbMoIgLWOfMg9gm
WMbMoIgLWOd009FmSIfE_HfMUKf=WIFmSIfE_HfM001mGGenOEimOWeMOGimGP00IAi]OVDNKGiU7Ven
IAi]OP00MGiUGGEnIEeeOVEMMGh008fmSEf=_HEMSKf=GHfmQEf=_HeM0080000cYK`00000002U_9fL
YKbMW:FlWI`00;GK]O^efkGk]M^enkGK]O^efkGk]M^enkGK002mf[gj_MZmn[gJ_OZmf[gj_MZmn[gJ
_OZmfP00_Q[6>/HJaSZn6/HjaQ[6>[hJaS[66/Hj0080000;aQX00;hJaS^n6lHk_Q[6>khKaS^n6P02
00007<IkaQ[6N`00_Wbf6kil_Q^nO;HK_Wbn6`00]U^nO;iL002^7:hl[Qbf?:hL[Sb^7;Hl[Qb^?:hL
0`0000ZUg:glYMb]o:GL[ObUg:glYMb]o08001goo`00A?oo0P005Ooo01D00:GmWObUoIglYOfMo:Gm
WObUoIglYOd009GmSIfEoHfMUOf=WIGmSId0600000YeOVdMMGh008fmQEf=_HELSKf5G@H0000EYKbM
W:FlWI^U_9fLYKbMVjFlWI`00:gj]O^]nkGk[OZenjgk]O^]n[Gk0080000M[OX00;gj_O^mn[gk_OZm
nkgj_O^mn[gk_OX00;gj002n>/Hk_S[6>khjaS^n>/Hk_S[6>`00aSZn>P02aSX05@00_S[6>khjaS^n
>/Hk_SX00;hjaW^n>/Ik_S[6N`00_Wbf>kil]S^nO00200003[Hk002f>kil]S/00:hl]Sb^?;Hl[Sbf
?:hl]S`20002[S`03@00[SfUo:hlYOb^?JGl[SbUo:hmYOb^?00001goo`00@ooo00<00?ooool05_oo
010009gmWMbMoIgLWOfMg9gmWMbMoIgLWOd009FmSIfE_@@0000HUIfE_IFM001eGGfnOEim_WEMOKim
GP00IAiU?VDNICiU7VDnIAiU?P00ICiU7Fdn2P0001V5GHEmQEf5OHEM002MW:FlWIbU_9fLYKbMW:Fl
WIbU_000]O^efkGk]M^enkGK]O^ef`0200003KGk]M^en`00_OZmf[gj_MZmn[gJ_OZmf[gj0080000d
_MZmn[gJ002n6/HjaQ[6>[hJaS[66/Hj0036>/HJaS[66/HjaQX00;hJaS^n6lHk_QX00<HKaW_66/Ik
aQ_6NlHJ002n6kil]Q^nO000_WbfFkil_U`00;IK_WbnG000[Qb^?:hL]S`300004:hl[Qb^?:hL[S`0
0:glYMb]o:GL[ObUg:glYMb]o:GL0P007?oo000iool30002ool00`00ooooo`02ool00`00ooooo`0G
ool200002IglYOfMo:GmWObUoIglYOfMo004000089GmSIfEoHfMUOf=WIGmSId007EMOKieGGfnMEem
_WEM001M7FDnIAeU?UdMICiU7FDn001]?VDMKCiU7FdnIAd300006XEMQGf5GHEmQEf5OHEMQGd00:Fl
WI^U_9fLYKbMVjFlWIbU_9fKYK`00;Gk[OZenjgk]O/200006kGj]O^]n[Gk]OZen`00_O^mn[gk_OZm
nkgj_O/00<Hj_O[6>[gjaSZmnP00_S[6>khjaS^n>P0200000lHj_S[6>P02aSX01[hjaSX00<Hk_S[6
>`80000;_S[6NkhjaW^n>/Ik_S[6Nkhj002f>`0200003;il]S^nO;Hk_W`00;il]S^nO000]Sb^?080
00:^?00>]Sf^?:hl[Sbf?Jhl002Uo:hmYOb^?:Gl[SfUo0<00003YO`0000001_oo`00>_oo00H00?oo
ool00?oo0003ool2000Jool01`00WMbMoIgLWOfMg9gm0080000EWMbUo@00UKfEWIFmUIfE_IFMUKfE
WIFmUId007EMOKimGWfnMEem_WeN0080000:ICiU7VDnIAiU?VDNICh006DnIAd300006fDMKCh008Em
QEf5OHEMQGf5GHEmQEf5O@00YKbMW:FlWIbU_9fLYKbMW:FlWIbU_000]O^ef`020000@kGk]MZenkGK
]O^ef[Gk]M^en`00_OZmf[gj_MZmnP00_OZmf[gj_MZmn[gJ_OX00<Hj_Q[6>/HJ00366/HjaQ[6>/HJ
aS[66/HjaQ[6>P00aS/00<IkaQ_6NlHJaW_66lIkaQ[6NlHKaW_66P00_UbnO;IK_WbnG;il]U^nO000
_WbfFkil0080000>[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^7000YMb]o0@00006YMb]o:GLYObUg0006ooo
000hool400001?oo003oo`000ooo00<00?ooool06_oo00<009glYOd00`00022UoIglYOfMo:Gm002E
oHfMUOf=WIGmSIfEoHfMUOf=W@00MEem_WEMOKieGGfnMEem_P00ICiU7FDnGAeU?VDM0`0001]U7Fdn
IAe]?VDMKCh008EmQEf5OHEMQGf5GHEmQEf5O@00YKbMVjFlWIbU_9fKYKbMW:FlWI/00`0000n]n[Gk
]OZenjgj]O^en[Gk[OZenkGj]O/00;gk_OX00P0000_6>[gjaSZmn/Hj_O[6>[gjaSX00<Hk008000;6
>P05_S[6>/HjaSZn>P03aSX03[hjaSX00<Ik_S[6NkhjaW^n>/Ik_S[6NkhjaW/200002[ij002f>kil
]S^nO;Hk_Wbf>kil0`0000FnO000[Sb^?;Hm00>^?005]Sf^?:hl[Sbf?@0300002jgmYOb]o:Gl[OfU
o:glYOb]oJGl00006_oo0002ool500000ooo0000000300000ooo003oo`050003ool300000ooo0000
0002000Hool00`00ool00002ool00`00ool00003ool2000Lool200002JGmWMbMo9gLYOfMg9glWMbU
o@0200003iFMUKfEWIFmUIfE_IFMUKfEW@00MEem_WeNOKieG@0900006fDNICh006DnIAe]?VDMICiU
7Fdn0025OHEMQGf5GHEmQEf5OHEMQGd00:FlWIbU_9fLYKbMW0030000:ifLWK`00;Gk]MZenkGK]O^e
f[Gk]M^enkGJ]O^ef`00_MX00;gJ_OZmf[gj_MZmn[gJ_OZmf[gj_MZmnP00aS[66/HjaQ[6>/HJaS[6
6/HjaQ[6>/HJ0080000:aSX00<IkaQ[6NlHKaW_66/IkaQ/200002lIkaU_6NlIK002nG;il]U^nO;iL
_W`00`0000bnO;IL_W`00:hl[Qb^?:hL[Sb^7:hl[Q`200003Zhl[Q`00:GLYObUg:glYMbUo:GL[ObU
g:Gl0006ool50002ool00`00ooooo`02ool00`00ooooo`05ool000?oo`05003ooooo003oo`030000
2?oo003oo`00ool00?oo0002ool00`00ool00002ool00`00ool00002000Jool20002ool00`00ool0
0003ool00`00ooooo`0Lool04P00WObUoIglYOfMo:GmWObUoIglYOfMo000SIfEoHfMUOf=W@T00003
MEem_WEM00<00003GAeM?P0000P0000?KCiU7Fdn0025OHEMQGf5GHEmQEf5OHEM002MW:Fl00@0000U
WI^U_9fLYKbMV`00]OZenjgj]O^en[Gk[OZenkGj]O^]n[Gk]OX00;gjaSZmn/Hj_O[6>[gjaSZmn/Hj
_O[6>P00aOX00<Hj_SX00lHj01fn>/HjaS[6>[hj0036>LhjaSW>>P00aW^n>/Ik_S[6Nkhj0036N/Ik
_W[6NlIjaW/00;il]S^nO;Hk00800007_WbfN`00]WbnO;Ik00000jhl00>f?Jhl00000P000Zhl00jV
?:hm002]o:Gl[OfUo:glYOb]oJGl[ObUo:gm0P001_oo00L00?ooooooo`00ool00002ool00`00ool0
0006ool000?oo`03003ooooo00Coo`09003oo`00ool00?oo003oo`0000;oo`03003oo`0000;oo`05
003oooooool0000Kool01@00oooooooo00001?oo00<00?ooool07Ooo00/009gLYOfMg9glWMbUoIgL
WObMg:Gm00H0000:UIfEoIFMUOfEW@00OEem_WeNOKh200003WeNOKh005dnGAiM?UdNGCiM7Udn001M
?UdMGCh?00005JFlWIbM_9fLYKbMW9flWIbU_9fL002efkGk]MZenkGK]O^ef[Gk]M^en`0200002kGK
002mf[gj_MZmn[gJ_OZmf[gj_MX00P0001O5n[gJaOX00<HjaQ[6>/HJaS[66/HjaQX00<HJaS[66/Hj
aQX00<HKaW_66/Ik0080000:aU_6NlIKaW_6FlIkaU_6N`00_W`200003;IL_WbfG;il]U`00;IL_Wbf
G000[Qb^?080000B[Qb^?:hL[Sb^7:hl[Qb^?000[ObUg:GlYMb]o:GLYObUg:gl0P001ooo00L00?oo
ooooo`00ool00002ool00`00ool00006ool000?oo`03003ooooo00?oo`800005ool00000ool00002
ool30003ool30002ool2000Sool2000Pool200001ZGmWObUoIglYOfMo080000<YOfMo000UIfEoIFL
UOfEWIGmUIbEoIFM1000039m_WEMOKieGGfn001M?UdMGCiM7EdnGAeM?P00GCiLgEdnG=eM?UcMGCh0
08EnOEf5OGeMQGimGHEmOEd009fLYKbMVjFlWIbU_9fKYKbMW:FlWI/00;Gj]O^]n[Gk]OZenjgj0P00
01JenkGj]O^enP00_O[6>[gjaSZmn/Hj_OX00;giaOZmnLGj_OW5nP00aSZn>P?6>P800009aSW>>/Hi
cS[6>LhjaST00;hj0080000GaW_6N/Ik_W[6NlIjaW^nN/IkaW[6N`00_WbfO;il]W^nO;Il_WbfN`00
]WbnO00300000jhlYSb^?@02[S`03:Hl[Sf^?:hlYSb^?@00[ObUo:gmYOb]o0<00003[ObUo00000Ko
o`07003oooooool00?oo00000_oo00<00?oo00001_oo0003ool00`00ooooo`0<ool00`00ooooo`05
ool00`00ooooo`0Uool00`00ooooo`0Qool00`00YOfMg003000039gLYObMg:GlWM`009FMUOfEWIGm
UIfEo@@0000bOEem_WeNOKimGGfnOEim_P00GCiM7UdnGAiM?UdNGCh005dnGAeM?UdMGCiM7Edn001m
OGeMOGemGGemOEemOGeM002MW:FlWIbM_9fLYKbMW9flWIbU_9fL002efkGk]MZen`80000a]MZenkGK
]O^ef[Gk]M/00;gJ_OZmf[gj_MX00;gJaOZmf/Gj_M[5n[gJ00366/HjaQ[6>P00aS[66/HjaQ[6>/HJ
aS[66/HjaQX00<IKaW_6FlIkaU_6NlIKaW_6FlIkaU/00P0000[6N`00_WbfG;il]UbnO;IL_WbfG080
000A]WbfG000[Qb^?:hL[Sb^7:hl[Qb^?:hL[Sb^7000YMb]o00300001jGlYMbUo:GLYObUg00000Go
o`07003oooooool00?oo00000_oo00<00?oo00001_oo0002ool3000<ool20006ool2000Wool2000S
ool2000039glYOfMo:GmWObUoIglYOfMo000UIfEo@<0000dUOfEW9GmUId007EMOKieGGfnMEem_WEM
OKh005dnGAeM?UdMGCiM7Edn001M?UcMGCiLgEdnG=eM?P00QGimGHEmOEf5OWeMQGemG@00WIbU_9fK
YKbMW:FlWI^U_9fLYK`00;Gk]OX200003KGk]OZenkGj]O^en[Gk]OZen`00aSZmn/Hj0080000;_OW5
n[giaOZmnLGj_OW5n[gi0036>P0200006LhjaSW>>/HicS[6>LhjaSW>>/Hi0036>@00aW[6NkijaW_6
N/Ik_W[6NlIj0036N/ik00;6N`06002nO;Il_WbfNkil0`0000FnOKIl]WbfO00000:^?006YSb^?Jhl
[SbV?:hm0Zhl0`0000V]o:Gl[ObUo:glYOb]o:Gl[O`00P000ooo0P001?oo00<00?ooool00_oo00<0
0?ooool01Ooo0012ool00`00ooooo`0Sool02P00YObMg:GlWMbUo9gLYObMg:Gl0`0000NEoIFMUOfE
WIGmUIfEo@0?00007EdnGAiM?P00GCiM7EdnGAeM?UdM001mGGemOEemOGeMOGemGGemOEd009fLYKbM
W9flWIbU_9fLWK`0100003:efkGk]MZenkGK]O^ef[Gk]M^enkGJ]O/00;gj0035n[gJaOZmf/Gj_M[5
n[gJaOZmf/Gj_MX00<HJaS[66/HjaQ[6>/HJaS[66/HjaQX00<hIcS[66@00aU_6NlIKaW_6FlIk0P00
00W6FlIkaU_6NlIKaW/00;il]U`00P0000nfO;IL]W`00;Il]UbfO000[Sb^7:hl[Qb^?:hL[S`00`00
00j]o:GL002Ug:GlYMbUo:GLYObUg:GlYMbUo0005_oo000fool20004ool00`00ooooo`03ool00`00
ooooo`0Tool01P00YOfMo:GmWObUo@<00006YOfMo000UIfEoIFL100000nMoIFL001mGHFnOEem_WeM
QKimGGfn001M?UCMGCh02000015LgEdnG=d007eMQGimGHEmOEf5OWeMQGemG@00WIbU_9fK00@0000i
YKbMW9fl002enkGj]O^en[Gk]OZenkGj]O^en[Gk]OZen`00aOZmnLGj_OW5n[giaOZmnLGj_OW5n[gi
002mn@00aSW>>/HicS[6>LhjaSW>>/Hi0036>LhjaSW>>/Hi0036N/Ik_W[6N`00aW_6N/ik00;6N`04
aW[>NlIkaW/20003]W`01Kim]WbfO000_Wd00[Il00<00:hm[S`01000012^?:Gl[SfUo:hl002]o:Gl
[ObUo:glYOb]o:Gl[ObUo08001Goo`00=_oo00<00?oo00000_oo00<00?oo00001?oo00<00?ooool0
9Ooo00<00:Gl00000P0000BUo9gLYObMg0D0000KUIfEoIFMWOfEWIGmUId007fMOKimWGfnOIem_WfM
OKh005DnEAiM?UDMECiE7Udn001<oDcM0140000CWIbM_9fLWKbMW9flWI`00;GJ]O^efkGk]MZenkGK
]O^ef[Gk]M/00P0001NenP00aOZmf/Gj_M[5n[gJaOZmf/Gj_MX00<GIaO[5f@00aQ[6>/HJaS[66/Hj
00800009cQW>>/HIcS[>6LhjaQT00<IK0080000FaW_6FlIkaU_6NlIKaW_6FlIk0036^`00]WbfG;Il
]UbfO;IL002fG;Il]U`300004JGL[ObUg:glYMb]o:GL[ObUg:gl002Uo:GLYObUg:GlYM`00`0000>U
g00000005?oo000fool00`00ool00002ool00`00ool00003ool2000Vool300000jGmWObUo@040000
3IglYOfMo000UIbMoIFLWOfEW9gmUIbMoIFL0080000cQKimGGfnOEf5_WeMOKh005dnE=eM?UCMGCiD
gEdn001DoTcME?i<gECnC=d007DMMGie7GEnMAeeOWDMMGie7@00WIbM_9fKYKbMW9flWI^U_9fL002e
n[Gk]OZenkGj]O^en[Gk0080000T]IZenkFJ002mnLGj_OW5n[giaOZmnLGj_OT00;giaO[5nLGj_OT0
0<HicS[6>Lhj003>>/HicS[6>LhjaSW>>/HicS[6>@000/Ik00O6N/ikaW_6NlIjcW_6N`0200001Ljl
a[_>_000_Wd00kIl00>nOKIl00000P00012^?;Im002^?JGl[SbUo:hmYOb^?:Gl[SfUo000YOb]o0@0
00>Uo003[ObUo00001Coo`00=_oo0P000ooo00<00?oo00000ooo00<00?ooool08_oo0`000ooo0`00
05>Uo:GLYObUg:GlYMbUo:GL002EWIgmUIfEoIFMWOfEWIGmUIfMo@00OKimWGfnOIem_WfMOKh005Dn
EAiM?UDMECiE7Udn001<oDcMC?i<gDcmC=d007DMMGee7GEmMAeeOGDMMGd009flWIbM_9fLWKbMW9fl
WIbM_9fL002ef[Gk]M^enkGJ]O/00;Gj]IZen[FJ]OZeVP00_M[5n[gJaOZmf/Gj0080000[aMW5n/GI
aOW5fLGj0036>/HJaSX00<hjcQW>>/HIcS[>6LhjaQW>>/hI003>6@00aU_6NlIKaW_6FlIkaU/00<JK
a[_6VlJkaY/00;IL]WbfG;Il]U`00`0000j^G;Il[UbfO@00[ObUg:glYMb]o:GL[ObUg:gl0`0000^U
o:GLYObUg:GlYMbUo:GLYObUg00001?oo`00=_oo00<00?ooool00_oo00<00?oo00000ooo0P008Ooo
0P001ooo01@00:GmWObUoIglYOfMo:GmWObUoIgl002EW9gmUIbMoIFLWOfEW9gm3`00029M?UCMGCh0
05CnC=eDoTcME?i<g@00MAeeOWDMMGie7GEnMAeeOP00YKbMW9flWI^U_9fLWKbMVjFlWI`00;Gj]O^e
nP80000Y_O^eV[Gk]IZmnkFJ]O^eVP00_OW5n[giaOX00<Gj_OW5n/GiaOZmnLGjaOW5nP00cSX00<hj
aSW>>/HicS[6>LhjaSW>>/Hi003>>LijcST00002aW/03/IjcW_6N`00a[_>_<Jkc[c6^ljla[/00;Il
_Wd200003Zhl]Wf^?000[SbfOJhl002Uo:hmYOb^?:Gl[Sd300001JglYO`00:Gl[O`00jGl00J]o:Gl
YObUo:gl000Cool003Ooo`8000?oo`03003ooooo00;oo`03003ooooo01goo`<000[oo`0?002Uo:GL
YObUg:GlYMbUo:GLYObUg000UIfMoIFM00@0000;WOfMgIgm001m_WfMQKimWGfnOIf5_P0200000dcN
E?h0000600006DcnC=e<oDcM001e7GEmMAeeOGDMMGee7GEm002M_9fLWKbMW9flWIbM_9fLWK`00;Gk
0080000^]IZen[FJ]OZeV[Gj]IZen[FJ]OZeVP00_M[5nP00aOW5fLGjaMW5nLGIaO[5fLGiaMW5nP00
cS[>6LhjaQW>>/hIcS[66LhjcQT00<hIcSW>6Lhi0036NlIKaW/200002LJKa[_6VlJkaY_6^lJKa[_6
V`0200003KIl[UbfOJiL]W`00;Im[UbfO:iL002Ug:gl00<0000BYObUg:GlYMbUo:GL002Ug:GlYMbU
o:GLYObUg:GlYMbUo0004_oo0011ool00`00ooooo`0Jool3000>ool02P00YOfMo:GmWObUoIglYOfM
o:Gm100001ZEW9gmUIbMoIFLWOfEW9gm0025_WfMQKimWHFnOIf5_WfM001<gEDnC=eE?TcMECh004Bn
1000019<g@00MAeeOWDMMGie7GEnMAeeOP00YKbMW9flWI^U_9fLWK`30000>KGk]IZmnkFJ]O^eV[gk
]IZenkFJ_O^eV[Gk0035nP00aOZmnLGjaOW5n[giaO[5nLGj_OW5nP00cOT00<hjaSW>>/HicS[6>Lhj
aST00<hicW[>>MIjcSW>NP00cW/00<jla[_>_<Jkc[c6^ljla[_>_00200003<Kl002^?;Im[SbfOJhl
]Wd00;Im[SbfO@<0000:[ObUo:glYOb]o:Gl[ObUo:gl0002YO`01ZglYObUo:Gl[ObUo0<001;oo`00
1ooo0`00=ooo0P006?oo0`004_oo00L00:GlYMbUo:GLYObUg00200005ZGlYM`009gMWOfMg9gmWMfM
oIgLWOfMgIgm001m_WfMQKimWGfnOIf5_WfM0P0000YDoTcME?i<gUCn000l_CBM?;ddW@L00007MAee
OGDM002MW9flWI`0100002NM_9fLWK`00;Gj]IZen[FJ]OZeV[Gj]IZen[FJ]OZeV[Gj0035nLGIaO[5
fLGiaMW5n/GIaOW5fLGj0035nLGI00366LhjcQW>>/HIcSX00P0001?>6LhicQW>>LhIcSW>6Lhi0036
^lJKa[_6VlJkaY_6^lJKa[/00004a_`01`00[UbfO:iL]Wf^G;Il00<0000A[Sb^7000YMbUo:GLYObU
g:GlYMbUo:GLYO`00:GlYMbUo0040002ool00`00ooooo`0@ool000Soo`03003ooooo03Goo`03003o
oooo01Goo`<001Koo`03002UoIgl00<0000FWObUoJGlYObMo000UIbMoIFLWOfEW9gmUIbMoIFLWOd0
08FnOIf5_WfMQKh600003dcMECi<gEDn0014_SbM?;dlWDBn?9d006DMKCiU7@0700004ieKWKbEFifl
WE^M_9EKWK`00;Gk]IZmnkFJ]O^eV[gk]IZenkFJ0080000X_KX00<GjaOW5n[giaO[5nLGj_OW5nP00
cOW5n<giaOT00<HicS[6>Lhj003FN/hicW[>>MIjcSW>N/hieWX00=Ii003>_<Jkc[c6^ljla[/20000
2Lkla_c6o<Kkc_c6o000[SbfO@0300004:hm002^?JHl[SfV?000YOb]o:Gl[ObUo:glYOb]o:Gl1000
1_oo00<00?ooool04?oo0004ool20002ool30003ool20002ool30003ool200000ooo00000002ool0
0`00ooooo`0Nool00`00ool0000Bool3000Jool200002JGLYObUg:GlYMbUo:GLYObUg002000029gm
WMbMoIgMWOfMg9gmWMd600001HFmQIf5_XFMQKd01@0002=DoP00?;ddWCbm=9dl_CBM001U7FdmIAe]
?FDMKCeU7@00WIbM_9fLWKbMW9flWIbM_9fLWK`00;Gj]IZen[FJ]OZeV[Gj0080000Z]IZe^[FJ0035
fLGiaMW5n/GIaOW5fLGj0035nLGIaOW5fLGiaMT00<HIcSX00<hicQW>>LhIcSW>6LhicQW>>@00eWWF
FMIi0036^lJKa[_6V`002LKl0P00012^?:hL[Sb^7000[Qb^?:hL[S`00:GlYMbUo:GLYObUg0<000_o
o`03003ooooo00ooo`000ooo00H00?ooool00?oo0002ool00`00ool00002ool01000ooooo`000ooo
00H00?ooool00?oo0002ool00`00ooooo`0Nool2000@ool3000Nool01000YObMo:Gm0ZGl00ZMo:Gm
YObUo9glYOd009gmUIbMo@@0000@WObMo@00QKj5WHFnQIf5_XFMQKj5WHFn001<oTCMC?h400007CbM
?;dlWDBn?9d006DMKCiU7FdnIAe]?VDM002EFiflWE^M_9EKWKbMFiflUE/00;FJ]O^eV[gk]IX00P00
02Fm^[FJ_KZeVKfj]IX00;giaO[5nLGj_OW5nP00cOW5n<giaOW=nLGhcOT00<hj003FN/hicW[>>MIj
cSW>N/hieWX00=IicWWFNP02eWT01P00c[`00000a__>o0;6o004a__>o<Kla_`200003kkl002V?:hm
YSb^?JHl002V?:hmYSb^?@00[ObUo003000>ool00`00ooooo`0?ool000?oo`06003ooooo003oo`00
0_oo00<00?oo00001Ooo00D00?ooooooo`0000;oo`03003oo`0000;oo`03003ooooo01Coo`03003o
oooo00;oo`03003ooooo00;oo`03003ooooo00coo`<002;oo`0;002Uo:GLYObUg:GlYMbUo:GLYObU
g00400005igmWMbMoIgLWOfMg9gm0025_HFMQKj5WHFmQIf5_XFMQKd004cnC=e<oTcNC?h0100001Pd
WCbm001]?FDMKCeU7FdmIAe]?FDM002MW9flWIbM_9fLWKbMW9flWI`00;FJ]OX20000:kFJ]KZeV[Fj
]IZe^[FJ]KZeVP00aMW5nLGIaOX00<GiaMW5nLGIaOW5fLGiaMW5n@00cSW>6LhicQW>>LhIcSW>6Lhi
003FNMIIeWWFFMIieUWFN@0000S6o08000Bno@0:002^7:hl[Qb^?:hL002^7:hl[Q`3000Aool00`00
ooooo`0?ool000?oo`03003ooooo00D00003ool00000008000;oo`8000Coo`800003ool000000080
01Koo`03003oo`0000;oo`03003oo`0000?oo`8000[oo`<002Koo`800006WObUoJGlYObMo:Gm0P00
01bUo:Gm002MoIglYOfMo9gmWObUoIglWOd008FnQIf5_XFMQKj5WHFnQIf5_P00C?i4gDcnC=e<oP80
000391`000000080000@KCiU7FdnIAe]?VDMKCh009flUE^M_9eKWKbEFiflWE/400009kfj]IVm^[FJ
_KZeVKfj]IZm^[FI_KZeVP00_OW5nP00cOW5n<giaOW=nLGhcOW5nLgi003=n@00cW[>>MIjcSW>N/hi
eWX00=IicWWFNP02eWT01/iieWX00=kj003>o0;6o00Aa__>o000002no;km__bnoKkl__d00:hmYSb^
?JHl[SfV?003000Dool00`00ooooo`0?ool000?oo`04003ooooo0006ool00`00ooooo`0Uool00`00
ool00002ool00`00ool00003ool00`00ooooo`07ool2000[ool00`00YMbUo00300005JGlYMbUo:GL
YO`009gmWMbMoIgLWOfMg9gmWMbMo@00QKf5WHFnQIf5_@0800001dcNC?i<g@0071`T7A`L00H00007
KCeU7Fdm002M_9fLWK`0100003:EG9elUE`00;FJ]KZeV[Fj]IZe^[FJ]KZeV[Fj]IZe^P00aOX00<Gi
aMW5nLGIaOW5fLGiaMW5n@00cOS=f<gh003>>LhIcSW>6Lhi003FNMIIeWWFFMIieUWFN@00g[WNVMji
0P0000?6o00000002Kkm00<00:hl[Q`010005_oo00<00?ooool03ooo0004ool2000=ool00`00oooo
o`0Pool01`00oooooooo003oo`0000;oo`03003ooooo00Goo`<002koo`800005YOfUo:GlYObUo@03
YO`02ZGm002MoIglYOfMo9gmWObUoIgl1P0000R=_XfMSKj5WHfn001<oTCM1P0000LT?A`L93d005cn
E=eLoP070000;IelUE^MO9EKWGbEFiel002m^[FJ_KZeVKfj]IZm^[FI_KZeV[fj]IVm^P00cOW5n<gi
aOW=nLGhcOW5nLgi003=nLGhcOW5n<gi003>N/hieWX00=IicWWFNP02eWT05LiieWX00=kje[WNn]Ji
g_[F^@00__bnoKkl__fno;km__bnoKkl__fno0030004ool00`00ooooo`0Cool00`00ooooo`0?ool0
03Goo`03003oo`0000;oo`03003oo`0000;oo`8000?oo`<003;oo`0?002Ug:GlYMbUo:GLYObUg:Gl
YMbUo000WOfMg9gm00@0000<WMbUo@00SKf=WHfmSIf=_HfMSKf=WHfm0P0000E<gDcnC=i<oTcM00<0
000O71`T7000E?eDgECmE=eDoECME?d009elUEbMO9ELWGbEG9elUEbMO000]KZeV[Fj]IZe^[FJ]KZe
V[Fj]IX00P0002Fm^@00aOW5fLGiaMW5nLGIaOT00<ghcMS=n<gHcOS=f<gh003>>@00eWWFFMIieUWF
NMIIeWT00=jigYWN^MjIg[WNV@00gkT00007__d30008ool00`00ooooo`0Bool00`00ooooo`0?ool0
03Koo`03003ooooo00;oo`06003oooooool00?oo0`00=_oo00<00:GlYOd00jGl00BUoJGlYObUo0@0
000JYOfMo:GmWObUoIglYOd008fnSIf=_XFMSKj=WHfnQIf=_XfM0014gDcnA=e<oTCM0003V`80000K
93d005cnE=eLoUCMG?iDg@00UE^MO9EKWGbEFielUE^MO9EKWG`00;fj]IZm^[FI_KZeV[fj0080000H
]IVm^[FI0035nLgiaOS=nLGicOT00<giaOS=nLGhcOW5n<giaOS=n@00eWW>NMIj0]Ii00g>NMIj003N
n]Jig_[F^Mkje[T00=miik[ON@0200000kkm__`00002000<ool00`00ooooo`0Bool00`00ooooo`0>
ool003ooo`8003[oo`07002Ug:GlYMbUo:GLYO`00P0000bUg:Gl002UoIgLYObMg:GmWMbUo9gLYOd2
000028fMSKf=WHfmSIf=_HfMSKd300001dcnC=i<oTcM0003V`^k00<0000FE?eDgECmE=eDoECM002E
G9elUEbMO9ELWGbEG9elUEbMO000]KZeV[Fj]IX20000:kfj]IVm^KFI_KZeV@00aMW5nLGIaOT00<gh
cMS=n<gHcOS=f<ghcMS=n000cOP00=IieUWFNMIIeWWFF@00gYWN^MjIg[WNV@00gkWW^^Niik[O^NNj
008000ooo`03003ooooo01;oo`03003ooooo00koo`00@?oo00<00?ooool0>Ooo00<00:GlYOd00`00
01B]o:GlYObUo:gl002UoIglYOfMo:GmWObUoIglYOfMo000SIf=_XFM100000>EoHfM0000100000E4
g@000i/;^`>J00<0000BE=eLoUCMG?iDg@00UE^MO9EKWGbEFielUE^MO9EK002eVKfj0P0002feVKfj
]IVm^[FI_KZeVKfj]IT00<GicOT00<giaOS=nLGhcOW5n<giaOS=n@00eOS=mmGh003FNLiieW[FN@00
e[WNn]Jig_[F^@00ggWW^]miik[ONNNj00004_oo00<00?ooool04Ooo00<00?ooool03_oo0011ool2
000jool200004ZGlYMbUo:GLYObUg:GlYMbUo000YOfMg:GlWMbUoIgLYObMg0D0000;UIfE_IFMUKfE
WIFmUId004cNECi<gP0400000`^k0i/;^`0400002eCME?eDg@00UEbMO9ELWGbEG9elUE`0100002jm
^KFI_KZeVKfi]IVm^[FI_KVeVKfj0035n@00cOS=f<ghcMS=n<gHcOS=f<ghcMP00<gHcOS=e`00eUWF
NMII003NVMjigYWN^MjI003O^NNjikWW^]niikX001Coo`03003ooooo013oo`03003ooooo00koo`00
@ooo00<00?ooool0>?oo00<00:Gl[O`00jGl00V]o:GlYObUo:gl002UoIglYOd0100001>Mo:GlWO`0
08fMUOf=WIGmSIfEoHfMUOf=W@00C=eE?TcMECi<g@0300001@>J2k/003am=5`0100000>MO9EKWG`0
1000036EFiElUE/00;FI_KZeVKfj]IVm^[FI_KZeVKfj]IVm^P00cOW5n<giaOS=nLGhcOW5n<giaOP0
0<ggeOS=mmGhcOL00=Ii003F^Mkje[WNn]Jig_X00>NjggWW^]miikX0000Eool00`00ooooo`0@ool0
0`00ooooo`0>ool004Coo`03003ooooo03Soo`0:002Ug:GlYMbUo:GLYObUg:GlYM`400002:GlYMbU
o:GLYObUg:GlYM`200003YFmUIfE_IFMUKfEWIFmUId004cNECi<gUDnC=h400001P^k000lGCAM?5dd
G@@0000bUGbEG9ElUEbEO9ELUG`00;fj]IVm^KFI_KZeVKfi]IVm^[FI_KT00;fi003=n<gHcOS=f<gh
cMS=n<gH003=f<ghcMO=n<gHcOS=e`00gYWN^MjIg[WNVMji003W^^Niik[O^@8001Ooo`03003ooooo
00ooo`03003ooooo00koo`00AOoo00<00?ooool0>?oo00<00:Gl[O`00jGl01N]o000002Uo:gl002U
o9glYOfMo:GlWObUoIglYObMo:Gm002EoHfMUOf=WIGm00L00005ECi<gEDn0002n@03000063am=5`l
OCAL?7d009ElUE^EO9EKUGbEFiElUE^EO000_KZeVKfj]IVm^[FI_KZeV@80000O_KVeF000aOS=nLGh
cOW5n<giaOP00<ggeOS=mmGhcOOEn<gg003=UP00e[WNn]Jig_X00>NjggWW^]mi00006_oo00<00?oo
ool03ooo00<00?ooool03Ooo0016ool2000iool00`00YMbUo00300004:GlYMbUo:GLYO`00:GlYMbU
o:GLYObUg:GlYMbUo:GL1P0000NMoIgLWOfMg@00GAiU?P0500020]P30000;CAM?5ddGCaM002EO9EL
UGbEG9ElUEbEO9ELUG`00;fj]IVm^KFI_KZeV@00_EVm^KeI_KVmF@00cMS=n<gHcOS=f000cMS=n<gG
cOS=f<ghcMO=n000eOOEeP0200001mji003W^^Niik[O^@0001coo`03003ooooo00koo`03003ooooo
00goo`00B?oo00<00?ooool0=ooo0P0000F]o:GlYObUo:gl00>Uo008[O`00:GlWObUoIglYObMo0<0
00:Uo009002MoIFLWOfEW9gmUIbMoIFL00800005IGiM7VEnGAeUOP0200000`:H0_T000020000;Cam
=5`lO@00UGbEFiElUE^EO9EKUGbEF`00]IVm^[FI_KZeV@00]ERm^KEH_KVeF;fi]EP00<GhcOW5n000
cOOEn<ggeOS=mmGhcOOEn000eOOEU]GgcIKEm`0200001=miik[ON@007Ooo00<00?ooool03_oo00<0
0?ooool03Ooo0019ool00`00ooooo`0gool03P00YMbUo:GLYObUg:GlYMbUo:GLYO`00:GlYM`30000
5jGLYObUg:GlYMbUo000WOfMg9gmWMfMoIgLWOfMgIgm001U?UdNICiM7VDnGAh00P0000<2f0002e/0
0P0000hdG@00UEbEO9ELUGbEG9ElUEbEO9EL002eVKfj0P0001fmFKfi_EVm^KeI_KVmFKfi_ET00<gH
cOP00<ghcMO=n<gHcOS=elgh003EmmGFeOOEemGgeMH00=gF00<001ooo`03003ooooo00goo`03003o
oooo00goo`00B_oo00<00?ooool0=ooo0P0000F]o:GlYObUo:gl00>Uo0<000VUo009002EW9gmUIbM
oIFLWOfEW9gm00d000032g/3FP000080000]UE^EO9EKUGbEFiElUE^EO000_KX00;fi]ERm^KEH_KVe
F;fi]ERm^KEH_KT00<gi003En<ggeOS=mmGhcOOEn<gg003EU]GgcIKEmmFF003MmNGfgOGMmP00023o
o`03003ooooo00coo`03003ooooo00goo`00Booo00<00?ooool0>?oo00@00:GlYMbUo0@0000AYMbU
o000YObUg:GlYMbUo:GLYObUg:GlYM`009gMWOfMg00400002jGlYMbUo000OGimGWenMEemOWeNOGh0
0`0000<;F`=K2e/02`0002:m^KeI_KVmFKfi_EVm^KeI_KVmFKfi_EVm^@00cOS=elghcMS=n<gGcOS=
f000eMKEmmGGeOOEe]Gg003Mm]gFgOH002;oo`03003ooooo00_oo`03003ooooo00goo`00C?oo0P00
>Ooo0`000ZGl00F]o:GlYObUo:gl008000RUo0@0000@WObUoIglYOfMo:GmWObUo@00OKieGGfnMEem
_WEMOKh30000;`]k0eX;N`]J002=6hdlSA^=?8dKSCb=6hdl002m^KEH_KVeF;fi]ERm^KEH_KVeF;fi
002mN000eOS=mmGhcOOEn<gg003EU]GgcIKEmmFFeOL00>GfgOGMm]ge00008_oo00<00?ooool02ooo
00<00?ooool03Ooo001>ool00`00ooooo`0gool03`00YObUg:GlYMbUo:GLYObUg:GlYM`00:GLYObU
g00400004jGlYM`00:GLYObMg:GlYMbUo9gLYObUg:Gl001mOWeNOGieGGen00H0000E0e/;F`00SCb=
6hdlSAb=?8dKSCb=7000_EVm^KeI_KVmFKfi_EVm^KeI0080000F_GRmF000cMS=n<gGcOS=f000eMKE
mmGGeOOEe]GgeML00=gFgOKMe]gf000Sool00`00ooooo`0;ool00`00ooooo`0<ool004ooo`03003o
oooo03Ooo`03002]o:Gl00:Uo005[ObUo:GlYOb]o0040003YO`03ZglYObUo:Gl002Mo:GmWObUoIgl
YOfMo:GmWO`6000019GmUIbEoIFL0`0002/3FP]k002=?8dKSCb=6hdlSA^=?8dK002eF;fi]ERm^KEH
_KVeF000_ENmN;eH_GRmE`00cOOEn<ggeOP00=GgcIKEmmFFeOO=UP00gOGMm]geiOH0000Uool00`00
ooooo`0:ool00`00ooooo`0<ool0053oo`03003ooooo03Ooo`07002Uo:GLYObUg:GlYM`00P0001>U
o:GL002Ug:GlYMbUo:GLYObUg:GlYM`00:GLYObMg:GlYMbUo00200003:GLYO`009FmUIfE_IFMUKfE
WIFmUIfE_@<0000Y2e/008dlSA^=?8dLSCb=6hdlSA`00;eI_KVmFKfi_ET00;eH_GRmF;eh_ERmN000
cOS=f<gh003EmmGGeOOEe]GgeMOEm`00gOKMe]gfgMH0000Vool00`00ooooo`09ool00`00ooooo`0<
ool0057oo`8003Soo`03002]o:Gl00<000>Uo005[ObUo000YOb]o003YO`01jglYObUo:Gl002Mo:Gm
00<000FUo00:002EoIFLUOfEW9GmUIbEoIFLUOd300003@]k002=?8dKSCb=6hdlSA^=?8dK002eF;fi
0080000H_ENmN;eH_GRmEkeh_ERmN000eOP00=GgcIKEmmFFeOO=U]Gg003Mm]geiOKMm@009ooo00<0
0?ooool02Ooo00<00?ooool03?oo001Cool00`00ooooo`0fool200004ZGLYObUg:GlYMbUo:GLYObU
g000YMbUo:GLYObUg:GlYMbUo0<0000@YObUg:GlYMbUo:GLYObUg:Gl002E_IFMUKfEWIFmUId20002
ool300009HdLSCb=6hdlSAb=?8dKSC`00;fi002mN;eH_GRmF;eh_ERmN;eH_GRmF000cML00=GGeOOE
e]GgeMOEmmGF003Me]gfgMKMmP0002Soo`03003ooooo00Soo`03003ooooo00coo`00E?oo00<00?oo
ool0=_oo00<00:glYO`00ZGl00Z]o:GlYObUo:glYO`00:Gl[ObUo0@000:Uo003002Uo:Gl00RUo003
002EoIFL00<000Goo`030001E00000T0000K_GRmEkeh_ERmN;eG_GRmF;eh_ENmN;eH003=U]GgeIKE
mlfFeOOEUP00gOGUm]gegOKMm@0002Woo`03003ooooo00Ooo`03003ooooo00coo`00EOoo00<00?oo
ool0=_oo0P0000RUg:GlYMbUo:GLYObUg:Gl100000NUg:GlYMbUo:GLYObUg00200002:GlYMbUo:GL
YObUg:GlYM`30009ool09@000I@007cLQ?alfhClO=b4o7cKQ?`00;eh_ERmN;eH_GRmF;eh_ERmN;eH
002m5`00eMKEmmGGeOOEe]Gg003Mm]gFgOKMeP0002[oo`03003ooooo00Ooo`03003ooooo00coo`00
E_oo0P00>?oo00@00:GlYObUo0@00005[ObUo000YOb]o003YO`01ZglYObUo:Gl[O`000>Uo0@000go
o`80000RQ?alfhClO=^4o7cKQ?alf`00_ERmN;eG_GRmF;eh_ENmN;eH002m5/Dg003EmlfFeOOEU]Gg
003Um]gegOKMmNGf000[ool00`00ooooo`07ool00`00ooooo`0;ool005Soo`03003ooooo03Koo`<0
0007YMbUo:GLYObUg:GlYM`00P0000RUo:GLYObUg:GlYMbUo:GL10004Ooo02@0006D0024o7cLQ?al
fhClO=b4o7cK002mF;eh_ERmN;eH_GRmF000_ANm=kdF_CL00=GgeMKEmmGG003Me]gfgMKMm]gF000/
ool00`00ooooo`06ool00`00ooooo`0;ool005Woo`03003ooooo03Koo`05002Uo:GlYOb]o003YO`0
1JglYObUo000[O`00ZGl10005_oo0P00021lfhClO=^4o7cKQ?alfhCl002mN;eH_GRmEkeh_EP00;dF
aCNm5[dg_AK5=`00eOO=UP00gOGMm]geiOKMm@00;_oo00<00?ooool01Ooo00<00?ooool02ooo001J
ool00`00ooooo`0fool02P00YMbUo:GLYObUg:GlYMbUo:GL10006ooo0P0001mlfhClO=b4o7cKQ?al
g8Cl002mN;eH_GRmF;eh002m=kdF_CNm5kdg_AJm=`00eOL00=gfgMKMm]gFgOH0000^ool00`00oooo
o`05ool00`00ooooo`0;ool005_oo`03003ooooo03Koo`05002Uo:GlYOb]o002YO`2000Pool05`00
Q?alfhClO=^4o7cKQ?alf`00_ENmN;eH_GP00<Dg_AJm=kdFaCNm5[dg_AH00P0000OMm]geiOKMmMgf
gOD0000_ool00`00ooooo`04ool00`00ooooo`0;ool005coo`8003Ooo`03002Ug:Gl00<002?oo`<0
000KQ?alg8ClO=^4o7cL002mF;eh002m=kdF_CNm5kdg_AJm=kdG_CNm5P00gMKMm]gFgOKMeP00037o
o`03003ooooo00?oo`03003ooooo00_oo`00G_oo00<00?ooool0=Ooo0P009ooo00<006bl00001000
01J4o000_GP00<Dg_AJm=kdFaCNm5[dg_AK5=kdF002dU000gOGMm]geiOH003;oo`03003ooooo00?o
o`03003ooooo00[oo`00Gooo00<00?ooool0=?oo00<00?ooool09ooo00<006aLI5/00VAL01I/G000
00000;dg_AJm=kdG_CNm5[dg_ANm=kdF002lUKbe003Mm]gFgOH003?oo`03003ooooo00?oo`03003o
oooo00[oo`00H?oo00<00?ooool0<ooo00<00?ooool0:?oo01X006blI5]/_6AKK;aTF`00_AJm=kdF
aCNm5[dg_AK5=kdF_CL00;be]9Fl]@00iOKMm@00=?oo00<00?ooool00_oo00<00?ooool02_oo001Q
ool2000cool00`00ooooo`0Xool01000I5a/G6AK0VAL01A/G6AK002m5kdg_AJm=kdG_CNm5[dg002l
]KbE_;FlUKbe003MmP00=Ooo00D00?ooooooo`0000coo`00Hooo00<00?ooool0<?oo00<00?ooool0
:Ooo01H006AKK;aTFfblI5]/_000aCNm5[dg_AK5=kdF_CL00;be]9Fl]KBD_;FdU@8003Ooo`04003o
oooo000<ool006Coo`03003ooooo02ooo`03003ooooo02[oo`04001TG6aLI5/2I5`04FaL002m=kdG
_CNm5[dg002l]KbE_;FlUKbe_9Fl]KbE0000=ooo00@00?ooool000coo`00IOoo00<00?ooool0;_oo
00<00?ooool0:ooo0P0001A/_6AKK;aTF`00_AK5=kdF_CNm5P00]9Fl]KBD_;FdUKbe]9Bl]@00>?oo
00<00?oo00003?oo001Vool2000^ool00`00ooooo`0[ool05@002]X006aLI5]TG000_CNm5[dg_AL0
0;bE_;FlUKbe_9Fl]KbE_;D0000jool00`00ool0000;ool006Soo`03003ooooo02_oo`03003ooooo
02coo`0D000:nP00001TFfbl002m=kdF002dUKbe]9Bl]KBE_;FdU;be]9D003_oo`8000_oo`00JOoo
00<00?ooool0:_oo00<00?ooool0;Ooo01<000[J0]X006AK002m5`00_9Fl]KbE_;FlUKbe_9Fl]KbE
_;D0000kool2000;ool006[oo`03003ooooo02Woo`03003ooooo02goo`040002f@[j0]T400002[be
]9Bl]KBE_;FdU;be]9Fl]@00??oo0P002ooo001[ool00`00ooooo`0Wool00`00ooooo`0_ool04@00
0]X:fP;J2]X00;be_9Fl]KbE_;FlUKbe_9Fl]KbE0000>?oo10003Ooo001/ool2000Wool00`00oooo
o`0`ool03`000]T:nP;I002dU;be]9Fl]KBD_;FdUKbe]9@0000eool4000Aool006koo`03003ooooo
02Coo`03003ooooo033oo`0?000:fP;J2]X2fP00_9Fl]KbE_;FlUKbe_9Fl]@00037oo`@001Goo`00
Kooo00<00?ooool08ooo00<00?ooool0<Ooo00h000[j0]T:nP00_;FdU;be]9Fl]KBD_;FdU@00;Ooo
10006Ooo001`ool00`00ooooo`0Rool00`00ooooo`0bool030002]X2fP00_9Fl]KbE_;FlUKbe_9D0
02_oo`<001goo`00LOoo0P008_oo00<00?ooool0<_oo00`000;I2_X2f@00]9Fl]KBD_;FdUKbe000W
ool4000Pool007?oo`03003ooooo01ooo`03003ooooo03?oo`0;0002fP[J002l]KbE_;FlUKbe_9D0
000Sool4000Tool007Coo`03003ooooo01koo`03003ooooo03?oo`0:000:nP;I002dU;be]9Fl]KBD
000Pool4000Xool007Goo`03003ooooo01goo`03003ooooo03Coo`09000:fP;J002lUKbe_9Fl]@00
01coo`@002coo`00M_oo0P007Ooo00<00?ooool0=Ooo00P000[j002l]KBD_;FdU@006Ooo0`00<?oo
001hool00`00ooooo`0Jool00`00ooooo`0eool01`000]X00;bE_;FlU@0001Koo`@003?oo`00NOoo
00<00?ooool06Ooo00<00?ooool0=_oo0P0000Bl]KBE_;D001;oo`@003Ooo`00N_oo00<00?ooool0
6?oo00<00?ooool0=ooo0P0000>l]@00ool03_oo1000>ooo001kool00`00ooooo`0Gool00`00oooo
o`0gool200000kBD003oo`0:ool4000oool007coo`8001Ooo`03003ooooo03Soo`03002l]@0000So
o`<004?oo`00O_oo00<00?ooool05?oo00<00?ooool0>?oo0P001Ooo1000A_oo001oool00`00oooo
o`0Cool00`00ooooo`0iool00`00ool00003001:ool0083oo`03003ooooo01;oo`03003ooooo03Oo
o`@004koo`00POoo0P004_oo00<00?ooool0=?oo0`00D_oo0023ool00`00ooooo`0?ool00`00oooo
o`0`ool4001Eool008Coo`03003ooooo00koo`03003ooooo02coo`@005Woo`00QOoo00<00?ooool0
3Ooo00<00?ooool0:?oo1000GOoo0026ool2000<ool00`00ooooo`0Uool4001Qool008Soo`03003o
oooo00Woo`03003ooooo02;oo`<006Goo`00ROoo00<00?ooool02?oo00<00?ooool07_oo1000J?oo
002:ool00`00ooooo`07ool00`00ooooo`0Jool4001/ool008_oo`03003ooooo00Koo`03003ooooo
01Koo`@0073oo`00S?oo0P001_oo00<00?ooool04_oo1000M?oo002>ool00`00ooooo`03ool00`00
ooooo`0?ool3001hool008ooo`03003ooooo00;oo`03003ooooo00_oo`@007_oo`00T?oo00D00?oo
ooooo`0000Woo`@007ooo`00TOoo0P0000?oo`00ool01?oo1000Pooo002Cool200000ooo00000002
0027ool009Coo`8008_oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?oo
ob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo
003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?oo
ob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00001\
\>"],
  ImageRangeCache->{{{0, 288}, {233.375, 0}} -> {-0.28375, -0.0852261, \
0.00445697, 0.00445697}}]
}, Open  ]],

Cell[TextData[{
  "Here is the analytical expression for the elasticity of the put option ",
  StyleBox["xyzft", "MB"],
  ". "
}], "MathCaption",
  CellTags->"0.45"],

Cell["Elasticity[xyzft, settlement, r]", "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \(\(20\ \((\(-1\) - Erf[\(\(-\(2\/\(5\ \@3\)\)\) - \@3\/20\)\/\@2])\)\)\/\
\(\(-20\)\ \((1 + Erf[\(\(-\(2\/\(5\ \@3\)\)\) - \@3\/20\)\/\@2])\) + \(20\ \
\((1 + Erf[\(\(-\(2\/\(5\ \@3\)\)\) + \@3\/20\)\/\@2])\)\)\/E\^\(1/25\)\)\)], \
"Output",
  CellLabel->"Out[40]="],

Cell["This is a numerical approximation. ", "MathCaption",
  CellTags->"0.46"],

Cell[CellGroupData[{

Cell["N[%]", "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(\(-7.53155276864398448`\)\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[TextData[{
  "We define the elasticity of the option ",
  StyleBox["abcft", "MB"],
  " as a function of two variables, ",
  StyleBox["x", "MB"],
  " and ",
  StyleBox["t", "MB"],
  ", the price of the underlying asset and the time to maturity, \
respectively. "
}], "MathCaption",
  CellTags->"0.47"],

Cell["\<\
optionelasticity[x_, t_] = Elasticity[abcft,
   ToCalendar[ToJulian[settlement] + Floor[t]], r] /.
   Price[ABC] -> x;\
\>", "Input",
  CellLabel->"In[42]:="],

Cell["\<\
This illustrates how the graph of the option elasticity changes as \
the time to maturity varies. \
\>", "MathCaption",
  CellTags->"0.48"],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Table[optionelasticity[x, t],
   {t, 0, 100, 10}]], {x, 25, 45},
   PlotLabel -> \"Call Option Elasticity\\n\"<>
      \"for Different Maturities\",
   FrameLabel -> {\"Stock Price\", \"\"}];\
\>", "Input",
  CellLabel->"In[43]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.16667 0.0476191 -0.0197661 0.00661195 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -35 -24 ]
[.5 -0.0125 35 -9 ]
[-0.0125 .11247 -12 -4.5 ]
[-0.0125 .11247 0 4.5 ]
[-0.0125 .24471 -12 -4.5 ]
[-0.0125 .24471 0 4.5 ]
[-0.0125 .37695 -12 -4.5 ]
[-0.0125 .37695 0 4.5 ]
[-0.0125 .50919 -12 -4.5 ]
[-0.0125 .50919 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74 0 ]
[.5 .63053 74 31 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(25)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(30)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(35)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(40)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(45)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -96 -28 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .11247 m
.00625 .11247 L
s
[(20)] -0.0125 .11247 1 0 Mshowa
0 .24471 m
.00625 .24471 L
s
[(40)] -0.0125 .24471 1 0 Mshowa
0 .37695 m
.00625 .37695 L
s
[(60)] -0.0125 .37695 1 0 Mshowa
0 .50919 m
.00625 .50919 L
s
[(80)] -0.0125 .50919 1 0 Mshowa
.125 Mabswid
0 .14553 m
.00375 .14553 L
s
0 .17859 m
.00375 .17859 L
s
0 .21165 m
.00375 .21165 L
s
0 .27777 m
.00375 .27777 L
s
0 .31083 m
.00375 .31083 L
s
0 .34389 m
.00375 .34389 L
s
0 .41001 m
.00375 .41001 L
s
0 .44307 m
.00375 .44307 L
s
0 .47613 m
.00375 .47613 L
s
0 .07941 m
.00375 .07941 L
s
0 .04635 m
.00375 .04635 L
s
0 .01329 m
.00375 .01329 L
s
0 .54225 m
.00375 .54225 L
s
0 .57531 m
.00375 .57531 L
s
0 .60837 m
.00375 .60837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .11247 m
1 .11247 L
s
.99375 .24471 m
1 .24471 L
s
.99375 .37695 m
1 .37695 L
s
.99375 .50919 m
1 .50919 L
s
.125 Mabswid
.99625 .14553 m
1 .14553 L
s
.99625 .17859 m
1 .17859 L
s
.99625 .21165 m
1 .21165 L
s
.99625 .27777 m
1 .27777 L
s
.99625 .31083 m
1 .31083 L
s
.99625 .34389 m
1 .34389 L
s
.99625 .41001 m
1 .41001 L
s
.99625 .44307 m
1 .44307 L
s
.99625 .47613 m
1 .47613 L
s
.99625 .07941 m
1 .07941 L
s
.99625 .04635 m
1 .04635 L
s
.99625 .01329 m
1 .01329 L
s
.99625 .54225 m
1 .54225 L
s
.99625 .57531 m
1 .57531 L
s
.99625 .60837 m
1 .60837 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Call) show
93.000000 15.000000 moveto
(Option) show
135.000000 15.000000 moveto
(Elasticity) show
63.000000 31.000000 moveto
(for) show
87.000000 31.000000 moveto
(Different) show
147.000000 31.000000 moveto
(Maturities) show
207.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.02381 .10215 m
.06244 .09613 L
.10458 .08987 L
.14415 .08427 L
.18221 .07913 L
.22272 .07391 L
.26171 .06912 L
.30316 .06428 L
.34309 .05984 L
.3815 .05578 L
.42237 .05168 L
.46172 .04794 L
.49955 .04452 L
.53984 .04108 L
.57861 .03794 L
.61984 .0348 L
.65954 .03195 L
.69774 .02937 L
.73838 .02678 L
.77751 .02445 L
.81909 .02213 L
.85916 .02004 L
.89771 .01817 L
.93871 .0163 L
.97619 .01472 L
s
.02381 .11183 m
.06244 .10521 L
.10458 .09832 L
.14415 .09216 L
.18221 .0865 L
.22272 .08075 L
.26171 .07547 L
.30316 .07013 L
.34309 .06525 L
.3815 .06077 L
.42237 .05626 L
.46172 .05213 L
.49955 .04837 L
.53984 .04458 L
.57861 .04113 L
.61984 .03768 L
.65954 .03455 L
.69774 .03172 L
.73838 .02889 L
.77751 .02634 L
.81909 .02381 L
.85916 .02153 L
.89771 .01949 L
.93871 .01748 L
.97619 .01576 L
s
.02381 .12339 m
.06244 .11604 L
.10458 .1084 L
.14415 .10156 L
.18221 .09527 L
.22272 .08888 L
.26171 .08301 L
.30316 .07708 L
.34309 .07165 L
.3815 .06667 L
.42237 .06165 L
.46172 .05707 L
.49955 .05289 L
.53984 .04868 L
.57861 .04485 L
.61984 .04102 L
.65954 .03756 L
.69774 .03442 L
.73838 .0313 L
.77751 .02849 L
.81909 .02571 L
.85916 .02321 L
.89771 .02098 L
.93871 .01878 L
.97619 .01691 L
s
.02381 .13744 m
.06244 .12921 L
.10458 .12064 L
.14415 .11296 L
.18221 .1059 L
.22272 .09872 L
.26171 .09213 L
.30316 .08547 L
.34309 .07936 L
.3815 .07377 L
.42237 .06812 L
.46172 .06297 L
.49955 .05827 L
.53984 .05355 L
.57861 .04925 L
.61984 .04496 L
.65954 .04108 L
.69774 .03758 L
.73838 .0341 L
.77751 .03097 L
.81909 .02788 L
.85916 .02512 L
.89771 .02266 L
.93871 .02023 L
.97619 .01819 L
s
.02381 .15492 m
.06244 .14557 L
.10458 .13583 L
.14415 .1271 L
.18221 .11907 L
.22272 .1109 L
.26171 .1034 L
.30316 .09581 L
.34309 .08885 L
.3815 .08248 L
.42237 .07605 L
.46172 .07018 L
.49955 .06483 L
.53984 .05945 L
.57861 .05457 L
.61984 .0497 L
.65954 .0453 L
.69774 .04134 L
.73838 .0374 L
.77751 .03388 L
.81909 .03041 L
.85916 .02732 L
.89771 .02457 L
.93871 .02188 L
.97619 .01962 L
s
.02381 .17724 m
.06244 .16646 L
.10458 .15521 L
.14415 .14513 L
.18221 .13584 L
.22272 .1264 L
.26171 .11772 L
.30316 .10892 L
.34309 .10086 L
.3815 .09348 L
.42237 .08602 L
.46172 .07922 L
.49955 .07303 L
.53984 .0668 L
.57861 .06116 L
.61984 .05553 L
.65954 .05046 L
.69774 .0459 L
.73838 .04138 L
.77751 .03735 L
.81909 .0334 L
.85916 .02989 L
.89771 .02679 L
.93871 .02376 L
.97619 .02123 L
s
.02381 .2068 m
.06244 .19409 L
.10458 .18084 L
.14415 .16894 L
.18221 .15797 L
.22272 .14681 L
.26171 .13654 L
.30316 .12613 L
.34309 .11659 L
.3815 .10785 L
.42237 .09901 L
.46172 .09096 L
.49955 .08362 L
.53984 .07625 L
.57861 .06958 L
.61984 .06293 L
.65954 .05696 L
.69774 .0516 L
.73838 .04631 L
.77751 .04161 L
.81909 .03701 L
.85916 .03296 L
.89771 .02939 L
.93871 .02594 L
.97619 .02307 L
s
.02381 .24783 m
.06244 .23244 L
.10458 .21636 L
.14415 .20191 L
.18221 .18858 L
.22272 .175 L
.26171 .1625 L
.30316 .14982 L
.34309 .13818 L
.3815 .12751 L
.42237 .11673 L
.46172 .10689 L
.49955 .09794 L
.53984 .08894 L
.57861 .08081 L
.61984 .07273 L
.65954 .06548 L
.69774 .059 L
.73838 .05262 L
.77751 .04698 L
.81909 .04151 L
.85916 .03671 L
.89771 .03252 L
.93871 .02851 L
.97619 .0252 L
s
.02381 .30871 m
.06244 .28929 L
.10458 .26899 L
.14415 .25071 L
.18221 .23384 L
.22272 .21663 L
.26171 .20076 L
.30316 .18464 L
.34309 .16983 L
.3815 .15625 L
.42237 .14251 L
.46172 .12997 L
.49955 .11855 L
.53984 .10709 L
.57861 .09675 L
.61984 .08648 L
.65954 .0773 L
.69774 .06912 L
.73838 .06113 L
.77751 .0541 L
.81909 .04733 L
.85916 .04146 L
.89771 .03639 L
.93871 .03158 L
.97619 .02767 L
s
.02381 .40863 m
.06244 .38255 L
.10458 .35524 L
.14415 .33062 L
.18221 .30786 L
.22272 .28459 L
.26171 .26311 L
.30316 .24125 L
.34309 .22114 L
.3815 .20266 L
.42237 .18394 L
.46172 .16684 L
.49955 .15127 L
.53984 .13564 L
.57861 .12155 L
.61984 .10759 L
.65954 .09516 L
.69774 .08416 L
.73838 .07347 L
.77751 .06417 L
.81909 .05531 L
.85916 .04775 L
.89771 .04133 L
.93871 .03535 L
.97619 .03059 L
s
.02381 .60332 m
.06244 .56414 L
.10458 .52305 L
.14415 .48594 L
.18221 .45157 L
.22272 .41634 L
.26171 .38375 L
.30316 .35049 L
.34309 .31981 L
.3815 .29154 L
.42237 .26285 L
.46172 .23658 L
.49955 .21263 L
.53984 .18857 L
.57861 .16689 L
.61984 .14547 L
.65954 .1265 L
.69774 .10983 L
.73838 .09382 L
.77751 .08011 L
.81909 .06733 L
.85916 .0567 L
.89771 .04793 L
.93871 .04003 L
.97619 .03397 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[43]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo003ooolX
ool00?ooobSoo`00oooo:?oo003ooolXool007Woo`<000?oo`8000?oo`8000;oo`<00004ool00000
ool2000;ool30003ool30002ool30002ool30003ool2001cool007Woo`03003oo`0000;oo`06003o
oooo003oo`000_oo00<00?oo00001?oo00<00?oo00003Ooo00<00?ooool00ooo00<00?ooool00_oo
00D00?ooooooo`0000Coo`03003ooooo07?oo`00Nooo00@00?ooool000Coo`06003ooooo003oo`00
1?oo0`003Ooo0`000ooo00<00?ooool00_oo00D00?ooooooo`0000Coo`<007?oo`00N_oo00<00?oo
ool010000ooo0P000_oo0`000_oo00@00?oo000000coo`05003ooooo003oo`0400000ooo00000003
ool30002ool3001cool007Woo`03003oo`0000;oo`03003ooooo00coo`03003ooooo00goo`04003o
oooo0026ool007Woo`<0013oo`8000koo`@000Soo`03003ooooo07coo`00oooo:?oo003ooolXool0
0?ooobSoo`00oooo:?oo003ooolXool003Soo`<000?oo`03003ooooo02Goo`8000Coo`03003ooooo
02Koo`8000Coo`03003ooooo02Ooo`<000;oo`03003ooooo02Ooo`<000;oo`03003ooooo02_oo`00
>?oo00<00?ooool00_oo00<00?oo0000:?oo00H00?ooool00?oo000Yool01P00ooooo`00ool002Wo
o`06003ooooo003oo`00:Ooo00H00?ooool00?oo000/ool003Woo`03003ooooo00?oo`03003ooooo
02Goo`07003oooooool00?oo0000:?oo00<00?ooool00ooo00<00?ooool09Ooo100000Coo`00ool0
02Ooo`@000?oo`03003ooooo02[oo`00>Ooo00@00?ooooooo`8002Woo`06003ooooo003oo`00:Ooo
00<00?ooool00P00:?oo00<00?oo00000_oo00<00?oo00009ooo00<00?oo00000_oo0P00;Ooo000h
ool00`00ool00002ool00`00ooooo`0Vool00`00ool00002ool00`00ool0000Wool00`00ool00002
ool00`00ooooo`0Xool20002ool00`00ool0000Xool20002ool00`00ooooo`0/ool003Woo`04003o
ooooool3000Wool00`00ooooo`02ool00`00ooooo`0Wool01000oooooooo0`00:Ooo00D00?oooooo
o`0002[oo`03003ooooo00<002coo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo000gooo6
000Zool003Ooo`03003ooooo00;oo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03
003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Ooo`03
003ooooo00Koo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Ooo`03003ooooo00Koo`03003ooooo00Koo`03
003ooooo00Ooo`03003ooooo00Koo`03003ooooo00;oo`03003ooooo02Soo`00=ooo00<00?ooool0
0_oo00<00?ooool0:ooo00<00?ooool0;?oo00<00?ooool0;?oo00<00?ooool0;?oo00<00?ooool0
0_oo00<00?ooool0:?oo000gool2002kool40003ool2000Zool003Ooo`03003ooooo0:?ooa/000Co
o`03003ooooo02Soo`00=ooo00<00?ooool0Tooo:`001?oo00<00?ooool0:?oo000gool00`00oooo
o`23oolk0004ool00`00ooooo`0Xool003Ooo`03003ooooo07CoodX000Coo`03003ooooo02Soo`00
=ooo00<00?ooool0I?ooC`000_oo1@002?oo00<00?ooool0:?oo000gool2001Moom90004ool40004
ool4000<ool2000Zool003Ooo`03003ooooo05Goobh000;oo`H000Soo`h000;oo`H000Coo`@0017o
o`03003ooooo02Soo`00=ooo00<00?ooool0AOoo=`001Ooo10001_oo40000_oo1P001_oo10005Ooo
00<00?ooool0:?oo000gool00`00ooooo`0moolg0008ool50002ool80002ool60006ool40008ool4
000Iool00`00ooooo`0Xool003Ooo`03003ooooo03GooaP000Soo`l000;oo`H000Soo`P000;oo`D0
00Koo`@000Soo`@000Soo`@001goo`03003ooooo02Soo`00=ooo00<00?ooool0;Ooo40000_oo1P00
2?oo3`001_oo10001_oo20001_oo10001ooo10002?oo10002?oo10008Ooo00<00?ooool0:?oo000g
ool00`00ooooo`0Vool?0006ool40006ool80002ool60007ool60004ool60008ool60007ool40008
ool40008ool4000Uool00`00ooooo`0Xool003Ooo`8001ooo`l000Soo`H000;oo`P000Koo`@000Ko
o`L000Koo`@000Soo`H000Soo`D000Soo`@000Soo`@002Soo`8002[oo`00=ooo00<00?ooool05_oo
40001ooo40002?oo1P001?oo1P001ooo1P002?oo10002?oo1P002Ooo10002_oo0P00;Ooo00<00?oo
ool0:?oo000gool00`00ooooo`0>ool80002ool60008ool70002ool60008ool80006ool40008ool5
000:ool40008ool4000;ool4000;ool3000_ool00`00ooooo`0Xool003Ooo`03003ooooo00Koo`P0
00Koo`@000Koo`P000Goo`@000Soo`H000Soo`H000Soo`@000_oo`@000Soo`@000coo`<000coo`<0
03;oo`03003ooooo02Soo`00:ooo0`000ooo00<00?ooool00ooo00<00?ooool00_oo10002?oo1P00
1?oo1P002?oo1@002?oo10002?oo1P002_oo10002Ooo1P002?oo10003_oo0P003Ooo0P00=Ooo00<0
0?ooool0:?oo000[ool00`00ooooo`02ool00`00ool00004ool00`00ooooo`06ool80006ool40008
ool60007ool60008ool4000<ool40008ool5000:ool4000?ool3000<ool3000gool00`00ooooo`0X
ool002coo`07003oooooool00?oo00001?oo0P000ooo10002?oo1P002?oo10002?oo1@002_oo1000
2_oo1P002?oo10003Ooo0P004?oo0`003?oo0`00>Ooo0P00:_oo000/ool01`00oooooooo003oo`00
00Coo`03003ooooo00Soo`H000Soo`H000Soo`@000_oo`@000Soo`H000[oo`@000koo`<000koo`@0
00goo`8003goo`03003ooooo02Soo`00:ooo00<00?oo00000_oo00<00?oo00001?oo00<00?ooool0
1?oo10002?oo1P002?oo1P002Ooo1P002?oo10003?oo10003ooo0`003Ooo10003ooo0P00?ooo00<0
0?ooool0:?oo000/ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`02ool20008ool40008
ool6000:ool5000:ool4000<ool4000?ool4000>ool2000Aool20011ool00`00ooooo`0Xool003Oo
o`03003ooooo00Koo`H000Soo`@000coo`@000_oo`@000koo`80013oo`<000ooo`<0017oo`8004?o
o`03003ooooo02Soo`00=ooo00<00?ooool00_oo10002_oo10003?oo10002ooo10003ooo0`003_oo
10003ooo0`004_oo0P00AOoo00<00?ooool0:?oo000gool00`00ooooo`0<ool4000<ool4000;ool4
000@ool3000=ool4000Aool2000Cool20017ool00`00ooooo`0Xool003Ooo`8000Woo`@000coo`@0
00coo`<0013oo`@000koo`8001;oo`<001?oo`8004Soo`8002[oo`00=ooo00<00?ooool01?oo1000
3?oo10003?oo10003ooo10003ooo0`004Ooo0`005?oo0P00Booo00<00?ooool0:?oo000gool00`00
ooooo`02ool2000<ool4000<ool4000?ool4000@ool3000Bool2000Eool2001=ool00`00ooooo`0X
ool003Ooo`03003ooooo00coo`@000koo`8000ooo`@001;oo`8001?oo`8001Goo`8004ooo`03003o
oooo02Soo`00=ooo00<00?ooool02?oo10003ooo0`003ooo0P004ooo0`004ooo0P005Ooo0P00DOoo
00<00?ooool0:?oo000gool00`00ooooo`04ool4000@ool3000@ool2000Bool3000Dool2000Eool2
001Cool00`00ooooo`0Xool003Ooo`03003ooooo00;oo`80013oo`@0013oo`<001;oo`8001Goo`80
01Goo`8005Goo`03003ooooo02Soo`00=ooo0P004Ooo10004?oo10004ooo0P005Ooo0P005Ooo0P00
E_oo0P00:_oo000gool00`00ooooo`0>ool2000@ool4000Dool3000Dool3000Eool2001Iool00`00
ooooo`0Xool003Ooo`03003ooooo00_oo`<0013oo`8001Goo`<001Goo`8001Koo`8005_oo`03003o
oooo02Soo`00=ooo00<00?ooool02?oo0`004?oo0`005?oo0`005Ooo0`005ooo00<00?ooool0Fooo
00<00?ooool0:?oo000gool00`00ooooo`04ool4000@ool3000Dool3000Fool2000Hool2001Nool0
0`00ooooo`0Xool003Ooo`03003ooooo00;oo`8001;oo`8001Goo`8001Ooo`8001Soo`80063oo`03
003ooooo02Soo`00=ooo0P005?oo0`005Ooo0P005ooo0P006Ooo00<00?ooool0Gooo0P00:_oo000g
ool00`00ooooo`0@ool3000Eool3000Gool2000Iool2001Sool00`00ooooo`0Xool003Ooo`03003o
oooo00koo`8001Koo`8001Soo`8001[oo`03003ooooo06?oo`03003ooooo02Soo`00=ooo00<00?oo
ool02ooo0`005Ooo0`006?oo0P006ooo00<00?ooool0I?oo00<00?ooool0:?oo000gool00`00oooo
o`08ool3000Fool2000Iool2000Kool2001Wool00`00ooooo`0Xool002coo`<000;oo`03003ooooo
00?oo`03003ooooo00Koo`8001Ooo`8001Woo`8001coo`03003ooooo06Ooo`03003ooooo02Soo`00
;Ooo00H00?ooool00?oo0004ool00`00ooooo`04ool2000Gool2000Iool2000Lool2001Zool00`00
ooooo`0Xool002_oo`@00004ool00?oo0004ool20003ool2000Gool2000Iool2000Mool00`00oooo
o`1Yool2000Zool002_oo`03003oo`0000;oo`03003oo`0000Coo`03003ooooo01Soo`<001Woo`80
01goo`8006goo`03003ooooo02Soo`00;?oo0P000_oo00<00?oo00001?oo00<00?ooool05_oo0P00
6_oo0P007Ooo0P00Kooo00<00?ooool0:?oo000]ool01@00oooooooo00001Ooo00<00?ooool04ooo
0`006_oo0P007_oo00<00?ooool0Kooo00<00?ooool0:?oo000gool00`00ooooo`0Aool2000Kool2
000Oool00`00ooooo`1`ool00`00ooooo`0Xool003Ooo`03003ooooo00ooo`8001_oo`8001ooo`80
07?oo`03003ooooo02Soo`00=ooo0P003_oo0P006ooo0P008?oo00<00?ooool0L_oo0P00:_oo000g
ool00`00ooooo`0;ool2000Lool00`00ooooo`0Oool00`00ooooo`1dool00`00ooooo`0Xool003Oo
o`03003ooooo00Woo`8001coo`80023oo`8007Ooo`03003ooooo02Soo`00=ooo00<00?ooool01ooo
0P007Ooo00<00?ooool07ooo00<00?ooool0Mooo00<00?ooool0:?oo000gool00`00ooooo`05ool2
000Mool2000Pool2001jool00`00ooooo`0Xool003Ooo`03003ooooo00?oo`8001goo`80027oo`03
003ooooo07[oo`03003ooooo02Soo`00=ooo00<00?ooool00_oo00<00?ooool07?oo00<00?ooool0
7ooo0P00OOoo00<00?ooool0:?oo000gool2000Pool2000Pool2001nool2000Zool003Ooo`03003o
oooo01goo`80027oo`03003ooooo07ooo`03003ooooo02Soo`00=ooo00<00?ooool06ooo0P008_oo
00<00?ooool0P?oo00<00?ooool0:?oo000gool00`00ooooo`0Iool2000Sool00`00ooooo`21ool0
0`00ooooo`0Xool003Ooo`03003ooooo01Ooo`8002?oo`8008Coo`03003ooooo02Soo`00=ooo00<0
0?ooool05_oo00<00?ooool08_oo00<00?ooool0Q?oo00<00?ooool0:?oo000gool2000Eool2000T
ool00`00ooooo`24ool2000Zool003Ooo`03003ooooo01;oo`8002Goo`03003ooooo08Koo`03003o
oooo02Soo`00=ooo00<00?ooool04Ooo00<00?ooool09?oo00<00?ooool0Qooo00<00?ooool0:?oo
000gool00`00ooooo`0@ool00`00ooooo`0Sool2002:ool00`00ooooo`0Xool003Ooo`03003ooooo
00koo`8002Goo`03003ooooo08[oo`03003ooooo02Soo`00:ooo0P001?oo00<00?ooool00ooo00<0
0?ooool03Ooo00<00?ooool09?oo00<00?ooool0Rooo00<00?ooool0:?oo000[ool00`00ool00002
ool00`00ool00004ool00`00ooooo`0<ool00`00ooooo`0Sool2002>ool00`00ooooo`0Xool002_o
o`03003oo`0000;oo`03003oo`0000Coo`8000_oo`8002Goo`03003ooooo08goo`8002[oo`00:ooo
0P000ooo00<00?oo00001?oo00<00?ooool02Ooo00<00?ooool09?oo00<00?ooool0Sooo00<00?oo
ool0:?oo000[ool00`00ooooo`02ool00`00ool00004ool00`00ooooo`07ool2000Vool00`00oooo
o`2@ool00`00ooooo`0Xool002coo`8000?oo`03003ooooo00?oo`03003ooooo00Koo`03003ooooo
02Goo`03003ooooo097oo`03003ooooo02Soo`00=ooo00<00?ooool01Ooo00<00?ooool09?oo0P00
U?oo00<00?ooool0:?oo000gool00`00ooooo`03ool2000Vool00`00ooooo`2Dool00`00ooooo`0X
ool003Ooo`8000?oo`03003ooooo02Goo`03003ooooo09Coo`8002[oo`00=ooo00<00?ooool0:Ooo
00<00?ooool0U_oo00<00?ooool0:?oo000gool00`00ooooo`0Xool00`00ooooo`2Gool00`00oooo
o`0Xool003Ooo`03003ooooo02Ooo`03003ooooo09Soo`03003ooooo02Soo`00=ooo00<00?ooool0
9_oo00<00?ooool0VOoo00<00?ooool0:?oo000gool00`00ooooo`0Tool2002Lool00`00ooooo`0X
ool003Ooo`03003ooooo02?oo`03003ooooo09coo`03003ooooo02Soo`00=ooo0P008ooo00<00?oo
ool0W?oo0P00:_oo000gool00`00ooooo`0Qool00`00ooooo`2Nool00`00ooooo`0Xool003Ooo`03
003ooooo023oo`03003ooooo09ooo`03003ooooo02Soo`00=ooo00<00?ooool07ooo00<00?ooool0
X?oo00<00?ooool0:?oo000gool00`00ooooo`0Nool00`00ooooo`2Qool00`00ooooo`0Xool003Oo
o`03003ooooo01coo`800:Coo`03003ooooo02Soo`00=ooo0P007?oo00<00?ooool0Xooo0P00:_oo
000gool00`00ooooo`0Jool00`00ooooo`2Uool00`00ooooo`0Xool003Ooo`03003ooooo01Woo`03
003ooooo0:Koo`03003ooooo02Soo`00=ooo00<00?ooool06?oo00<00?ooool0Yooo00<00?ooool0
:?oo000gool00`00ooooo`0Gool00`00ooooo`2Xool00`00ooooo`0Xool002coo`03003ooooo00;o
o`03003ooooo00?oo`03003ooooo01Koo`03003ooooo0:Woo`03003ooooo02Soo`00:ooo00<00?oo
00000_oo00<00?oo00001?oo00<00?ooool05?oo0P00[?oo00<00?ooool0:?oo000[ool00`00ool0
0002ool00`00ool00004ool2000Dool00`00ooooo`2[ool2000Zool002coo`07003oooooool00?oo
00001?oo00<00?ooool04_oo00<00?ooool0[Ooo00<00?ooool0:?oo000[ool00`00ool00002ool0
0`00ool00004ool00`00ooooo`0Aool00`00ooooo`2^ool00`00ooooo`0Xool002coo`03003ooooo
00;oo`03003ooooo00?oo`03003ooooo013oo`03003ooooo0:ooo`03003ooooo02Soo`00=ooo00<0
0?ooool03ooo00<00?ooool0/?oo00<00?ooool0:?oo000gool00`00ooooo`0>ool00`00ooooo`2a
ool00`00ooooo`0Xool003Ooo`8000koo`03003ooooo0;7oo`8002[oo`00=ooo00<00?ooool03?oo
00<00?ooool0/ooo00<00?ooool0:?oo000gool00`00ooooo`0;ool00`00ooooo`2dool00`00oooo
o`0Xool003Ooo`03003ooooo00[oo`03003ooooo0;Goo`03003ooooo02Soo`00=ooo00<00?ooool0
2Ooo00<00?ooool0]_oo00<00?ooool0:?oo000gool00`00ooooo`08ool00`00ooooo`2gool00`00
ooooo`0Xool003Ooo`03003ooooo00Ooo`03003ooooo0;Soo`03003ooooo02Soo`00=ooo0P001ooo
00<00?ooool0^?oo0P00:_oo000gool00`00ooooo`05ool00`00ooooo`2jool00`00ooooo`0Xool0
03Ooo`03003ooooo00Goo`03003ooooo0;[oo`03003ooooo02Soo`00=ooo00<00?ooool01?oo00<0
0?ooool0^ooo00<00?ooool0:?oo000gool00`00ooooo`03ool00`00ooooo`2lool00`00ooooo`0X
ool003Ooo`03003ooooo00;oo`03003ooooo0;goo`03003ooooo02Soo`00=ooo0P00`_oo0P00:_oo
000gool00`00ooooo`02ool00`00ooooo`06ool00`00ooooo`06ool00`00ooooo`07ool00`00oooo
o`06ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`07ool00`00oooo
o`06ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`06ool00`00oooo
o`07ool00`00ooooo`06ool00`00ooooo`07ool00`00ooooo`06ool00`00ooooo`06ool00`00oooo
o`07ool00`00ooooo`06ool00`00ooooo`02ool00`00ooooo`0Xool003OoolH002[oo`00oooo:?oo
003ooolXool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSoo`00D_oo0`000ooo0P000_oo0`00
2_oo10000_oo0`000_oo0`000_oo0`000ooo0P000_oo0`000ooo0P0000?oo`0000000_oo00<00?oo
ool00P004?oo0P0000Coo`00003oo`@000;oo`8000?oo`<00004ool000000002ool30003ool20002
ool30003ool20002ool2001Bool005?oo`05003oooooool00002ool01000ooooo`003?oo00@00?oo
ool000;oo`03003ooooo00;oo`03003ooooo00;oo`05003oooooool00005ool01@00oooooooo0000
1?oo00H00?ooool00?oo0002ool00`00ooooo`0=ool01P00oooooooo003oo`<000;oo`06003ooooo
003oo`000_oo00@00?ooool000Coo`05003oooooool00002ool01000ooooo`000ooo00<00?ooool0
1?oo00<00?ooool0Cooo001Cool01@00oooooooo00000_oo00@00?ooool000coo`04003ooooo0002
ool00`00ooooo`02ool00`00ooooo`02ool01000oooooooo0`000ooo00@00?ooooooo`<000;oo`06
003ooooo003oo`004_oo00D00?oo003oo`0000?oo`04003ooooo0004ool01000ooooo`000_oo00<0
0?ooool00_oo00D00?ooooooo`0000Goo`04003oooooool30003ool00`00ooooo`1@ool005;oo`<0
00?oo`8000;oo`@000[oo`05003ooooo003oo`020003ool30002ool30002ool30002ool400001Ooo
00000000ool0100000?oo`0000000P004?oo0P0000?oo`0000000_oo0P0000?oo`0000000P0000Co
o`00003oo`800003ool0000000800003ool0000000;oo`@000;oo`8000?oo`<000?oo`80057oo`00
Dooo00<00?ooool05?oo00@00?ooool000Ooo`03003ooooo00;oo`03003ooooo01Goo`03003ooooo
013oo`800003ool0000000Koo`03003ooooo017oo`03003ooooo063oo`00E?oo00<00?ooool04_oo
10000ooo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool09ooo0P0000?oo`0000005_oo00<0
0?ooool01ooo00<00?ooool0F_oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool00?ooobSo
o`00oooo:?oo003ooolXool00?ooobSoo`00M?oo0`00D?oo0P00G_oo001eool00`00ooooo`1@ool0
0`00ooooo`1Lool005?oo`8000;oo`@00004ool000000002ool3000=ool20002ool30003ool20002
ool30003ool200000ooo00000002ool00`00ooooo`0:ool500001?oo000000000_oo100000?oo`00
00001?oo0P000_oo0`000_oo0`000_oo0`000ooo0P000ooo00<00?ooool0G?oo001Bool00`00oooo
o`02ool30003ool00`00ooooo`02ool00`00ooooo`0;ool01P00ooooo`00ool000;oo`03003oo`00
00;oo`04003ooooo0003ool01P00ooooo`00ool000;oo`03003ooooo00_oo`04003ooooo0002ool0
1000oooooooo0`001?oo00@00?ooool000;oo`04003ooooo0003ool00`00ooooo`03ool01@00oooo
oooo00000_oo00D00?oo003oo`0005goo`00D_oo00<00?ooool01?oo00D00?ooooooo`0000Coo`03
003ooooo00_oo`06003ooooo003oo`000_oo00<00?oo00001Ooo00D00?ooooooo`0000;oo`03003o
o`0000;oo`03003ooooo00_oo`03003ooooo00?oo`03003ooooo00?oo`05003oooooool00003ool0
0`00ooooo`03ool01@00oooooooo00001Ooo00D00?ooooooo`0000Coo`03003oo`0005goo`00D_oo
00<00?ooool00ooo0P000ooo00<00?ooool00_oo00<00?ooool02ooo00<00?ooool01@0000?oo`00
00000P000_oo0P001?oo0P0000?oo`0000000P003_oo0P001?oo00<00?ooool00_oo0P000ooo0P00
00?oo`0000000P000_oo0P000ooo0`000_oo0P000_oo100000Coo`00003oo`8005coo`00D_oo00<0
0?oo00002?oo00<00?ooool00_oo00<00?ooool02ooo00@00?ooool000Koo`03003ooooo01goo`04
003ooooo0002ool00`00ooooo`0;ool00`00ooooo`0Aool00`00ooooo`1Rool005;oo`<000Ooo`80
00?oo`8000koo`8000goo`03003ooooo01Koo`D00003ool0000001?oo`03003ooooo00Ooo`03003o
oooo06Koo`00oooo:?oo003ooolXool00?ooobSoo`00oooo:?oo003ooolXool00001\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {18.5922, -17.3346, \
0.106644, 0.768045}}]
}, Open  ]],

Cell["Here is the equivalent three\[Hyphen]dimensional graph. ", "MathCaption",
  CellTags->"0.49"],

Cell[CellGroupData[{

Cell["\<\
Plot3D[optionelasticity[x, t], {x, 25, 55}, {t, 0, 100},
   AxesLabel->{\"Stock Price\", \"Time\",
      \"Option    \\nElasticity\"}];\
\>", "Input",
  CellLabel->"In[44]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -11.1734 -9 ]
[.3345 .12542 .8266 0 ]
[.56094 .0364 -10.3394 -9 ]
[.56094 .0364 1.66057 0 ]
[.29165 .07573 -65.1782 -15 ]
[.29165 .07573 4.82182 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 12 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 12 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 12 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 12 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 28 4.94788 ]
[.01764 .3057 -12 -2.77662 ]
[.01764 .3057 0 6.22338 ]
[.00967 .35562 -12 -2.81894 ]
[.00967 .35562 0 6.18106 ]
[.00145 .40717 -12 -2.86277 ]
[.00145 .40717 0 6.13723 ]
[-0.00705 .46042 -12 -2.90821 ]
[-0.00705 .46042 0 6.09179 ]
[-0.05457 .39542 -64 -9.75946 ]
[-0.05457 .39542 0 21.2405 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(20)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(40)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(60)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(80)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(100)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
87.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02989 .30101 m
.03602 .29866 L
s
[(20)] .01764 .3057 1 -0.38297 Mshowa
.02196 .35103 m
.02811 .34874 L
s
[(40)] .00967 .35562 1 -0.37357 Mshowa
.01378 .40269 m
.01994 .40044 L
s
[(60)] .00145 .40717 1 -0.36383 Mshowa
.00532 .45605 m
.01151 .45386 L
s
[(80)] -0.00705 .46042 1 -0.35373 Mshowa
.125 Mabswid
.02793 .31336 m
.03161 .31196 L
s
.02596 .32582 m
.02964 .32443 L
s
.02397 .33838 m
.02765 .33699 L
s
.01994 .36379 m
.02363 .36242 L
s
.0179 .37665 m
.0216 .37529 L
s
.01585 .38961 m
.01955 .38826 L
s
.01169 .41586 m
.01539 .41452 L
s
.00958 .42915 m
.01329 .42782 L
s
.00746 .44254 m
.01117 .44122 L
s
.03183 .28875 m
.03551 .28733 L
s
.03376 .27658 m
.03743 .27516 L
s
.03567 .26451 m
.03934 .26308 L
s
.00316 .46967 m
.00688 .46836 L
s
.00099 .4834 m
.0047 .4821 L
s
gsave
-0.05457 .39542 -125 -13.7595 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 39 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Option) show
63.000000 31.000000 moveto
(Elasticity) show
123.000000 31.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.704 .57 .702 r
.3768 .73529 .39806 .80578 .43782 .76011 .41631 .69851 Metetra
.709 .587 .717 r
.41631 .69851 .43782 .76011 .47733 .71794 .45575 .66424 Metetra
.715 .606 .734 r
.45575 .66424 .47733 .71794 .51669 .67892 .49522 .63225 Metetra
.72 .627 .753 r
.49522 .63225 .51669 .67892 .55602 .64293 .53479 .60246 Metetra
.724 .65 .775 r
.53479 .60246 .55602 .64293 .59541 .60999 .57455 .57486 Metetra
.727 .675 .8 r
.57455 .57486 .59541 .60999 .63498 .58027 .61458 .54952 Metetra
.725 .7 .826 r
.61458 .54952 .63498 .58027 .67485 .55398 .65496 .52653 Metetra
.719 .721 .852 r
.65496 .52653 .67485 .55398 .71517 .53117 .69581 .50583 Metetra
.708 .737 .873 r
.69581 .50583 .71517 .53117 .75604 .5115 .73719 .48721 Metetra
.697 .744 .888 r
.73719 .48721 .75604 .5115 .79754 .49424 .77919 .47025 Metetra
.687 .747 .897 r
.77919 .47025 .79754 .49424 .83969 .47853 .82182 .45443 Metetra
.679 .746 .901 r
.82182 .45443 .83969 .47853 .88251 .46369 .86511 .43931 Metetra
.675 .745 .904 r
.86511 .43931 .88251 .46369 .92599 .44927 .90908 .42455 Metetra
.672 .744 .905 r
.90908 .42455 .92599 .44927 .97014 .43502 .95372 .40993 Metetra
.719 .615 .74 r
.35464 .68434 .3768 .73529 .41631 .69851 .39413 .65264 Metetra
.721 .63 .756 r
.39413 .65264 .41631 .69851 .45575 .66424 .43368 .62288 Metetra
.724 .647 .772 r
.43368 .62288 .45575 .66424 .49522 .63225 .47335 .5949 Metetra
.726 .665 .79 r
.47335 .5949 .49522 .63225 .53479 .60246 .51321 .56863 Metetra
.726 .683 .809 r
.51321 .56863 .53479 .60246 .57455 .57486 .55334 .54404 Metetra
.724 .701 .828 r
.55334 .54404 .57455 .57486 .61458 .54952 .59379 .52115 Metetra
.719 .717 .848 r
.59379 .52115 .61458 .54952 .65496 .52653 .63464 .49998 Metetra
.712 .731 .865 r
.63464 .49998 .65496 .52653 .69581 .50583 .67598 .48046 Metetra
.702 .74 .88 r
.67598 .48046 .69581 .50583 .73719 .48721 .71785 .46243 Metetra
.693 .744 .891 r
.71785 .46243 .73719 .48721 .77919 .47025 .76033 .4456 Metetra
.685 .746 .898 r
.76033 .4456 .77919 .47025 .82182 .45443 .80345 .42964 Metetra
.679 .746 .902 r
.80345 .42964 .82182 .45443 .86511 .43931 .84723 .41423 Metetra
.674 .745 .904 r
.84723 .41423 .86511 .43931 .90908 .42455 .89169 .39912 Metetra
.671 .744 .905 r
.89169 .39912 .90908 .42455 .95372 .40993 .93684 .38413 Metetra
.725 .648 .771 r
.33172 .64284 .35464 .68434 .39413 .65264 .37132 .61434 Metetra
.726 .661 .786 r
.37132 .61434 .39413 .65264 .43368 .62288 .41105 .58743 Metetra
.726 .675 .8 r
.41105 .58743 .43368 .62288 .47335 .5949 .45098 .56197 Metetra
.725 .689 .816 r
.45098 .56197 .47335 .5949 .51321 .56863 .49117 .53789 Metetra
.723 .703 .831 r
.49117 .53789 .51321 .56863 .55334 .54404 .53166 .51515 Metetra
.719 .716 .846 r
.53166 .51515 .55334 .54404 .59379 .52115 .57253 .49375 Metetra
.713 .727 .861 r
.57253 .49375 .59379 .52115 .63464 .49998 .61383 .47366 Metetra
.706 .736 .874 r
.61383 .47366 .63464 .49998 .67598 .48046 .65563 .45482 Metetra
.698 .741 .885 r
.65563 .45482 .67598 .48046 .71785 .46243 .69799 .4371 Metetra
.69 .744 .893 r
.69799 .4371 .71785 .46243 .76033 .4456 .74095 .42029 Metetra
.683 .745 .899 r
.74095 .42029 .76033 .4456 .80345 .42964 .78456 .40414 Metetra
.678 .745 .902 r
.78456 .40414 .80345 .42964 .84723 .41423 .82883 .38844 Metetra
.674 .745 .904 r
.82883 .38844 .84723 .41423 .89169 .39912 .8738 .37297 Metetra
.671 .744 .905 r
.8738 .37297 .89169 .39912 .93684 .38413 .91947 .35759 Metetra
.728 .671 .795 r
.3081 .60646 .33172 .64284 .37132 .61434 .34788 .58013 Metetra
.726 .683 .808 r
.34788 .58013 .37132 .61434 .41105 .58743 .38785 .55512 Metetra
.725 .694 .821 r
.38785 .55512 .41105 .58743 .45098 .56197 .42806 .53133 Metetra
.722 .705 .834 r
.42806 .53133 .45098 .56197 .49117 .53789 .46858 .50868 Metetra
.719 .716 .847 r
.46858 .50868 .49117 .53789 .53166 .51515 .50946 .48713 Metetra
.714 .725 .859 r
.50946 .48713 .53166 .51515 .57253 .49375 .55074 .46665 Metetra
.708 .733 .87 r
.55074 .46665 .57253 .49375 .61383 .47366 .59249 .44722 Metetra
.701 .739 .88 r
.59249 .44722 .61383 .47366 .65563 .45482 .63475 .42877 Metetra
.694 .742 .889 r
.63475 .42877 .65563 .45482 .69799 .4371 .67758 .41118 Metetra
.687 .745 .895 r
.67758 .41118 .69799 .4371 .74095 .42029 .72103 .39429 Metetra
.681 .745 .899 r
.72103 .39429 .74095 .42029 .78456 .40414 .76513 .37792 Metetra
.677 .745 .902 r
.76513 .37792 .78456 .40414 .82883 .38844 .8099 .36189 Metetra
.674 .745 .904 r
.8099 .36189 .82883 .38844 .8738 .37297 .85539 .34605 Metetra
.671 .744 .905 r
.85539 .34605 .8738 .37297 .91947 .35759 .90159 .33026 Metetra
.727 .689 .813 r
.28378 .57304 .3081 .60646 .34788 .58013 .32378 .54822 Metetra
.725 .698 .825 r
.32378 .54822 .34788 .58013 .38785 .55512 .36402 .52453 Metetra
.722 .707 .836 r
.36402 .52453 .38785 .55512 .42806 .53133 .40455 .50187 Metetra
.718 .716 .847 r
.40455 .50187 .42806 .53133 .46858 .50868 .44542 .48018 Metetra
.714 .724 .858 r
.44542 .48018 .46858 .50868 .50946 .48713 .48668 .4594 Metetra
.709 .731 .868 r
.48668 .4594 .50946 .48713 .55074 .46665 .52838 .43952 Metetra
.703 .736 .877 r
.52838 .43952 .55074 .46665 .59249 .44722 .57057 .42047 Metetra
.697 .74 .885 r
.57057 .42047 .59249 .44722 .63475 .42877 .61329 .4022 Metetra
.691 .743 .891 r
.61329 .4022 .63475 .42877 .67758 .41118 .6566 .38461 Metetra
.685 .745 .896 r
.6566 .38461 .67758 .41118 .72103 .39429 .70054 .36757 Metetra
.68 .745 .9 r
.70054 .36757 .72103 .39429 .76513 .37792 .74513 .35094 Metetra
.676 .745 .902 r
.74513 .35094 .76513 .37792 .8099 .36189 .79042 .33457 Metetra
.673 .744 .904 r
.79042 .33457 .8099 .36189 .85539 .34605 .83643 .31833 Metetra
.671 .744 .905 r
.83643 .31833 .85539 .34605 .90159 .33026 .88318 .30212 Metetra
.725 .702 .828 r
.25875 .54137 .28378 .57304 .32378 .54822 .29901 .51762 Metetra
.722 .709 .838 r
.29901 .51762 .32378 .54822 .36402 .52453 .33955 .49486 Metetra
.718 .717 .848 r
.33955 .49486 .36402 .52453 .40455 .50187 .38041 .47298 Metetra
.714 .723 .857 r
.38041 .47298 .40455 .50187 .44542 .48018 .42164 .45193 Metetra
.71 .729 .866 r
.42164 .45193 .44542 .48018 .48668 .4594 .4633 .43165 Metetra
.705 .735 .874 r
.4633 .43165 .48668 .4594 .52838 .43952 .50541 .41211 Metetra
.7 .739 .881 r
.50541 .41211 .52838 .43952 .57057 .42047 .54804 .39326 Metetra
.694 .742 .888 r
.54804 .39326 .57057 .42047 .61329 .4022 .59123 .37504 Metetra
.688 .744 .893 r
.59123 .37504 .61329 .4022 .6566 .38461 .63502 .35736 Metetra
.683 .744 .897 r
.63502 .35736 .6566 .38461 .70054 .36757 .67945 .34011 Metetra
.679 .745 .901 r
.67945 .34011 .70054 .36757 .74513 .35094 .72456 .32318 Metetra
.676 .745 .903 r
.72456 .32318 .74513 .35094 .79042 .33457 .77037 .30644 Metetra
.673 .744 .904 r
.77037 .30644 .79042 .33457 .83643 .31833 .81691 .28979 Metetra
.671 .744 .905 r
.81691 .28979 .83643 .31833 .88318 .30212 .86421 .27313 Metetra
.723 .711 .839 r
.23301 .51072 .25875 .54137 .29901 .51762 .27355 .48774 Metetra
.719 .718 .848 r
.27355 .48774 .29901 .51762 .33955 .49486 .3144 .46562 Metetra
.715 .723 .856 r
.3144 .46562 .33955 .49486 .38041 .47298 .3556 .44427 Metetra
.711 .729 .864 r
.3556 .44427 .38041 .47298 .42164 .45193 .39721 .42363 Metetra
.706 .733 .872 r
.39721 .42363 .42164 .45193 .4633 .43165 .43927 .40365 Metetra
.701 .737 .879 r
.43927 .40365 .4633 .43165 .50541 .41211 .48181 .38429 Metetra
.696 .74 .885 r
.48181 .38429 .50541 .41211 .54804 .39326 .52489 .3655 Metetra
.691 .742 .89 r
.52489 .3655 .54804 .39326 .59123 .37504 .56854 .34722 Metetra
.686 .744 .895 r
.56854 .34722 .59123 .37504 .63502 .35736 .61281 .32937 Metetra
.682 .744 .898 r
.61281 .32937 .63502 .35736 .67945 .34011 .65774 .31186 Metetra
.678 .745 .901 r
.65774 .31186 .67945 .34011 .72456 .32318 .70336 .29459 Metetra
.675 .744 .903 r
.70336 .29459 .72456 .32318 .77037 .30644 .74971 .27746 Metetra
.672 .744 .904 r
.74971 .27746 .77037 .30644 .81691 .28979 .7968 .26037 Metetra
.67 .744 .905 r
.7968 .26037 .81691 .28979 .86421 .27313 .84466 .24326 Metetra
.717 .713 .845 r
.2066 .47984 .23301 .51072 .27355 .48774 .24742 .45753 Metetra
.714 .719 .853 r
.24742 .45753 .27355 .48774 .3144 .46562 .28858 .43596 Metetra
.71 .724 .861 r
.28858 .43596 .3144 .46562 .3556 .44427 .33013 .41505 Metetra
.706 .729 .869 r
.33013 .41505 .3556 .44427 .39721 .42363 .37211 .39475 Metetra
.702 .733 .875 r
.37211 .39475 .39721 .42363 .43927 .40365 .41457 .375 Metetra
.697 .737 .881 r
.41457 .375 .43927 .40365 .48181 .38429 .45754 .35575 Metetra
.693 .74 .887 r
.45754 .35575 .48181 .38429 .52489 .3655 .50106 .33697 Metetra
.689 .742 .892 r
.50106 .33697 .52489 .3655 .56854 .34722 .54519 .31859 Metetra
.684 .743 .896 r
.54519 .31859 .56854 .34722 .61281 .32937 .58995 .30054 Metetra
.68 .744 .899 r
.58995 .30054 .61281 .32937 .65774 .31186 .63539 .28275 Metetra
.677 .744 .901 r
.63539 .28275 .65774 .31186 .70336 .29459 .68153 .26512 Metetra
.674 .744 .903 r
.68153 .26512 .70336 .29459 .74971 .27746 .72841 .24758 Metetra
.672 .744 .904 r
.72841 .24758 .74971 .27746 .7968 .26037 .77606 .23004 Metetra
.67 .743 .905 r
.77606 .23004 .7968 .26037 .84466 .24326 .82451 .21244 Metetra
.716 .724 .856 r
.17935 .45004 .2066 .47984 .24742 .45753 .22049 .42808 Metetra
.712 .729 .863 r
.22049 .42808 .24742 .45753 .28858 .43596 .26199 .40677 Metetra
.708 .732 .87 r
.26199 .40677 .28858 .43596 .33013 .41505 .3039 .38605 Metetra
.704 .736 .876 r
.3039 .38605 .33013 .41505 .37211 .39475 .34628 .36584 Metetra
.7 .738 .881 r
.34628 .36584 .37211 .39475 .41457 .375 .38915 .34611 Metetra
.695 .741 .886 r
.38915 .34611 .41457 .375 .45754 .35575 .43255 .32681 Metetra
.691 .742 .89 r
.43255 .32681 .45754 .35575 .50106 .33697 .47654 .30789 Metetra
.687 .743 .894 r
.47654 .30789 .50106 .33697 .54519 .31859 .52114 .28929 Metetra
.683 .744 .897 r
.52114 .28929 .54519 .31859 .58995 .30054 .5664 .27096 Metetra
.679 .744 .9 r
.5664 .27096 .58995 .30054 .63539 .28275 .61235 .25281 Metetra
.676 .744 .902 r
.61235 .25281 .63539 .28275 .68153 .26512 .65903 .23478 Metetra
.674 .744 .904 r
.65903 .23478 .68153 .26512 .72841 .24758 .70646 .21679 Metetra
.672 .744 .905 r
.70646 .21679 .72841 .24758 .77606 .23004 .75468 .19877 Metetra
.67 .743 .905 r
.75468 .19877 .77606 .23004 .82451 .21244 .80371 .18066 Metetra
.714 .728 .862 r
.1513 .42019 .17935 .45004 .22049 .42808 .19277 .39843 Metetra
.709 .732 .868 r
.19277 .39843 .22049 .42808 .26199 .40677 .23462 .37727 Metetra
.705 .735 .874 r
.23462 .37727 .26199 .40677 .3039 .38605 .27692 .35661 Metetra
.701 .738 .879 r
.27692 .35661 .3039 .38605 .34628 .36584 .31969 .33641 Metetra
.697 .74 .884 r
.31969 .33641 .34628 .36584 .38915 .34611 .36298 .31662 Metetra
.693 .741 .888 r
.36298 .31662 .38915 .34611 .43255 .32681 .40683 .29718 Metetra
.689 .743 .892 r
.40683 .29718 .43255 .32681 .47654 .30789 .45128 .27805 Metetra
.685 .744 .896 r
.45128 .27805 .47654 .30789 .52114 .28929 .49637 .25918 Metetra
.682 .744 .898 r
.49637 .25918 .52114 .28929 .5664 .27096 .54213 .24051 Metetra
.678 .744 .901 r
.54213 .24051 .5664 .27096 .61235 .25281 .5886 .22197 Metetra
.676 .744 .902 r
.5886 .22197 .61235 .25281 .65903 .23478 .63582 .2035 Metetra
.673 .744 .904 r
.63582 .2035 .65903 .23478 .70646 .21679 .68382 .18503 Metetra
.671 .744 .905 r
.68382 .18503 .70646 .21679 .75468 .19877 .73262 .1665 Metetra
.67 .743 .905 r
.73262 .1665 .75468 .19877 .80371 .18066 .78225 .14785 Metetra
.711 .732 .867 r
.12243 .3901 .1513 .42019 .19277 .39843 .16423 .36845 Metetra
.707 .734 .873 r
.16423 .36845 .19277 .39843 .23462 .37727 .20645 .34732 Metetra
.703 .737 .878 r
.20645 .34732 .23462 .37727 .27692 .35661 .24913 .32665 Metetra
.699 .739 .882 r
.24913 .32665 .27692 .35661 .31969 .33641 .29231 .30637 Metetra
.695 .741 .887 r
.29231 .30637 .31969 .33641 .36298 .31662 .33603 .28643 Metetra
.691 .742 .89 r
.33603 .28643 .36298 .31662 .40683 .29718 .38033 .26678 Metetra
.687 .743 .894 r
.38033 .26678 .40683 .29718 .45128 .27805 .42525 .24739 Metetra
.684 .744 .897 r
.42525 .24739 .45128 .27805 .49637 .25918 .47083 .2282 Metetra
.68 .744 .899 r
.47083 .2282 .49637 .25918 .54213 .24051 .5171 .20915 Metetra
.677 .744 .901 r
.5171 .20915 .54213 .24051 .5886 .22197 .56411 .19018 Metetra
.675 .744 .903 r
.56411 .19018 .5886 .22197 .63582 .2035 .61188 .17124 Metetra
.673 .744 .904 r
.61188 .17124 .63582 .2035 .68382 .18503 .66045 .15226 Metetra
.671 .744 .905 r
.66045 .15226 .68382 .18503 .73262 .1665 .70984 .13319 Metetra
.67 .743 .906 r
.70984 .13319 .73262 .1665 .78225 .14785 .76009 .11398 Metetra
.708 .734 .871 r
.0927 .35964 .12243 .3901 .16423 .36845 .13485 .338 Metetra
.704 .736 .876 r
.13485 .338 .16423 .36845 .20645 .34732 .17744 .31684 Metetra
.7 .738 .881 r
.17744 .31684 .20645 .34732 .24913 .32665 .22051 .29606 Metetra
.696 .74 .885 r
.22051 .29606 .24913 .32665 .29231 .30637 .2641 .27562 Metetra
.693 .742 .889 r
.2641 .27562 .29231 .30637 .33603 .28643 .30826 .25547 Metetra
.689 .743 .892 r
.30826 .25547 .33603 .28643 .38033 .26678 .35302 .23556 Metetra
.686 .743 .895 r
.35302 .23556 .38033 .26678 .42525 .24739 .39842 .21585 Metetra
.682 .744 .898 r
.39842 .21585 .42525 .24739 .47083 .2282 .4445 .19629 Metetra
.679 .744 .9 r
.4445 .19629 .47083 .2282 .5171 .20915 .49129 .17682 Metetra
.677 .744 .902 r
.49129 .17682 .5171 .20915 .56411 .19018 .53883 .15739 Metetra
.674 .744 .903 r
.53883 .15739 .56411 .19018 .61188 .17124 .58717 .13795 Metetra
.672 .744 .904 r
.58717 .13795 .61188 .17124 .66045 .15226 .63632 .11843 Metetra
.671 .744 .905 r
.63632 .11843 .66045 .15226 .70984 .13319 .68632 .09879 Metetra
.669 .743 .906 r
.68632 .09879 .70984 .13319 .76009 .11398 .7372 .07898 Metetra
.706 .736 .874 r
.06207 .32869 .0927 .35964 .13485 .338 .10458 .307 Metetra
.702 .738 .879 r
.10458 .307 .13485 .338 .17744 .31684 .14754 .28571 Metetra
.698 .74 .883 r
.14754 .28571 .17744 .31684 .22051 .29606 .19102 .26477 Metetra
.695 .741 .887 r
.19102 .26477 .22051 .29606 .2641 .27562 .23503 .24411 Metetra
.691 .742 .89 r
.23503 .24411 .2641 .27562 .30826 .25547 .27963 .22369 Metetra
.688 .743 .894 r
.27963 .22369 .30826 .25547 .35302 .23556 .32485 .20347 Metetra
.684 .744 .896 r
.32485 .20347 .35302 .23556 .39842 .21585 .37074 .18339 Metetra
.681 .744 .899 r
.37074 .18339 .39842 .21585 .4445 .19629 .41732 .16341 Metetra
.678 .744 .9 r
.41732 .16341 .4445 .19629 .49129 .17682 .46464 .14348 Metetra
.676 .744 .902 r
.46464 .14348 .49129 .17682 .53883 .15739 .51274 .12355 Metetra
.674 .744 .903 r
.51274 .12355 .53883 .15739 .58717 .13795 .56164 .10357 Metetra
.672 .744 .904 r
.56164 .10357 .58717 .13795 .63632 .11843 .61139 .08348 Metetra
.67 .743 .905 r
.61139 .08348 .63632 .11843 .68632 .09879 .66201 .06324 Metetra
.669 .743 .906 r
.66201 .06324 .68632 .09879 .7372 .07898 .71353 .0428 Metetra
.704 .738 .877 r
.0305 .29717 .06207 .32869 .10458 .307 .07337 .27534 Metetra
.7 .739 .882 r
.07337 .27534 .10458 .307 .14754 .28571 .11673 .25387 Metetra
.696 .741 .885 r
.11673 .25387 .14754 .28571 .19102 .26477 .1606 .2327 Metetra
.693 .742 .889 r
.1606 .2327 .19102 .26477 .23503 .24411 .20505 .21176 Metetra
.689 .743 .892 r
.20505 .21176 .23503 .24411 .27963 .22369 .2501 .19102 Metetra
.686 .743 .895 r
.2501 .19102 .27963 .22369 .32485 .20347 .29579 .17043 Metetra
.683 .744 .897 r
.29579 .17043 .32485 .20347 .37074 .18339 .34217 .14994 Metetra
.68 .744 .899 r
.34217 .14994 .37074 .18339 .41732 .16341 .38927 .1295 Metetra
.678 .744 .901 r
.38927 .1295 .41732 .16341 .46464 .14348 .43713 .10907 Metetra
.675 .744 .902 r
.43713 .10907 .46464 .14348 .51274 .12355 .48578 .08861 Metetra
.673 .744 .904 r
.48578 .08861 .51274 .12355 .56164 .10357 .53527 .06805 Metetra
.672 .744 .905 r
.53527 .06805 .56164 .10357 .61139 .08348 .58562 .04736 Metetra
.67 .743 .905 r
.58562 .04736 .61139 .08348 .66201 .06324 .63687 .02649 Metetra
.669 .743 .906 r
.63687 .02649 .66201 .06324 .71353 .0428 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(30)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(40)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(50)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.17542 .201 m
.17816 .20382 L
s
.21633 .18498 m
.21903 .18784 L
s
.2579 .1687 m
.26056 .1716 L
s
.30014 .15216 m
.30275 .1551 L
s
.3867 .11827 m
.38922 .12129 L
s
.43105 .1009 m
.43352 .10397 L
s
.47614 .08324 m
.47856 .08635 L
s
.522 .06529 m
.52436 .06844 L
s
.09549 .2323 m
.09832 .23504 L
s
.05645 .24758 m
.05931 .25029 L
s
.61605 .02846 m
.6183 .03169 L
s
.6643 .00957 m
.66649 .01284 L
s
gsave
.29165 .07573 -126.178 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Stock) show
99.000000 15.000000 moveto
(Price) show
129.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40n007h00Ooooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00
oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00
oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00
oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQ
ool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00
oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQ
ool00=Ooo`03003ooooo04Koo`00e_oo00<00?oo0000Aooo003Fool00`00ool00017ool00=Koo`03
003oo`0004Ooo`00e_oo00<00?oo0000Aooo002cool00`00ooooo`02ool00`00ooooo`0Gool20003
ool00`00ooooo`16ool00;;oo`03003oo`0000;oo`03003oo`0001Koo`D004_oo`00]?oo00H00?oo
ool00?oo000Cool500000jgl0000001;ool00;;oo`8000?oo`03003oo`00017oo`800006ool00000
YMb]o:GL0`00B_oo002bool00`00ooooo`02ool00`00ool0000>ool300002_oo00000:glYO^]o:Gl
[O`00:gl0P00BOoo0016ool30003ool20003ool20002ool300001?oo00000?oo0P002ooo0`000ooo
0`000_oo0`000_oo0`000ooo0P00<Ooo0`000ooo00<00?ooool02ooo0P000_oo0P0000VUg:GlYMb]
o:GLYObUg000YM`00P00BOoo0016ool00`00ool00002ool01P00ooooo`00ool000;oo`03003oo`00
00Coo`03003oo`0000goo`03003ooooo00?oo`03003ooooo00;oo`05003oooooool00004ool00`00
ooooo`12ool300004?oo00000000[ObUo:glYO^]o:Gl[ObUnjgl002]o:Gk0P00B?oo0018ool01000
ooooo`001?oo00H00?ooool00?oo0004ool3000=ool30003ool00`00ooooo`02ool01@00oooooooo
00001?oo0`00@?oo0P000_oo0P0001:Uo:GL002Ug:GlYMb]o:GLYObUg:glYM`00:GL[O`00?oo0017
ool004Ooo`03003ooooo00@000?oo`8000;oo`<000;oo`04003oo`00000<ool01@00ooooo`00ool0
100000?oo`0000000ooo0`000_oo0`00?Ooo0`0001Koo`0000000:Gl[ObUnjgl002]o:Gk[ObUo:gl
YO^]o:Gl[O`00:glYOb]o08004Ooo`00A_oo00<00?oo00000_oo00<00?ooool03?oo00<00?ooool0
3Ooo00@00?ooool004goo`<000;oo`80000DYMb]o:GLYObUg:glYMbUo000[ObUg:GlYMb]o:GLYObU
g000YMbUo0800003ool00?oo04Goo`00A_oo0`004?oo0P003_oo10002?oo00<00?ooool0@Ooo0`00
01Ooo`0000000:glYO^]o:Gl[ObUnjglYOb]o:Gk[O`00:glYO^]o:Gl[ObUnjgl00<00004[ObUo000
0016ool00;Koo`<000;oo`80000D[ObUg000YMb]o:GLYObUg:glYMbUo:GL[ObUg:Gl002]o:GLYObU
g0<00004YMb]o:GLYO`30015ool00;Coo`8000;oo`<0000DYO^]o:Gl[O`00:glYOb]o:Gk[ObUo:gl
YO^]o:Gl[ObUn`00YOb]o080000;YOb]o000[ObUo:glYO^]o000ool00014ool00;7oo`<000;oo`80
000DYMb]o:GL[ObUg:glYMb]o000YObUg:glYMbUo:GL[ObUg:GlYMb]o0<0000;[ObUg:GlYMb]o000
YObUg:glYMbUo0020014ool00:ooo`800003ool000000080000D[ObUo:glYO^]o:Gl[ObUnjglYOb]
o000[ObUo:glYO^]o:Gl[ObUn`80000?[ObUn`00YOb]o:Gk[ObUo000YO^]o:Gl[ObUnjgl008004?o
o`00[?oo0`000_oo0P0001B]o:GL002Ug:glYMb]o:GL[ObUg:glYMb]o:GL[O`00:GlYMb]o:GL0`00
01BUg:GlYMb]o000YObUg:glYMbUo000[ObUg:GlYMb]o:GL003oo`001Ooo0`000ooo00<00?ooool0
=?oo002Zool20002ool300005:Gl[ObUnjgl002]o:Gk[ObUo:glYO^]o:Gl[ObUnjglYO`00:Gk[O`2
00005:Gk[ObUo:glYO^]o:Gl[O`00:glYOb]o:Gk002Uo:glYO^]o:Gl[O`30005ool00`00ooooo`02
ool00`00ool0000eool008Goo`<000;oo`03003ooooo01[oo`<000;oo`80000DYMb]o:GL[ObUg:gl
YMb]o000[ObUg:glYMb]o:GL[ObUg:glYMb]o0<0000DYObUg:glYMbUo:GL[ObUg:GlYMb]o000YObU
g:gl002Uo:GL[ObUg0800004[ObUg0000005ool01`00oooooooo003oo`0003Goo`00Q_oo00H00?oo
ool00?oo000Iool20002ool300005:glYO^]o:Gl[ObUnjglYOb]o:Gk[O`00:glYO^]o:Gl[ObUnjgl
YO`200005:glYO`00:Gk[ObUo:glYO^]o:Gl[ObUnjglYOb]o000[ObUo000YO/300001jGk[ObUo:gl
003oo`0000Coo`07003oooooool00?oo0000=Ooo0024ool400001?oo003oo`005_oo0`000_oo0P00
01B]o:GL002Ug:glYMb]o:GL[ObUg:glYMb]o:GL[O`00:glYMb]o:GL0`0001BUg:glYMb]o000[ObU
g:GlYMb]o:GLYObUg:glYMbUo:GL002Ug:Gl0P0000RUg:GlYMb]o:GLYObUg:gl0P000ooo00<00?oo
00000_oo00<00?oo0000=Ooo0024ool00`00ool00002ool00`00ool0000Dool20003ool200005:Gk
[ObUnjglYO/00:Gl[ObUnjglYOb]o:Gk[ObUo:glYO/00:Gl[O`200005:Gl[ObUnjglYOb]o:Gk[O`0
0:glYO^]o:Gl[ObUnjglYOb]o:Gk[O`400002ZGl[ObUnjglYOb]o:Gk[ObUo:gl0P000ooo00<00?oo
ool00_oo00<00?ooool0=?oo0025ool20002ool00`00ool0000Aool40002ool200004jglYMb]o:GL
[ObUg:glYM`00:GL[ObUg:glYMb]o:GL[ObUg:gl00<0000D[ObUg:glYMb]o:GL[ObUg:glYMb]o000
[ObUg:GlYMb]o:GLYObUg080000?YObUg000002Uo:GL[ObUg:GlYMb]o:GLYObUg:gl008003koo`00
Q_oo00D00?ooooooo`00013oo`8000?oo`<0000CYO^]o:Gk[ObUnjglYO^]o:Gk[O`00:glYOb]o:Gk
[ObUo:glYO/00P0001B]o:Gk002Uo:glYO^]o:Gl[ObUnjglYOb]o:Gk[O`00:glYO^]o:Gl0`0000BU
o:glYO^]o080000;YO^]o:Gl[ObUnjglYOb]o:Gk[ObUo002000nool009Soo`<000?oo`80000D[Mb]
o000[ObUg:glYMb]o:GL[ObUg:glYMb]o000[ObUg:glYMb]o080000DYMb]o:GL[O`00:glYMb]o:GL
[ObUg:glYMb]o:GL[ObUg000YMb]o080000DYMb]o:GLYObUg:glYMbUo000[ObUg:GlYMb]o:GLYObU
g:glYMbUo0<003goo`00U_oo0P000ooo0`0001B]o:Gk[ObUn`00YO^]o:Gk[ObUnjglYO^]o:Gk[ObU
njgl002]o:Gl0P0001>]o:Gl[ObUnjglYOb]o000[ObUo:glYO^]o:Gl[ObUnjglYOb]o00300002Zgl
YO^]o:Gl[ObUnjglYOb]o:Gk0P0000R]o:Gk[ObUo:glYO^]o:Gl0P0000B]o:Gl000003coo`00Tooo
0`000ooo0P0001B]o:GL[Ob]g:glYMb]o:gL002Ug:glYMb]o:GL[ObUg:glYMb]o:GL0`0001>Ug:gl
YMb]o:GL[ObUg:glYMb]o000[ObUg:glYMb]o:GL[ObUg00200005:glYM`00:GL[ObUg:GlYMb]o:GL
YObUg:gl002Uo000[ObUg:GlYM`300001:GL[ObUg:Gl0P00??oo002@ool30003ool300005:Gk[ObU
njglYO^]o:Gk[ObUnjglYO/00:Gk[ObUnjglYO^]o:Gk[O`200004jGk[O`00:glYOb]o:Gk[ObUo:gl
YO^]o:Gl[O`00:glYOb]o:Gk00<0000DYO^]o:Gl[O`00:glYOb]o:Gk[ObUo:glYO^]o:Gl002Un`00
YOb]o0800008YOb]o:Gk[ObUo:glYO^]o08003_oo`00S_oo0P001?oo0P0001B]g:gl002]o:GL[Ob]
g:glYMb]o:gL[ObUg:gl[M`00:GL[ObUg:gl0`0001>]o:GL[Ob]g000YMb]o:GL[ObUg:glYMb]o:GL
[ObUg000YMb]o00200005:GL[ObUg:glYMb]o:GL[O`00:GlYMb]o:GLYObUg:glYMbUo000[O`30000
2ZglYMbUo:GL[ObUg:GlYMb]o:GL0P00>ooo002;ool300001?oo003ooooo0P0001B]o:Gk[ObUnjgl
002]o:Gk[ObUnjglYO^]o:Gk[ObUnjgl002]o:Gk0P0001>]o:Gk[ObUnjglYO^]o:Gk002UnjglYOb]
o:Gk[ObUo:glYO^]o00300005:glYOb]o:Gk[ObUo:glYO^]o:Gl[O`00:glYOb]o:Gk[ObUo:glYO/2
00003ZglYO/00:Gl[ObUnjglYOb]o:Gk[ObUo:glYO/2000jool008Woo`8000Goo`80000C[Mb]o:gL
[Ob]g:gl[Mb]o000[ObUg:gl[Mb]o:GL[Ob]g:glYM`00`0001>Ug:gl[Mb]o:GL[Ob]g:glYMb]o:gL
002Ug:glYMb]o:GL[ObUg00200005:glYM`00:GL[ObUg:glYMb]o:GL[ObUg:glYMb]o000YObUg:gl
YM`400004ZGlYMb]o000YObUg:glYMbUo:GL[ObUg:GlYMb]o000ool003Woo`00Q_oo0`001?oo0`00
01>]o:Gk[ObUnjglYO^]o:Gk[ObUn`00YO^]o:Gk[ObUnjglYO^]o00200005:Gk[O`00:glYO^]o:Gk
[ObUnjglYO^]o:Gk[ObUn`00YO^]o:Gl[O`200005:Gl[ObUnjglYO`00:Gk[ObUo:glYO^]o:Gl[ObU
njglYO`00:Gk[O`200004jGk[ObUo000YO^]o:Gl[O`00:glYOb]o:Gk[ObUo:glYO^]o:Gl00<003Wo
o`00Q?oo0`001?oo0P0001B]o:gK002]g:gl[Mb]o:gL[Ob]g:gl[Mb]o:gL002]g:glYMb]o:gL0P00
01B]o:gL[ObUg:gl002]o:GL[Ob]g:glYMb]o:gL[ObUg:gl002]o:GL0P0001>]o:GL[ObUg:glYMb]
o:GL002Ug:glYMb]o:GL[ObUg:glYMb]o00300004ZGlYMb]o:GLYO`00:glYMbUo:GL[O`00:GlYMb]
o:GLYObUg0<00004YMb]o000000hool0087oo`<000Goo`80000DYO^]o:Gk[ObUn`00YO^]o:Gk[ObU
njglYO^]o:Gk[ObUn`00YO^]o080000CYO^]o:Gk[ObUnjglYO^]o000[ObUnjglYO^]o:Gk[ObUnjgl
YO/00`0001:UnjglYOb]o:Gk[ObUo:glYO^]o000[ObUnjglYOb]o:Gk[O`300004JglYO`00:Gk[ObU
o:glYO/00:Gl[ObUnjglYO`00:Gk[O`0100000RUo:glYO^]o:Gl003oo`00=ooo001Jool20004ool0
0`00ooooo`0Lool20006ool200004jgl[Mb]o:gK[Ob]g:gl[M/00:gL[Ob]g:gl[Mb]o:gL[Ob]g:gl
00<0000B[ObUg:gl[Mb]o:GL[Ob]g:glYM`00:gL[ObUg:gl[Mb]o:GL0`00016Ug:gl002]o:GL[ObU
g:glYMb]o:GL[ObUg:gl002]o:GL00@0000A[ObUg:glYMb]o:GL002Ug:GlYMb]o000YObUg:glYMbU
o00300002ZGlYMb]o:GLYObUg:glYMbUo:GL0P00=ooo001Lool01P00ooooo`00ool001[oo`<000Go
o`<0000CYO^]o:Gk[ObUnjglYO^]o:Gk[O`00:glYO^]o:Gk[ObUnjglYO/00P00016]o:Gk002Unjgl
YO^]o:Gk[ObUnjglYO^]o:Gk002Unjgl00@0000AYO^]o:Gk[ObUnjgl002]o:Gk[ObUo:glYO^]o:Gl
[ObUn`0300004jGk[ObUo:glYO^]o:Gl[ObUnjglYO`00:Gk[ObUo000YO^]o:Gl0080000>[ObUo000
YO^]o:Gl[ObUnjglYOb]o:Gk[ObUo08000Koo`<000;oo`03003ooooo02Soo`00Fooo00L00?oooooo
o`00ool0000Hool20006ool200005:gL[O`00:gl[Mb]o:gK[Ob]g:gl[M^]o:gL[O`00:gl[Mb]o:gL
[O`200004:gL[Ob]g:gl[M`00:gL[ObUg:gl[Mb]o:GL[Ob]g:gl0`0001>]o:GL[Ob]g:glYMb]o:gL
[ObUg:gl002]o:GL[ObUg:glYMb]o00200005:GL[O`00:glYMb]o:GL[ObUg:glYMb]o:GL[O`00:gl
YMbUo000[O`200004jGL[ObUg:Gl002]o:GLYObUg:glYMbUo:GL[ObUg:Gl003oo`0000Koo`06003o
oooo003oo`00:Ooo001Lool01P00ooooo`00ool001Goo`<000Koo`80000D[ObUnjgl[O^]o000[ObU
njglYO^]o:Gk[ObUnjglYO^]o000[ObUn`80000@[ObUnjglYO^]o:Gk[ObUn`00YO^]o:Gk[ObUnjgl
YO/200005:glYO/00:Gk[ObUnjglYO^]o:Gk[ObUnjglYO/00:Gl[ObUnjglYO`200005:glYOb]o:Gk
002Uo:glYO^]o:Gl[ObUnjglYOb]o:Gk[O`00:glYO/200004ZglYO^]o:Gl[ObUnjgl002]o:Gk[ObU
o:glYO^]o:Gl[ObUn`<000Coo`@00004ool00?oo000Yool005[oo`03003oo`0000;oo`03003oo`00
01?oo`8000Ooo`80000C[M^]o:gL[Ob]fjgl[Mb]o000[Ob]g:gl[M^]o:gL[Ob]fjgl[M`00`00012]
g:gl[Mb]o:gL[Ob]g:gl[Mb]o000[Ob]g:glYMb]o080000DYMb]o:gL[ObUg000[Mb]o:GL[Ob]g:gl
YMb]o:gL[ObUg000YMb]o080000CYMb]o:GL[ObUg:glYM`00:GL[ObUg:glYMb]o:GL[ObUg:glYM`0
0`0001:Ug000YMb]o:GLYObUg:glYMbUo000[ObUg:GlYMb]o:GLYO`200001:GLYO`000000ooo00<0
0?oo00000_oo00<00?oo00003?oo0`000_oo0`0000Koo`00ool00?oo0002ool2000;ool005_oo`03
003ooooo00;oo`03003ooooo00ooo`<00003ool00?oo00?oo`<0000C[Ob]njglYO^]o:gk[ObUnjgl
[O/00:Gk[ObUnjglYO^]o:Gk[O`00P00016]njgl002]o:Gk[ObUnjglYO^]o:Gk[ObUnjgl002]o:Gk
0080000C[ObUnjglYO^]o:Gk[ObUn`00YO^]o:Gk[ObUnjglYO^]o:Gk[O`00`0001>]o:Gk[ObUo:gl
YO^]o:Gl[ObUn`00YOb]o:Gk[ObUo:glYO^]o00200004jGk[O`00:gl002]o:Gl[ObUnjglYOb]o:Gk
[O`00:glYO^]o:Gl00800007[ObUo:glYO/00?oo00000ooo0P000_oo00<00?oo00003Ooo00<00?oo
ool00_oo00X00?ooool00?oo003oo`00ool000goo`00L?oo0P001ooo0P0001B]o:gK002]fjgl[Mb]
o:gK[Ob]g:gl[M^]o:gL002]fjgl[Mb]o:gK0P00012]o:gK[Ob]g:gl002]o:gL[Ob]g:gl[Mb]o:gL
[Ob]g0<0000C[Mb]o:GL[Ob]g:glYMb]o:gL[O`00:gl[Mb]o:GL[Ob]g:glYM`00P0001>]o:GL002U
g:glYMb]o:GL[ObUg:glYMb]o:GL002Ug:glYMb]o00300004jglYMb]o:GL002Ug000YMbUo:GL[ObU
g:GlYMb]o:GL002Ug:gl00800007YMb]o:GLYObUg:glYM`00P001?oo00D00?ooooooo`0000koo`03
003ooooo00;oo`09003ooooo003oo`00ool00?oo00<000_oo`00KOoo0`001ooo0P0001B]njgl[O^]
o:gk002Unjgl[O^]o:Gk[Ob]njglYO^]o:gk002Unjgl0P00012Unjgl[O^]o:Gk[Ob]njgl002]o:Gk
[ObUnjglYO^]o080000DYO^]o000[ObUnjglYO^]o:Gk[ObUnjglYO^]o000[ObUnjglYO^]o080000C
YO^]o:Gk[ObUn`00YOb]o:Gk[ObUo:glYO^]o:Gl[O`00:glYO`00P0000R]o:Gl[ObUnjglYOb]o:Gk
0P0000V]o:Gk[ObUo:glYO^]o:Gl[O`00`0000Z]o:Gk[ObUo:glYO^]o:Gl[ObUn`8001Koo`04003o
ooooool20002ool200001?oo003ooooo0`002ooo001[ool200000ooo003oo`05ool200004jgl[M^]
o:gK[Ob]fjgl[M/00:gK[Ob]g:gl[M^]o:gL[Ob]fjgl00<0000@[Ob]g:gl[M^]o:gL[Ob]fjgl[M`0
0:gL[Ob]g:gl[M`200005:gl[M^]o:gL002Ug:gl[Mb]o:GL[Ob]g:glYMb]o:gL[O`00:gl[M`20000
4Zgl[Mb]o:GL[Ob]g:glYM`00:GL[ObUg:glYMb]o:GL[ObUg0<0000BYMb]o:GL[ObUg:glYMb]o:GL
[ObUg000YMb]o:GLYObUg:gl0`00012]o:GL002Ug:glYMbUo:GL[ObUg:GlYMb]o000ool001?oo`05
003oo`00ool0000Iool006Soo`<000Ooo`<0000C[O^]o:gk[Ob]njgl[O^]o:gk[O`00:glYO^]o:gk
[ObUnjgl[O/00P00016]o:gk002Unjgl[O^]o:Gk[Ob]njglYO^]o:gk002Unjgl0080000CYO^]o:Gk
[ObUnjglYO/00:Gk[ObUnjglYO^]o:Gk[ObUnjglYO/00`00016UnjglYO^]o:Gk[ObUnjglYO^]o000
[ObUo:glYO^]o:Gl00<0000AYO^]o000[ObUo:glYO^]o:Gl[ObUnjglYOb]o000[ObUo00400004:gl
YO^]o:Gl[O`00:glYOb]o:Gk[ObUo:glYO^]o:Gl0`004ooo1@000_oo00<00?ooool05?oo001Uool3
0008ool200005:gK[O/00:gl[M^]o:gK[Ob]fjgl[M^]o:gK[O`00:gl[M^]o:gL[O`200004:gK[Ob]
fjgl[M/00:gK[Ob]g:gl[M^]o:gL[Ob]fjgl0`0001>]o:gL[Ob]fjgl[Mb]o:gK[Ob]g000YMb]o:gL
[ObUg:gl[Mb]o00200004JgL[O`00:gl[Mb]o:GL[Ob]g:glYMb]o:gL[O`00:glYM`00`00016]g:gl
YMb]o:gL[O`00:glYMb]o:GL[ObUg:glYMb]o:GL00<0000BYMb]o:GL[ObUg:glYMb]o:GL[O`00:Gl
YMb]o:GLYObUg:gl0P0000BUg:gl0000033oo`00Hooo0P0000?oo`00ool01_oo0P0001Beo:gk[Ob]
nkGl002]o:gk[Ob]njgl[O^]o:gk[Ob]njgl002]o:Gk0P00012]o:gk[Ob]njgl[O^]o:gk002Unjgl
[O^]o:Gk[Ob]n`80000C[Ob]n`00YO^]o:Gk[ObUnjglYO^]o:Gk[ObUn`00YO^]o:Gk[O`00`00012]
o:Gk[ObUnjgl002]o:Gk[ObUnjglYO^]o:Gk[ObUn`<0000BYO^]o:Gk[ObUnjglYO^]o:Gk[O`00:gl
YOb]o:Gk[ObUo:gl0`0001:]o000[ObUo:glYO^]o:Gl[ObUnjglYOb]o000[ObUo:glYO/200001:gl
YO^]o:Gl0P00<?oo001Pool30009ool200004jgK[Ob]fjgk[M^]o:gK[O/00:gl[M^]o:gK[Ob]fjgl
[M^]o:gK00<0000@[M^]o:gK[Ob]fjgl[M^]o:gK[O`00:gl[M^]o:gL[O`200004jgL[Ob]fjgl[M`0
0:gK[Ob]g:gl[M^]o:gL[Ob]fjgl002]o:GL0080000A[Ob]g:gl[Mb]o:gL[Ob]g:gl002]o:gL[ObU
g:gl[Mb]o00200004jgL[O`00:gl[Mb]o:GL[Ob]g:glYMb]o:gL002Ug:glYMb]o:GL0080000C[ObU
g000YM`00:GL[ObUg:glYMb]o:GL[ObUg:glYM`00:GLYO`00P0000NUg:GlYMb]o:GLYObUg002000_
ool005goo`<000[oo`80000C[Ob]nkGl[O^]o:gk]Ob]njgl[O/00:gk[Ob]njgl[O^]o:gk[O`00P00
016]njgl002]o:gk[Ob]njgl[O^]o:gk[Ob]njgl002]o:Gk0080000B[ObUnjgl[O^]o:Gk[Ob]n`00
YO^]o:Gk[ObUnjglYO^]o:Gk0`00016UnjglYO^]o:Gk[ObUnjglYO^]o:Gk002UnjglYO^]o:Gk0080
000C[ObUnjglYO/00:Gk[ObUnjglYO^]o:Gk[ObUnjglYO/00:Gk[O`00P0001:UnjglYOb]o000[ObU
o000YO^]o:Gl[ObUnjglYOb]o:Gk[O`300002ZglYOb]o:Gk[ObUo:glYO^]o:Gl0P00;_oo001Kool4
0009ool200004jgK002]fjgl[M^]njgK[Ob]fjgk[M^]o:gK002]fjgl[M^]o:gK0080000@[O^]fjgl
[M^]n`00[Ob]fjgl[M^]o:gK[Ob]fjgl[M/300004JgK[Ob]g:gl[M^]o:gL[Ob]fjgl002]o:gK[Ob]
g:gl[M/00`0001:]fjgl002]o:gL[Ob]g:gl[Mb]o:gL[Ob]g:gl[M`00:GL[O`200004ZGL[Ob]g:gl
YMb]o:gL002Ug:gl[Mb]o:GL[Ob]g:glYMb]o0<0000A[ObUg:glYMb]o:GL002Ug:glYM`00:GL[ObU
g:glYMb]o00300003JglYM`00:GLYObUg:glYMbUo:GL[ObUg:Gl008002koo`00FOoo0P002ooo0P00
01>eo:gk]Ob]n`00[O^]o:gk]Ob]njgl[O^eo:gk[Ob]n`00[O^]o00200004:gk[Ob]njgl[O^]o:gk
[O`00:gl[O^]o:gk[Ob]njgl0P00016]njgl002]o:Gk[Ob]njglYO^]o:gk[ObUnjgl002]o:Gk00<0
000BYO^]o:gk[ObUnjgl002]o:Gk[ObUnjglYO^]o:Gk[ObUnjgl0`00016]o:Gk[ObUnjglYO^]o:Gk
[ObUn`00YO^]o:Gk[ObUnjgl00<0000@[ObUn`00YO^]o:Gl[ObUnjgl002]o:Gk[O`00:glYO/40000
4:glYOb]o:Gk[O`00:glYO^]o:Gl[ObUnjglYOb]o:Gk0`00;Ooo001Eool4000;ool200004ZgK[O^]
fjgk[M^]njgK002]fjgl[M^]njgK[Ob]fjgk[M^]o0<0000@[Ob]fjgk[M^]o:gK[O^]fjgl[M/00:gK
[Ob]fjgl[M/200004Jgl[M^]o:gK[O`00:gl[M^]o:gL[Ob]fjgl[Mb]o:gK[O`00P0001>]fjgl[Mb]
o:gK[Ob]g:gl[M^]o000[Ob]g:gl[Mb]o:gL[Ob]g00200004:gl[M`00:GL[Ob]g:glYMb]o:gL[ObU
g:gl002]o:GL100000^]o:gL[ObUg:gl002]o:GL[ObUg:gl00800003YMb]o:GL00<0000BYMb]o:GL
[ObUg:glYMb]o:GL[O`00:glYMbUo:GL[ObUg:Gl0P0000BUg:Gl000002coo`00E?oo0`002ooo0P00
01:eo:gk]Ob]nkGl[O^eo:gk]O`00;Gl[O^]o:gk]Ob]njgl[O/200004Jgl[O/00:gk[Ob]njgl[O^]
o:gk[Ob]njgl[O/00:gk[O`00P00016]njgl[O^]o:gk[Ob]njgl002]o:Gk[Ob]njglYO^]o:gk0080
000B[O`00:glYO^]o:gk[ObUnjgl[O^]o:Gk002UnjglYO^]o:Gk0`0000nUnjglYO^]o000[ObUnjgl
YO^]o:Gk[ObUnjglYO/00`0000bUnjglYO^]o:Gk[ObUnjglYO^]o000[O`300000jglYO/000020000
4jGk[O`00:glYO^]o:Gl[ObUnjglYOb]o:Gk[O`00:glYO^]o:Gl00800004[ObUo:glYO/2000/ool0
05;oo`8000goo`0C002]fjgk[M^]njgK[O^]fjgk[M^]njgK[O/00:gk[M^]o:gK[O/00P00016]fjgk
[M^]o:gK002]fjgl[M^]njgK[Ob]fjgk[M^]o:gK0080000A[Ob]fjgl[M^]o:gK[Ob]fjgl[M^]o000
[Ob]fjgl[Mb]o00200004ZgK[Ob]fjgl002]o:gK[Ob]g:gl[M^]o:gL[Ob]f`00[Mb]o080000@[Mb]
o:gK[Ob]g:gl[M^]o000[ObUg:gl[Mb]o:GL[O`200003:GL[O`00:glYMb]o:gL[ObUg:gl[Mb]o0<0
0004[ObUg:glYM`200004jglYMb]o:GL[O`00:glYMb]o:GL[ObUg:glYMb]o:GL002Ug:gl00800007
YMb]o:GLYObUg:glYM`00P001Ooo0P001?oo00<00?ooool07Ooo001Bool2000;ool200004Jgk002]
nkGl[O^eo:gk]Ob]nkGl[O^eo:gk]O`00;Gl[O/00P00016eo:gk[Ob]nkGl[O^]o:gk002]njgl[O^]
o:gk[Ob]njgl0080000A[O/00:gk[Ob]njgl[O^]o:gk[Ob]njgl[O^]o000[ObUn`0200004JglYO^]
o:gk[ObUnjgl002]o:Gk[Ob]njglYO^]o:gk[O`00`00012]o:Gk[ObUnjglYO^]o:Gk[ObUnjgl002]
o:Gk[ObUn`80000;[ObUnjglYO^]o000[ObUnjglYO^]o00300001JglYO/00:Gl[O`00P0001:Uo:gl
002]o:Gl[ObUnjgl002]o:Gk[ObUo:glYO^]o:Gl[O`300002ZglYO^]o:Gl[ObUnjglYOb]o:Gk0P00
1?oo00<00?oo00000_oo00<00?oo00007_oo001Aool200000ooo003oo`07ool200004;Gk[M^]njgK
002]fjgk[M^]njgK[O^]fjgk[M^]njgK0`00016]fjgl[M^]njgK[Ob]fjgk[M^]o:gK002]fjgl[M^]
njgK0080000@[O^]fjgl[M/00:gK[Ob]fjgl[M^]o:gK[Ob]fjgl[M/300004JgK[Ob]fjgl[M^]o:gK
[Ob]fjgl002]o:gK[Ob]g:gl[M/00P00016]o:gK002]g:gl[M^]o:gL[Ob]fjgl[Mb]o:gK002]g:gl
0080000:[Mb]o:GL[Ob]g:glYMb]o000[O`300001JglYMb]o:gL[O`00`00016]o:GL[ObUg:gl002]
o:GL[ObUg000YMb]o:GL[ObUg:gl00<0000=[ObUg000YMb]o:GLYObUg:glYMbUo:GL[O`00P001?oo
00<00?oo00000_oo00<00?oo00007_oo001Aool01@00oooooooo00001Ooo0P00012]nkGl[O^enjgk
]Ob]n`00[O^eo:gk]Ob]nkGl[O^eo080000B[O^eo000]Ob]njgl[O^eo:gk[Ob]nkGl[O^]o:gk002]
njgl0P00012]njgl[O^eo:gk[Ob]n`00[O^]o:gk[Ob]njgl[O^]o080000A[O^]o000[ObUnjgl[O^]
o:Gk[Ob]njglYO^]o000[ObUn`0300004:Gk[Ob]njglYO/00:Gk[ObUnjglYO^]o:Gk[ObUnjgl0`00
00Z]o:Gk[ObUnjglYO^]o:Gk[ObUn`800005[ObUnjglYO^]o00300004JglYO/00:Gl[ObUnjglYOb]
o000[ObUo:glYO/00:Gl[O`00`00012]o:Gk[ObUo:gl002]o:Gl[ObUnjglYOb]o:Gk[ObUo0<000?o
o`8000?oo`03003oo`0001koo`00DOoo0P000ooo00<00?oo00000P00012]njgK]O^]fjgk[M^enjgK
[O^]f`00[M^]njgK[O^]f`80000A[O^]fjgk[M^]n`00[O^]fjgl[M^]njgK[Ob]fjgk[M^]o0030000
4:gl[M^]njgK[Ob]fjgk[M^]o:gK002]fjgl[M^]o:gK0P00012]njgK[Ob]fjgk002]o:gK[Ob]fjgl
[M^]o:gK[Ob]f`<0000A[M^]o:gL[Ob]fjgl[Mb]o:gK002]g:gl[M^]o:gL[Ob]f`0200002Zgl[M/0
0:gL[ObUg:gl[Mb]o:GL0`0000BUg000[Mb]o0<0000A[ObUg:gl[Mb]o000[ObUg:glYMb]o:GL002U
g:glYMb]o00300004JglYMb]o:GL[ObUg:glYMb]o000YObUg:glYMbUo:GL[O`00P0000BUg:gl0000
00;oo`03003ooooo00;oo`03003oo`0001koo`00DOoo00<00?ooool00_oo0P00016enjgk002]nkGl
[O^enjgk]Ob]nkGk[O^eo:gk002]nkGl0080000A[O^eo:gk]Ob]nkGl[O^eo000]Ob]njgl[O^eo:gk
[Ob]n`0200004KGl[O/00:gk[Ob]nkGl[O^]o:gk]Ob]njgl[O/00:gk[O`00P00012]njgl[O^]o:gk
[Ob]njgl002]o:Gk[Ob]njglYO^]o080000B[O^]o000[ObUnjgl[O^]o:Gk[Ob]njgl002]o:Gk[ObU
njgl0P0000VUnjglYO^]o:Gk002UnjglYO/00`0000BUnjglYO^]o0<0000B[ObUnjglYO^]o:Gk[ObU
njgl002]o:Gl[ObUnjglYO`00:Gk0P0001:]o:Gk002Uo:glYO^]o:Gl[ObUnjglYOb]o000[ObUo:gl
YO/200001:glYO^]o:Gl0P000ooo0P000ooo00<00?ooool07Ooo001Aool00`00ooooo`0200004JgK
]O^]fkGk[M/00:gK[O^]fkGk[M^]njgK]O^]fjgk[M/00P00016]njgK[O^]fjgk[M^]njgK[O^]fjgk
002]njgK[Ob]fjgk0080000@[M^]njgK[O^]f`00[M^]o:gK[O^]fjgl[M^]njgK[O`300004:gl[M^]
njgK[Ob]fjgk[M^]o:gK002]fjgl[M^]o:gK0P0001:]o:gK[Ob]fjgl002]o:gK[Ob]g:gl[M^]o:gL
[O`00:gl[M`200002:gl[Mb]o:gK[Ob]g:gl[M/300001JGL[Ob]g:glYM`00P0001:]o:gL002]g:gl
YMb]o:gL[ObUg:gl[Mb]o000[ObUg:glYM`300004ZGL[ObUg:gl002]o:GL[ObUg:glYMb]o:GL[ObU
g000YMbUo0800007YMbUo:GL[ObUg:GlYM`00P009ooo001Aool300004KGk[O^enjgk]O^]nkGk[O/0
0:gk]Ob]nkGk[O^eo:gk]O/00P00016]n`00[O^eo:gk]Ob]nkGl[O^eo:gk]Ob]nkGl002eo:gk0080
000@]Ob]nkGl[O^eo:gk]Ob]n`00[O^]o:gk]Ob]njgl[O/200004Jgl[O/00:gk[Ob]njgl[O^]o:gk
[Ob]njgl[O/00:gk[O`00P00016]njgl[O^]o:gk[Ob]njgl002]o:Gk[Ob]njglYO^]o:gk00<00007
YO^]o:Gk[ObUnjglYO/0100000F]o:Gk[ObUnjgl0080000BYO^]o:Gk[O`00:glYO^]o:Gk[ObUnjgl
YO^]o:Gk002Unjgl0P0001:UnjglYO`00:Gk[ObUo:gl002]o:Gl[ObUnjglYOb]o:Gk[O`300002Zgl
YOb]o:Gk[ObUo:glYO^]o:Gl0P009_oo001@ool200004JgK]O^]fkGk[M^enjgK]O^]fkGk[M/00:gK
[O^]fkGk[M/00P00012enjgK[O^]f`00[M^]njgK[O^]fjgk[M^]njgK[O^]f`<0000@[M^]njgK[O^]
fjgk[M^]njgK[O/00:gk[M^]o:gK[O/200004:gK[O^]fjgl[M/00:gK[Ob]fjgk[M^]o:gK[O^]fjgl
0`00016]o:gK[Ob]fjgl[M^]o:gK[Ob]f`00[Mb]o:gK[Ob]g:gl00800007[M^]o000[Ob]g:gl[M/0
0`0000N]fjgl[Mb]o000[Ob]g00200004Jgl[Mb]o:gL[Ob]g:gl002]o:gL[ObUg:gl[Mb]o:GL[O`0
0`00016]o:GL[ObUg:gl002]o:GL[ObUg:gl002]o:GL[ObUg:gl00<0000=[ObUg000YMbUo:GL[ObU
g:GlYMb]o:GLYO`00P009_oo001@ool200003kGk[O^enjgk]O^]nkGk[O^enjgk]O^]n`00[O^eo002
00004:gk]Ob]nkGk[O^eo:gk002]nkGl[O^eo:gk]Ob]nkGl0P00016]nkGk002eo:gk]Ob]nkGl[O^e
o:gk]Ob]nkGl002eo:gk0080000@]Ob]njgl[O^eo:gk[Ob]n`00[O^]o:gk[Ob]njgl[O/200004Jgl
[O/00:gk[Ob]njgl[O^]o:gk[Ob]njgl[O/00:gk[O`00`0000F]o:Gk[Ob]njgl00@00007YO^]o:Gk
[ObUnjglYO/00`00012UnjglYO^]o:Gk[ObUnjglYO^]o000[ObUnjglYO^]o0<0000A[ObUn`00YO^]
o:Gl[ObUnjgl002]o:Gk[ObUo000YO^]o00300004:glYOb]o:Gk[ObUo000YO^]o:Gl[ObUnjglYOb]
o:Gk0`009Ooo0015ool30003ool00`00ooooo`02ool03`00ool00;Gk[M^enjgK]O^]fkGk[M^enjgK
]O^]f`0200004:gk[M^enjgK[O^]fkGk[M^]njgK002]fjgk[M^]njgK0P00016enjgK[O^]fkGk002]
njgK[O^]fjgk[M^]njgK[O^]fjgk0080000@[M^]o:gK[O^]fjgl[M^]njgK[O`00:gk[M^]o:gK[O/2
00004:gK[O^]fjgl[M/00:gK[Ob]fjgl[M^]o:gK[Ob]fjgl0`0000J]o:gK[Ob]fjgl[M/400001Zgl
[Mb]o:gK[Ob]g0<0000@[Mb]o000[Ob]g:gl[Mb]o:gL[Ob]g:gl[M`00:GL[O`300004Jgl[Mb]o:GL
[Ob]g000YMb]o:GL[ObUg:gl002]o:GL[O`00`00012]o:GL[ObUg:glYMb]o:GL[O`00:glYMbUo:GL
[ObUg0<00003YMbUo00002Goo`00AOoo00<00?ooool00_oo00<00?oo00000ooo0P0000_oo`00002]
nkGk[O^enjgk]O^]nkGk0080000@[O/00:gk]Ob]nkGk[O^eo:gk]O^]nkGl[O/00:gk]O`200004Jgk
]Ob]nkGk[O^eo:gk]O/00;Gl[O^eo:gk]Ob]nkGl[O/00P00012en`00]Ob]njgl[O^eo:gk[Ob]nkGl
[O^]o000[Ob]n`80000@]Ob]njgl[O^eo:gk[Ob]n`00[O^]o:gk[Ob]njgl[O/200001Zgl[O/00:gk
[ObUn`<00007YO^]o:gk[O`00:glYO/00`00012]njglYO^]o:gk002UnjglYO^]o:Gk[ObUnjglYO^]
o0<0000@[ObUnjglYO^]o:Gk[ObUnjglYO/00:Gk[ObUo:glYO/400004:glYO`00:Gk[ObUo:glYO^]
o:Gl[ObUnjgl002]o:Gk0`0000FUnjglYOb]o:Gk008002Coo`00A_oo00L00?ooooooo`00ool00003
ool00`00ooooo`02ool01P00[M^enjgK]O^]f`80000@]O^]fkGk[M/00:gK[O^]fkGk[M^]njgK]O^]
fjgk[M/200004Jgk[M^enjgK[O^]fkGk[M^]njgK]O/00:gk[M^]njgK[O/00P00012]fjgk[M^]n`00
[O^]fjgl[M^]njgK[Ob]fjgk[M^]o080000@[M^]o:gK[O^]fjgl[M^]njgK[O`00:gl[M^]o:gK[O`2
00001ZgK[O^]fjgl002]o0800007[M^]o:gK[Ob]fjgl[M/00`00016]g:gl[M^]o:gL[Ob]fjgl[M`0
0:gL[Ob]g:gl[Mb]o:gL0080000A[Ob]g000YMb]o:gL[ObUg:gl[Mb]o:GL[Ob]g000YMb]o0040000
3jgL[ObUg:gl002]o:GL[ObUg:glYMb]o:GL[ObUg00300002JGLYObUg:glYMbUo:GL[ObUg002000S
ool004Koo`07003oooooool00?oo00000ooo00<00?ooool00ooo00<00:gk]O/00P00012]n[Gk[O^e
njgj]O^]n`00[O^eo:gk]O^]nkGl[O^en`80000A[O/00:gk]Ob]nkGk[O^eo:gk]O^]nkGl[O^en`00
]Ob]n`0200004;Gl[O^enjgk]Ob]nkGk002eo:gk[Ob]nkGl[O^]o:gk0P00012eo000]Ob]njgl[O^e
o:gk[Ob]nkGl[O^]o000[Ob]n`800005[Ob]njgl[O^]o00300001jgl[O^]o:Gk[Ob]njgl0080000B
[O^]o000[Ob]njglYO^]o:gk[ObUnjgl[O/00:Gk[ObUnjgl0P00012UnjglYO^]o:Gk002UnjglYO^]
o:Gk[ObUnjglYO^]o0<0000A[ObUo:glYO/00:Gl[ObUnjgl002]o:Gk[ObUo:glYO^]o00200003ZGk
[O`00:glYO^]o:Gl[ObUnjglYOb]o:Gk000Sool004Goo`03003oo`0000;oo`03003oo`0000;oo`80
00Koo`80000@]O^]fkGk[M^enjgK]O^]fkGk[M/00:gK[O^]fkGk[M/200004;Gk[M^enjgK002]fjgk
[M^enjgK[O^]fkGk[M^]njgK0`00012]fjgk[M^]njgK[O^]fjgk[M^]n`00[O^]fjgl[M^]n`80000?
[M^]njgK[O/00:gk[M^]o:gK[O^]fjgl[M^]njgK00<00004[M^]o:gK[O/300002:gk[M^]o000[Ob]
fjgl[M/200004Zgl[M^]o:gK[O`00:gl[Mb]o:gK[Ob]g:gl[M^]o000[Ob]g080000@[Ob]fjgl[Mb]
o:gK[Ob]g000YMb]o:gL[ObUg:gl[M`200004Zgl[M`00:GL[Ob]g:glYM`00:gL[ObUg:gl002]o:GL
[ObUg080000?[ObUg:glYM`00:GL[ObUg:GlYMb]o:GLYObUg:gl008002;oo`00A_oo00<00?ooool0
0_oo00D00?ooooooo`0000Soo`0?002]n[Gk[O^enjgj]O^]nkGk[OZenjgk002]nkGl0080000@[O^e
njgk]O^]nkGk[O/00:gk]Ob]nkGk[O^eo:gk]O/200004Jgk]O/00;Gl[O^enjgk]Ob]nkGk[O^eo:gk
]O/00;Gl[O/00P0000neo:gk]Ob]nkGl[O^eo000]Ob]njgl[O^eo:gk[O`00P0000B]njgl002]o0<0
0009[Ob]njgl[O^]o:gk002Unjgl0080000A[O^]o:gk[Ob]njgl[O^]o000[Ob]njglYO^]o:gk[ObU
n`0300004:Gk[ObUnjglYO^]o:Gk[ObUnjgl002]o:Gk[ObUnjgl0P0001:UnjglYO^]o000[ObUnjgl
YOb]o000[ObUo:glYO/00:Gl[O`200004JGl[ObUnjglYOb]o:Gk002Uo:glYO^]o:Gl[ObUnjglYO`0
0`001_oo00<00?ooool00_oo00<00?ooool04ooo001?ool20008ool03000[M^enjgK]O^]fkGk[M^e
njgK]O^]f`80000@]O^]fkGk[M^enjgK]O^]fkGk[M/00:gK[O^]fkGk[M/200004;Gk[M^]njgK]O/0
0:gk[M^]njgK[O^]fjgk[M^]njgK0`0000n]fjgk[M^]njgK[O^]fjgk[M/00:gK[O^]fjgl[M/00P00
00>]njgK[O/00`0000Z]njgK[Ob]fjgk[M^]o:gK[O^]f`80000A[Ob]fjgl[M^]o:gK[Ob]fjgl[M/0
0:gK[Ob]g:gl[M^]o00200004JgK[O`00:gl[M^]o:gL[Ob]fjgl[Mb]o:gK[O`00:glYM`00P00016]
o:GL[Ob]g:glYMb]o000[ObUg:gl[Mb]o000[Ob]g:gl00<0000@[ObUg:glYMb]o:GL[ObUg:gl002U
o:GL[ObUg:GlYM`300000jGL[O`00005ool00`00ool00002ool00`00ool0000Dool004ooo`03003o
oooo00Soo`09002]n[Gk[O^enjgj]O^]nkGk0080000@[IX00:gk]O^]nkGk[O^enjgk]O^]nkGk[O/0
0:gk]O`200004:gk]O^]nkGk[O^enjgk]O/00;Gl[O^enjgk]Ob]nkGk0P00012]nkGk002eo:gk]Ob]
nkGl[O^eo:gk]Ob]n`00[O^eo0800003[O^eo0000080000;]Ob]njgl002]o:gk[Ob]njgl[O^]o002
00004:gk002]njgl[O^]o:gk[Ob]njgl[O^]o:gk002Unjgl0`00012]o:gk[ObUnjgl002]o:Gk[ObU
njglYO^]o:Gk[ObUn`<0000@YO^]o:Gk[ObUnjglYO^]o:Gk[O`00:glYO^]o:Gl[O`300003jglYO/0
0:Gl[ObUnjglYOb]o:Gk[ObUo:gl002]o00400001JGl[ObUnjglYO`00P001?oo00<00?oo00000_oo
00<00?oo00005?oo001?ool20009ool06@00]O^]fkGk[M^enjgK]O/00;Gk[M^enkGK002]fkGk[M^e
njgK]O^]fkGk[M^enjgK0080000@[O^]fkGk[M^]njgK]O^]fjgk[M/00:gK[O^]fjgk[M/200004;Gk
[M^]njgK]O/00:gk[M^]njgK[O^]fjgk[M^]njgK0P00012]n`0000000:gk[M^]njgK[O^]f`00[M^]
njgK[Ob]f`80000?[Ob]fjgk[M/00:gK[Ob]fjgl[M^]o:gK[Ob]fjgl00<0000@[Ob]g:gl[M^]o:gL
[Ob]fjgl002]o:gK[Ob]g:gl[M/300004:gK[O`00:glYMb]o:gL[ObUg:gl[Mb]o:GL002]g:gl0`00
00n]o000[Ob]g:gl002]o:GL[ObUg:glYMb]o:GL[O`00`0000ZUo:GL[ObUg:GlYMb]o:GLYObUg080
00Coo`07003oooooool00?oo00005?oo001?ool00`00ooooo`09ool01@00]O^]n[Gk[O/00P0000ne
njfJ]O^]V[Gk[IX00:gk]O^]nkGk[O^enjgk]O/00P00012]V`00[O^enjgk]O^]nkGk[O^enjgk]O^]
n`00[O^eo080000@[O^eo:gk]O^]nkGl[O^en`00]Ob]nkGl[O^eo:gk]O`500003KGl[O^]o:gk]Ob]
njgl[O^eo:gk002]njgl0080000?[O^eo:gk[Ob]nkGl[O/00:gk[Ob]njgl[O^]o:gk0080000@[Ob]
n`00YO^]o:gk[ObUnjgl[O^]o:Gk[O`00:glYO/300004:Gk[ObUnjglYO^]o000[ObUnjglYO^]o:Gk
[ObUnjgl0`0000n]o:Gk[ObUn`00YO^]o:Gk[O`00:glYOb]o:Gk[O`00`0000f]o:Gl002UnjglYOb]
o:Gk[ObUo:glYO^]o0020003ool00`00ool00002ool00`00ool0000Dool004Coo`<000;oo`03003o
oooo00?oo`03003ooooo00[oo`0C002en`00002efkGk[M^enkGK]O^]fkGk]M/00:gK]O^]fkGk[M/0
0P00012enjgK]O^]f`00[M^]njgK]O^]fjgk[M^enjgK[O^]f`80000@[O^]fkGk[M^]njgK]O^]fjgk
[M/00:gK[O^]fjgk[M/400003Jgk[M/00:gK[O^]fjgk[M^]njgK[O^]fjgk00<0000?[O^]fjgl[M^]
njgK[Ob]fjgk002]o:gK[Ob]fjgl0080000?[M^]o:gK[O/00:gl[M^]o:gL[Ob]fjgl[Mb]o:gK00<0
000@[M^]o:gL[Ob]fjgl[Mb]o:gK002]g:glYMb]o:gL[O`300003jgl[M`00:gL[ObUg:gl[M`00:GL
[Ob]g000YMb]o00300004:glYMb]o:GL[ObUg000YMbUo:GL[ObUg:GlYMb]o:GL0`000ooo00<00?oo
ool00_oo00<00?ooool04ooo000`ool2000Cool01P00ooooo`00ool000?oo`8000goo`0@002enjfJ
]O^]V[Gk[IZenjfJ]O^]V[Gk[IX00:gk]O/200004:fJ]O^]VkGk[IZenjfK002]nkGk[O^enjgk]O^]
nkGk0P00012]n`00[O^eo:gk]O^]nkGl[O^enjgk]Ob]n`00[O^eo0<0000>]Ob]nkGk[O^eo:gk002]
nkGl[O^]o:gk]Ob]n`80000@]Ob]n`00[O^eo:gk[Ob]nkGl[O^]o:gk]O`00:gl[O/200003jgl[O^]
o:gk[Ob]njgl002]o:Gk[Ob]njglYO^]o00200004:gk[O`00:glYO^]o:Gk[ObUnjglYO^]o:Gk002U
njgl0`0000n]o:Gk[ObUnjglYO/00:Gk[ObUnjglYO/00:Gk[O`00`00012]o:Gl[ObUnjglYOb]o:Gk
[O`00:glYO^]o:Gl[ObUn`<00004YO^]o000000Mool0037oo`03003ooooo00ooo`@00004ool00?oo
0003ool00`00ooooo`0=ool03@00]O^]fkGk]M^enjgK]O^efkGk[M^enkGK0080000@]O^]fkGk[M^e
njgK]O^]fkGk[M/00:gK[O^]fkGk[M/200003kGk[M^enjgK002]fjgk[M^enjgK[O^]fkGk[M^]n`03
00003jgk[M^enjgK[O^]fkGk[M^]n`00[O^]fjgk[M^]n`0200003jgK[O^]fjgk[M/00:gK[O^]fjgl
[M^]njgK[Ob]f`0300003jgK[O^]fjgl[M^]njgK[Ob]fjgk002]o:gK[Ob]g00200003jgl[M^]o:gK
[O`00:gl[M^]o:gL[Ob]fjgl[Mb]o00300003jgl[Mb]o:gL[Ob]g:gl[Mb]o000[Ob]g:glYMb]o003
00004:gl[M`00:GL[ObUg:glYMb]o:GL[ObUg:gl002]o:GL0`0000NUg:GlYMb]o:GLYO`0000Mool0
00;oo`D00004ool000000002ool400000ooo00000004ool20002ool30002ool30002ool30003ool2
0003ool00`00ooooo`0?ool00`00ool00002ool00`00ool00003ool00`00ooooo`0>ool02P00]O^]
V[Gk[IZenjfJ]O^]V[Gk0P00012]VP00[IZenjfK]O^]V[Gk[I^enjfJ]O^]V`00[O^en`80000?[OZe
njgk]O^]n[Gk[O/00:gk]Ob]nkGk[O^eo:gk00<0000?[O/00:gk]Ob]nkGk[O^eo:gk]O^]nkGl002]
o:gk0080000?]O^]nkGl[O^enjgk]Ob]n`00[O^eo:gk[Ob]nkGl0080000@[O^eo000[Ob]njgl[O^]
o:gk[Ob]njgl[O/00:gk[O`200003Zgk[Ob]njgl[O^]o:gk002UnjglYO^]o:Gk[O`300004:glYO/0
0:Gk[ObUnjglYO^]o:Gk[ObUnjgl002]o:Gk100000j]o:Gk[ObUn`00YO^]o:Gl[ObUnjglYOb]o:Gk
0`0000VUnjglYOb]o:Gk[ObUo:glYO/00P007?oo0003ool01000ooooo`000_oo00@00?ooooooo`<0
00Coo`04003ooooo0002ool01000ooooo`000ooo00<00?ooool00ooo00D00?ooooooo`0000;oo`05
003oo`00ool0000Aool20002ool00`00ool00003ool2000@ool06000]O^]fkGk]M^enjgK]O/00;Gk
]MZenkGK002]fkGk[M^enjgK]O^]fkGk[M^en`<0000>]O^]fkGk[M^enjgK]O^]fkGk002enjgK[O^]
f`<0000?[M^enjgK]O^]f`00[M^]njgK]O^]fjgk[M^enjgK00<0000>[M^]njgK[O^]fjgk[M^]njgK
[O^]f`00[M^]n`<0000?[O^]fjgk[M^]n`00[Ob]fjgk[M^]o:gK[O^]fjgl00<0000=[Ob]fjgl[M^]
o:gK[Ob]fjgl[M/00:gL[O`00`00012]o:gK[Ob]g:gl[M/00:gL[Ob]g:gl[Mb]o:gL[Ob]g0<0000?
[Mb]o:GL[O`00:glYMb]o000[ObUg:glYMb]o:GL00<0000=YMb]o000[ObUg:GlYMb]o:GLYObUg:gl
YM`00P006ooo0003ool00`00ooooo`03ool00`00ooooo`03ool01@00oooooooo00000ooo00<00?oo
ool00ooo00D00?ooooooo`0000Goo`05003oooooool00004ool00`00ool0000Bool01@00oooooooo
00001?oo00<00?ooool04?oo00D00;Gk[IZenjfJ0080000>]O^]V[Gk[IZenjfJ002]V[Gk[I^enjfJ
]O^]V`80000=]O^]VP00[OZenjgk]O^]n[Gk[O^enjgj]O/01@0000nenjgk]O^]nkGk[O^enjgk002]
nkGl[O^enjgk]O`00P0000j]V[Gk002enjgk]Ob]nkGk[O^eo:gk]O^]nkGl0`00012eo:gk]Ob]nkGl
[O^eo:gk]O`00:gl[O^]o:gk[Ob]n`80000>[Ob]n`00[O^]o:gk[Ob]njgl[O^]o:gk[Ob]n`80000@
[ObUnjgl[O^]o:Gk[Ob]njgl002]o:Gk[ObUnjglYO/300003jGk[O`00:glYO^]o:Gk[O`00:glYO^]
o000[ObUn`0300004:Gk[ObUo:glYO^]o000[ObUnjglYOb]o:Gk[ObUo:gl0P006ooo0003ool20004
ool00`00ooooo`02ool20003ool200000ooo000000020002ool20003ool30002ool20002ool40000
1?oo00000?oo0P006Ooo0P004ooo01800;Gk00000;GK]O^ef[Gk]M^enkGJ]O/00;Gk[M^enjgK]O/2
00003KGK]O^]fkGk]M/00:gK]O^]fkGk[M^enjgK00D0000>[M^enjgK]O^]fkGk[M^enjgK]O^]f`00
[M^]n`<0000>[O^]fkGk[M^]n`00[O^]fjgk[M^]njgK[O^]f`80000@[O^]f`00[M^]njgK[O^]fjgk
[M^]njgK[O/00:gl[M/300003ZgK[O^]fjgl[M/00:gK[Ob]fjgl[M^]o:gK[O`200003jgK002]g:gl
[M^]o:gL[Ob]fjgl[Mb]o000[Ob]g00300003jgL[Ob]g:gl[M`00:GL[Ob]g:glYM`00:gL[ObUg003
00004:GL[ObUg:glYMb]o:GL[ObUg000YMb]o:GLYObUg:gl0`0000>]o:GL00006_oo0003ool01000
ooooo`000_oo00<00?ooool02ooo00<00?ooool04Ooo00<00?ooool07ooo00<00?ooool04ooo00l0
0;Gk[IZenjfJ]O^]V[Gk[IZenjfJ]O/00;Gk[IX00P0000benjfJ]O^]V[Gk[IZenjfJ002]n[Gk[O/3
00004Jgk00000;Gk002enjgk]O^]nkGk[O^enjgk]O^]nkGk[O/00P0000nenjfK]O^]V[Gk[I^enjfJ
]O/00;Gk[O^eo:gk]O/00P0000n]nkGk[O^eo000]Ob]nkGl[O^eo:gk]Ob]nkGl[O/00`0000n]nkGl
[O^]o:gk]Ob]njgl[O/00:gk[Ob]njgl[O/00P0000j]o:gk[O`00:gl[O^]o:Gk[Ob]njglYO^]o:gk
0`0000nUnjglYO^]o:Gk[ObUnjglYO/00:Gk[ObUnjglYO/00`00012Unjgl002]o:Gk[ObUo:glYO^]
o:Gl[ObUn`00YOb]o0<00006[ObUnjglYOb]o0006_oo0002ool500000ooo0000000Cool00`00oooo
o`07ool00`00ooooo`0Sool00`00ooooo`0Dool03000]O^ef[Gk]M^enkGJ]O^efkGk]MZen`80000:
[M^enkGK]O^]fkGk]M^enjgK]O/400004ZgK]O/00000]M^enjgK]O/00;Gk[M^enjgK]O^]fkGk[M^e
n`80000?[I/00:gK[O^]fkGk[M^]njgK]O^]fjgk002]njgK0080000?]O^]fjgk[M^enjgK[O/00:gk
[M^]njgK[O^]fjgk0080000@[M^]n`00[Ob]fjgk[M^]o:gK[O^]fjgl[M/00:gK[O`200003ZgK[Ob]
fjgl[M^]o000[Ob]g:gl[M^]o:gL[O`200003jgL[O`00:gl[Mb]o:gL[Ob]g:gl[Mb]o000[ObUg003
00004:GL002]g:glYMb]o000[ObUg:glYMb]o:GL[ObUg:gl0`0000Z]o:GLYObUg:glYMbUo:GL[O`0
01Woo`00COoo0P005_oo00T00;Gk[IZenjfJ]O^]V[Gk[IX00P0000Zen`00]O^]V[Gk[IZenjfJ]O^]
VP@0000;]O^]nP00002enjfJ]O^]V[Gk[IZen`0200001Jgk]O^]nkGk[O/00P0000nenjfJ]O^]VP00
[IZenjfK]O^]V[Gk[I^enjfJ]O/00P0000n]nkGl[O^enjgk]Ob]nkGk[O^eo000]Ob]nkGl[O/00P00
00neo:gk]O^]n`00[O^]o:gk]Ob]njgl[O^eo:gk[O`00`0000j]o:gk[Ob]njgl[O^]o:gk[O`00:gl
[O^]o:Gk0P0000n]o:Gk[Ob]n`00YO^]o:Gk[ObUnjglYO^]o:Gk[O`00P00012UnjglYO^]o:Gk002U
njglYO/00:Gl[ObUnjglYOb]o0<0000<[ObUn`00YOb]o:Gk[ObUo:glYO^]o:Gl0P006?oo0012ool2
0004ool00`00ooooo`02ool00`00ooooo`0Fool01P00]O^ef[Gk]M^en`800009]IZenkFJ]O/00;Gk
[M^enkGK00<00004]M^enjgK]O/200003ZgK]O^efkGk[M^enkGK]O^]fkGk]M/00:gK]O/200003jfK
]O^]VkGk[I^enjfK002]fjgk[M^enjgK[O^]f`0200003kGk002enjgK[O^]fkGk[M^]njgK]O^]f`00
[M^]n`0200003jgK]O^]fjgk[M^enjgK002]fjgl[M^]njgK[Ob]f`0200003jgk[M/00:gK[Ob]fjgl
[M^]o:gK[Ob]f`00[M^]o00200003jgK[Ob]g:gl[M^]o:gL002]g:gl[Mb]o:gL[Ob]g00200003jgl
002]o:GL[Ob]g:gl002]o:gL[ObUg000YMb]o00300003jglYMb]o:GL[O`00:GlYMb]o:GLYObUg:gl
YMbUo0020005ool50002ool00`00ooooo`02ool00`00ooooo`04ool004;oo`03003oo`0000;oo`03
003oo`0000?oo`03003ooooo01Ooo`03002enjfJ00800007]O^]V[Gk[IZenjfJ]O/0100000F]V[Gk
[IZenjfJ0080000>]O/00;Gk[IZenjfJ]O^]V[Gk[IZenjfJ]O^]VP80000?]O^]V[Gk[IZenjfJ]O^]
V[Gk002enjfJ]O^]VkGk0080000?[I^enjfJ]O/00;Gk[O^eo:gk]O^]nkGl[O^enjgk0080000?]O^]
nkGl[O^enjgk]Ob]nkGk[O/00:gk[Ob]nkGl0080000>[O^eo:gk]Ob]n`00[O^]o:gk[Ob]njgl[O^]
o0<0000?[Ob]njglYO^]o:gk[ObUnjgl[O/00:Gk[ObUnjgl0080000>YO^]o:Gk[O`00:glYO^]o:Gk
[O`00:glYO^]o0<0000?[ObUnjglYOb]o:Gk[ObUo:gl002]o:Gl[ObUnjgl00<00003[ObUo00000Ko
o`07003oooooool00?oo00000_oo00<00?oo00001Ooo0012ool00`00ool00002ool00`00ool00002
ool2000Jool200002;FJ]O^eV[Gk]IZenkFJ]O/300001KGk[M^enkGK]O/00P0000jeV[Gk]IZen`00
]O^]fkGk]M^enjgK]O^efkGk0P0000neVP00[I^enjfK]O^]VkGk[I^enjfK]O/00;Gk[M/00P0000ne
njgK]O^]fkGk[M^en`00]O^]fjgk[M^enjgK[O/00P0000n]f`00[M^enjgK[O^]fkGk[M^]njgK]O/0
0:gk[M/00P0000j]njgK[O^]fjgk[M^]n`00[Ob]fjgl[M^]o:gK0P00012]njgK002]fjgl[Mb]o:gK
[Ob]g:gl[M^]o000[Ob]g080000=[Ob]g:gl[Mb]o:gL002]g:glYMb]o:gL[O`00`0000n]o:GL002U
g:glYMb]o:GL[ObUg:glYM`00:GLYO`00`0000F]o:GL[ObUg:gl008000Goo`07003oooooool00?oo
00000_oo00<00?oo00001Ooo0012ool20003ool00`00ool00002ool00`00ooooo`0Jool01P00]O^]
V[Gk[IZen`<00006]O^]V[Gk002enjfJ0P0000jenjfJ]O^]V[Gk[IZen`00]O^]V[Gk[IZenjfJ0P00
00nenjfJ]O^]VP00[IZenjfJ]O^]V[Gk[IZenjfJ]O/00P0000n]V[Gk[I^enjfJ]O^]VkGk[IX00:gk
]O^]nkGl[O/00P0000jenjgk]O^]nP00[O^enjgk]Ob]nkGk[O^eo:gk0`0000f]nkGl[O^eo:gk]Ob]
nkGl[O^eo000[Ob]n`0300003jgk[Ob]nkGl[O/00:Gk[Ob]njglYO^]o:gk[ObUn`0300003:Gk[ObU
njglYO^]o:Gk[ObUn`00YO^]o0@0000>YO^]o:Gk[O`00:glYOb]o:Gk[ObUo:glYO^]o0<0000:[ObU
o:glYO^]o:Gl[ObUnjgl0005ool01`00oooooooo003oo`0000;oo`03003oo`0000Goo`00@_oo00<0
0?ooool00_oo00<00?oo00000_oo0P007?oo00<00;Gk00000P0000NenkFJ]O^eV[Gk]IZen`020000
3[FJ]O^eV[Gk]IZenkFJ]O^eVP00]M^enjgK]O/200003jfJ]K^eV[Fk[IZe^kFJ002]VkGk[I^enjfK
]O^]V`0200003kGk002enjgK]O^]fkGk[M^enjgK]O^]f`00[M^en`0200003ZgK]O^]fkGk[M^enjgK
002]fkGk[M^]njgK]O/200003JgK]O/00:gk[M^]njgK[O^]fjgk[M^]njgK00<0000?[M^]o:gK[O^]
fjgl[M^]n`00[Ob]fjgl[Mb]o:gK00<0000=[M^]o000[Ob]g:gl[Mb]o:gL[Ob]g:gl[M`00P0000n]
o:GL[Ob]g000YMb]o:gL[O`00:glYMb]o:GL[O`00`0000b]o:GL002Ug:glYMb]o:GL[ObUg:glYM`2
0004ool01`00oooooooo003oo`0000;oo`03003oo`0000Goo`00@ooo0P000ooo00D00?ooooooo`00
01coo`<00008]O^]V[Gk[IZenjfJ]O^]VP80000>]O/00;Gk[IZenjfJ]O^]V[Gk[IZenjfJ002]VP80
000?]O^]V[Gk[IZenjfJ]O^]V[Gk002enjfJ]O^]V[Gk0080000?[IZenjfJ]O/00;Gk[IZenjfK]O^]
V[Gk[I^enjfJ0080000=]O^]n[Gk[O^enjgj]O^]nkGk[OX00:gk]O/00`0000fenjgk]O^]nkGk002e
o:gk]Ob]nkGl[O^eo00200003jgk]O/00;Gl[O^]o:gk]Ob]njgl[O^eo000[ObUn`0300003Zgk[Ob]
njgl[O^]o000[ObUnjglYO^]o:Gk[O`200003ZGk002UnjglYO^]o:Gk002UnjglYO/00:Gk[O`30000
3jglYOb]o:Gk[O`00:glYO^]o:Gl[ObUnjglYOb]o0020003ool20004ool00`00ooooo`02ool00`00
ooooo`04ool004coo`03003ooooo01Ooo`<000?oo`06002enkFJ]O^eV[Gk0P0001neV[Fk]IZe^P00
]O^eV[Gk]IZenkFJ]O^eV[Gk]IX00;FJ]K^]V[Fk]IZe^jfJ]K^eV[Fk[IZe^`00]O^]V`0200003kGk
]IZenkFK]O^eV[Gk002enjgK]O^]fkGk[M^en`0200003JfJ002]fkGk[M^enjgK]O^]fkGk[M^enjgK
0080000>]O^]fjgk[M^enjgK[O^]f`00[M^]njgK[O^]f`80000>]O^]fjgk[M^en`00[O^]fjgl[M^]
njgK[Ob]f`<0000?[M^]o:gK[Ob]fjgl[M^]o:gK002]g:gl[Mb]o:gL0080000=[Ob]g:gl[M/00:gL
[ObUg:gl[M`00:GL[O`00`0000n]o:GL[ObUg:glYMb]o:GL[O`00:glYMb]o:GL[O`00`0000?oo`00
ool05?oo0007ool30012ool2000Eool30007ool00`00]O^]VP0200003kGk[IZenkFJ]O^]V[Gk002e
njfJ]O^]V[Gk[IZen`0200003JfJ002]V[Gk[IZenjfJ]O^]V[Gk[IZenjfJ00<0000?[IZenjfJ]O^]
V[Gk[IZenjfJ002]VkGk[IZenjfK0080000=]O^]V[Gk[IX00:gk]O^]n[Gk[O^enjgj]O/00P0000j]
VP00[O^enjgk]O^]nkGk[O^enjgk002]nkGl0P0000j]nkGl[O^enjgk]Ob]n`00[O^eo:gk[Ob]nkGl
0P00012]nkGl002]o:gk[Ob]njgl[O^]o:gk[Ob]n`00YO^]o080000<[O^]o:Gk[Ob]njgl002]o:Gk
[ObUnjgl0`0000n]o:Gk002UnjglYOb]o:Gk[ObUo:glYO/00:Gl[O`00`001?oo00<00?ooool04ooo
0008ool00`00ooooo`10ool00`00ooooo`0Bool3000;ool200003kFJ]KZeV[Fk]IZe^[FJ]K^eVP00
]IZenkFJ]O^eVP0200003KFj]IZe^[FJ002eV[Fk[IZe^kFJ]K^]V[Fk0080000@]IZe^P00]O^eV[Gk
]I^enkFJ]O^eVkGk]IX00:gK]O/200003KFK]O^]V[Gk]I^enjfJ002]fkGk[M^enjgK0080000>]O^e
fkGk002]njgK]O^]fjgk[M^enjgK[O^]f`80000=[O^]fkGk[M^]njgK]O^]fjgk[M/00:gK[O/00`00
00n]njgK[O^]fjgk002]o:gK[Ob]fjgl[M^]o:gK[O`00`0000b]o:gK[Ob]g:gl[M^]o:gL[O`00:gl
[M`400003JglYMb]o:gL002Ug:glYMb]o:GL[ObUg:gl00<000Soo`03003ooooo01;oo`001?oo0P00
0_oo0`000ooo0P000_oo0`000ooo0P0000?oo`0000000_oo00<00?ooool0:Ooo00<00?oo00003ooo
0`003ooo00h00;Gk[IZenkFJ]O^]V[Gk]IZenjfJ002]V[Gk0P0000f]V[Fk[IZe^jfJ]K^]VP00[IZe
njfJ]O^]VP0200004;Gk]IZenjfJ]O/00;Gk[IZenjfJ]O^]V[Gk[IZenjfJ0P0000fenjfJ]O^]V[Gk
[IZenjfJ]O^]VP00[O^en`0200003ZfJ]O^]V[Gk[IZen`00]O^]nkGk[O^enjgk]O/200003JfJ002]
nkGl[O^enjgk]Ob]nkGk[O^eo:gk0080000?]Ob]nkGl[O^eo:gk]Ob]n`00[O^]o:gk[Ob]njgl00<0
000<[Ob]n`00[O^]o:Gk[Ob]njglYO^]o:gk0`0000nUnjglYO^]o000[ObUnjgl002]o:Gk[ObUo:gl
YO/00P002ooo00<00?ooool04_oo0003ool01P00ooooo`00ool000;oo`03003oo`0000;oo`04003o
oooo0003ool01P00ooooo`00ool000;oo`03003ooooo02Woo`8000goo`<001?oo`0;002e^kFJ]KZe
V[Fk]IZe^[FJ]K^eVP0200003KFj]IZe^[FJ]KZeV[Fj]IZe^[FJ002eV[Fk0080000@]IZe^kFJ]KZe
V[Fk]IZe^P00]O^eV[Gk]I^enkFJ]O/200003;FJ002eVkGk[IZenkFK]O^]V[Gk]I^en`<0000>]O^]
fkGk]M^enjgK]O^efkGk002]njgK]O^]f`80000=]O^]fkGk]M/00:gK[O^]fkGk[M^]njgK]O/00P00
00j]f`00[M^]njgK[O^]fjgk[M^]njgK002]fjgl0`0000b]o:gK[Ob]fjgl[M/00:gL[Ob]fjgl[M`3
00003jgL[O`00:gl[Mb]o:GL[O`00:glYMb]o000[ObUg003000=ool00`00ooooo`0Bool000?oo`06
003ooooo003oo`000_oo00<00?oo00001Ooo00D00?ooooooo`0000;oo`03003oo`0000;oo`03003o
oooo01ooo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00[oo`8001Ooo`08002enjfJ]O^e
V[Gk[IZen`80000=[IX00:fJ]K^]V[Fk[IZe^jfJ]K^]V[Fk[IX00P00012enjfJ]O^eV[Gk[IZenkFJ
]O^]VP00[IZenjfJ]O^]VP80000<]O^]V[Gk[IX00:fJ]O^]V[Gk[IZenjfJ0P0000nenjfJ002]V[Gk
[IZenjfJ]O^]V[Gk[IX00:gk]O/00P0000f]V[Gk[IZenjfJ]O^]VP00[O^eo:gk]O^]n`0200003KGk
[OZenjgk002]nkGl[O^eo:gk]Ob]nkGl00<0000<[Ob]nkGl[O^]o:gk]Ob]njgl002]o:gk0`0000n]
njglYO^]o:gk002UnjglYO^]o:Gk002UnjglYO/00`004?oo00<00?ooool04_oo0003ool00`00oooo
o`0500000ooo000000020002ool20004ool200000ooo00000002000Qool00`00ool00002ool00`00
ool00003ool20008ool3000Iool01P00]IZe^kFJ]KZeVP80000=]KZeV[Fj]IX00;FJ]KZeV[Fj]IZe
^[FJ]KX00P00012eVP00]IZe^kFJ]KZeV[Fk]IZe^[FJ]K^eVP00]I^en`80000<]IZe^kFJ]KZeV[Fk
002enkFK]O^]V[Gk0P0000neV[Fj]IZe^`00]O^efkGk[M^enkGK]O^]fkGk]M/00P0000fenkGK]O^]
fkGk]M^enjgK]O^ef`00[M^]n`0200003JgK]O^]fkGk[M^en`00[O^]fjgk[M^]njgK0080000=]O^]
f`00[M^]o:gK[Ob]fjgl[M^]o:gK[O`00P0000n]g:gl[M^]o:gL[Ob]fjgl[M`00:GL[Ob]g:glYM`0
0`004ooo00<00?ooool04_oo0003ool01000ooooo`001_oo00<00?ooool0<?oo00<00?oo00000_oo
00<00?oo00000ooo00<00?ooool01?oo0`007Ooo00<00;FJ]O/00P0001jeV[Fj[IZe^[FJ]KZ]VP00
[IZe^jfJ]K^]V[Fk002e^kFJ]KZeVP00]IZenjfJ]O^eV[Gk[IZenkFJ]O/300003;Gk[IZenjfJ]O^]
V[Gk[IZen`00]O^]VP80000?]O^]V[Gk[IZenjfJ]O/00;Gk[IZenjfJ]O^]V[Gk0080000=[IX00:fJ
]O^]V[Gk[IZenjfJ]O^]V[Gk[IX00P0000benjgk]O^]n[Gk[O^enjgj]O/00;Gl[O/300003Jgk]Ob]
nkGk[O/00:gk[Ob]nkGl[O^]o:gk0080000>]O`00:gl[O^]o:Gk[Ob]njglYO^]o000[ObUn`<00003
ool00?oo01?oo`03003ooooo01;oo`001?oo0P003Ooo00<00?ooool0:ooo00L00?ooooooo`00ool0
0002ool00`00ooooo`02ool3000Qool200003[Fj]IZe^[FJ]KZeV[Fj]IZe^P00]KZeV[Fj]IX20000
3[Fj]IZe^[FJ]KZeVP00]IZe^kFJ]KZeV[Fk]IX200003KFj]IX00;FJ]K^eV[Fj]IZe^kFJ]KZeV[Fk
0080000?]IZe^kFJ]KZeV[Fk]IZe^[FJ]K/00;Gk]M^enjgK0080000=]K^eV[Fj]IX00:gK]O^efkGk
[M^enkGK]O/00P0000beVP00[M^enjgK]O^]fkGk[M^enjgK]O/200003ZgK[O^]fkGk[M^]njgK]O/0
0:gl[M^]o:gK[O`200003JgK[O^]fjgl002]o:gL[Ob]fjgl[Mb]o:gK00<000Goo`03003ooooo017o
o`03003ooooo01;oo`00@?oo00<00?oo00000_oo00<00?oo00000_oo1@009Ooo00d00;FJ]KZ]V[Fj
]IZe^ZfJ]KZeV[Fj002e^`0200003[FJ]K^eV[Fj]IZe^kFJ]KX00;Gk]IZenjfJ]O/200003JfJ]K^e
V[Fj002enjfJ]O^]V[Gk[IZenjfJ0080000?]KX00;Gk[IZenjfJ]O^]V[Gk[IZenjfJ002]V[Gk0080
000=[IZenjfJ]O^]V[Gk[IX00:fJ]O^]V[Gk[IX00P0000benjfJ]O^]VP00[OZenjgk]O^]n[Gk[O/2
00003[Gk002enjgk]Ob]nkGk[O^eo:gk]O/00;Gl[O/200003KGl[O^eo:gk]Ob]n`00YO^]o:gk[ObU
njgl008000Soo`03003ooooo017oo`03003ooooo01;oo`00@Ooo00<00?ooool00_oo00@00?oooooo
o`8002Woo`0J002eV[Fj]IZe^[FJ]KZeV[Fj]IZe^P00]KZeV[Fj]IZe^[FJ]KZeV[Fj]IZe^P00]KZe
VP80000N]KZeV[Fj]IZe^[FJ]KX00;Fj]IZe^kFJ]KZeVP00]IZe^[FJ]KX00;Fj]IZe^kFJ]KZeV[Fk
]IZe^[FJ0P0000fe^[FJ]K^eV[Fj]IZe^kFJ]KZeVP00[M^en`0200003;FJ]O^eV[Gk]IZen`00]O^]
fkGk[M^en`80000=]M^enkGJ]O/00;Gk[M^]njgK]O^]fjgk[M/00`0000b]fjgl[M^]njgK[Ob]fjgk
[M/00:gK[O`3000;ool00`00ooooo`0Aool00`00ooooo`0Aool004_oo`03003ooooo02Soo`08002e
V[Fj[IZe^[FJ]KZ]VP80000=]KX00;Fk]IZe^[FJ]K^eV[Fj]IZe^kFJ]KX00P0000jeV[Fj[IZe^kFJ
]KZ]V[Fk]IZe^P00]O^]V[Gk0P0000jeV[Fj[IZe^[FJ]KX00;Gk[IZenjfJ]O^]V[Gk0P0000beVP00
[IZenjfJ]O^]V[Gk[IZenjfJ]O/300003;Gk[IZenjfJ]O^]V[Gk[IZen`00]O^]nP80000=]O^]V[Gk
[IZenjfJ002]nkGk[O^eo:gk]O/00P0000f]nkGk002eo:gk]Ob]nkGl[O^eo:gk]Ob]n`02000?ool0
0`00ooooo`0@ool00`00ooooo`0Aool004coo`8002Soo`06002e^[FJ]KZeV[Fj0P0000feV[Fj]IZe
^P00]KZeV[Fj]IZe^[FJ]KZeVP0200003[Fj002e^[FJ]KZeV[Fj]IZe^[FJ]KZeVP00]IX200003[Fj
]IZe^[FJ]KZeV[Fj]IX00;FJ]KZeV[Fk]IX200003;Fj]IZe^[FJ002eV[Fj]IZe^kFJ]KZeVP80000=
]KZeVP00]IZenkFJ]O^eV[Gk]IZenkFJ]O/00P0000bef[Gk]M^enkGJ]O^efkGk]MX00:gK]O/30000
3KGk[M^enkGK]O/00:gk[M^]o:gK[O^]fjgl0080017oo`03003ooooo013oo`03003ooooo017oo`00
C_oo00<00?ooool09_oo00<00;Fj]IX00P0002fm^[FI]KZeVKfj]IVe^P00]K^eV[Fj]IZe^kFJ002e
VKFj]IVe^P00]K^eV[Fj[IZe^kFJ]KZ]V[Fk]IX00:fJ]KZeV[Fj[IZe^[FJ]KZ]V[Fj]IX00:fJ]O/0
0P0000beV[Fj]IZe^[FJ]KX00;Gk[IZenjfJ]O/200003KFJ]KZeV[Fj]IX00:fJ]O^]V[Gk[IZenjfJ
0080000<]K/00;Gk[IZenjfJ]O^]V[Gk[IZenjfJ0P0000jenjgj]O^]nkGk[OZenjgk002]nkGl[O^e
o:gk0P005?oo00<00?ooool03ooo00<00?ooool04Ooo001?ool00`00ooooo`0Vool200003[FJ]KZe
V[Fj]IZe^[FJ]KZeVP00]IZe^[FJ]KX200003[FJ]KZeV[Fj]IZe^P00]KZeV[Fj]IZe^[FJ]KX20000
3KFJ002eV[Fj]IZe^[FJ]KZeV[Fj]IZe^[FJ0080000<]KZeV[Fj]IZe^[FJ]KZeV[Fj002e^kFJ0P00
00fe^[FJ]KZeV[Fj]IZe^P00]O^eV[Gk]IZen`0200003;FJ]KZeVP00]M^enkGJ]O^efkGk]MZen`80
000>]IX00;GK]O^]fkGk]M^enjgK]O^ef`00[M^]n`8001Ooo`03003ooooo00koo`03003ooooo017o
o`00D?oo00<00?ooool09_oo00d00;fj]IVe^[FI_KZeVKFj]IVm^[FI002eVP0200003[Fj]IVe^[FI
]KZeVKFj]IT00:fJ]K^eV[Fj[IX200003KFj]IVe^[FI002]V[Fj]IZe^ZfJ]KZeV[Fj0080000<]IT0
0;FJ]KZeV[Fj]IZe^[FJ]KZeV[Fj0P0000feV[Fj]IZe^[FJ]KZeV[Fj]IZe^P00]O^]VP0200006kFj
]IZe^kFJ]KZeVP00[IZenjfJ]O^]V[Gk002e^kFJ]K^eVP00[O^enjgj]O^]nkGk[OZen`03000Jool0
0`00ooooo`0=ool00`00ooooo`0Aool0057oo`8002Ooo`0J002e^[FJ]KZeV[Fj]IZe^[FJ]KZeVP00
]IZe^[FJ]KZeV[Fj]IZe^[FJ]KZeVP00]IZe^P80000=]IZe^[FJ]KZeV[Fj]IX00;FJ]KZeV[Fj]IX0
0P0000be^[FI]KX00;Fj]IZe^[FJ]KZeV[Fj]IX200003KFj002e^[FJ]KZeV[Fj]IZe^[FJ]KZeV[Fj
0080000=]IZe^[FJ]KZeV[Fj]IZe^[FJ002efkGk]MX00P0000be^[FJ]KZeV[Fj002enkGK]O^]fkGk
]M/2000Mool00`00ooooo`0=ool00`00ooooo`0Aool005?oo`03003ooooo02Goo`08002m^[FI]KZe
VKfj]IVe^P80000=]ET00;FI]KZeVKFj]IVe^[FI]KZeVKFj]IT00P0000fe^[FI]KZeVKFj]IVe^[FI
]KZeV@00[IZe^P0200006kFI]KZeVKFj]IVe^P00]KZeV[Fj]IZe^[FJ002eFKFj]EVm^P00]KZeV[Fj
]IZe^[FJ]KZeVP0200003Kfj002e^[FJ]K^eV[Fj]IZe^kFJ]KX00;Gk0080000;]IZe^kFJ]K^eV[Fk
]IZe^`00]O^]n`03000Pool00`00ooooo`0=ool00`00ooooo`0@ool005Coo`03003ooooo02Coo`06
002eV[Fj]IZe^[FJ0P0000fe^[FI]KVeV@00]IZe^[FJ]KZeV[Fj]IZe^P0200003KEI002eV[Fj]IZe
^[FJ]KZeV[Fj]IZe^[FJ0080000=]KZeV[Fj]IVe^[FJ]KZeVKFj002e^[FJ]KX00P0002ReVKFj]IVe
^[FI]KX00;Fj]IZe^[FJ]KZeVP00]IVe^[FI002eV[Fj]IZe^[FJ]KZeV[Fj]IZe^P00]KZeV[Fj]IZe
^[FJ]KZeV[Fj]IZe^P8002Coo`03003ooooo00coo`03003ooooo013oo`00EOoo00<00?ooool09?oo
00<00;FI_KX00P0001beFKfj]EVe^[EI_KZeF@00]IVe^[FI]KZeVKFj002e^[EI_KZeF@00]IVe^[FI
]KZeVKFj]IVe^P80000=]ET00;FI]KZeVKFj]IVe^[FI]KZeV@00]IX00P0000fm^[EI]KZeFKfj]EVe
^[EI002eV[Fj]IZe^P0200003KEI_KZeFKFj]ET00;FJ]KZeV[Fk]IZe^[FJ0080000:]KX00;Fk]IZe
^kFJ]K^eV[Fk]IX2000Wool00`00ooooo`0;ool00`00ooooo`0@ool005Koo`03003ooooo02Coo`80
000>]KVeVKFj]IVe^KFI]KZeVKFi002e^[FJ]KZeVP80000Z]KVeFKFj]EVe^KEI002eV[Fj]IZe^[FJ
]KX00;Ei]EVeN@00]KZeVKFj]IZe^[FI]KZeV[Fj]IT00;FI]KZeVKFj]IVe^[FI]KZeVKFj]IT00;FJ
0P0000fe^KFI]KZeVKFi]IVe^[FI002eV[Fj]IZe^P0200003;FI]KVeVKFj002e^[FJ]KZeV[Fj]IX0
02Woo`03003ooooo00_oo`03003ooooo013oo`00Eooo0P009Ooo00d00;EI_KZeFKFj]EVm^[EI]KZe
FKfj002e^P0200003KEI]KZeFKfj]EVe^[EI_KX00;Fj]IVe^[FI0080000=_KZeFKFj]EVm^P00]KZe
VKFj]IVe^[FI]KX00P0001^eF@00]EVe^[EI_KZeFKFj]EVm^[EI]KZeF@00]EVe^[EI_KZeFKFj]EVm
^[EI]KX00;Fk]IX00P0000^m^[EI]KZeFKfj]ET00;FJ]K^eV[Fk008002_oo`03003ooooo00[oo`03
003ooooo013oo`00FOoo00<00?ooool08_oo01X00;Fj]IVe^KFI]KZeVKFi]IVe^[FI]KT00;Fj]EVe
^KEI]KZeFKFi]EVe^[EI]KT00;Fj0P0001beFKEi]EVeNKEI]GVeF@00]IZe^[FI]KZeV[Fj002eNKEI
]GVeF@00]IVe^[FI]KZeVKFj]IVe^P80000<]ET00;FI]KZeVKFi]IVe^[FI]KVeVKFj0P0000^eVKFj
]IVe^KFI]KZeVKFi]IT00;FJ008002koo`03003ooooo00Woo`03003ooooo013oo`00F_oo00<00?oo
ool08_oo00T00;Fj]EVm^[EI]KZeFKfj]ET00P0001bmN@00]KZeFKfj]EVe^[EI_KZeFKFj]EVm^P00
]KZeFKfj]EVe^[EI_KZeFKFj]ET00;FI]KZeV@80000J]GVeFKei]EVeNKEI002eFKFj]EVm^[EI]KX0
0;ei]EVeN@00_KZeFKFj]EVm^[EI]KZeF@80000=_GT00;fj]EVe^[EI_KZeFKFj]EVm^[EI0000<?oo
00<00?ooool02Ooo00<00?ooool04?oo001Kool00`00ooooo`0Rool05@00]KZeVKFi]IVe^[FI002e
FKEi]EVeN@00]KZeFKFi]EVe^[EI]KVeF@0200003KEi002eNKEI]GVeFKEi]EVeNKEI]GT00;Fj0080
000=]EVeNKEI]GVeFKEi]EVeN@00]KZeVKFj]IT00P0001VeNKEI]GVeFKEi002e^KFI]KZeVKFi]IT0
0;EH]GVeF000]IVe^KFI]KZeVKFi]IVe^P02000bool00`00ooooo`08ool00`00ooooo`0@ool005co
o`8002?oo`04002e^[EI_KX20000:[EI_GVeFKei]EVmN@00]KZeFKfj]EVe^[EI002eF;Ei]EP00;EI
]KZeFKfj]EVe^[EI_KZeFKFj002mNKEI]GVeFKei]EVeNKEI_GVeFKEi002m^P80000<]ERmNKEI]GVe
F;ei]EVeN@00_KZeFKFj0P0000feF;ei]ERmNKEH002eFKfj]EVe^[EI_KX0000eool00`00ooooo`08
ool00`00ooooo`0?ool005koo`03003ooooo023oo`0A002eV@00002eNKEI]GVeFKEi]EVeNKEI002e
FKFj]EVe^@0200003KEI]GVeFKEi]ET00;EI]GVeFKEi]EVeNKEI0080000J]GT00;Ei]EVeNKEI]GVe
FKEi]EVeNKEI]GT00;Ei]EVeNKEI]GVeFKEi]EVeNKEI002eV@80000<]GVeF;Ei]EReNKEH]GVeF000
]IVe^KFI0P00=ooo00<00?ooool01ooo00<00?ooool03ooo001Oool00`00ooooo`0Pool03P00]EVm
NKEI_GVeFKei]EVmNKEI_GVeF@00]ET200007;ei]EReNKEH_GVeF;Ei]EP00;EI]KZeFKfj]ET00;EH
_GVeF;Ei002mNKEI]GVeFKei]EVeNKEI0P0001VeN@00_GVeFKEi]ERmNKEI]GVeF;ei]ET00;EH_GVe
F;ei]ERmNKEH_GVeF;ei002e^P02000iool00`00ooooo`07ool00`00ooooo`0?ool0063oo`03003o
oooo023oo`16002eFKEi]EVeNKEI]GVeFKEi]EVeNKEI002eFKEi]EVeNKEI]GVeFKEi]EVeNKEI002e
FKEi]ET00;EH]GVeF;Ei]EReN@00]GVeFKEi]EVeNKEI002e6;Eh]AP00;EI]GVeFKEi]EVeNKEI]GVe
F@00]AP00;EH]GVeF;Ei]EReNKEH]GVeF;Ei000lool00`00ooooo`06ool00`00ooooo`0?ool0067o
o`80027oo`09002eFKei]EVmNKEI_GVeFKei0080000>]AP00;EH]GVeF;ei]EReNKEH_GVeF;Ei002m
^P80000<]ERmNKEH]GVeF;ei]EP00;EI_GVeFKEi0P0000be6;Ei]ARmNKDH002eF;ei]EVeNKEH_GT2
00003KDG_CP00;ei]ERmNKEH_GVeF;ei]ERmN@0003koo`03003ooooo00Goo`03003ooooo00ooo`00
Hooo00<00?ooool07ooo02@00;EI]GVeFKEi]EVeN@00]GReF;Ei002eNKEI]GVeFKEi]EVeNKEI]GVe
FKEi002eNKEH]GVeF;Ei]EReNKEH]GVeF000]ET200006[Eh]AReN;DH]GRe6;Eh002eNKEI]GVeFKEi
002e>;DH]CRe6;Dh002eNKEH]GVeF;Ei]EP20010ool00`00ooooo`04ool00`00ooooo`0?ool006Co
o`03003ooooo01koo`05002mNKEI_GVeF@0200003[ei]ARmNKDH_GT00;ei]EReNKEH_GVeF;Ei]EP2
0000:KEh002mNKEH]GVeF;ei]EReNKEH_GVeF000]ARmNKDH]GVe6;ei]AReNKDH_GT00;Ei]ERmN@00
]CRe5kdh]ANe>;DG002eF;ei]ERmNKEH0000@_oo00<00?ooool01?oo00<00?ooool03ooo001Uool0
0`00ooooo`0Nool0;`00]GT00000]EReN;EH]GVeF;Eh]EReN@00]GVeFKEi]EVeNKEI002e6;Dh]AP0
0;EH]GVeF;Ei]EReNKEH]GVeF000]AP00;DH]GRe6;Eh]AReN;DH]GRe6000]ET00P0000fe>;DH]CRe
6;Dh]ARe>;DH002eF;Ei]EP00014ool00`00ooooo`04ool00`00ooooo`0>ool006Koo`8001ooo`0@
002mNKDH_GVe6;ei]ARmNKDH_GVe6;ei002mNKEH]GT200003;DH]GRe6;ei]AP00;EH_GVeF;Ei]ERm
N@80000J]ANm>000]GVe6;ei]AReNKDH_GVe6;Ei]AP00;DG]CRe5kdh]ANe>;DG_CRe5kDh002mN@80
04Koo`03003ooooo00?oo`03003ooooo00koo`00J?oo00<00?ooool07Ooo00d00;Eh]EReNKEH]GRe
F;Ei]EReN;EH002eF@0200006kDh]ARe>;DH]CRe6;Dh002eNKEH]GVeF;Ei002e>;DH]CRe5kDh002e
N;DH]GRe6;Eh]AReN00200003KCG002e6;Dh]ARe>;DH]CRe6;Dh]ARe>00004Soo`03003ooooo00?o
o`03003ooooo00koo`00JOoo00<00?ooool07?oo03P00;DH_GVe6;ei]ARmNKDH_GVe6;ei]AP00;DH
_GVe6;Eh]ARmNKDH]GRe6;ei002eNKEH_GT00;Dh]ANm>;DG]CRe5`00]AReNKDH_GVe6;Ei002dmkCG
]?L00;dh]ANe>;DG_CRe5kDh]ANm>000B_oo00<00?ooool00_oo00<00?ooool03_oo001Zool00`00
ooooo`0Lool06000]EReN;EH]GVeF;Eh]EReNKEH002e6000]ARe>;DH]CRe6;Dh]ARe>;DH002eF080
000<]CRe6;Dh]ANe>;DH]CRe5`00]AReN;DH0P0000jdmkCG]?NdekCg002e>;DH]CRe6;Dh]ARe>000
C?oo00D00?ooooooo`00013oo`00Jooo00<00?ooool07?oo00L00;DH_GVe6;ei]ARmN@0200006[DG
_CP00;Eh]ARmNKDH]GRe6;ei]AReN;DH002e5kDh]ANm>;DG]CRe5kdh]ANe>000_GT200003kCG]?Nd
ekCg]=NdmkCG002e5kdh]ANe>;DG_CP0001>ool01000ooooo`004?oo001/ool2000Lool05000]GVe
F;Eh]EReN@00]CRe6;Dh]ANe>000]CRe6;Dh]ARe>;DH]CP200006kCG002e6;Dh]ANe>;DH]CRe5kDh
]ARe>000]?NdekCg]=NdmkCG]?NdekCg]=L00;DH]CRe6002001?ool01000ooooo`004?oo001^ool0
0`00ooooo`0Jool08000_GVe6;ei002e>;DG_CRe5kDh]AL00;DH]GRe6;ei]AReN000]CRdekDg002m
>;DG]CRe5kdh]ANe>;DG_CP200003[CG]?NdekCg]=NdmkCG]?NdekCg002e>;DG001Bool00`00ool0
000@ool006ooo`03003ooooo01Woo`0@002eF000002e>;DH]CRe5kDh]ARe>;DG002e6;Dh]AP20000
6kCg]=NdmkCG]?L00;Dh]ARe>;DG]CRe6;Dh002dm[CF002dekCg]=NdmkCG]?NdekCg]=Ndm`02001D
ool00`00ool0000?ool0073oo`03003ooooo01Woo`0=002e5kDh]ANm>;DG]CRe5kdh]ANe>000_GT0
0P0001jdekDh]=Ne=kCG]CRde`00]ANm>;DG]CRe5kdh002dmjbF]?L00;Cg]=NdmkCG]?NdekCg]=Nd
mkCG001Fool2000?ool0077oo`8001[oo`0J002e6;Dh]ANe>;DH]CRe5kDh]ARe>000]?NdekCg]=Nd
mkCG]?NdekCg]=L00;DG]CRe6080000?]?Jde[Cg]=JdmP00]?NdekCg]=NdmkCG]?Nde`0005Ooo`80
00ooo`00Looo00<00?ooool05ooo02X00;dh]ANe>;DG_CRe5kDh]ANm>000]?L00;Dh]=Ne=kCG]CRd
ekDg]=Ne>000]CRe5`00]9JdmjbF]?NdU[Cg[9H00;CG]?NdekCg]=NdmkCG001Hool2000?ool007Co
o`03003ooooo01Ooo`0F002e>;DH]CRe5kDh]ARe>000]?Nde`00]=NdmkCG]?NdekCg]=NdmkCG]?L2
00004;CF]?Jde[Cg]=Jdm[CF]?L00;Cg]=NdmkCG]?Nde`00EOoo10004Ooo001eool00`00ooooo`0F
ool09@00]ANm>;DG]CRe5kdh002dmkCF]?NdeP00]=Ne>;CG]CNdekDh]=Ne=kCG002dU[Cg[9JdmkBF
]?N/U[Cg]9Jdm`00]?NdekCg008005;oo`@001Goo`00M_oo0P005ooo00@00;DG]CRe6080000N]?Nd
ekCg]=Jdm`00]?NdekCg]=NdmkCG]?Nde`00[9H00;CF]?Nde[Cf]=JdmkCF]?JdeP00]=Ndm`00D?oo
10006Ooo001hool00`00ooooo`0Dool08@00]CRe5`00]=JdmkCF]?Nde[Cg]=Jdm`00]CNdekDh]=Ne
=kCG002/U[Bf002dmkBF]?N/U[Cg]9JdmjbF]?NdUP02001=ool4000Mool007Woo`03003ooooo01Co
o`80000O]=JdmkCG]?Nde[Cg]=NdmkCF002dekCg]=NdmkCG002/U[Bf]9Jd]P00]?Jde[Cg]=Jdm[CF
]?Nde[Cf0000B_oo10008Ooo001jool00`00ooooo`0Cool08000]=JdmkCF]?Nde[Cg]=JdmkCF]?Nd
eP00]=Ne=kCG002/U[Bf[9Fd]ZbF002/U[Cg]9JdmjbF]?NdU[Cg0018ool3000Uool007_oo`03003o
oooo01?oo`0N002dekCg]=JdmkCG]?Nde[Cg]=Ndm`00]?Nde`00[9Jd][BF];J/U[Bf]9H00;CF]?Jd
e[Cg]=JdmP00AOoo1000:?oo001lool2000Cool03000]?Nde[Cg]=JdmkCF]?Nde[Cg]=Jdm`80000?
[9Jd]ZbE];J/U[Bf[9Fd]P00]?N/U[Cg]9Jdm`0004;oo`@002coo`00O_oo00<00?ooool04Ooo01/0
0;Cg]=NdmkCF]?NdekCg]=JdmkCG002/U[Bf]9Jd]ZbF];JdU[Bf[9Jd]P00]?Nde[Cf0000?ooo1000
<?oo001oool00`00ooooo`0@ool02P00]=JdmkCF]?Nde[Cg]=JdmkCF0P0000jd]ZbE];J/U[Bf[9Fd
]ZbF];J/U@00]9Jdm`00??oo1000=?oo0020ool00`00ooooo`0@ool05P00]=JdmkCG]?Nde[Cg]=L0
0:aE]5D00;Bf[9Jd][BF];J/U[Bf]9Jd]ZbF0P00>Ooo1000>?oo0021ool2000@ool05`00]?Nde[Cg
]=JdmkCF002/EKBf[5D00:bF];J/UKBf[9Jd]ZbE];J/U[Bf0000=ooo0`00??oo0023ool00`00oooo
o`0>ool01000]?Nde[Cg0P0000n/EKAE[5FdEP00];JdU[Bf[9Jd][BF];J/U[Bf0000=?oo1000?ooo
0024ool00`00ooooo`0=ool05000]=Jdm`00];J/EKBf[5Fd]ZaE];H00;Bf[9Jd]ZbE];J/U[Bf000a
ool40013ool008Goo`03003ooooo00goo`80000@]5J/EKAE[5FdEZaE]5F/E@00[9Jd][BF];J/U[Bf
000^ool40017ool008Koo`8000goo`0A002d]ZaE];J/EKBf[5Fd]ZaE];H00;Bf[9Fd]ZbF];H0000[
ool4001;ool008Soo`03003ooooo00[oo`0A002/EKAE[5FdEZaE]5F/EKAF[5FdE@00];J/U[Bf]9H0
000Wool4001?ool008Woo`03003ooooo00[oo`0?002/EKBf[5Fd]ZaE];J/EKBf[5D00:bF];J/U@00
02Coo`@005?oo`00R_oo00<00?ooool02Ooo00h00;AF[5FdEJaE]5J/EKAE[5FdEP00];JdUP008_oo
0`00Eooo002;ool20009ool02`00[5Fd]ZaE];J/EKBf[5Fd]ZaE];H00P007ooo1000F_oo002=ool0
0`00ooooo`06ool03000]5F/EKAF[5FdEJaE]5J/EKAE[5D001coo`@005koo`00S_oo00<00?ooool0
1_oo00X00;Bf[5Fd]ZaE];J/EKBf[5D001Woo`@006;oo`00Sooo00<00?ooool01Ooo00T00:aE]5F/
EKAF[5FdEJaE00005_oo1000I_oo002@ool00`00ooooo`04ool02000];J/EKBf[5Fd]ZaE000Cool4
001Zool0097oo`8000Goo`06002dEZaE]5F/E@004Ooo0`00K_oo002Cool00`00ooooo`02ool01P00
[5Fd]ZaE];H000goo`@0077oo`00U?oo00T00?ooooooo`00]5F/EKAF00002_oo1000MOoo002Eool0
1`00ooooo`00[5Fd]P0000Ooo`@007Woo`00U_oo0P0000?oo`0000001?oo1000OOoo002Hool20000
0ooo000000020021ool009Woo`8008Goo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003o
oolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7o
o`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003o
oolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7o
o`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003o
oolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7o
o`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003o
oolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7oo`00oooo8Ooo003ooolQool00?ooob7o
o`00oooo8Ooo003ooolQool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.360234, -0.257423, \
0.00481634, 0.00481634}}]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ImpliedVolatility",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox[\(option, \ settlement, \ riskfreerate, \ price\),
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], TopSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[" ",
              "TraditionalForm"], 
            RowBox[{
              StyleBox["return",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["the",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["volatility",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["of",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["the",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["underlying",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["asset",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["implicit",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["in",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["the",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox[\(option'\),
                "TraditionalForm"], 
              StyleBox["s",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False}], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["price",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["given",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["the",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["settlement",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["day",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["and",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["the",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["riskless",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["interest",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["rate",
                "TraditionalForm"]}]}
          }], BottomBox]]],

Cell["Implied volatility function. ", "Caption"],

Cell["This calculates the implied volatility. ", "MathCaption",
  CellTags->"0.51"],

Cell[CellGroupData[{

Cell["ImpliedVolatility[xyzft, settlement, r, val1]", "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    StyleBox["0.3`",
      StyleBoxAutoDelete->True,
      PrintPrecision->1]], "Output",
  CellLabel->"Out[45]="]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["HistoricalVolatility",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["prices",
                FontSlant->"Italic"], 
              StyleBox["]",
                "MR"]}], 
            StyleBox[" ",
              "TraditionalForm"]}
          }], TopSpanBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[" ",
              "MR"], 
            RowBox[{
              StyleBox["return",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["the",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["historical",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["volatility",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["given",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["a",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["list",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["of",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["the",
                "TraditionalForm"], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox[\(asset'\),
                "TraditionalForm"], 
              StyleBox["s",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False}], 
              StyleBox[" ",
                "TraditionalForm"], 
              StyleBox["prices",
                "TraditionalForm"]}]}
          }], MiddleBox]]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Norm",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["x",
                "TraditionalForm"], 
              StyleBox["]",
                "MR"]}], 
            
            StyleBox[\(give\ the\ cumulative\ normal\ distribution\ function\ \
at\ x\),
              "TraditionalForm"]}
          }], BottomBox]]],

Cell["Auxiliary functions. ", "Caption"],

Cell[TextData[{
  "To use the Black\[Hyphen]Scholes model we need to know the underlying \
asset's volatility. The function ",
  StyleBox["HistoricalVolatility", "MB"],
  " computes the maximum likelihood estimate of the asset's volatility given \
a list of past prices. "
}], "Text",
  CellTags->"0.53"],

Cell[TextData[{
  "We read in the prices for one year of IBM stock from the file ",
  StyleBox["IBM\[Hyphen]90.prc", "TI"],
  " as pairs {",
  StyleBox["date", "TI"],
  ", ",
  StyleBox["price", "TI"],
  "}. "
}], "MathCaption",
  CellTags->"0.54"],

Cell["\<\
prices[IBM] ^=
   Last[Transpose[ReadList[
   ToFileName[{\"Finance\", \"Data\"}, \"IBM-90.prc\"],
   {Number, Number}]]];\
\>", "Input",
  CellLabel->"In[46]:="],

Cell["Here is the graph of IBM's prices. ", "MathCaption",
  CellTags->"0.55"],

Cell[CellGroupData[{

Cell["ListPlot[prices[IBM], PlotJoined -> True];", "Input",
  CellLabel->"In[47]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.02 0.00380952 -2.11481 0.0222115 [
[.02 -0.0125 -3 -9 ]
[.02 -0.0125 3 0 ]
[.21048 -0.0125 -6 -9 ]
[.21048 -0.0125 6 0 ]
[.40095 -0.0125 -9 -9 ]
[.40095 -0.0125 9 0 ]
[.59143 -0.0125 -9 -9 ]
[.59143 -0.0125 9 0 ]
[.7819 -0.0125 -9 -9 ]
[.7819 -0.0125 9 0 ]
[.97238 -0.0125 -9 -9 ]
[.97238 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .10634 -18 -4.5 ]
[-0.0125 .10634 0 4.5 ]
[-0.0125 .21739 -18 -4.5 ]
[-0.0125 .21739 0 4.5 ]
[-0.0125 .32845 -18 -4.5 ]
[-0.0125 .32845 0 4.5 ]
[-0.0125 .43951 -18 -4.5 ]
[-0.0125 .43951 0 4.5 ]
[-0.0125 .55057 -18 -4.5 ]
[-0.0125 .55057 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02 0 m
.02 .00625 L
s
[(0)] .02 -0.0125 0 1 Mshowa
.21048 0 m
.21048 .00625 L
s
[(50)] .21048 -0.0125 0 1 Mshowa
.40095 0 m
.40095 .00625 L
s
[(100)] .40095 -0.0125 0 1 Mshowa
.59143 0 m
.59143 .00625 L
s
[(150)] .59143 -0.0125 0 1 Mshowa
.7819 0 m
.7819 .00625 L
s
[(200)] .7819 -0.0125 0 1 Mshowa
.97238 0 m
.97238 .00625 L
s
[(250)] .97238 -0.0125 0 1 Mshowa
.125 Mabswid
.0581 0 m
.0581 .00375 L
s
.09619 0 m
.09619 .00375 L
s
.13429 0 m
.13429 .00375 L
s
.17238 0 m
.17238 .00375 L
s
.24857 0 m
.24857 .00375 L
s
.28667 0 m
.28667 .00375 L
s
.32476 0 m
.32476 .00375 L
s
.36286 0 m
.36286 .00375 L
s
.43905 0 m
.43905 .00375 L
s
.47714 0 m
.47714 .00375 L
s
.51524 0 m
.51524 .00375 L
s
.55333 0 m
.55333 .00375 L
s
.62952 0 m
.62952 .00375 L
s
.66762 0 m
.66762 .00375 L
s
.70571 0 m
.70571 .00375 L
s
.74381 0 m
.74381 .00375 L
s
.82 0 m
.82 .00375 L
s
.8581 0 m
.8581 .00375 L
s
.89619 0 m
.89619 .00375 L
s
.93429 0 m
.93429 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10634 m
.00625 .10634 L
s
[(100)] -0.0125 .10634 1 0 Mshowa
0 .21739 m
.00625 .21739 L
s
[(105)] -0.0125 .21739 1 0 Mshowa
0 .32845 m
.00625 .32845 L
s
[(110)] -0.0125 .32845 1 0 Mshowa
0 .43951 m
.00625 .43951 L
s
[(115)] -0.0125 .43951 1 0 Mshowa
0 .55057 m
.00625 .55057 L
s
[(120)] -0.0125 .55057 1 0 Mshowa
.125 Mabswid
0 .01749 m
.00375 .01749 L
s
0 .0397 m
.00375 .0397 L
s
0 .06191 m
.00375 .06191 L
s
0 .08413 m
.00375 .08413 L
s
0 .12855 m
.00375 .12855 L
s
0 .15076 m
.00375 .15076 L
s
0 .17297 m
.00375 .17297 L
s
0 .19518 m
.00375 .19518 L
s
0 .23961 m
.00375 .23961 L
s
0 .26182 m
.00375 .26182 L
s
0 .28403 m
.00375 .28403 L
s
0 .30624 m
.00375 .30624 L
s
0 .35066 m
.00375 .35066 L
s
0 .37287 m
.00375 .37287 L
s
0 .39509 m
.00375 .39509 L
s
0 .4173 m
.00375 .4173 L
s
0 .46172 m
.00375 .46172 L
s
0 .48393 m
.00375 .48393 L
s
0 .50614 m
.00375 .50614 L
s
0 .52836 m
.00375 .52836 L
s
0 .57278 m
.00375 .57278 L
s
0 .59499 m
.00375 .59499 L
s
0 .6172 m
.00375 .6172 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02 .61178 m
.02 .61803 L
s
.21048 .61178 m
.21048 .61803 L
s
.40095 .61178 m
.40095 .61803 L
s
.59143 .61178 m
.59143 .61803 L
s
.7819 .61178 m
.7819 .61803 L
s
.97238 .61178 m
.97238 .61803 L
s
.125 Mabswid
.0581 .61428 m
.0581 .61803 L
s
.09619 .61428 m
.09619 .61803 L
s
.13429 .61428 m
.13429 .61803 L
s
.17238 .61428 m
.17238 .61803 L
s
.24857 .61428 m
.24857 .61803 L
s
.28667 .61428 m
.28667 .61803 L
s
.32476 .61428 m
.32476 .61803 L
s
.36286 .61428 m
.36286 .61803 L
s
.43905 .61428 m
.43905 .61803 L
s
.47714 .61428 m
.47714 .61803 L
s
.51524 .61428 m
.51524 .61803 L
s
.55333 .61428 m
.55333 .61803 L
s
.62952 .61428 m
.62952 .61803 L
s
.66762 .61428 m
.66762 .61803 L
s
.70571 .61428 m
.70571 .61803 L
s
.74381 .61428 m
.74381 .61803 L
s
.82 .61428 m
.82 .61803 L
s
.8581 .61428 m
.8581 .61803 L
s
.89619 .61428 m
.89619 .61803 L
s
.93429 .61428 m
.93429 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .10634 m
1 .10634 L
s
.99375 .21739 m
1 .21739 L
s
.99375 .32845 m
1 .32845 L
s
.99375 .43951 m
1 .43951 L
s
.99375 .55057 m
1 .55057 L
s
.125 Mabswid
.99625 .01749 m
1 .01749 L
s
.99625 .0397 m
1 .0397 L
s
.99625 .06191 m
1 .06191 L
s
.99625 .08413 m
1 .08413 L
s
.99625 .12855 m
1 .12855 L
s
.99625 .15076 m
1 .15076 L
s
.99625 .17297 m
1 .17297 L
s
.99625 .19518 m
1 .19518 L
s
.99625 .23961 m
1 .23961 L
s
.99625 .26182 m
1 .26182 L
s
.99625 .28403 m
1 .28403 L
s
.99625 .30624 m
1 .30624 L
s
.99625 .35066 m
1 .35066 L
s
.99625 .37287 m
1 .37287 L
s
.99625 .39509 m
1 .39509 L
s
.99625 .4173 m
1 .4173 L
s
.99625 .46172 m
1 .46172 L
s
.99625 .48393 m
1 .48393 L
s
.99625 .50614 m
1 .50614 L
s
.99625 .52836 m
1 .52836 L
s
.99625 .57278 m
1 .57278 L
s
.99625 .59499 m
1 .59499 L
s
.99625 .6172 m
1 .6172 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .06191 m
.02762 .08135 L
.03143 .10634 L
.03524 .10078 L
.03905 .11467 L
.04286 .09246 L
.04667 .08413 L
.05048 .10356 L
.05429 .05914 L
.0581 .06469 L
.0619 .10911 L
.06571 .08135 L
.06952 .09523 L
.07333 .0758 L
.07714 .03137 L
.08095 .03415 L
.08476 .05081 L
.08857 .01472 L
.09238 .03693 L
.09619 .04526 L
.1 .04526 L
.10381 .0758 L
.10762 .05636 L
.11143 .07024 L
.11524 .09801 L
.11905 .12855 L
.12286 .17575 L
.12667 .16742 L
.13048 .16187 L
.13429 .13133 L
.1381 .17852 L
.1419 .18963 L
.14571 .18963 L
.14952 .18408 L
.15333 .1702 L
.15714 .21462 L
.16095 .17852 L
.16476 .16464 L
.16857 .19518 L
.17238 .18963 L
.17619 .19241 L
.18 .19518 L
.18381 .21462 L
.18762 .21739 L
.19143 .23405 L
.19524 .2285 L
.19905 .26182 L
.20286 .25071 L
.20667 .27848 L
.21048 .24516 L
Mistroke
.21429 .24516 L
.2181 .26182 L
.2219 .29791 L
.22571 .30624 L
.22952 .28403 L
.23333 .26737 L
.23714 .25071 L
.24095 .21739 L
.24476 .19796 L
.24857 .20629 L
.25238 .23683 L
.25619 .23961 L
.26 .24238 L
.26381 .23683 L
.26762 .25349 L
.27143 .25071 L
.27524 .24238 L
.27905 .23683 L
.28286 .2285 L
.28667 .23683 L
.29048 .24794 L
.29429 .26459 L
.2981 .34789 L
.3019 .35344 L
.30571 .32568 L
.30952 .30902 L
.31333 .31457 L
.31714 .31457 L
.32095 .30346 L
.32476 .31457 L
.32857 .30069 L
.33238 .27015 L
.33619 .30624 L
.34 .28403 L
.34381 .30902 L
.34762 .31179 L
.35143 .33956 L
.35524 .33956 L
.35905 .34511 L
.36286 .35622 L
.36667 .3812 L
.37048 .4173 L
.37429 .42285 L
.3781 .45339 L
.3819 .44784 L
.38571 .4645 L
.38952 .44784 L
.39333 .48393 L
.39714 .50059 L
.40095 .5228 L
Mistroke
.40476 .5228 L
.40857 .46727 L
.41238 .54501 L
.41619 .57 L
.42 .55057 L
.42381 .53946 L
.42762 .5589 L
.43143 .56723 L
.43524 .56445 L
.43905 .56445 L
.44286 .5228 L
.44667 .54779 L
.45048 .55612 L
.45429 .58111 L
.4581 .57 L
.4619 .5589 L
.46571 .5228 L
.46952 .5228 L
.47333 .50614 L
.47714 .53113 L
.48095 .46727 L
.48476 .4756 L
.48857 .47838 L
.49238 .50614 L
.49619 .49781 L
.5 .49504 L
.50381 .51725 L
.50762 .49781 L
.51143 .49226 L
.51524 .50614 L
.51905 .52836 L
.52286 .50059 L
.52667 .53113 L
.53048 .55057 L
.53429 .57278 L
.5381 .60332 L
.5419 .56723 L
.54571 .54779 L
.54952 .55057 L
.55333 .49781 L
.55714 .45894 L
.56095 .43396 L
.56476 .43396 L
.56857 .39786 L
.57238 .35899 L
.57619 .37565 L
.58 .36177 L
.58381 .36455 L
.58762 .3229 L
.59143 .28681 L
Mistroke
.59524 .19241 L
.59905 .17297 L
.60286 .17575 L
.60667 .17852 L
.61048 .15076 L
.61429 .18963 L
.6181 .20351 L
.6219 .21739 L
.62571 .18963 L
.62952 .13688 L
.63333 .15631 L
.63714 .11744 L
.64095 .08413 L
.64476 .03693 L
.64857 .11467 L
.65238 .20351 L
.65619 .18685 L
.66 .19241 L
.66381 .14521 L
.66762 .14798 L
.67143 .16187 L
.67524 .15909 L
.67905 .15909 L
.68286 .2285 L
.68667 .23683 L
.69048 .27292 L
.69429 .28125 L
.6981 .21739 L
.7019 .20351 L
.70571 .22017 L
.70952 .26737 L
.71333 .29236 L
.71714 .28125 L
.72095 .25626 L
.72476 .21739 L
.72857 .24794 L
.73238 .22572 L
.73619 .20351 L
.74 .24794 L
.74381 .30624 L
.74762 .28958 L
.75143 .27015 L
.75524 .28125 L
.75905 .28958 L
.76286 .31735 L
.76667 .22572 L
.77048 .18408 L
.77429 .12855 L
.7781 .11189 L
.7819 .08968 L
Mistroke
.78571 .09246 L
.78952 .123 L
.79333 .22572 L
.79714 .2757 L
.80095 .27848 L
.80476 .25626 L
.80857 .29791 L
.81238 .28681 L
.81619 .25349 L
.82 .23961 L
.82381 .24794 L
.82762 .2285 L
.83143 .26737 L
.83524 .29236 L
.83905 .28125 L
.84286 .28125 L
.84667 .25071 L
.85048 .27292 L
.85429 .334 L
.8581 .39509 L
.8619 .37287 L
.86571 .40619 L
.86952 .38676 L
.87333 .40897 L
.87714 .43396 L
.88095 .38676 L
.88476 .42007 L
.88857 .38676 L
.89238 .41452 L
.89619 .40619 L
.9 .3812 L
.90381 .40342 L
.90762 .43396 L
.91143 .43118 L
.91524 .36177 L
.91905 .38398 L
.92286 .40342 L
.92667 .39231 L
.93048 .42563 L
.93429 .39231 L
.9381 .35622 L
.9419 .36177 L
.94571 .40619 L
.94952 .38953 L
.95333 .41175 L
.95714 .41452 L
.96095 .41452 L
.96476 .40619 L
.96857 .40897 L
.97238 .40342 L
Mistroke
.97619 .39509 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[47]:=",
  ImageSize->{289, 289},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004Q00018A000`40n007h00Ooooo8_oo003ooolR
ool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00
oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolR
ool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00
oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolR
ool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00
oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolR
ool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00
oooo8_oo003ooolRool00?ooob;oo`006_oo00<00?ooool0;Ooo00<00?ooool00_oo00<00?ooool0
9_oo1@000_oo00<00?ooool00_oo00<00?ooool08ooo1@000_oo00<00?ooool00_oo00<00?ooool0
9Ooo0`000ooo00<00?ooool00_oo00<00?ooool09?oo0`000ooo00<00?ooool00_oo00<00?ooool0
0ooo000Iool00`00ool0000]ool00`00ool00002ool00`00ool0000Yool01`00oooooooo003oo`00
00;oo`03003oo`0002Koo`07003oooooool00?oo00000_oo00<00?oo00009_oo00<00?ooool00_oo
00<00?oo00000_oo00<00?oo00009Ooo00<00?ooool00_oo00<00?oo00000_oo00<00?oo00001?oo
000Iool00`00ool0000_ool01P00ooooo`00ool002Woo`07003oooooool00?oo00000_oo00<00?oo
00009_oo00<00?ooool00ooo00H00?ooool00?oo000Wool01`00oooooooo003oo`0000;oo`03003o
o`0002Koo`03003ooooo00?oo`06003ooooo003oo`001?oo000Iool00`00ool0000]ool20003ool0
0`00ool0000Yool01`00oooooooo003oo`0000;oo`03003oo`0002Koo`04003oooooool20003ool0
0`00ool0000Wool01`00oooooooo003oo`0000;oo`03003oo`0002Koo`04003oooooool20003ool0
0`00ool00004ool001Woo`03003oo`0002goo`03003ooooo00;oo`03003oo`0002Woo`07003ooooo
ool00?oo00000_oo00<00?oo00009_oo00D00?ooooooo`0000Coo`03003oo`0002Koo`03003oo`00
00;oo`03003oo`0000;oo`03003oo`0002Goo`03003oo`0000;oo`03003ooooo00;oo`03003oo`00
00Coo`006_oo00<00?ooool0;?oo0`000ooo00<00?ooool09ooo0P001?oo00<00?ooool00_oo00<0
0?ooool09?oo0P000ooo0`000ooo00<00?ooool09_oo00<00?ooool00_oo00<00?ooool00_oo00<0
0?ooool09Ooo00@00?ooooooo`<000?oo`03003ooooo00?oo`00oooo8_oo003ooolRool00?ooob;o
o`00oooo8_oo003ooolRool00?ooob;oo`005Oooo`002`000_oo000Eool00`00ooooo`02ool00`00
ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`08ool00`00
ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00
ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`08ool00`00
ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00
ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`07ool00`00ooooo`08ool00`00
ooooo`04ool10001ool1ool001Goo`03003ooooo0?ooo`Ooo`40007oo`7oo`005Ooo00<00?ooool0
oooo1ooo0@000Ooo0Ooo000Eool2000Eool00`00ooooo`3^ool20002ool001Goo`03003ooooo01Co
o`03003ooooo0>ooo`40007oo`7oo`005Ooo00<00?ooool05?oo00<00?ooool0kooo0@000Ooo0Ooo
000Eool00`00ooooo`0Dool2003`ool10001ool1ool001Goo`03003ooooo017oo`03003ooooo0080
0?3oo`40007oo`7oo`005Ooo00<00?ooool04Ooo0`0000?oo`00ool0kooo0@000Ooo0Ooo000Eool2
000Bool300000ooo003oo`2Aool00`00ooooo`1Jool20002ool001Goo`03003ooooo017oo`03003o
o`0000;oo`03003ooooo08ooo`03003ooooo05_oo`40007oo`7oo`005Ooo00<00?ooool04Ooo00<0
0?oo00000_oo0P00T?oo00<00?ooool0Fooo0@000Ooo0Ooo000Eool00`00ooooo`0Aool00`00ool0
0003ool00`00ooooo`2>ool00`00ooooo`1Kool10001ool1ool001Goo`03003ooooo013oo`03003o
oooo00Coo`03003ooooo08koo`03003ooooo05_oo`40007oo`7oo`005Ooo00<00?ooool02ooo00<0
0?ooool00_oo00<00?ooool01?oo00<00?oo0000S_oo00<00?ooool0Fooo0@000Ooo0Ooo000Eool2
0004ool00`00ooooo`05ool20003ool00`00ooooo`05ool2002=ool2001Lool20002ool001Goo`03
003ooooo00?oo`03003ooooo00Goo`8000?oo`03003ooooo00Goo`<008coo`8005goo`40007oo`7o
o`005Ooo00<00?ooool00ooo00<00?ooool01Ooo0P000ooo00<00?ooool01Ooo00<00?oo0000S?oo
0P00GOoo0@000Ooo0Ooo000Eool00`00ooooo`04ool00`00ooooo`04ool20003ool00`00ooooo`05
ool00`00ool0002<ool2001Mool10001ool1ool001Goo`03003ooooo00Coo`03003ooooo00Coo`80
00?oo`03003ooooo00Goo`03003oo`0008coo`03003oo`0005coo`40007oo`7oo`005Ooo00<00?oo
ool01?oo00<00?ooool00ooo00L00?oo003oo`00ool00009ool00`00ooooo`2:ool00`00ool0001L
ool10001ool1ool001Goo`8000Goo`03003ooooo00;oo`800006ool00?oo003oo`002_oo00<00?oo
ool0ROoo00<00?oo0000Fooo0P000_oo000Eool00`00ooooo`04ool01000oooooooo0`000_oo0`00
2ooo00<00?ooool0ROoo00<00?oo0000G?oo0@000Ooo0Ooo000Eool00`00ooooo`04ool01000oooo
oooo0`000_oo0`002ooo00<00?ooool0ROoo00<00?oo00008_oo0P00>?oo0@000Ooo0Ooo000Eool0
0`00ooooo`05ool01P00ooooo`00ool000;oo`03003oo`0000_oo`03003ooooo08Woo`03003oo`00
02;oo`8003Soo`40007oo`7oo`000ooo1@000_oo00<00?ooool00_oo00<00?ooool00ooo00<00?oo
ool01Ooo0P0000Coo`00ool000;oo`03003ooooo00_oo`03003ooooo08Woo`03003oo`0002;oo`80
03Soo`40007oo`7oo`001Ooo00L00?ooooooo`00ool00002ool00`00ool00004ool00`00ooooo`05
ool30002ool01000ooooo`003Ooo00<00?ooool0R?oo00@00?ooool0027oo`03003oo`0003Soo`40
007oo`7oo`001Ooo00L00?ooooooo`00ool00002ool00`00ool00004ool20006ool00`00ool00005
ool00`00ooooo`0;ool00`00ooooo`28ool01000ooooo`008Ooo00@00?ooool003Goo`<000;oo`00
1Ooo00L00?ooooooo`00ool00002ool00`00ool00004ool00`00ooooo`07ool00`00ooooo`03ool0
0`00ooooo`0;ool00`00ooooo`28ool01000ooooo`008Ooo00@00?ooool003Ooo`40007oo`7oo`00
1Ooo00L00?ooooooo`00ool00002ool00`00ool00004ool00`00ooooo`07ool00`00ooooo`0Bool0
0`00ooooo`27ool01000ooooo`008Ooo00@00?ooool003Ooo`40007oo`7oo`001?oo0P001?oo00<0
0?ooool00_oo00<00?ooool00ooo00<00?ooool07?oo00<00?ooool0Qooo00@00?ooool0027oo`04
003ooooo000gool10001ool1ool001Goo`03003ooooo01coo`03003ooooo08Ooo`04003ooooo000P
ool01@00oooooooo0000=ooo0@000Ooo0Ooo000Eool00`00ooooo`0Lool00`00ooooo`27ool01000
ooooo`008?oo00D00?ooooooo`0003Ooo`40007oo`7oo`005Ooo0P007Ooo00<00?ooool0Qooo00@0
0?ooool0023oo`05003oooooool0000fool20002ool001Goo`03003ooooo01coo`05003oooooool0
0025ool01000ooooo`008?oo00D00?ooooooo`0003Ooo`40007oo`7oo`005Ooo00<00?ooool07?oo
00D00?ooooooo`0008?oo`8000?oo`03003ooooo01koo`05003oooooool0000gool10001ool1ool0
01Goo`03003ooooo01coo`05003oooooool00023ool20003ool00`00ooooo`0Nool01@00oooooooo
0000=ooo0@000Ooo0Ooo000Eool00`00ooooo`0Lool01@00oooooooo0000Pooo0P000ooo00D00?oo
ooooo`0001coo`05003oooooool0000gool10001ool1ool001Goo`03003ooooo01coo`03003ooooo
008008?oo`8000?oo`04003oooooool2000Kool01@00oooooooo0000=ooo0@000Ooo0Ooo000Eool2
000Nool01000ool00000O_oo00<00?ooool00_oo0P000ooo00@00?ooooooo`8001_oo`05003ooooo
ool0000fool20002ool001Goo`03003ooooo01goo`05003oo`00ool0001mool00`00ooooo`02ool2
0003ool01`00oooooooo003oo`0001[oo`05003oooooool0000gool10001ool1ool001Goo`03003o
oooo01goo`05003oo`00ool0001mool00`00ooooo`02ool00`00ooooo`03ool01@00ooooo`00ool0
0`005ooo00<00?ooool00_oo00<00?ooool0=Ooo0@000Ooo0Ooo000Eool00`00ooooo`0Mool01@00
ool00?oo00001_oo00<00?ooool0M?oo00D00?ooooooo`0000Koo`08003ooooo003oo`00ool001Oo
o`03003ooooo00;oo`03003ooooo03Goo`40007oo`7oo`005Ooo00<00?ooool07Ooo0P000_oo00<0
0?ooool01?oo00<00?ooool0Looo0P000ooo00<00?ooool01?oo00@00?ooool000?oo`03003ooooo
01Goo`03003ooooo00;oo`03003ooooo03Goo`40007oo`7oo`005Ooo00<00?ooool07Ooo00D00?oo
ooooo`0000?oo`04003oo`00001eool00`00ool00002ool00`00ooooo`04ool00`00ool00004ool0
0`00ooooo`0Eool00`00ooooo`02ool00`00ooooo`0eool10001ool1ool001Goo`8001koo`05003o
ooooool00003ool01000ool00000Looo0`0000Goo`00ooooo`0000Koo`03003oo`0000Coo`03003o
oooo01Goo`03003ooooo00?oo`03003ooooo03?oo`8000;oo`005Ooo00<00?ooool08Ooo00<00?oo
ool00P0000Coo`00ool007;oo`05003oo`00ool00002ool00`00ooooo`04ool00`00ool00004ool0
0`00ooooo`0Eool00`00ooooo`03ool00`00ooooo`0dool10001ool1ool001Goo`03003ooooo027o
o`03003ooooo00800004ool00?oo001bool01@00oooooooo00000_oo00<00?ooool01?oo00<00?oo
00001?oo00<00?ooool05Ooo00<00?ooool00ooo00<00?ooool0=?oo0@000Ooo0Ooo000Eool00`00
ooooo`0Rool02000ool00000ool00?oo001aool00`00ooooo`02ool01000ooooo`001_oo0`001?oo
00<00?ooool05Ooo00<00?ooool00ooo00<00?ooool0=?oo0@000Ooo0Ooo000Eool00`00ooooo`0R
ool200001Ooo003oo`00ool00P00L?oo00<00?ooool00_oo00@00?ooool000Koo`<000Coo`03003o
oooo01Goo`03003ooooo00?oo`03003ooooo03Coo`40007oo`7oo`005Ooo0P009ooo0P0000?oo`00
ool00`00KOoo00<00?ooool00_oo00@00?ooool000Koo`<000Goo`03003ooooo01Coo`03003ooooo
00?oo`03003ooooo03?oo`8000;oo`005Ooo00<00?ooool09_oo00<00?ooool01?oo00<00?ooool0
3_oo00<00?ooool0F_oo00<00?ooool00ooo00<00?oo00001_oo00<00?ooool01Ooo00<00?ooool0
5?oo00<00?ooool00ooo00<00?ooool0=?oo0@000Ooo0Ooo000Eool00`00ooooo`0Vool00`00oooo
o`04ool00`00ooooo`0>ool2001Kool00`00ooooo`03ool00`00ool00006ool00`00ooooo`05ool0
0`00ooooo`0Dool00`00ooooo`03ool00`00ooooo`0dool10001ool1ool001Goo`03003ooooo02Ko
o`03003ooooo00Goo`03003ooooo00goo`8005_oo`03003ooooo00?oo`8000Ooo`03003ooooo00Go
o`03003ooooo00;oo`03003ooooo00Koo`03003ooooo00Koo`03003ooooo00?oo`03003ooooo03Co
o`40007oo`7oo`000ooo1@000_oo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool09_oo00<0
0?ooool01Ooo00<00?ooool03?oo00<00?oo0000Fooo00<00?ooool00ooo0P003ooo00<00?ooool0
0_oo00<00?ooool01_oo00<00?ooool01Ooo00<00?ooool01?oo00<00?ooool0=?oo0@000Ooo0Ooo
0005ool01`00oooooooo003oo`0000;oo`03003oo`0000Coo`03003ooooo02Koo`03003ooooo00Go
o`03003ooooo00coo`03003oo`0005_oo`03003ooooo00Coo`03003ooooo00goo`07003oooooool0
0?oo00001ooo00<00?ooool01Ooo00<00?ooool01?oo00<00?ooool0=?oo0@000Ooo0Ooo0005ool0
1`00oooooooo003oo`0000Coo`03003ooooo00;oo`8002Ooo`03003ooooo00Goo`8000goo`03003o
o`0005_oo`03003ooooo00Coo`03003ooooo00goo`07003oooooool00?oo00001?oo00@00?oo0000
00Ooo`03003ooooo00Coo`03003ooooo03;oo`<000;oo`001Ooo00L00?ooooooo`00ool00002ool2
0005ool00`00ooooo`0_ool00`00ooooo`0;ool00`00ool0001Kool00`00ooooo`0Dool01`00oooo
oooo003oo`0000Coo`04003oo`000007ool00`00ooooo`04ool00`00ooooo`0dool10001ool1ool0
00Goo`07003oooooool00?oo00000_oo00<00?ooool01?oo00<00?ooool0;ooo00<00?ooool02ooo
00@00?ooool005[oo`03003ooooo01Coo`07003oooooool00?oo00001?oo00@00?oo000000Ooo`03
003ooooo00Coo`03003ooooo03Coo`40007oo`7oo`001?oo0P001?oo00@00?ooooooo`<000Coo`03
003ooooo033oo`8000_oo`04003ooooo0007ool00`00ooooo`1@ool00`00ooooo`0Dool01`00oooo
oooo003oo`0000Coo`05003oo`00ool00006ool00`00ooooo`04ool00`00ooooo`06ool00`00oooo
o`0[ool10001ool1ool001Goo`03003ooooo033oo`8000_oo`04003ooooo0007ool00`00ooooo`1@
ool00`00ooooo`0Dool01`00oooooooo003oo`0000Coo`<00003ool00?oo00Goo`03003ooooo00Co
o`03003ooooo00Koo`03003ooooo02_oo`40007oo`7oo`005Ooo00<00?ooool0<?oo0P002_oo00D0
0?ooooooo`0000Koo`03003oo`00057oo`03003ooooo01Goo`06003ooooo003oo`001?oo0`0000?o
o`00ool01Ooo00<00?ooool01?oo00<00?ooool01_oo00<00?ooool0:ooo0@000Ooo0Ooo000Eool2
000bool00`00ooooo`08ool01000oooooooo0P0000?oo`00ool00_oo00<00?oo0000DOoo00<00?oo
ool05Ooo00H00?ooool00?oo0003ool00`00ool00002ool00`00ooooo`04ool00`00ooooo`04ool0
0`00ooooo`04ool3000/ool20002ool001Goo`03003ooooo037oo`03003ooooo00Soo`03003ooooo
00?oo`8000;oo`05003oooooool0001?ool00`00ooooo`0Fool01P00ooooo`00ool000?oo`03003o
o`0000;oo`03003ooooo00Coo`03003ooooo00Coo`03003ooooo00Coo`<002goo`40007oo`7oo`00
5Ooo00<00?ooool0<_oo00<00?ooool00P001Ooo00<00?ooool01Ooo0P001?oo00<00?ooool0COoo
00<00?ooool05_oo00@00?ooool000;oo`06003ooooo003oo`000_oo00<00?ooool01?oo00<00?oo
ool01?oo00<00?ooool00ooo00@00?oo000002goo`40007oo`7oo`005Ooo00<00?ooool0<_oo0P00
00?oo`0000001Ooo00<00?ooool01Ooo0P001?oo00<00?ooool0COoo00<00?ooool05_oo00<00?oo
00000ooo00@00?ooool000Coo`03003ooooo00Coo`03003ooooo00Coo`03003ooooo00?oo`05003o
ooooool00003ool00`00ooooo`0Vool10001ool1ool001Goo`03003ooooo03;oo`800004ool00?oo
0004ool00`00ooooo`05ool00`00ooooo`03ool00`00ooooo`1=ool00`00ooooo`0Fool00`00ool0
0003ool01000ooooo`001?oo00<00?ooool01?oo00<00?ooool01Ooo00<00?ooool00_oo00D00?oo
ooooo`0000?oo`03003ooooo02Koo`40007oo`7oo`005Ooo00<00?ooool0<_oo0P0000Coo`00ool0
00Coo`03003ooooo00coo`03003ooooo04coo`03003ooooo01Ooo`8000?oo`04003ooooo0004ool0
0`00ooooo`04ool00`00ooooo`05ool00`00ool00002ool01@00oooooooo00000ooo00<00?ooool0
9_oo0@000Ooo0Ooo000Eool2000cool200001?oo003oo`000ooo00<00?ooool03Ooo00<00?ooool0
C?oo00<00?ooool05ooo0P000ooo00@00?ooool000Coo`03003ooooo00Coo`03003ooooo00Goo`03
003oo`0000;oo`05003oooooool00003ool2000Vool20002ool001Goo`03003ooooo03Coo`04003o
oooo0003ool00`00ooooo`0=ool00`00ooooo`1<ool00`00ooooo`0Gool20003ool01000ooooo`00
1?oo00<00?ooool01?oo00<00?ooool01Ooo00<00?oo00000_oo00D00?ooooooo`0000;oo`03003o
o`0002Ooo`40007oo`7oo`005Ooo00<00?ooool0=?oo00@00?ooool000?oo`03003ooooo00goo`03
003ooooo00Ooo`03003ooooo04;oo`03003ooooo01Ooo`8000?oo`03003oo`0000Goo`04003ooooo
0003ool00`00ooooo`05ool30002ool01@00oooooooo00000_oo00<00?oo00009ooo0@000Ooo0Ooo
000Eool00`00ooooo`0dool01000ooooo`000ooo00<00?ooool03Ooo00<00?ooool01ooo00<00?oo
ool0@_oo00<00?ooool05ooo0P000ooo00<00?oo00001Ooo00@00?ooool000;oo`03003ooooo00Ko
o`<00003ool00?oo00?oo`06003ooooo003oo`009ooo0@000Ooo0Ooo000Eool00`00ooooo`0dool0
1000ooooo`000_oo00<00?ooool03_oo00<00?ooool01ooo00<00?ooool0@_oo00<00?ooool06?oo
00L00?ooooooo`00ool00006ool01P00ool00000ool000Soo`<00003ool00?oo00?oo`06003ooooo
003oo`009ooo0@000Ooo0Ooo000Eool00`00ooooo`0dool01`00oooooooo003oo`00013oo`03003o
oooo00Ooo`03003ooooo04;oo`03003ooooo01Soo`03003ooooo00;oo`8000Koo`800004ool00?oo
0009ool01000ool000001Ooo0`0000?oo`00ool09_oo0@000Ooo0Ooo000Eool2000iool00`00ool0
000@ool00`00ooooo`06ool200000ooo003oo`11ool00`00ooooo`0Mool20006ool200001?oo003o
o`002ooo0P001Ooo0P000_oo00<00?ooool09?oo0P000_oo000Eool00`00ooooo`0hool00`00ool0
000@ool00`00ooooo`06ool01000ool00000@_oo00<00?ooool07Ooo00<00?ooool01Ooo0P000_oo
0P002ooo0P001Ooo00D00?ooooooo`0002Ooo`40007oo`7oo`005Ooo00<00?ooool0>?oo00<00?oo
00004?oo00<00?ooool01_oo00@00?oo000004;oo`03003ooooo01goo`03003ooooo00Goo`8000;o
o`8000_oo`8000Goo`05003oooooool0000Wool10001ool1ool001Goo`03003ooooo03Soo`80017o
o`03003ooooo00Koo`04003oo`000012ool00`00ooooo`0Uool20002ool2000;ool00`00ooooo`08
ool00`00ooooo`0Uool10001ool1ool001Goo`03003ooooo03Soo`80017oo`03003ooooo00Koo`05
003oo`00ool00011ool00`00ooooo`0Uool01000oooooooo0P002ooo00<00?ooool02?oo00<00?oo
ool09Ooo0@000Ooo0Ooo000Eool00`00ooooo`0iool00`00ooooo`0?ool00`00ooooo`04ool01`00
ool00?oo003oo`00047oo`03003ooooo02Goo`04003oooooool2000Gool00`00ooooo`0Tool10001
ool1ool001Goo`8003[oo`03003ooooo013oo`03003ooooo00?oo`8000;oo`03003oo`00043oo`03
003ooooo02Koo`03003ooooo00;oo`03003ooooo01Goo`03003ooooo02?oo`8000;oo`005Ooo00<0
0?ooool0C?oo00P00?ooool00?oo003oo`001?oo0P00?ooo00<00?ooool0:ooo00<00?ooool05Ooo
00<00?ooool09?oo0@000Ooo0Ooo000Eool00`00ooooo`1<ool00`00ooooo`0300000ooo003oo`04
ool00`00ooooo`0mool00`00ooooo`0[ool00`00ooooo`0Eool00`00ooooo`0Tool10001ool1ool0
01Goo`03003ooooo04coo`03003oo`0000[oo`03003ooooo03goo`03003ooooo02_oo`03003ooooo
01Goo`03003ooooo02Coo`40007oo`7oo`000ooo2P000_oo00<00?ooool00ooo00<00?ooool0C?oo
00<00?oo00002_oo00<00?ooool0?Ooo00<00?ooool0@ooo00<00?ooool09?oo0@000Ooo0Ooo0005
ool00`00ooooo`02ool01`00oooooooo003oo`0000Coo`03003ooooo04coo`03003oo`0000_oo`03
003ooooo03coo`03003ooooo04?oo`03003ooooo02Coo`40007oo`7oo`001Ooo00<00?ooool00_oo
00L00?ooooooo`00ool00004ool2001=ool00`00ool0000;ool00`00ooooo`0lool00`00ooooo`13
ool00`00ooooo`0Rool30002ool000Goo`03003ooooo00;oo`07003oooooool00?oo00001?oo00<0
0?ooool0C?oo00<00?oo00002ooo00<00?ooool0??oo00<00?ooool0@ooo00<00?ooool09?oo0@00
0Ooo0Ooo0005ool00`00ooooo`02ool01`00oooooooo003oo`0000Coo`03003ooooo04coo`03003o
o`0000_oo`03003ooooo03coo`03003ooooo04?oo`03003ooooo02Coo`40007oo`7oo`001?oo0P00
0ooo0P001?oo00<00?ooool00ooo00<00?ooool0C?oo0P003?oo0P00?Ooo00<00?ooool0@ooo00<0
0?ooool09?oo0@000Ooo0Ooo000Eool00`00ooooo`1<ool2000>ool00`00ooooo`0iool00`00oooo
o`14ool00`00ooooo`0Tool10001ool1ool001Goo`03003ooooo04coo`8000koo`03003ooooo03Wo
o`03003ooooo04Coo`03003ooooo02Coo`40007oo`7oo`005Ooo0P00C_oo00<00?ooool03Ooo00<0
0?ooool0>?oo00<00?ooool0A?oo00<00?ooool08ooo0P000_oo000Eool00`00ooooo`1Mool00`00
ooooo`0hool00`00ooooo`14ool00`00ooooo`0Cool00`00ooooo`0>ool10001ool1ool001Goo`03
003ooooo05goo`03003ooooo03Coo`05003oooooool00016ool00`00ooooo`0Cool2000?ool10001
ool1ool001Goo`03003ooooo05goo`03003ooooo03Coo`800003ool0000004Ooo`03003ooooo00co
o`03003ooooo00?oo`8000ooo`40007oo`7oo`005Ooo00<00?ooool0GOoo00<00?ooool0=?oo0P00
00?oo`00ool0Aooo00<00?ooool03?oo00<00?ooool00ooo0P003ooo0@000Ooo0Ooo000Eool00`00
ooooo`1Nool00`00ooooo`0cool00`00ool00019ool00`00ooooo`0<ool00`00ooooo`03ool2000?
ool10001ool1ool001Goo`8005ooo`03003ooooo03?oo`03003oo`0004Woo`8000goo`8000?oo`03
003oo`0000koo`8000;oo`005Ooo00<00?ooool0G_oo00<00?ooool0<_oo00<00?ooool0B_oo0P00
3Ooo0P000ooo00<00?oo00003ooo0@000Ooo0Ooo000Eool00`00ooooo`1Nool00`00ooooo`0bool0
0`00ooooo`1:ool20009ool01000oooooooo0P000ooo00<00?oo00003ooo0@000Ooo0Ooo000Eool0
0`00ooooo`1Nool00`00ooooo`0bool00`00ooooo`1:ool200001ooo003ooooo003oo`0000;oo`04
003oooooool20003ool01000ooooo`003_oo0@000Ooo0Ooo000Eool00`00ooooo`1Nool00`00oooo
o`0bool00`00ooooo`1:ool01000ool000000_oo00<00?oo00000_oo00@00?ooooooo`8000?oo`03
003ooooo008000goo`40007oo`7oo`005Ooo0P00Gooo00<00?ooool0<_oo00<00?ooool0B_oo00@0
0?oo000000;oo`07003oo`00ool00?oo00000_oo0P0000Coo`00ool000;oo`8000Ooo`03003ooooo
00;oo`8000;oo`005Ooo00<00?ooool0G_oo00<00?ooool0<_oo00<00?ooool0C?oo00d00?oo003o
o`00ool00?oo003oo`00ool00002ool200001?oo003ooooo0P001ooo00<00?ooool00ooo0@000Ooo
0Ooo000Eool00`00ooooo`1Oool00`00ooooo`0aool00`00ooooo`1<ool01P00ool00?oo003oo`<0
0004ool00?oo0002ool200001ooo003ooooo003oo`0000Goo`03003ooooo00Coo`40007oo`7oo`00
5Ooo00<00?ooool0Gooo00<00?ooool0<Ooo00<00?ooool0C?oo00@00?oo003oo`800007ool00000
ool00?oo00000_oo0P0000Ooo`00ooooo`00ool00002ool01000ooooo`001_oo0@000Ooo0Ooo000E
ool00`00ooooo`1Oool00`00ooooo`0aool00`00ooooo`1>ool01@00ool00000ool00P0000Coo`00
ool000?oo`03003oo`0000Coo`03003ooooo00<000Ooo`40007oo`7oo`005Ooo00<00?ooool0Gooo
00<00?ooool0<Ooo00<00?ooool0C_oo0P0000Coo`00ool000;oo`03003oo`0000Coo`03003ooooo
00?oo`03003oo`0000[oo`40007oo`7oo`005Ooo0P00H?oo00<00?ooool0<?oo00<00?ooool0Cooo
0P0000Coo`00ool000;oo`03003oo`0000Coo`03003ooooo00Coo`8000Woo`8000;oo`005Ooo00<0
0?ooool0H?oo00<00?ooool0;ooo00<00?ooool0Cooo0P0000?oo`00ool01?oo0P001?oo00<00?oo
ool04?oo0@000Ooo0Ooo000Eool00`00ooooo`1Pool00`00ooooo`0_ool00`00ooooo`1@ool00`00
ooooo`05ool20004ool00`00ooooo`0@ool10001ool1ool001Goo`03003ooooo063oo`03003ooooo
02ooo`03003ooooo053oo`03003ooooo00Goo`8000Coo`03003ooooo013oo`40007oo`7oo`000ooo
2P000_oo00<00?ooool00ooo00<00?ooool0H?oo00<00?ooool0;ooo00<00?ooool0D?oo00<00?oo
ool01Ooo0P005ooo0@000Ooo0Ooo0005ool00`00ooooo`02ool01`00oooooooo003oo`0000Coo`03
003ooooo063oo`03003ooooo02koo`8005;oo`03003ooooo00Goo`03003ooooo01Koo`40007oo`7o
o`001Ooo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool00_oo0P00H_oo00<00?ooool0;Ooo
00<00?ooool0L?oo0`000_oo0005ool00`00ooooo`02ool01000oooooooo0P001Ooo00<00?ooool0
HOoo00<00?ooool0;Ooo00<00?ooool0L_oo0@000Ooo0Ooo0005ool00`00ooooo`02ool01@00oooo
oooo00001_oo00<00?ooool0HOoo0P0000?oo`00ool0:_oo00<00?ooool0Looo0@000Ooo0Ooo0004
ool20003ool20003ool30004ool00`00ooooo`1Qool200000ooo003oo`0Zool00`00ooooo`1cool1
0001ool1ool001Goo`03003ooooo067oo`800003ool00?oo02[oo`03003ooooo07?oo`40007oo`7o
o`005Ooo00<00?ooool0Hooo0P00:ooo00<00?ooool0Looo0@000Ooo0Ooo000Eool2001Tool2000[
ool00`00ooooo`1bool20002ool001Goo`03003ooooo06?oo`03003oo`0002[oo`03003ooooo07?o
o`40007oo`7oo`005Ooo00<00?ooool0IOoo00D00?ooooooo`0001;oo`03003ooooo017oo`03003o
oooo07?oo`40007oo`7oo`005Ooo00<00?ooool0IOoo00D00?ooooooo`0001;oo`8001;oo`03003o
oooo07?oo`40007oo`7oo`005Ooo00<00?ooool0IOoo00D00?ooooooo`0001;oo`8001;oo`03003o
oooo07?oo`40007oo`7oo`005Ooo00<00?ooool0IOoo00D00?ooooooo`0001;oo`03003oo`00013o
o`03003ooooo07Coo`40007oo`7oo`005Ooo0P00I_oo00D00?ooooooo`0001;oo`03003oo`00013o
o`03003ooooo07?oo`8000;oo`005Ooo00<00?ooool0IOoo00D00?ooooooo`0001;oo`03003oo`00
013oo`03003ooooo07Coo`40007oo`7oo`005Ooo00<00?ooool0I_oo00@00?ooool001;oo`03003o
o`0000Goo`03003ooooo00Soo`03003ooooo07Coo`40007oo`7oo`005Ooo00<00?ooool0I_oo00@0
0?oo000001;oo`07003ooooo003oo`00ool00P002_oo00<00?ooool0M?oo0@000Ooo0Ooo000Eool0
0`00ooooo`1Vool01000ool000004_oo00<00?ooool00`0000Koo`00ool00?oo0007ool00`00oooo
o`1dool10001ool1ool001Goo`03003ooooo06Koo`04003oo`00000Aool03@00oooooooo003oo`00
ool00?oo003oo`0000Ooo`03003ooooo07Coo`40007oo`7oo`005Ooo0P00Iooo00D00?oo003oo`00
00ooo`8000?oo`03003ooooo00800004ool00?oo0007ool00`00ooooo`1cool20002ool001Goo`03
003ooooo06Ooo`800003ool00?oo00koo`8000Koo`06003ooooo003oo`001ooo00<00?ooool0M?oo
0@000Ooo0Ooo000Eool00`00ooooo`1Wool200000ooo003oo`0=ool30006ool00`00ooooo`030007
ool00`00ooooo`1dool10001ool1ool001Goo`03003ooooo06Ooo`800003ool00?oo00goo`<000Ko
o`07003oooooool00?oo00001_oo00<00?ooool0M?oo0@000Ooo0Ooo000Eool00`00ooooo`1Wool2
00000ooo003oo`06ool00`00ooooo`03ool200000ooo003oo`09ool00`00ool00006ool00`00oooo
o`1dool10001ool1ool001Goo`03003ooooo06[oo`03003ooooo00Goo`03003ooooo00?oo`04003o
oooo000:ool00`00ool00005ool00`00ooooo`1eool10001ool1ool001Goo`8006_oo`03003ooooo
00Goo`03003ooooo00?oo`04003ooooo000:ool00`00ool00005ool00`00ooooo`1dool20002ool0
01Goo`03003ooooo06[oo`03003ooooo00Goo`03003ooooo00?oo`04003ooooo000<ool00`00oooo
o`03ool00`00ooooo`1eool10001ool1ool001Goo`03003ooooo06[oo`03003ooooo00Goo`8000Co
o`03003ooooo00goo`03003ooooo00?oo`03003ooooo07Goo`40007oo`7oo`005Ooo00<00?ooool0
J_oo00@00?ooool000Coo`8000?oo`03003ooooo00koo`03003ooooo00?oo`03003ooooo07Goo`40
007oo`7oo`000ooo1@0000Coo`00000000?oo`03003ooooo00?oo`03003ooooo06[oo`04003ooooo
0003ool00`00ool00003ool00`00ooooo`0?ool00`00ooooo`02ool00`00ooooo`1eool10001ool1
ool000Goo`05003oooooool00004ool00`00ool00004ool00`00ooooo`1Zool01000ool000000ooo
00<00?oo00000ooo00<00?ooool03ooo00@00?ooooooo`8007Ooo`40007oo`7oo`001Ooo00<00?oo
ool00_oo00L00?ooooooo`00ool00004ool2001[ool01@00ool00?oo00000_oo00@00?ooool000;o
o`03003ooooo00ooo`04003oooooool2001eool30002ool000Goo`03003ooooo00;oo`07003ooooo
ool00?oo00001?oo00<00?ooool0J_oo00D00?oo003oo`0000;oo`04003ooooo0002ool00`00oooo
o`0?ool01@00oooooooo0000N?oo0@000Ooo0Ooo0005ool01`00oooooooo003oo`0000;oo`03003o
o`0000Coo`03003ooooo06_oo`800005ool00?ooool00002ool01000ooooo`004Ooo00@00?ooool0
07Woo`40007oo`7oo`001?oo0P001?oo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool0Jooo
00@00?ooooooo`<000;oo`04003ooooo000Bool00`00ool0001iool10001ool1ool001Goo`03003o
oooo06_oo`05003oooooool00004ool00`00ool0000Cool00`00ool0001iool10001ool1ool001Go
o`03003ooooo06_oo`03003ooooo00Ooo`8001?oo`03003oo`0007Woo`40007oo`7oo`005Ooo0P00
M_oo0P004ooo00<00?oo0000N?oo0P000_oo000Eool00`00ooooo`1eool00`00ooooo`0Bool00`00
ool0001iool10001ool1ool001Goo`03003ooooo07Goo`03003ooooo01;oo`03003oo`0007Woo`40
007oo`7oo`005Ooo00<00?ooool0R_oo0P00N_oo0@000Ooo0Ooo000Eool00`00ooooo`2;ool00`00
ooooo`1hool10001ool1ool001Goo`8008coo`03003ooooo07Ooo`8000;oo`005Ooo00<00?ooool0
Rooo00<00?ooool0N?oo0@000Ooo0Ooo000Eool00`00ooooo`2;ool00`00ooooo`1hool10001ool1
ool001Goo`03003ooooo08_oo`03003ooooo07Soo`40007oo`7oo`005Ooo00<00?ooool0oooo1ooo
0@000Ooo0Ooo000Eool00`00ooooo`02ool00`00ooooo`0`ool00`00ooooo`0_ool00`00ooooo`0`
ool00`00ooooo`0_ool00`00ooooo`0`ool00`00ooooo`04ool10001ool1ool001Goo`8000?oo`03
003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Soo`03
003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03
003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Soo`03
003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03
003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Ooo`03003ooooo00Soo`03
003ooooo00?oo`8000;oo`005Oooo`002`000_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolR
ool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00
oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolR
ool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00
oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolR
ool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00
oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolR
ool00?ooob;oo`00oooo8_oo003ooolRool00?ooob;oo`00oooo8_oo003ooolRool00001\
\>"],
  ImageRangeCache->{{{0, 288}, {288, 0}} -> {-26.3625, 83.6146, 0.990551, \
0.169891}}]
}, Open  ]],

Cell["\<\
Now we compute the maximum likelihood estimate for IBM's stock \
volatility. This is the daily volatility since we used daily stock prices. \
\
\>", "MathCaption",
  CellTags->"0.56"],

Cell[CellGroupData[{

Cell["HistoricalVolatility[prices[IBM]]", "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(0.0124714509346542623`\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell["\<\
To get an estimate of the yearly volatility we multiply by the \
square root of the number of days in a year. Usually we only take the number \
of trading days, which is about 250. \
\>", "MathCaption",
  CellTags->"0.57"],

Cell[CellGroupData[{

Cell["% Sqrt[250.]", "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(0.197190953402716182`\)], "Output",
  CellLabel->"Out[49]="]
}, Open  ]],

Cell["\<\
The cumulative normal distribution is often used in modern finance \
and especially in the context of option pricing. Here is the graph of the \
cumulative standard normal distribution function. \
\>", "MathCaption",
  CellTags->"0.58"],

Cell[CellGroupData[{

Cell["Plot[Norm[x], {x, -5, 5}];", "Input",
  CellLabel->"In[50]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147149 0.588604 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -6 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -18 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -18 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -18 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(0)] -0.0125 .01471 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(0.2)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(0.4)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(0.6)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(0.8)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.04262 .01472 L
.04795 .01472 L
.053 .01472 L
.05753 .01472 L
.06244 .01472 L
.06751 .01472 L
.07308 .01472 L
.0789 .01472 L
.08435 .01472 L
.08944 .01472 L
.0941 .01472 L
.09917 .01472 L
.10458 .01472 L
.10974 .01473 L
.11442 .01473 L
.12357 .01474 L
.12869 .01474 L
.13424 .01475 L
.13943 .01476 L
.14429 .01477 L
.15379 .0148 L
.15883 .01482 L
.16423 .01484 L
.16989 .01487 L
.17525 .01491 L
.18529 .015 L
.19495 .01512 L
.2052 .01529 L
.21396 .0155 L
.22362 .01581 L
.23371 .01624 L
.24297 .01676 L
.25313 .01752 L
.26382 .01858 L
.27337 .01982 L
.28357 .0215 L
.30193 .02577 L
.31218 .02902 L
.32328 .03341 L
.34343 .0442 L
.36331 .05922 L
.38435 .08082 L
.40392 .10685 L
.42224 .13662 L
.46106 .21562 L
.50234 .31478 L
Mistroke
.5421 .40953 L
.58034 .48592 L
.6017 .51927 L
.62104 .54335 L
.64123 .56268 L
.66022 .5761 L
.67001 .58147 L
.68034 .58617 L
.69883 .59248 L
.70833 .59487 L
.7185 .59691 L
.72804 .59842 L
.73685 .59953 L
.74705 .60053 L
.75813 .60134 L
.7679 .60187 L
.77826 .60229 L
.78766 .60258 L
.79777 .6028 L
.80732 .60295 L
.81607 .60305 L
.82589 .60314 L
.83503 .60319 L
.84028 .60322 L
.84505 .60323 L
.85025 .60325 L
.85574 .60326 L
.86051 .60327 L
.86575 .60328 L
.87497 .60329 L
.88016 .6033 L
.88572 .6033 L
.89578 .60331 L
.90105 .60331 L
.90593 .60331 L
.91119 .60331 L
.91699 .60332 L
.92202 .60332 L
.92674 .60332 L
.93169 .60332 L
.93711 .60332 L
.94219 .60332 L
.94692 .60332 L
.95192 .60332 L
.95726 .60332 L
.96224 .60332 L
.96695 .60332 L
.97576 .60332 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[50]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo000gool3
000`ool3000`ool00`00ooooo`0`ool3000bool3000Oool003Soo`03003ooooo02ooo`03003ooooo
02ooo`03003oo`00037oo`03003ooooo03?oo`03003ooooo01koo`00<Ooo0`000_oo1000:ooo0`00
0ooo00<00?ooool0;_oo00<00?oo0000<_oo00<00?ooool0<?oo10007ooo000fool00`00ool0000b
ool00`00ooooo`0^ool00`00ool0000bool00`00ooooo`0`ool00`00ool0000Pool003Ooo`80037o
o`03003oo`0002ooo`03003oo`00037oo`03003oo`0003;oo`80023oo`00>?oo00<00?ooool0<?oo
00<00?ooool0;ooo00<00?ooool0<Ooo00<00?ooool0<_oo00<00?ooool07_oo003ooolXool00?oo
obSoo`00oooo:?oo003ooolXool00?ooobSoo`005Oooo`004`00000Eool00`00ooooo`03ool00`00
ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00
ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00
ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00
ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00
ooooo`04ool1000000ooo`03003ooooo00?oo`03003ooooo01goo`03003ooooo037oo`03003ooooo
037oo`03003ooooo037oo`03003ooooo037oo`03003ooooo01koo`4000003_oo00<00?oo00001?oo
00<00?ooool0oooo3ooo0@00000>ool00`00ool00004ool30003oolc003Fool3000000koo`03003o
o`0000Coo`03003ooooo03Kooa400<Ooo`4000003_oo00<00?oo00001?oo00<00?ooool0Aooo1P00
`Ooo0@00000?ool00`00ooooo`03ool00`00ooooo`1=ool4002mool1000001Goo`03003ooooo057o
o`<00;[oo`4000005Ooo00<00?ooool0E?oo0P00^?oo0@00000Eool00`00ooooo`1Fool2002fool1
000001Goo`03003ooooo05Soo`800;Coo`4000005Ooo0P00Fooo0P00/Ooo0P00000Eool00`00oooo
o`1Lool00`00ooooo`2_ool1000001Goo`03003ooooo05goo`800:ooo`4000005Ooo00<00?ooool0
Gooo00<00?ooool0[?oo0@00000Eool00`00ooooo`1Pool00`00ooooo`2[ool1000001Goo`03003o
oooo067oo`03003ooooo0:[oo`4000005Ooo00<00?ooool0H_oo00<00?ooool0ZOoo0@00000Eool0
0`00ooooo`1Sool00`00ooooo`2Xool1000001Goo`8006Goo`03003ooooo0:Koo`8000005Ooo00<0
0?ooool0IOoo00<00?ooool0Y_oo0@00000Eool00`00ooooo`1Vool00`00ooooo`2Uool1000001Go
o`03003ooooo06Ooo`03003ooooo0:Coo`4000005Ooo00<00?ooool0Iooo00<00?ooool0Y?oo0@00
000Eool00`00ooooo`1Xool00`00ooooo`2Sool1000001Goo`03003ooooo06Woo`03003ooooo0:;o
o`4000005Ooo00<00?ooool0J_oo00<00?ooool0XOoo0@00000Eool2001[ool00`00ooooo`2Pool2
000001Goo`03003ooooo06_oo`03003ooooo0:3oo`4000005Ooo00<00?ooool0K?oo00<00?ooool0
Wooo0@00000Eool00`00ooooo`1/ool00`00ooooo`2Oool1000001Goo`03003ooooo06goo`03003o
oooo09koo`4000005Ooo00<00?ooool0KOoo00<00?ooool0W_oo0@000005ool00`00ooooo`02ool0
1000oooooooo0`001?oo00<00?ooool0K_oo00<00?ooool0WOoo0@000004ool00`00ool00007ool0
0`00ooooo`04ool00`00ooooo`1^ool00`00ooooo`2Mool1000000Coo`03003oo`0000Soo`03003o
oooo00?oo`<006ooo`03003ooooo09[oo`<000001?oo00<00?oo00002?oo00<00?ooool00ooo00<0
0?ooool0Kooo00<00?ooool0W?oo0@000004ool00`00ool00007ool00`00ool00004ool00`00oooo
o`1`ool00`00ooooo`2Kool1000000Goo`03003ooooo00Ooo`03003ooooo00?oo`03003ooooo077o
o`03003ooooo09[oo`4000005Ooo00<00?ooool0LOoo00<00?ooool0V_oo0@00000Eool00`00oooo
o`1bool00`00ooooo`2Iool1000001Goo`03003ooooo07;oo`03003ooooo09Woo`4000005Ooo00<0
0?ooool0Looo00<00?ooool0V?oo0@00000Eool2001dool00`00ooooo`2Gool2000001Goo`03003o
oooo07Coo`03003ooooo09Ooo`4000005Ooo00<00?ooool0M?oo00<00?ooool0Uooo0@00000Eool0
0`00ooooo`1eool00`00ooooo`2Fool1000001Goo`03003ooooo07Goo`03003ooooo09Koo`400000
5Ooo00<00?ooool0M_oo00<00?ooool0UOoo0@00000Eool00`00ooooo`1fool00`00ooooo`2Eool1
000001Goo`03003ooooo07Ooo`03003ooooo09Coo`4000005Ooo00<00?ooool0Mooo00<00?ooool0
U?oo0@00000Eool2001iool00`00ooooo`2Bool2000001Goo`03003ooooo07Soo`03003ooooo09?o
o`4000005Ooo00<00?ooool0NOoo00<00?ooool0T_oo0@00000Eool00`00ooooo`1iool00`00oooo
o`2Bool1000001Goo`03003ooooo07[oo`03003ooooo097oo`4000005Ooo00<00?ooool0N_oo00<0
0?ooool0TOoo0@00000Eool00`00ooooo`1kool00`00ooooo`2@ool1000001Goo`03003ooooo07_o
o`03003ooooo093oo`4000005Ooo0P00OOoo00<00?ooool0S_oo0P00000Eool00`00ooooo`1lool0
0`00ooooo`2?ool1000001Goo`03003ooooo07goo`03003ooooo08koo`4000005Ooo00<00?ooool0
OOoo00<00?ooool0S_oo0@00000Eool00`00ooooo`1mool00`00ooooo`2>ool1000001Goo`03003o
oooo07koo`03003ooooo08goo`4000001Ooo00<00?ooool00_oo00<00?ooool00_oo0`000ooo00<0
0?ooool0O_oo00<00?ooool0SOoo0@000004ool00`00ool00009ool00`00ooooo`02ool00`00oooo
o`1oool00`00ooooo`2<ool1000000Coo`03003oo`0000Ooo`@000?oo`<007ooo`03003ooooo08[o
o`<000001?oo00<00?oo00001ooo00<00?oo00001?oo00<00?ooool0Oooo00<00?ooool0S?oo0@00
0004ool00`00ool00008ool20004ool00`00ooooo`20ool00`00ooooo`2;ool1000000Goo`03003o
oooo00Soo`03003ooooo00;oo`03003ooooo083oo`03003ooooo08_oo`4000005Ooo00<00?ooool0
POoo00<00?ooool0R_oo0@00000Eool00`00ooooo`21ool00`00ooooo`2:ool1000001Goo`03003o
oooo08;oo`03003ooooo08Woo`4000005Ooo00<00?ooool0P_oo00<00?ooool0ROoo0@00000Eool2
0023ool00`00ooooo`28ool2000001Goo`03003ooooo08?oo`03003ooooo08Soo`4000005Ooo00<0
0?ooool0Pooo00<00?ooool0R?oo0@00000Eool00`00ooooo`24ool00`00ooooo`27ool1000001Go
o`03003ooooo08Coo`03003ooooo08Ooo`4000005Ooo00<00?ooool0Q?oo00<00?ooool0Qooo0@00
000Eool00`00ooooo`25ool00`00ooooo`26ool1000001Goo`03003ooooo08Goo`03003ooooo08Ko
o`4000005Ooo0P00Qooo00<00?ooool0Q?oo0P00000Eool00`00ooooo`26ool00`00ooooo`25ool1
000001Goo`03003ooooo08Koo`03003ooooo08Goo`4000005Ooo00<00?ooool0Qooo00<00?ooool0
Q?oo0@00000Eool00`00ooooo`27ool00`00ooooo`24ool1000001Goo`03003ooooo08Soo`03003o
oooo08?oo`4000005Ooo00<00?ooool0R?oo00<00?ooool0Pooo0@00000Eool00`00ooooo`29ool0
0`00ooooo`22ool1000001Goo`8008[oo`03003ooooo087oo`8000005Ooo00<00?ooool0ROoo00<0
0?ooool0P_oo0@00000Eool00`00ooooo`2:ool00`00ooooo`21ool1000001Goo`03003ooooo08[o
o`03003ooooo087oo`4000005Ooo00<00?ooool0Rooo00<00?ooool0P?oo0@00000Eool00`00oooo
o`2;ool00`00ooooo`20ool1000000Goo`03003ooooo00;oo`04003oooooool20005ool00`00oooo
o`2<ool00`00ooooo`1oool1000000Coo`03003oo`0000Ooo`03003oo`0000Coo`03003ooooo08co
o`03003ooooo07ooo`4000001?oo00<00?oo00001ooo00<00?oo00001?oo0`00S?oo00<00?ooool0
OOoo0`000004ool00`00ool00007ool20005ool00`00ooooo`2=ool00`00ooooo`1nool1000000Co
o`03003oo`0000Ooo`03003ooooo00Coo`03003ooooo08goo`03003ooooo07koo`4000001Ooo00<0
0?ooool01ooo0P001?oo00<00?ooool0S_oo00<00?ooool0OOoo0@00000Eool00`00ooooo`2>ool0
0`00ooooo`1mool1000001Goo`03003ooooo08koo`03003ooooo07goo`4000005Ooo00<00?ooool0
Sooo00<00?ooool0O?oo0@00000Eool00`00ooooo`2?ool00`00ooooo`1lool1000001Goo`80097o
o`03003ooooo07[oo`8000005Ooo00<00?ooool0T?oo00<00?ooool0Nooo0@00000Eool00`00oooo
o`2Aool00`00ooooo`1jool1000001Goo`03003ooooo097oo`03003ooooo07[oo`4000005Ooo00<0
0?ooool0TOoo00<00?ooool0N_oo0@00000Eool00`00ooooo`2Bool00`00ooooo`1iool1000001Go
o`03003ooooo09;oo`03003ooooo07Woo`4000005Ooo00<00?ooool0Tooo00<00?ooool0N?oo0@00
000Eool2002Dool00`00ooooo`1gool2000001Goo`03003ooooo09Coo`03003ooooo07Ooo`400000
5Ooo00<00?ooool0U?oo00<00?ooool0Mooo0@00000Eool00`00ooooo`2Eool00`00ooooo`1fool1
000001Goo`03003ooooo09Goo`03003ooooo07Koo`4000005Ooo00<00?ooool0U_oo00<00?ooool0
MOoo0@00000Eool00`00ooooo`2Fool00`00ooooo`1eool1000001Goo`03003ooooo09Ooo`03003o
oooo07Coo`4000005Ooo0P00V?oo00<00?ooool0Looo0P00000Eool00`00ooooo`2Hool00`00oooo
o`1cool1000001Goo`03003ooooo09Soo`03003ooooo07?oo`4000005Ooo00<00?ooool0VOoo00<0
0?ooool0L_oo0@00000Eool00`00ooooo`2Iool00`00ooooo`1bool1000001Goo`03003ooooo09[o
o`03003ooooo077oo`4000001Ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00ooo00<0
0?ooool0V_oo00<00?ooool0LOoo0@000004ool00`00ool00007ool00`00ool00004ool00`00oooo
o`2Kool00`00ooooo`1`ool1000000Coo`03003oo`0000Ooo`03003oo`0000Coo`<009_oo`03003o
oooo06koo`<000001?oo00<00?oo00002?oo00<00?ooool00ooo00<00?ooool0W?oo00<00?ooool0
Kooo0@000004ool00`00ool00007ool00`00ool00004ool00`00ooooo`2Lool00`00ooooo`1_ool1
000000Goo`03003ooooo00Ooo`03003ooooo00?oo`03003ooooo09goo`03003ooooo06koo`400000
5Ooo00<00?ooool0W_oo00<00?ooool0KOoo0@00000Eool00`00ooooo`2Nool00`00ooooo`1]ool1
000001Goo`03003ooooo09ooo`03003ooooo06coo`4000005Ooo00<00?ooool0X?oo00<00?ooool0
Jooo0@00000Eool2002Qool00`00ooooo`1Zool2000001Goo`03003ooooo0:7oo`03003ooooo06[o
o`4000005Ooo00<00?ooool0X_oo00<00?ooool0JOoo0@00000Eool00`00ooooo`2Rool00`00oooo
o`1Yool1000001Goo`03003ooooo0:?oo`03003ooooo06Soo`4000005Ooo00<00?ooool0Y?oo00<0
0?ooool0Iooo0@00000Eool00`00ooooo`2Uool00`00ooooo`1Vool1000001Goo`03003ooooo0:Go
o`03003ooooo06Koo`4000005Ooo0P00Yooo00<00?ooool0I?oo0P00000Eool00`00ooooo`2Wool0
0`00ooooo`1Tool1000001Goo`03003ooooo0:Soo`03003ooooo06?oo`4000005Ooo00<00?ooool0
ZOoo0P00Hooo0@00000Eool00`00ooooo`2[ool00`00ooooo`1Pool1000001Goo`03003ooooo0:co
o`03003ooooo05ooo`4000005Ooo00<00?ooool0[Ooo00<00?ooool0G_oo0@00000Eool00`00oooo
o`2^ool2001Nool1000001Goo`800;7oo`03003ooooo05[oo`8000005Ooo00<00?ooool0/Ooo0P00
Fooo0@00000Eool00`00ooooo`2cool3001Hool1000001Goo`03003ooooo0;Koo`<005Goo`400000
5Ooo00<00?ooool0^Ooo0P00Dooo0@00000Eool00`00ooooo`2kool2001Aool1000000goo`D000?o
o`03003ooooo0;goo`H004_oo`4000003ooo00<00?ooool00ooo00<00?ooool0`ooo2`00@?oo0@00
000?ool00`00ooooo`03ool3003>oolj0004ool3000000ooo`03003ooooo00?oo`03003ooooo0?oo
o`ooo`4000003ooo00<00?ooool00ooo00<00?ooool07Ooo00<00?ooool0<Ooo00<00?ooool0<Ooo
00<00?ooool0<Ooo00<00?ooool0<Ooo00<00?ooool07_oo0@00000>ool20005ool00`00ooooo`03
ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:
ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:
ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:
ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:
ool00`00ooooo`04ool1000001Goool001<00000\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {-6.07388, -0.102249, \
0.0384605, 0.00622304}}]
}, Open  ]],

Cell[TextData[{
  "Its derivative with respect to ",
  StyleBox["x", "MB"],
  " is indeed the standard normal distribution. "
}], "MathCaption",
  CellTags->"0.59"],

Cell[CellGroupData[{

Cell["D[Norm[x], x]", "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(E\^\(-\(x\^2\/2\)\)\/\@\(2\ \[Pi]\)\)], "Output",
  CellLabel->"Out[51]="]
}, Open  ]],

Cell["Here is the graph of the standard normal distribution. ", "MathCaption",
  CellTags->"0.60"],

Cell[CellGroupData[{

Cell["Plot[Evaluate[D[Norm[x], x]], {x, -5, 5}];", "Input",
  CellLabel->"In[52]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.0147129 1.47544 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01471 -6 -4.5 ]
[-0.0125 .01471 0 4.5 ]
[-0.0125 .16226 -18 -4.5 ]
[-0.0125 .16226 0 4.5 ]
[-0.0125 .3098 -18 -4.5 ]
[-0.0125 .3098 0 4.5 ]
[-0.0125 .45735 -18 -4.5 ]
[-0.0125 .45735 0 4.5 ]
[-0.0125 .60489 -18 -4.5 ]
[-0.0125 .60489 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01471 m
.00625 .01471 L
s
[(0)] -0.0125 .01471 1 0 Mshowa
0 .16226 m
.00625 .16226 L
s
[(0.1)] -0.0125 .16226 1 0 Mshowa
0 .3098 m
.00625 .3098 L
s
[(0.2)] -0.0125 .3098 1 0 Mshowa
0 .45735 m
.00625 .45735 L
s
[(0.3)] -0.0125 .45735 1 0 Mshowa
0 .60489 m
.00625 .60489 L
s
[(0.4)] -0.0125 .60489 1 0 Mshowa
.125 Mabswid
0 .04422 m
.00375 .04422 L
s
0 .07373 m
.00375 .07373 L
s
0 .10324 m
.00375 .10324 L
s
0 .13275 m
.00375 .13275 L
s
0 .19177 m
.00375 .19177 L
s
0 .22127 m
.00375 .22127 L
s
0 .25078 m
.00375 .25078 L
s
0 .28029 m
.00375 .28029 L
s
0 .33931 m
.00375 .33931 L
s
0 .36882 m
.00375 .36882 L
s
0 .39833 m
.00375 .39833 L
s
0 .42784 m
.00375 .42784 L
s
0 .48685 m
.00375 .48685 L
s
0 .51636 m
.00375 .51636 L
s
0 .54587 m
.00375 .54587 L
s
0 .57538 m
.00375 .57538 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01471 m
1 .01471 L
s
.99375 .16226 m
1 .16226 L
s
.99375 .3098 m
1 .3098 L
s
.99375 .45735 m
1 .45735 L
s
.99375 .60489 m
1 .60489 L
s
.125 Mabswid
.99625 .04422 m
1 .04422 L
s
.99625 .07373 m
1 .07373 L
s
.99625 .10324 m
1 .10324 L
s
.99625 .13275 m
1 .13275 L
s
.99625 .19177 m
1 .19177 L
s
.99625 .22127 m
1 .22127 L
s
.99625 .25078 m
1 .25078 L
s
.99625 .28029 m
1 .28029 L
s
.99625 .33931 m
1 .33931 L
s
.99625 .36882 m
1 .36882 L
s
.99625 .39833 m
1 .39833 L
s
.99625 .42784 m
1 .42784 L
s
.99625 .48685 m
1 .48685 L
s
.99625 .51636 m
1 .51636 L
s
.99625 .54587 m
1 .54587 L
s
.99625 .57538 m
1 .57538 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.04262 .01472 L
.04795 .01472 L
.053 .01472 L
.06244 .01473 L
.06754 .01473 L
.07295 .01474 L
.08265 .01475 L
.08804 .01476 L
.09308 .01478 L
.09862 .01479 L
.10458 .01482 L
.11468 .01488 L
.1204 .01492 L
.12571 .01497 L
.13544 .0151 L
.14087 .01519 L
.1458 .0153 L
.15583 .01557 L
.16505 .01593 L
.17517 .01647 L
.18587 .01727 L
.19535 .01824 L
.20551 .01965 L
.2151 .02142 L
.22384 .0235 L
.23376 .02654 L
.24293 .03012 L
.25299 .03509 L
.26369 .04181 L
.27306 .04913 L
.28316 .05878 L
.30144 .08169 L
.32148 .1163 L
.34258 .16487 L
.38069 .28326 L
.42125 .43288 L
.43998 .49732 L
.46029 .55433 L
.4714 .57738 L
.47627 .58535 L
.48164 .59249 L
.48408 .59516 L
.4867 .59761 L
.48896 .59939 L
.49143 .60095 L
.49287 .60168 L
Mistroke
.49421 .60224 L
.49548 .60267 L
.49614 .60284 L
.49684 .60301 L
.49754 .60313 L
.49818 .60322 L
.49944 .60332 L
.50058 .60332 L
.50179 .60323 L
.50302 .60303 L
.50371 .60288 L
.50435 .60272 L
.50676 .60185 L
.50896 .60073 L
.51129 .5992 L
.51613 .59494 L
.52147 .58856 L
.53094 .57308 L
.53981 .55408 L
.56004 .49726 L
.57855 .4336 L
.61823 .2871 L
.65639 .16757 L
.67604 .12135 L
.697 .08401 L
.70727 .06983 L
.71839 .05718 L
.728 .04823 L
.73855 .04026 L
.74816 .03446 L
.75847 .02952 L
.76935 .0255 L
.77953 .02264 L
.78968 .02048 L
.80074 .01874 L
.81118 .01754 L
.82085 .01673 L
.83046 .01614 L
.8395 .01574 L
.8494 .01542 L
.85497 .01528 L
.86009 .01518 L
.86482 .0151 L
.86988 .01503 L
.87899 .01493 L
.88456 .01488 L
.88983 .01485 L
.89452 .01482 L
.89968 .0148 L
.90939 .01477 L
Mistroke
.9147 .01476 L
.91967 .01475 L
.92856 .01474 L
.93355 .01473 L
.93811 .01473 L
.94269 .01472 L
.94756 .01472 L
.95632 .01472 L
.96169 .01472 L
.96675 .01472 L
.97128 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[52]:=",
  ImageSize->{295.562, 182.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004W0000]Q000`40n007h00Ooooo:?oo000hool3
000`ool3000_ool00`00ooooo`0`ool3000bool3000Oool003Woo`03003ooooo02ooo`03003ooooo
02koo`03003oo`00037oo`03003ooooo03?oo`03003ooooo01koo`00<_oo0`000_oo1000:ooo0`00
0ooo00<00?ooool0;Ooo00<00?oo0000<_oo00<00?ooool0<?oo10007ooo000gool00`00ool0000b
ool00`00ooooo`0]ool00`00ool0000bool00`00ooooo`0`ool00`00ool0000Pool003Soo`80037o
o`03003oo`0002koo`03003oo`00037oo`03003oo`0003;oo`80023oo`00>Ooo00<00?ooool0<?oo
00<00?ooool0;_oo00<00?ooool0<Ooo00<00?ooool0<_oo00<00?ooool07_oo003ooolXool00?oo
obSoo`00oooo:?oo003ooolXool00?ooobSoo`005Oooo`004`00000Eool00`00ooooo`04ool00`00
ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00
ooooo`0:ool00`00ooooo`0:ool00`00ooooo`09ool00`00ooooo`0:ool00`00ooooo`0:ool00`00
ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00
ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00
ooooo`04ool1000000ooo`03003ooooo00?oo`03003ooooo01koo`03003ooooo037oo`03003ooooo
033oo`03003ooooo037oo`03003ooooo037oo`03003ooooo01koo`4000003_oo00<00?oo00001?oo
00<00?ooool0oooo3ooo0@00000>ool00`00ool00004ool30004oolS002moolT0004ool3000000ko
o`03003oo`0000Coo`03003ooooo02Ooo`d00:;oo`h002[oo`4000003_oo00<00?oo00001?oo00<0
0?ooool0=?oo1@00V?oo1@00>?oo0@00000?ool00`00ooooo`03ool00`00ooooo`0iool3002Bool3
000mool1000001Goo`03003ooooo03coo`@008coo`80043oo`4000005Ooo00<00?ooool0@?oo0P00
R?oo0P00@_oo0@00000Eool00`00ooooo`12ool00`00ooooo`23ool20014ool1000001Goo`03003o
oooo04?oo`80087oo`8004Koo`4000005Ooo0P00A_oo00<00?ooool0OOoo00<00?ooool0AOoo0P00
000Eool00`00ooooo`16ool2001lool00`00ooooo`17ool1000001Goo`03003ooooo04Soo`03003o
oooo07Soo`03003ooooo04Soo`4000005Ooo00<00?ooool0BOoo00<00?ooool0M_oo00<00?ooool0
BOoo0@00000Eool00`00ooooo`1:ool00`00ooooo`1dool00`00ooooo`1:ool1000001Goo`03003o
oooo04_oo`03003ooooo07;oo`03003ooooo04_oo`4000005Ooo00<00?ooool0Booo00<00?ooool0
LOoo00<00?ooool0C?oo0@00000Eool00`00ooooo`1<ool00`00ooooo`1_ool00`00ooooo`1=ool1
000001Goo`8004koo`03003ooooo06goo`03003ooooo04goo`8000005Ooo00<00?ooool0C_oo00<0
0?ooool0Jooo00<00?ooool0Cooo0@00000Eool00`00ooooo`1>ool00`00ooooo`1[ool00`00oooo
o`1?ool1000001Goo`03003ooooo04ooo`03003ooooo06Woo`03003ooooo053oo`4000005Ooo00<0
0?ooool0D?oo00<00?ooool0Iooo00<00?ooool0DOoo0@00000Eool00`00ooooo`1@ool00`00oooo
o`1Wool00`00ooooo`1Aool1000001Goo`03003ooooo057oo`03003ooooo06Goo`03003ooooo05;o
o`4000005Ooo00<00?ooool0D_oo00<00?ooool0I?oo00<00?ooool0D_oo0@00000Eool2001Cool0
0`00ooooo`1Sool00`00ooooo`1Bool2000001Goo`03003ooooo05?oo`03003ooooo067oo`03003o
oooo05Coo`4000005Ooo00<00?ooool0E?oo00<00?ooool0H?oo00<00?ooool0E?oo0@00000Eool0
0`00ooooo`1Dool00`00ooooo`1Oool00`00ooooo`1Eool1000001Goo`03003ooooo05Goo`03003o
oooo05koo`03003ooooo05Goo`4000005Ooo00<00?ooool0EOoo00<00?ooool0GOoo00<00?ooool0
E_oo0@00000Eool00`00ooooo`1Fool00`00ooooo`1Lool00`00ooooo`1Fool1000001Goo`03003o
oooo05Koo`03003ooooo05_oo`03003ooooo05Ooo`4000005Ooo0P00F?oo00<00?ooool0F_oo00<0
0?ooool0E_oo0P00000Eool00`00ooooo`1Gool00`00ooooo`1Iool00`00ooooo`1Hool1000001Go
o`03003ooooo05Soo`03003ooooo05Soo`03003ooooo05Soo`4000005Ooo00<00?ooool0F?oo00<0
0?ooool0F?oo00<00?ooool0F?oo0@00000Eool00`00ooooo`1Iool00`00ooooo`1Fool00`00oooo
o`1Iool1000001Goo`03003ooooo05Woo`03003ooooo05Koo`03003ooooo05Woo`4000001Ooo00<0
0?ooool00_oo00<00?ooool01@000ooo00<00?ooool0F_oo00<00?ooool0EOoo00<00?ooool0FOoo
0@000004ool00`00ool00008ool00`00ooooo`03ool00`00ooooo`1Jool00`00ooooo`1Dool00`00
ooooo`1Jool1000000Coo`03003oo`0000Soo`03003ooooo00?oo`<005_oo`03003ooooo05?oo`03
003ooooo05Soo`<000001?oo00<00?oo00002?oo00<00?ooool00ooo00<00?ooool0Fooo00<00?oo
ool0D_oo00<00?ooool0Fooo0@000004ool00`00ool00008ool00`00ooooo`03ool00`00ooooo`1K
ool00`00ooooo`1Bool00`00ooooo`1Kool1000000Goo`03003ooooo00Koo`8000Goo`03003ooooo
05coo`03003ooooo057oo`03003ooooo05_oo`4000005Ooo00<00?ooool0G?oo00<00?ooool0D?oo
00<00?ooool0G?oo0@00000Eool00`00ooooo`1Lool00`00ooooo`1@ool00`00ooooo`1Lool10000
01Goo`03003ooooo05goo`03003ooooo04ooo`03003ooooo05coo`4000005Ooo00<00?ooool0GOoo
00<00?ooool0C_oo00<00?ooool0GOoo0@00000Eool2001Nool00`00ooooo`1>ool00`00ooooo`1L
ool2000001Goo`03003ooooo05koo`03003ooooo04goo`03003ooooo05goo`4000005Ooo00<00?oo
ool0G_oo00<00?ooool0C?oo00<00?ooool0G_oo0@00000Eool00`00ooooo`1Nool00`00ooooo`1<
ool00`00ooooo`1Nool1000001Goo`03003ooooo05koo`03003ooooo04coo`03003ooooo05koo`40
00005Ooo00<00?ooool0Gooo00<00?ooool0Booo00<00?ooool0G_oo0@00000Eool00`00ooooo`1O
ool00`00ooooo`1:ool00`00ooooo`1Oool1000001Goo`03003ooooo05ooo`03003ooooo04[oo`03
003ooooo05ooo`4000005Ooo00<00?ooool0H?oo00<00?ooool0BOoo00<00?ooool0Gooo0@00000E
ool2001Qool00`00ooooo`18ool00`00ooooo`1Oool2000001Goo`03003ooooo063oo`03003ooooo
04Soo`03003ooooo063oo`4000005Ooo00<00?ooool0HOoo00<00?ooool0Aooo00<00?ooool0H?oo
0@00000Eool00`00ooooo`1Qool00`00ooooo`16ool00`00ooooo`1Qool1000001Goo`03003ooooo
067oo`03003ooooo04Koo`03003ooooo067oo`4000005Ooo00<00?ooool0H_oo00<00?ooool0AOoo
00<00?ooool0HOoo0@00000Eool00`00ooooo`1Rool00`00ooooo`14ool00`00ooooo`1Rool10000
01Goo`03003ooooo06;oo`03003ooooo04Coo`03003ooooo06;oo`4000005Ooo0P00I?oo00<00?oo
ool0@ooo00<00?ooool0HOoo0P00000Eool00`00ooooo`1Sool00`00ooooo`12ool00`00ooooo`1S
ool1000001Goo`03003ooooo06?oo`03003ooooo04;oo`03003ooooo06?oo`4000005Ooo00<00?oo
ool0Hooo00<00?ooool0@_oo00<00?ooool0Hooo0@00000Eool00`00ooooo`1Tool00`00ooooo`11
ool00`00ooooo`1Sool1000001Goo`03003ooooo06Coo`03003ooooo043oo`03003ooooo06Coo`40
00005Ooo00<00?ooool0I?oo00<00?ooool0@?oo00<00?ooool0I?oo0@00000Eool00`00ooooo`1U
ool00`00ooooo`0oool00`00ooooo`1Tool1000001Goo`8006Koo`03003ooooo03koo`03003ooooo
06Coo`8000005Ooo00<00?ooool0IOoo00<00?ooool0?_oo00<00?ooool0IOoo0@00000Eool00`00
ooooo`1Vool00`00ooooo`0mool00`00ooooo`1Uool1000001Goo`03003ooooo06Koo`03003ooooo
03coo`03003ooooo06Koo`4000005Ooo00<00?ooool0I_oo00<00?ooool0??oo00<00?ooool0I_oo
0@00000Eool00`00ooooo`1Vool00`00ooooo`0lool00`00ooooo`1Vool1000000Goo`03003ooooo
00;oo`04003oooooool30004ool00`00ooooo`1Wool00`00ooooo`0kool00`00ooooo`1Vool10000
00Coo`03003oo`0000Ooo`03003ooooo00Coo`03003ooooo06Ooo`03003ooooo03[oo`03003ooooo
06Ooo`4000001?oo00<00?oo00002?oo00<00?ooool00ooo0`00Iooo00<00?ooool0>_oo00<00?oo
ool0IOoo0`000004ool00`00ool00008ool00`00ooooo`03ool00`00ooooo`1Wool00`00ooooo`0j
ool00`00ooooo`1Wool1000000Coo`03003oo`0000Ooo`03003oo`0000Coo`03003ooooo06Soo`03
003ooooo03Woo`03003ooooo06Ooo`4000001Ooo00<00?ooool01ooo00<00?ooool00ooo00<00?oo
ool0J?oo00<00?ooool0>?oo00<00?ooool0J?oo0@00000Eool00`00ooooo`1Xool00`00ooooo`0h
ool00`00ooooo`1Xool1000001Goo`03003ooooo06Soo`03003ooooo03Soo`03003ooooo06Soo`40
00005Ooo00<00?ooool0JOoo00<00?ooool0=_oo00<00?ooool0JOoo0@00000Eool00`00ooooo`1Y
ool00`00ooooo`0fool00`00ooooo`1Yool1000001Goo`8006[oo`03003ooooo03Koo`03003ooooo
06Soo`8000005Ooo00<00?ooool0J_oo00<00?ooool0=Ooo00<00?ooool0JOoo0@00000Eool00`00
ooooo`1Zool00`00ooooo`0dool00`00ooooo`1Zool1000001Goo`03003ooooo06[oo`03003ooooo
03Coo`03003ooooo06[oo`4000005Ooo00<00?ooool0J_oo00<00?ooool0=?oo00<00?ooool0J_oo
0@00000Eool00`00ooooo`1[ool00`00ooooo`0bool00`00ooooo`1[ool1000001Goo`03003ooooo
06_oo`03003ooooo03;oo`03003ooooo06_oo`4000005Ooo00<00?ooool0Jooo00<00?ooool0<_oo
00<00?ooool0Jooo0@00000Eool2001/ool00`00ooooo`0bool00`00ooooo`1Zool2000001Goo`03
003ooooo06coo`03003ooooo033oo`03003ooooo06coo`4000005Ooo00<00?ooool0K?oo00<00?oo
ool0<?oo00<00?ooool0K?oo0@00000Eool00`00ooooo`1/ool00`00ooooo`0`ool00`00ooooo`1/
ool1000001Goo`03003ooooo06goo`03003ooooo02ooo`03003ooooo06coo`4000005Ooo00<00?oo
ool0KOoo00<00?ooool0;_oo00<00?ooool0KOoo0@00000Eool00`00ooooo`1]ool00`00ooooo`0^
ool00`00ooooo`1]ool1000001Goo`03003ooooo06goo`03003ooooo02koo`03003ooooo06goo`40
00005Ooo0P00Kooo00<00?ooool0;?oo00<00?ooool0KOoo0P00000Eool00`00ooooo`1^ool00`00
ooooo`0/ool00`00ooooo`1^ool1000001Goo`03003ooooo06koo`03003ooooo02coo`03003ooooo
06koo`4000005Ooo00<00?ooool0K_oo00<00?ooool0;?oo00<00?ooool0K_oo0@00000Eool00`00
ooooo`1_ool00`00ooooo`0Zool00`00ooooo`1_ool1000001Goo`03003ooooo06ooo`03003ooooo
02[oo`03003ooooo06ooo`4000005Ooo00<00?ooool0Kooo00<00?ooool0:_oo00<00?ooool0Kooo
0@00000Eool00`00ooooo`1_ool00`00ooooo`0Zool00`00ooooo`1_ool1000001Goo`80077oo`03
003ooooo02Soo`03003ooooo06ooo`8000005Ooo00<00?ooool0L?oo00<00?ooool0:?oo00<00?oo
ool0L?oo0@00000Eool00`00ooooo`1`ool00`00ooooo`0Xool00`00ooooo`1`ool1000001Goo`03
003ooooo077oo`03003ooooo02Koo`03003ooooo077oo`4000005Ooo00<00?ooool0LOoo00<00?oo
ool09_oo00<00?ooool0LOoo0@00000Eool00`00ooooo`1aool00`00ooooo`0Vool00`00ooooo`1a
ool1000000Goo`03003ooooo00;oo`04003oooooool20005ool00`00ooooo`1aool00`00ooooo`0V
ool00`00ooooo`1aool1000000Coo`03003oo`0000Woo`03003ooooo00;oo`03003ooooo07;oo`03
003ooooo02Coo`03003ooooo07;oo`4000001?oo00<00?oo00002?oo00<00?ooool00ooo0`00L_oo
00<00?ooool09?oo00<00?ooool0L?oo0`000004ool00`00ool00009ool00`00ooooo`02ool00`00
ooooo`1bool00`00ooooo`0Tool00`00ooooo`1bool1000000Coo`03003oo`0000Ooo`03003oo`00
00Coo`03003ooooo07?oo`03003ooooo02;oo`03003ooooo07?oo`4000001Ooo00<00?ooool01ooo
00<00?ooool00ooo00<00?ooool0Looo00<00?ooool08_oo00<00?ooool0Looo0@00000Eool00`00
ooooo`1cool00`00ooooo`0Rool00`00ooooo`1cool1000001Goo`03003ooooo07?oo`03003ooooo
02;oo`03003ooooo07?oo`4000005Ooo00<00?ooool0M?oo00<00?ooool08?oo00<00?ooool0M?oo
0@00000Eool00`00ooooo`1dool00`00ooooo`0Pool00`00ooooo`1dool1000001Goo`8007Goo`03
003ooooo023oo`03003ooooo07?oo`8000005Ooo00<00?ooool0M?oo00<00?ooool08?oo00<00?oo
ool0M?oo0@00000Eool00`00ooooo`1eool00`00ooooo`0Nool00`00ooooo`1eool1000001Goo`03
003ooooo07Goo`03003ooooo01koo`03003ooooo07Goo`4000005Ooo00<00?ooool0MOoo00<00?oo
ool07_oo00<00?ooool0MOoo0@00000Eool00`00ooooo`1fool00`00ooooo`0Lool00`00ooooo`1f
ool1000001Goo`03003ooooo07Koo`03003ooooo01coo`03003ooooo07Koo`4000005Ooo00<00?oo
ool0Mooo00<00?ooool06_oo00<00?ooool0Mooo0@00000Eool2001hool00`00ooooo`0Jool00`00
ooooo`1fool2000001Goo`03003ooooo07Ooo`03003ooooo01[oo`03003ooooo07Ooo`4000005Ooo
00<00?ooool0N?oo00<00?ooool06?oo00<00?ooool0N?oo0@00000Eool00`00ooooo`1hool00`00
ooooo`0Hool00`00ooooo`1hool1000001Goo`03003ooooo07Woo`03003ooooo01Koo`03003ooooo
07Woo`4000005Ooo00<00?ooool0NOoo00<00?ooool05_oo00<00?ooool0NOoo0@00000Eool00`00
ooooo`1iool00`00ooooo`0Fool00`00ooooo`1iool1000001Goo`03003ooooo07[oo`03003ooooo
01Coo`03003ooooo07[oo`4000005Ooo0P00Nooo00<00?ooool05?oo00<00?ooool0NOoo0P00000E
ool00`00ooooo`1kool00`00ooooo`0Bool00`00ooooo`1kool1000001Goo`03003ooooo07_oo`03
003ooooo01;oo`03003ooooo07_oo`4000005Ooo00<00?ooool0Nooo00<00?ooool04_oo00<00?oo
ool0Nooo0@00000Eool00`00ooooo`1lool00`00ooooo`0@ool00`00ooooo`1lool1000001Goo`03
003ooooo07coo`03003ooooo013oo`03003ooooo07coo`4000005Ooo00<00?ooool0OOoo00<00?oo
ool03_oo00<00?ooool0OOoo0@00000Eool00`00ooooo`1mool00`00ooooo`0>ool00`00ooooo`1m
ool1000001Goo`8007ooo`03003ooooo00coo`03003ooooo07goo`8000005Ooo00<00?ooool0O_oo
00<00?ooool03?oo00<00?ooool0O_oo0@00000Eool00`00ooooo`1oool00`00ooooo`0:ool00`00
ooooo`1oool1000001Goo`03003ooooo07ooo`03003ooooo00[oo`03003ooooo07ooo`4000005Ooo
00<00?ooool0P?oo00<00?ooool02?oo00<00?ooool0P?oo0@00000Eool00`00ooooo`20ool20008
ool00`00ooooo`21ool1000000Goo`03003ooooo00;oo`03003ooooo00;oo`<000?oo`03003ooooo
08;oo`03003ooooo00?oo`8008Coo`4000001?oo00<00?oo00002Ooo00<00?ooool00_oo00<00?oo
ool0Pooo1P00QOoo0@000004ool00`00ool00007ool40003ool30025ool20025ool3000000Coo`03
003oo`0000Ooo`03003oo`0000Coo`03003ooooo0?ooo`ooo`4000001?oo00<00?oo00002?oo0P00
1?oo00<00?ooool07_oo00<00?ooool0<Ooo00<00?ooool0<?oo00<00?ooool0<Ooo00<00?ooool0
<Ooo00<00?ooool07_oo0@000005ool00`00ooooo`08ool00`00ooooo`02ool00`00ooooo`04ool0
0`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool0
0`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`09ool00`00ooooo`0:ool00`00ooooo`0:ool0
0`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool0
0`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool00`00ooooo`0:ool0
0`00ooooo`04ool1000001Goool001<00000\
\>"],
  ImageRangeCache->{{{0, 294.562}, {181.625, 0}} -> {-6.0892, -0.0408463, \
0.0385586, 0.00248892}}]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{500, 350},
WindowMargins->{{-1, Automatic}, {Automatic, 0}},
StyleDefinitions -> "ApplicationManual.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "0.1"->{
    Cell[1717, 49, 45, 1, 72, "Section",
      CellTags->"0.1"]},
  "0.2"->{
    Cell[1765, 52, 187, 6, 53, "Text",
      CellTags->"0.2"]},
  "0.3"->{
    Cell[1955, 60, 121, 5, 32, "MathCaption",
      CellTags->"0.3"]},
  "0.4"->{
    Cell[2142, 70, 79, 1, 31, "MathCaption",
      CellTags->"0.4"]},
  "0.6"->{
    Cell[4124, 141, 210, 6, 49, "MathCaption",
      CellTags->"0.6"]},
  "0.7"->{
    Cell[4566, 159, 196, 5, 70, "MathCaption",
      CellTags->"0.7"]},
  "0.8"->{
    Cell[4861, 172, 93, 1, 70, "MathCaption",
      CellTags->"0.8"]},
  "0.9"->{
    Cell[5111, 185, 95, 1, 70, "MathCaption",
      CellTags->"0.9"]},
  "0.10"->{
    Cell[5387, 198, 204, 5, 70, "MathCaption",
      CellTags->"0.10"]},
  "0.11"->{
    Cell[5825, 215, 132, 4, 70, "MathCaption",
      CellTags->"0.11"]},
  "0.13"->{
    Cell[6809, 256, 253, 9, 70, "MathCaption",
      CellTags->"0.13"]},
  "0.14"->{
    Cell[7400, 280, 78, 1, 70, "MathCaption",
      CellTags->"0.14"]},
  "0.15"->{
    Cell[7646, 293, 144, 4, 70, "MathCaption",
      CellTags->"0.15"]},
  "0.16"->{
    Cell[7983, 309, 241, 8, 70, "MathCaption",
      CellTags->"0.16"]},
  "0.17"->{
    Cell[8388, 326, 144, 4, 70, "MathCaption",
      CellTags->"0.17"]},
  "0.18"->{
    Cell[50412, 2015, 99, 1, 70, "MathCaption",
      CellTags->"0.18"]},
  "0.20"->{
    Cell[128141, 3876, 160, 5, 70, "MathCaption",
      CellTags->"0.20"]},
  "0.21"->{
    Cell[128550, 3894, 78, 1, 70, "MathCaption",
      CellTags->"0.21"]},
  "0.22"->{
    Cell[128802, 3907, 300, 10, 70, "MathCaption",
      CellTags->"0.22"]},
  "0.23"->{
    Cell[129266, 3926, 144, 4, 70, "MathCaption",
      CellTags->"0.23"]},
  "0.24"->{
    Cell[170196, 5515, 99, 1, 70, "MathCaption",
      CellTags->"0.24"]},
  "0.25"->{
    Cell[234307, 6949, 160, 5, 70, "MathCaption",
      CellTags->"0.25"]},
  "0.26"->{
    Cell[234807, 6968, 78, 1, 70, "MathCaption",
      CellTags->"0.26"]},
  "0.27"->{
    Cell[235058, 6981, 300, 10, 70, "MathCaption",
      CellTags->"0.27"]},
  "0.28"->{
    Cell[235522, 7000, 144, 4, 70, "MathCaption",
      CellTags->"0.28"]},
  "0.29"->{
    Cell[275069, 8687, 99, 1, 70, "MathCaption",
      CellTags->"0.29"]},
  "0.30"->{
    Cell[369103, 10472, 160, 5, 70, "MathCaption",
      CellTags->"0.30"]},
  "0.31"->{
    Cell[369513, 10490, 78, 1, 70, "MathCaption",
      CellTags->"0.31"]},
  "0.32"->{
    Cell[369761, 10503, 300, 10, 70, "MathCaption",
      CellTags->"0.32"]},
  "0.33"->{
    Cell[370225, 10522, 144, 4, 70, "MathCaption",
      CellTags->"0.33"]},
  "0.34"->{
    Cell[414194, 12153, 99, 1, 70, "MathCaption",
      CellTags->"0.34"]},
  "0.35"->{
    Cell[501311, 13860, 158, 5, 70, "MathCaption",
      CellTags->"0.35"]},
  "0.36"->{
    Cell[501750, 13879, 78, 1, 70, "MathCaption",
      CellTags->"0.36"]},
  "0.37"->{
    Cell[502001, 13892, 298, 10, 70, "MathCaption",
      CellTags->"0.37"]},
  "0.38"->{
    Cell[502459, 13911, 142, 4, 70, "MathCaption",
      CellTags->"0.38"]},
  "0.39"->{
    Cell[542171, 15490, 99, 1, 70, "MathCaption",
      CellTags->"0.39"]},
  "0.40"->{
    Cell[601730, 16836, 224, 5, 70, "MathCaption",
      CellTags->"0.40"]},
  "0.41"->{
    Cell[602202, 16854, 78, 1, 70, "MathCaption",
      CellTags->"0.41"]},
  "0.42"->{
    Cell[602448, 16867, 301, 10, 70, "MathCaption",
      CellTags->"0.42"]},
  "0.43"->{
    Cell[602916, 16886, 145, 4, 70, "MathCaption",
      CellTags->"0.43"]},
  "0.44"->{
    Cell[641660, 18467, 99, 1, 70, "MathCaption",
      CellTags->"0.44"]},
  "0.45"->{
    Cell[715545, 20010, 165, 5, 70, "MathCaption",
      CellTags->"0.45"]},
  "0.46"->{
    Cell[716078, 20027, 78, 1, 70, "MathCaption",
      CellTags->"0.46"]},
  "0.47"->{
    Cell[716329, 20040, 305, 10, 70, "MathCaption",
      CellTags->"0.47"]},
  "0.48"->{
    Cell[716808, 20059, 149, 4, 70, "MathCaption",
      CellTags->"0.48"]},
  "0.49"->{
    Cell[742289, 20960, 99, 1, 70, "MathCaption",
      CellTags->"0.49"]},
  "0.51"->{
    Cell[821271, 22630, 83, 1, 70, "MathCaption",
      CellTags->"0.51"]},
  "0.53"->{
    Cell[824345, 22738, 304, 7, 70, "Text",
      CellTags->"0.53"]},
  "0.54"->{
    Cell[824652, 22747, 248, 9, 70, "MathCaption",
      CellTags->"0.54"]},
  "0.55"->{
    Cell[825078, 22766, 78, 1, 70, "MathCaption",
      CellTags->"0.55"]},
  "0.56"->{
    Cell[857771, 23749, 193, 5, 70, "MathCaption",
      CellTags->"0.56"]},
  "0.57"->{
    Cell[858163, 23766, 232, 5, 70, "MathCaption",
      CellTags->"0.57"]},
  "0.58"->{
    Cell[858572, 23783, 246, 5, 70, "MathCaption",
      CellTags->"0.58"]},
  "0.59"->{
    Cell[874281, 24369, 164, 5, 70, "MathCaption",
      CellTags->"0.59"]},
  "0.60"->{
    Cell[874637, 24386, 98, 1, 70, "MathCaption",
      CellTags->"0.60"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"0.1", 893574, 25030},
  {"0.2", 893651, 25033},
  {"0.3", 893726, 25036},
  {"0.4", 893808, 25039},
  {"0.6", 893889, 25042},
  {"0.7", 893972, 25045},
  {"0.8", 894055, 25048},
  {"0.9", 894137, 25051},
  {"0.10", 894220, 25054},
  {"0.11", 894305, 25057},
  {"0.13", 894390, 25060},
  {"0.14", 894475, 25063},
  {"0.15", 894559, 25066},
  {"0.16", 894644, 25069},
  {"0.17", 894729, 25072},
  {"0.18", 894814, 25075},
  {"0.20", 894900, 25078},
  {"0.21", 894988, 25081},
  {"0.22", 895075, 25084},
  {"0.23", 895164, 25087},
  {"0.24", 895252, 25090},
  {"0.25", 895339, 25093},
  {"0.26", 895427, 25096},
  {"0.27", 895514, 25099},
  {"0.28", 895603, 25102},
  {"0.29", 895691, 25105},
  {"0.30", 895778, 25108},
  {"0.31", 895867, 25111},
  {"0.32", 895955, 25114},
  {"0.33", 896045, 25117},
  {"0.34", 896134, 25120},
  {"0.35", 896222, 25123},
  {"0.36", 896311, 25126},
  {"0.37", 896399, 25129},
  {"0.38", 896489, 25132},
  {"0.39", 896578, 25135},
  {"0.40", 896666, 25138},
  {"0.41", 896755, 25141},
  {"0.42", 896843, 25144},
  {"0.43", 896933, 25147},
  {"0.44", 897022, 25150},
  {"0.45", 897110, 25153},
  {"0.46", 897199, 25156},
  {"0.47", 897287, 25159},
  {"0.48", 897377, 25162},
  {"0.49", 897466, 25165},
  {"0.51", 897554, 25168},
  {"0.53", 897642, 25171},
  {"0.54", 897724, 25174},
  {"0.55", 897813, 25177},
  {"0.56", 897901, 25180},
  {"0.57", 897990, 25183},
  {"0.58", 898079, 25186},
  {"0.59", 898168, 25189},
  {"0.60", 898257, 25192}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 45, 1, 72, "Section",
  CellTags->"0.1"],
Cell[1765, 52, 187, 6, 53, "Text",
  CellTags->"0.2"],
Cell[1955, 60, 121, 5, 32, "MathCaption",
  CellTags->"0.3"],
Cell[2079, 67, 60, 1, 30, "Input"],
Cell[2142, 70, 79, 1, 31, "MathCaption",
  CellTags->"0.4"],

Cell[CellGroupData[{
Cell[2246, 75, 59, 1, 30, "Input"],
Cell[2308, 78, 166, 7, 93, "Print"]
}, Open  ]],
Cell[2489, 88, 1322, 38, 41, InheritFromParent],
Cell[3814, 128, 267, 9, 26, InheritFromParent],
Cell[4084, 139, 37, 0, 16, "Caption"],
Cell[4124, 141, 210, 6, 49, "MathCaption",
  CellTags->"0.6"],

Cell[CellGroupData[{
Cell[4359, 151, 91, 1, 30, "Input"],
Cell[4453, 154, 98, 2, 70, "Output"]
}, Open  ]],
Cell[4566, 159, 196, 5, 70, "MathCaption",
  CellTags->"0.7"],
Cell[4765, 166, 93, 4, 70, "Input"],
Cell[4861, 172, 93, 1, 70, "MathCaption",
  CellTags->"0.8"],

Cell[CellGroupData[{
Cell[4979, 177, 51, 1, 70, "Input"],
Cell[5033, 180, 63, 2, 70, "Output"]
}, Open  ]],
Cell[5111, 185, 95, 1, 70, "MathCaption",
  CellTags->"0.9"],

Cell[CellGroupData[{
Cell[5231, 190, 67, 1, 70, "Input"],
Cell[5301, 193, 71, 2, 70, "Output"]
}, Open  ]],
Cell[5387, 198, 204, 5, 70, "MathCaption",
  CellTags->"0.10"],

Cell[CellGroupData[{
Cell[5616, 207, 92, 1, 70, "Input"],
Cell[5711, 210, 99, 2, 70, "Output"]
}, Open  ]],
Cell[5825, 215, 132, 4, 70, "MathCaption",
  CellTags->"0.11"],

Cell[CellGroupData[{
Cell[5982, 223, 63, 1, 70, "Input"],
Cell[6048, 226, 63, 2, 70, "Output"]
}, Open  ]],
Cell[6126, 231, 366, 12, 70, InheritFromParent],
Cell[6495, 245, 271, 7, 70, InheritFromParent],
Cell[6769, 254, 37, 0, 70, "Caption"],
Cell[6809, 256, 253, 9, 70, "MathCaption",
  CellTags->"0.13"],

Cell[CellGroupData[{
Cell[7087, 269, 75, 1, 70, "Input"],
Cell[7165, 272, 220, 5, 70, "Output"]
}, Open  ]],
Cell[7400, 280, 78, 1, 70, "MathCaption",
  CellTags->"0.14"],

Cell[CellGroupData[{
Cell[7503, 285, 46, 1, 70, "Input"],
Cell[7552, 288, 79, 2, 70, "Output"]
}, Open  ]],
Cell[7646, 293, 144, 4, 70, "MathCaption",
  CellTags->"0.15"],

Cell[CellGroupData[{
Cell[7815, 301, 71, 1, 70, "Input"],
Cell[7889, 304, 79, 2, 70, "Output"]
}, Open  ]],
Cell[7983, 309, 241, 8, 70, "MathCaption",
  CellTags->"0.16"],
Cell[8227, 319, 158, 5, 70, "Input"],
Cell[8388, 326, 144, 4, 70, "MathCaption",
  CellTags->"0.17"],

Cell[CellGroupData[{
Cell[8557, 334, 242, 7, 70, "Input"],
Cell[8802, 343, 41595, 1669, 70, 21141, 1411, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[50412, 2015, 99, 1, 70, "MathCaption",
  CellTags->"0.18"],

Cell[CellGroupData[{
Cell[50536, 2020, 170, 5, 70, "Input"],
Cell[50709, 2027, 62763, 1396, 70, 24797, 922, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[113487, 3426, 422, 14, 70, InheritFromParent],
Cell[113912, 3442, 2398, 69, 70, InheritFromParent],
Cell[116313, 3513, 425, 14, 70, InheritFromParent],
Cell[116741, 3529, 2390, 68, 70, InheritFromParent],
Cell[119134, 3599, 425, 14, 70, InheritFromParent],
Cell[119562, 3615, 2463, 70, 70, InheritFromParent],
Cell[122028, 3687, 423, 14, 70, InheritFromParent],
Cell[122454, 3703, 2099, 58, 70, InheritFromParent],
Cell[124556, 3763, 370, 12, 70, InheritFromParent],
Cell[124929, 3777, 2469, 70, 70, InheritFromParent],
Cell[127401, 3849, 430, 14, 70, InheritFromParent],
Cell[127834, 3865, 250, 7, 70, InheritFromParent],
Cell[128087, 3874, 51, 0, 70, "Caption"],
Cell[128141, 3876, 160, 5, 70, "MathCaption",
  CellTags->"0.20"],

Cell[CellGroupData[{
Cell[128326, 3885, 69, 1, 70, "Input"],
Cell[128398, 3888, 137, 3, 70, "Output"]
}, Open  ]],
Cell[128550, 3894, 78, 1, 70, "MathCaption",
  CellTags->"0.21"],

Cell[CellGroupData[{
Cell[128653, 3899, 46, 1, 70, "Input"],
Cell[128702, 3902, 85, 2, 70, "Output"]
}, Open  ]],
Cell[128802, 3907, 300, 10, 70, "MathCaption",
  CellTags->"0.22"],
Cell[129105, 3919, 158, 5, 70, "Input"],
Cell[129266, 3926, 144, 4, 70, "MathCaption",
  CellTags->"0.23"],

Cell[CellGroupData[{
Cell[129435, 3934, 242, 7, 70, "Input"],
Cell[129680, 3943, 40501, 1569, 70, 20175, 1313, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[170196, 5515, 99, 1, 70, "MathCaption",
  CellTags->"0.24"],

Cell[CellGroupData[{
Cell[170320, 5520, 169, 5, 70, "Input"],
Cell[170492, 5527, 63800, 1419, 70, 24959, 934, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[234307, 6949, 160, 5, 70, "MathCaption",
  CellTags->"0.25"],

Cell[CellGroupData[{
Cell[234492, 6958, 69, 1, 70, "Input"],
Cell[234564, 6961, 228, 4, 70, "Output"]
}, Open  ]],
Cell[234807, 6968, 78, 1, 70, "MathCaption",
  CellTags->"0.26"],

Cell[CellGroupData[{
Cell[234910, 6973, 46, 1, 70, "Input"],
Cell[234959, 6976, 84, 2, 70, "Output"]
}, Open  ]],
Cell[235058, 6981, 300, 10, 70, "MathCaption",
  CellTags->"0.27"],
Cell[235361, 6993, 158, 5, 70, "Input"],
Cell[235522, 7000, 144, 4, 70, "MathCaption",
  CellTags->"0.28"],

Cell[CellGroupData[{
Cell[235691, 7008, 242, 7, 70, "Input"],
Cell[235936, 7017, 39118, 1667, 70, 21893, 1449, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[275069, 8687, 99, 1, 70, "MathCaption",
  CellTags->"0.29"],

Cell[CellGroupData[{
Cell[275193, 8692, 168, 5, 70, "Input"],
Cell[275364, 8699, 93724, 1770, 70, 24702, 913, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[369103, 10472, 160, 5, 70, "MathCaption",
  CellTags->"0.30"],

Cell[CellGroupData[{
Cell[369288, 10481, 69, 1, 70, "Input"],
Cell[369360, 10484, 138, 3, 70, "Output"]
}, Open  ]],
Cell[369513, 10490, 78, 1, 70, "MathCaption",
  CellTags->"0.31"],

Cell[CellGroupData[{
Cell[369616, 10495, 46, 1, 70, "Input"],
Cell[369665, 10498, 81, 2, 70, "Output"]
}, Open  ]],
Cell[369761, 10503, 300, 10, 70, "MathCaption",
  CellTags->"0.32"],
Cell[370064, 10515, 158, 5, 70, "Input"],
Cell[370225, 10522, 144, 4, 70, "MathCaption",
  CellTags->"0.33"],

Cell[CellGroupData[{
Cell[370394, 10530, 242, 7, 70, "Input"],
Cell[370639, 10539, 43540, 1611, 70, 20264, 1319, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[414194, 12153, 99, 1, 70, "MathCaption",
  CellTags->"0.34"],

Cell[CellGroupData[{
Cell[414318, 12158, 163, 4, 70, "Input"],
Cell[414484, 12164, 86812, 1693, 70, 24808, 922, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[501311, 13860, 158, 5, 70, "MathCaption",
  CellTags->"0.35"],

Cell[CellGroupData[{
Cell[501494, 13869, 67, 1, 70, "Input"],
Cell[501564, 13872, 171, 4, 70, "Output"]
}, Open  ]],
Cell[501750, 13879, 78, 1, 70, "MathCaption",
  CellTags->"0.36"],

Cell[CellGroupData[{
Cell[501853, 13884, 46, 1, 70, "Input"],
Cell[501902, 13887, 84, 2, 70, "Output"]
}, Open  ]],
Cell[502001, 13892, 298, 10, 70, "MathCaption",
  CellTags->"0.37"],
Cell[502302, 13904, 154, 5, 70, "Input"],
Cell[502459, 13911, 142, 4, 70, "MathCaption",
  CellTags->"0.38"],

Cell[CellGroupData[{
Cell[502626, 13919, 238, 7, 70, "Input"],
Cell[502867, 13928, 39289, 1559, 70, 20217, 1318, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[542171, 15490, 99, 1, 70, "MathCaption",
  CellTags->"0.39"],

Cell[CellGroupData[{
Cell[542295, 15495, 162, 4, 70, "Input"],
Cell[542460, 15501, 59255, 1332, 70, 24490, 898, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[601730, 16836, 224, 5, 70, "MathCaption",
  CellTags->"0.40"],

Cell[CellGroupData[{
Cell[601979, 16845, 70, 1, 70, "Input"],
Cell[602052, 16848, 135, 3, 70, "Output"]
}, Open  ]],
Cell[602202, 16854, 78, 1, 70, "MathCaption",
  CellTags->"0.41"],

Cell[CellGroupData[{
Cell[602305, 16859, 46, 1, 70, "Input"],
Cell[602354, 16862, 79, 2, 70, "Output"]
}, Open  ]],
Cell[602448, 16867, 301, 10, 70, "MathCaption",
  CellTags->"0.42"],
Cell[602752, 16879, 161, 5, 70, "Input"],
Cell[602916, 16886, 145, 4, 70, "MathCaption",
  CellTags->"0.43"],

Cell[CellGroupData[{
Cell[603086, 16894, 244, 7, 70, "Input"],
Cell[603333, 16903, 38312, 1561, 70, 20589, 1337, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[641660, 18467, 99, 1, 70, "MathCaption",
  CellTags->"0.44"],

Cell[CellGroupData[{
Cell[641784, 18472, 171, 5, 70, "Input"],
Cell[641958, 18479, 73572, 1528, 70, 24876, 922, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[715545, 20010, 165, 5, 70, "MathCaption",
  CellTags->"0.45"],
Cell[715713, 20017, 74, 1, 70, "Input"],
Cell[715790, 20020, 285, 5, 70, "Output"],
Cell[716078, 20027, 78, 1, 70, "MathCaption",
  CellTags->"0.46"],

Cell[CellGroupData[{
Cell[716181, 20032, 46, 1, 70, "Input"],
Cell[716230, 20035, 84, 2, 70, "Output"]
}, Open  ]],
Cell[716329, 20040, 305, 10, 70, "MathCaption",
  CellTags->"0.47"],
Cell[716637, 20052, 168, 5, 70, "Input"],
Cell[716808, 20059, 149, 4, 70, "MathCaption",
  CellTags->"0.48"],

Cell[CellGroupData[{
Cell[716982, 20067, 255, 7, 70, "Input"],
Cell[717240, 20076, 25034, 881, 70, 10515, 697, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[742289, 20960, 99, 1, 70, "MathCaption",
  CellTags->"0.49"],

Cell[CellGroupData[{
Cell[742413, 20965, 185, 5, 70, "Input"],
Cell[742601, 20972, 74978, 1540, 70, 24868, 916, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[817594, 22515, 443, 14, 70, InheritFromParent],
Cell[818040, 22531, 3177, 95, 70, InheritFromParent],
Cell[821220, 22628, 48, 0, 70, "Caption"],
Cell[821271, 22630, 83, 1, 70, "MathCaption",
  CellTags->"0.51"],

Cell[CellGroupData[{
Cell[821379, 22635, 87, 1, 70, "Input"],
Cell[821469, 22638, 128, 4, 70, "Output"]
}, Open  ]],
Cell[821612, 22645, 405, 14, 70, InheritFromParent],
Cell[822020, 22661, 1819, 55, 70, InheritFromParent],
Cell[823842, 22718, 457, 16, 70, InheritFromParent],
Cell[824302, 22736, 40, 0, 70, "Caption"],
Cell[824345, 22738, 304, 7, 70, "Text",
  CellTags->"0.53"],
Cell[824652, 22747, 248, 9, 70, "MathCaption",
  CellTags->"0.54"],
Cell[824903, 22758, 172, 6, 70, "Input"],
Cell[825078, 22766, 78, 1, 70, "MathCaption",
  CellTags->"0.55"],

Cell[CellGroupData[{
Cell[825181, 22771, 84, 1, 70, "Input"],
Cell[825268, 22774, 32488, 972, 70, 8909, 676, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[857771, 23749, 193, 5, 70, "MathCaption",
  CellTags->"0.56"],

Cell[CellGroupData[{
Cell[857989, 23758, 75, 1, 70, "Input"],
Cell[858067, 23761, 81, 2, 70, "Output"]
}, Open  ]],
Cell[858163, 23766, 232, 5, 70, "MathCaption",
  CellTags->"0.57"],

Cell[CellGroupData[{
Cell[858420, 23775, 54, 1, 70, "Input"],
Cell[858477, 23778, 80, 2, 70, "Output"]
}, Open  ]],
Cell[858572, 23783, 246, 5, 70, "MathCaption",
  CellTags->"0.58"],

Cell[CellGroupData[{
Cell[858843, 23792, 68, 1, 70, "Input"],
Cell[858914, 23795, 15352, 571, 70, 5797, 448, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[874281, 24369, 164, 5, 70, "MathCaption",
  CellTags->"0.59"],

Cell[CellGroupData[{
Cell[874470, 24378, 55, 1, 70, "Input"],
Cell[874528, 24381, 94, 2, 70, "Output"]
}, Open  ]],
Cell[874637, 24386, 98, 1, 70, "MathCaption",
  CellTags->"0.60"],

Cell[CellGroupData[{
Cell[874760, 24391, 84, 1, 70, "Input"],
Cell[874847, 24394, 17992, 613, 70, 5930, 459, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

